import * as i0 from "@angular/core";
/**
 * Service for creating and manipulating branding versions.
 */
export declare class BrandingVersionService {
    static readonly nameAndIterationSeparator = "-";
    /**
     * Creates the initial branding version for a given name.
     * @param name The name of the branding.
     * @returns The initial branding version.
     */
    createInitialBrandingVersion<T extends string>(name: T): `${T}-1`;
    /**
     * Splits a branding version into its name and iteration.
     * @param version The branding version to split.
     * @returns The name and iteration of the branding version.
     *
     * Errors are thrown if the version is not in the expected format.
     */
    splitBrandingIntoNameAndIteration(version: string): {
        name: string;
        iteration: number;
    };
    /**
     * Bumps the iteration of a branding version.
     * @param version The branding version to bump.
     * @returns The bumped branding version.
     *
     * Errors are thrown if the version is not in the expected format.
     */
    bumpBrandingIteration(version: string): `${string}-${number}`;
    static ɵfac: i0.ɵɵFactoryDeclaration<BrandingVersionService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<BrandingVersionService>;
}
//# sourceMappingURL=branding-version.service.d.ts.map