import { EnvironmentInjector, TemplateRef, Type, Injector } from '@angular/core';
import { ActionBarItemWithComponent } from './action-bar.model';
import { ActionBarService } from './action-bar.service';
import * as i0 from "@angular/core";
/**
 * A <c8y-action-bar-item> can be added with content projection.
 * It allows to show items in three positions (left, right
 * or more).
 *
 * ```html
 * <c8y-action-bar-item [placement]="'right'">
 *   <button class="btn btn-link" (click)="addRandom()"><i c8yIcon="plus-circle"></i> Add random</button>
 * </c8y-action-bar-item>
 * ```
 */
export declare class ActionBarItemComponent implements ActionBarItemWithComponent {
    private actionBarService;
    /**
     * Where the item should be shown. Use "more" to place
     * it in a dropdown on the right.
     */
    placement: 'left' | 'right' | 'more';
    /**
     * Priority for sorting the list. Higher priority means
     * an earlier position in the list.
     */
    priority: number;
    /**
     * Adds additional classes to the item.
     */
    itemClass: string;
    /**
     * Allows to define a different injector.
     */
    injector: Injector;
    /**
     * If a group id is set, the action bar with the same group id is only rendered once.
     */
    groupId: any;
    /**
     * If action bar items has the same groupId, only one is displayed.
     * Action bar item with the same groupId that has highest inGroupPriority is displayed.
     */
    inGroupPriority: any;
    /**
     * @ignore
     */
    component: Type<any> | TemplateRef<any>;
    private viewInitTimeout;
    /**
     * @ignore
     */
    constructor(actionBarService: ActionBarService, _injector: EnvironmentInjector);
    /**
     * @ignore
     */
    ngAfterViewInit(): void;
    /**
     * @ignore
     */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ActionBarItemComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ActionBarItemComponent, "c8y-action-bar-item", never, { "placement": { "alias": "placement"; "required": false; }; "priority": { "alias": "priority"; "required": false; }; "itemClass": { "alias": "itemClass"; "required": false; }; "injector": { "alias": "injector"; "required": false; }; "groupId": { "alias": "groupId"; "required": false; }; "inGroupPriority": { "alias": "inGroupPriority"; "required": false; }; }, {}, never, ["*"], true, never>;
}
//# sourceMappingURL=action-bar-item.component.d.ts.map