import { OnDestroy, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { GainsightService } from '../product-experience/gainsight.service';
import { ActionBarItem } from './action-bar.model';
import * as i0 from "@angular/core";
/**
 * This component is used as the outlet to show the action bars.
 * In a c8ycli app it is by default placed on the bootstrap component.
 */
export declare class ActionBarComponent implements OnInit, OnDestroy {
    private gainsightService;
    /**
     * Identifies if the navigator is opened. If yes, the action-bar
     * needs to move to the right.
     */
    navigatorOpen: boolean;
    /**
     * Identifies if the current view has tabs. If yes, the action bar needs
     * to move down.
     */
    hasTabs: boolean;
    /**
     * Identifies if the current view has a header element.
     */
    hasHeader: boolean;
    /**
     * Identifies if the tabs are aligned horizontally. If yes, the tabs don't
     * need to move to the left.
     */
    isTabsHorizontal: boolean;
    /**
     * Identifies if in a mobile view the toolbar is expanded or not.
     */
    isPageToolbarExpanded: boolean;
    /**
     * Adds the default `c8y-ui-action-bar` class.
     */
    uiActionBar: boolean;
    /**
     * The current items to display in the ActionBar.
     */
    items$: Observable<ActionBarItem[]>;
    /**
     * Provides observable for right action items.
     */
    right$: Observable<ActionBarItem[]>;
    /**
     * Provides observable for left action items.
     */
    left$: Observable<ActionBarItem[]>;
    /**
     * Provides observable for more action items.
     */
    more$: Observable<ActionBarItem[]>;
    /**
     * Returns true if no items are present and hides the action bar.
     */
    hidden$: Observable<boolean>;
    /**
     * Binds hidden property to this component's native element
     */
    hidden: boolean;
    private destroy$;
    constructor(gainsightService: GainsightService);
    mouseDown(event: HTMLElement): void;
    ngOnInit(): void;
    ngOnDestroy(): void;
    private byPriority;
    static ɵfac: i0.ɵɵFactoryDeclaration<ActionBarComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ActionBarComponent, "c8y-action-bar", never, { "navigatorOpen": { "alias": "navigatorOpen"; "required": false; }; "hasTabs": { "alias": "hasTabs"; "required": false; }; "hasHeader": { "alias": "hasHeader"; "required": false; }; "isTabsHorizontal": { "alias": "isTabsHorizontal"; "required": false; }; "items$": { "alias": "items$"; "required": false; }; }, {}, never, never, false, never>;
}
//# sourceMappingURL=action-bar.component.d.ts.map