import { DocsService } from '../docs/docs.service';
import { HelpService } from './help.service';
import * as i0 from "@angular/core";
/**
 * A component which shows a context help in
 * the action bar.
 *
 * ```html
 * <c8y-help src="/docs/cockpit/working-with-dashboards/#working-with-dashboards"></c8y-help>
 * ```
 */
export declare class HelpComponent {
    private docsService;
    helpService: HelpService;
    /**
     * The source of the documentation. Used to link to the documentation as well as
     * to parse the source to display.
     */
    src: string;
    /**
     * Indicates if the help dialog is collapsed.
     */
    isCollapsed: boolean;
    /**
     * The priority where the help icon should be shown in the action bar. "-Infinity" value means that priority
     * of this item is the lowest possible, so it will be placed at the right edge of action bar.
     */
    priority: number;
    /**
     * A custom icon. If not set, the navigator icon is resolved
     */
    icon: any;
    /**
     * A title. Set in open by passing the source.
     */
    title: string;
    /**
     * The section heading in the doc which is going to be displayed.
     */
    sectionHeading: string;
    /**
     * The section content in the doc which is going to be displayed.
     */
    sectionContent: string;
    /**
     * Indicates if the component is loading.
     */
    isLoading: boolean;
    /**
     * Indicates if the component failed loading the source.
     */
    hasError: boolean;
    /**
     * Indicates if a warning should be shown.
     */
    showLangWarning: boolean;
    /**
     * @ignore
     */
    isInit: boolean;
    /**
     * @ignore Only private DI
     */
    constructor(docsService: DocsService, helpService: HelpService);
    /**
     * The component is shown by default and therefore breaks e2e test. This is
     * to prevent the visibility on first navigation.
     * @ignore
     */
    onCollapsed(): void;
    /**
     * Builds the URL based on the src. The Base URL can be set in the application options docBaseUrl.
     * @param src The source of the help on the guide.
     * @param index This flag is used to call the index.json content of a guide. For example, "https://cumulocity.com/docs/cockpit/data-explorer/index.json".
     */
    getUrl(src?: string, index?: boolean): string;
    /**
     * Toggles the visibility of the help dialog.
     */
    toggle(): void;
    /**
     * Closes the help dialog.
     */
    close(): void;
    /**
     * Opens the help dialog.
     */
    open(): void;
    private requestContent;
    private clean;
    private resolveIcon;
    private render;
    static ɵfac: i0.ɵɵFactoryDeclaration<HelpComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<HelpComponent, "c8y-help", never, { "src": { "alias": "src"; "required": false; }; "isCollapsed": { "alias": "isCollapsed"; "required": false; }; "priority": { "alias": "priority"; "required": false; }; "icon": { "alias": "icon"; "required": false; }; }, {}, never, never, false, never>;
}
//# sourceMappingURL=help.component.d.ts.map