import { EventEmitter } from '@angular/core';
import { GainsightService } from '../product-experience/gainsight.service';
import { ProductExperienceEvent, ProductExperienceEventSource } from '../product-experience/product-experience.model';
import { SupportedIconsSuggestions } from '@c8y/ngx-components/icon-selector/icons';
import * as i0 from "@angular/core";
/**
 * Actions are functions that can be executed on the
 * current list item. They are displayed next to the
 * item and can be grouped in a dropdown.
 *
 * ```html
 * <c8y-li>
 *   <c8y-li-action (click)="deleteDevice(device.id)" icon="times">
 *     Delete
 *   </c8y-li-action>
 *   <c8y-li-action (click)="(false)" icon="rocket">
 *     Launch to space
 *   </c8y-li-action>
 * </c8y-li>
 * ```
 */
export declare class ListItemActionComponent implements ProductExperienceEventSource {
    private gainsightService;
    /**
     * @ignore
     */
    template: any;
    /**
     * The label to display (you can alternatively use
     * content projection to display the label).
     */
    label: string;
    /**
     * The name of the icon to use.
     */
    icon: SupportedIconsSuggestions;
    /**
     * Defines if the action is disabled or not.
     */
    disabled: boolean;
    /**
     * An EventEmitter to determine what to do if the
     * action is triggered.
     */
    click: EventEmitter<void>;
    /**
     * The product experience event to be triggered
     * when the action is clicked.
     */
    productExperienceEvent: ProductExperienceEvent;
    constructor(gainsightService: GainsightService);
    /**
     * @ignore
     */
    onClick(event: HTMLElement): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ListItemActionComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ListItemActionComponent, "c8y-list-item-action, c8y-li-action", never, { "label": { "alias": "label"; "required": false; }; "icon": { "alias": "icon"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; }, { "click": "click"; }, never, ["*"], false, never>;
}
//# sourceMappingURL=list-item-action.component.d.ts.map