import { NavigatorNode } from './navigator-node';
import { ExtensionFactory } from '../common/extension-hooks';
/**
 * Factory enabling extension of the navigator menu through the **HOOK_NAVIGATOR_NODES** hook.
 * Refer to [Libraries > Component library > Extension points](https://cumulocity.com/guides/web/libraries/#extension-points) in our Web SDK guide.
 *
 * ```typescript
 * export class ExampleNavigatorFactory implements NavigatorNodeFactory {
 *   get() {
 *     const navs: NavigatorNode[] = [];
 *     navs.push(
 *       new NavigatorNode({
 *         label: 'Hello',
 *         icon: 'rocket',
 *         path: '/hello',
 *         priority: 100
 *       })
 *     );
 *     return navs;
 *   }
 * }
 * ```
 */
export type NavigatorNodeFactory = ExtensionFactory<NavigatorNode>;
//# sourceMappingURL=navigator-node-factory.interface.d.ts.map