import { Injector } from '@angular/core';
import { ExtensionFactory } from '../common/extension-hooks';
import { SupportedIconsSuggestions } from '@c8y/ngx-components/icon-selector/icons';
/**
 * The search is an icon that appears on the upper right corner
 * and opens a template or a search bar on click on it.
 * @deprecated Please don't use the search factory. It will be refactored soon.
 */
export interface Search {
    /**
     * The name of the search
     * @deprecated Needed for upgrade only.
     */
    name?: string;
    /**
     * The icon for the search. Defaults to the search icon. (optional)
     */
    icon?: SupportedIconsSuggestions;
    /**
     * Ordering of the actions (high number first) (optional)
     */
    priority?: number;
    /**
     * Angular template used for Content Projection (optional)
     */
    template?: any;
    /**
     * The default search term. Defaults to an empty string (optional=)
     */
    term?: string;
    /**
     * Used to load the providers for the components. If not provided, default injector us used.
     */
    injector?: Injector;
    /**
     * A function triggers if the user performance a search.
     * @param term The term used by the user.
     */
    onSearch(term: any): any;
}
/**
 * Factory to implement if used in a hook for Multi Provider extension.
 */
export type SearchFactory = ExtensionFactory<Search>;
//# sourceMappingURL=search.model.d.ts.map