import * as i0 from '@angular/core';
import { Injectable, Component, Input, ViewChild } from '@angular/core';
import * as i1$2 from '@c8y/ngx-components/branding/shared/data';
import { createGenericBrandingForm, brandingFormGroupTopLevelEntries, brandingFormGroupTopLevelEntriesToUnpack, createBrandingForm } from '@c8y/ngx-components/branding/shared/data';
import { merge, of, firstValueFrom, BehaviorSubject, defer, interval } from 'rxjs';
import { map, startWith, switchMap, shareReplay, distinctUntilChanged, filter, take, pairwise, delay } from 'rxjs/operators';
import * as i2$1 from '@angular/router';
import { RouterLink, RouterOutlet } from '@angular/router';
import * as i3 from '@c8y/ngx-components';
import { CoreModule, HumanizeAppNamePipe, ModalComponent, C8yTranslatePipe, BuiltInActionType, gettext as gettext$1, Status, DataGridModule, GENERIC_FILE_TYPE, ColorInputComponent } from '@c8y/ngx-components';
import * as i1 from '@c8y/client';
import { ApplicationType } from '@c8y/client';
import { saveAs } from 'file-saver';
import * as i3$1 from '@c8y/ngx-components/static-assets/data';
import * as i1$3 from 'ngx-bootstrap/modal';
import * as i2 from '@angular/forms';
import { ReactiveFormsModule, FormsModule, FormControl } from '@angular/forms';
import * as i4 from '@angular/common';
import { NgIf, NgForOf, AsyncPipe } from '@angular/common';
import { uniqBy, cloneDeep } from 'lodash-es';
import * as i1$1 from '@c8y/ngx-components/branding/shared/lazy/add-branding-modal';
import { gettext } from '@c8y/ngx-components/gettext';
import * as i1$4 from 'ngx-bootstrap/popover';
import { PopoverModule } from 'ngx-bootstrap/popover';
import * as i4$1 from 'ngx-bootstrap/collapse';
import { CollapseModule } from 'ngx-bootstrap/collapse';
import { StaticAssetsFilePickerComponent } from '@c8y/ngx-components/static-assets';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import { EditorComponent } from '@c8y/ngx-components/editor';

class ApplyBrandingToAppService {
    constructor(apps) {
        this.apps = apps;
    }
    async getBrandableApps() {
        const { data: apps } = await this.apps.list({
            pageSize: 2000,
            dropOverwrittenApps: true,
            type: ApplicationType.HOSTED
        });
        const appsWithDynamicOptionsUrl = this.getHostedAppsWhereDynamicOptionsUrlIsUndefined(apps);
        return appsWithDynamicOptionsUrl;
    }
    getHostedAppsWhereDynamicOptionsUrlIsUndefined(apps) {
        return apps.filter(app => {
            const manifest = app.manifest;
            if (!manifest) {
                return false;
            }
            // filter out none web sdk based apps
            if (!manifest.webSdkVersion) {
                return false;
            }
            // filter out packages
            if (manifest.isPackage) {
                return false;
            }
            const dynamicOptionsUrl = manifest.dynamicOptionsUrl;
            return dynamicOptionsUrl === undefined || dynamicOptionsUrl === true;
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ApplyBrandingToAppService, deps: [{ token: i1.ApplicationService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ApplyBrandingToAppService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ApplyBrandingToAppService, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }], ctorParameters: () => [{ type: i1.ApplicationService }] });

class ApplyBrandingToAppModalComponent {
    constructor(apply, formBuilder) {
        this.apply = apply;
        this.formBuilder = formBuilder;
        this.brandableApps = [];
        this.result = new Promise((resolve, reject) => {
            this._resovle = resolve;
            this._reject = reject;
        });
    }
    async ngOnInit() {
        const brandableApps = await this.apply.getBrandableApps();
        this.brandableApps = uniqBy(brandableApps, 'contextPath');
        const tags = this.brandableApps.map(app => app.contextPath);
        this.form = this.initForm(tags);
        if (this.currentTags.length) {
            this.form.patchValue(this.currentTags.reduce((prev, curr) => Object.assign(prev, { [curr]: true }), {}));
        }
        this.numberOfSelectedApps$ = merge(this.form.valueChanges, of(this.form.value)).pipe(map(value => Object.values(value).filter(Boolean).length));
    }
    save() {
        this._resovle(this.form.value);
    }
    cancel() {
        this._reject();
    }
    initForm(tags) {
        const tagsFormMap = tags.reduceRight((prev, curr) => Object.assign(prev, { [curr]: this.formBuilder.control(false) }), {});
        return this.formBuilder.group(tagsFormMap);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ApplyBrandingToAppModalComponent, deps: [{ token: ApplyBrandingToAppService }, { token: i2.FormBuilder }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: ApplyBrandingToAppModalComponent, isStandalone: true, selector: "c8y-apply-branding-to-app-modal", inputs: { currentTags: "currentTags" }, ngImport: i0, template: "<c8y-modal\n  [title]=\"'Apply branding to apps' | translate\"\n  [disabled]=\"!form || form.invalid || !brandableApps.length\"\n  [headerClasses]=\"'dialog-header'\"\n  (onDismiss)=\"cancel()\"\n  (onClose)=\"save()\"\n  [labels]=\"{ cancel: 'Cancel', ok: 'Save' }\"\n>\n  <ng-container c8y-modal-title>\n    <span c8yIcon=\"palette\"></span>\n  </ng-container>\n  <c8y-list-group\n    class=\"m-b-0 no-border-last\"\n    *ngIf=\"form\"\n    [formGroup]=\"form\"\n  >\n    <c8y-li>\n      <p\n        class=\"text-center text-medium\"\n        *ngIf=\"numberOfSelectedApps$ | async as numberOfApps; else noapps\"\n        translate\n      >\n        {{ numberOfApps }} apps selected for branding\n      </p>\n      <ng-template #noapps>\n        <p\n          class=\"text-center text-medium\"\n          translate\n        >\n          No apps selected for branding\n        </p>\n      </ng-template>\n    </c8y-li>\n    <c8y-li *ngFor=\"let app of brandableApps\">\n      <c8y-li-icon>\n        <c8y-app-icon\n          class=\"icon-40\"\n          [app]=\"app\"\n        ></c8y-app-icon>\n      </c8y-li-icon>\n      <c8y-li-checkbox\n        [attr.data-cy]=\"'branding-apply-branding-to-app-checkbox-' + app.contextPath\"\n        [formControlName]=\"app.contextPath\"\n      ></c8y-li-checkbox>\n      <c8y-li-body class=\"p-t-8 d-block\">{{ app | humanizeAppName | async }}</c8y-li-body>\n    </c8y-li>\n  </c8y-list-group>\n</c8y-modal>\n", dependencies: [{ kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "ngmodule", type: ReactiveFormsModule }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i2.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i2.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "ngmodule", type: CoreModule }, { kind: "component", type: i3.AppIconComponent, selector: "c8y-app-icon", inputs: ["contextPath", "name", "app"] }, { kind: "directive", type: i3.IconDirective, selector: "[c8yIcon]", inputs: ["c8yIcon"] }, { kind: "pipe", type: i3.C8yTranslatePipe, name: "translate" }, { kind: "directive", type: i3.C8yTranslateDirective, selector: "[translate],[ngx-translate]" }, { kind: "directive", type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "pipe", type: i4.AsyncPipe, name: "async" }, { kind: "pipe", type: i3.HumanizeAppNamePipe, name: "humanizeAppName" }, { kind: "component", type: i3.ModalComponent, selector: "c8y-modal", inputs: ["disabled", "close", "dismiss", "title", "body", "customFooter", "headerClasses", "labels"], outputs: ["onDismiss", "onClose"] }, { kind: "component", type: i3.ListGroupComponent, selector: "c8y-list-group" }, { kind: "component", type: i3.ListItemComponent, selector: "c8y-list-item, c8y-li", inputs: ["active", "highlighted", "emptyActions", "dense", "collapsed", "selectable"], outputs: ["collapsedChange"] }, { kind: "component", type: i3.ListItemIconComponent, selector: "c8y-list-item-icon, c8y-li-icon", inputs: ["icon", "status"] }, { kind: "component", type: i3.ListItemBodyComponent, selector: "c8y-list-item-body, c8y-li-body", inputs: ["body"] }, { kind: "component", type: i3.ListItemCheckboxComponent, selector: "c8y-list-item-checkbox, c8y-li-checkbox", inputs: ["selected", "indeterminate", "disabled", "displayAsSwitch"], outputs: ["onSelect"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ApplyBrandingToAppModalComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-apply-branding-to-app-modal', standalone: true, imports: [NgIf, ReactiveFormsModule, CoreModule], template: "<c8y-modal\n  [title]=\"'Apply branding to apps' | translate\"\n  [disabled]=\"!form || form.invalid || !brandableApps.length\"\n  [headerClasses]=\"'dialog-header'\"\n  (onDismiss)=\"cancel()\"\n  (onClose)=\"save()\"\n  [labels]=\"{ cancel: 'Cancel', ok: 'Save' }\"\n>\n  <ng-container c8y-modal-title>\n    <span c8yIcon=\"palette\"></span>\n  </ng-container>\n  <c8y-list-group\n    class=\"m-b-0 no-border-last\"\n    *ngIf=\"form\"\n    [formGroup]=\"form\"\n  >\n    <c8y-li>\n      <p\n        class=\"text-center text-medium\"\n        *ngIf=\"numberOfSelectedApps$ | async as numberOfApps; else noapps\"\n        translate\n      >\n        {{ numberOfApps }} apps selected for branding\n      </p>\n      <ng-template #noapps>\n        <p\n          class=\"text-center text-medium\"\n          translate\n        >\n          No apps selected for branding\n        </p>\n      </ng-template>\n    </c8y-li>\n    <c8y-li *ngFor=\"let app of brandableApps\">\n      <c8y-li-icon>\n        <c8y-app-icon\n          class=\"icon-40\"\n          [app]=\"app\"\n        ></c8y-app-icon>\n      </c8y-li-icon>\n      <c8y-li-checkbox\n        [attr.data-cy]=\"'branding-apply-branding-to-app-checkbox-' + app.contextPath\"\n        [formControlName]=\"app.contextPath\"\n      ></c8y-li-checkbox>\n      <c8y-li-body class=\"p-t-8 d-block\">{{ app | humanizeAppName | async }}</c8y-li-body>\n    </c8y-li>\n  </c8y-list-group>\n</c8y-modal>\n" }]
        }], ctorParameters: () => [{ type: ApplyBrandingToAppService }, { type: i2.FormBuilder }], propDecorators: { currentTags: [{
                type: Input
            }] } });

class BrandingTagsCellRendererComponent {
    constructor(context, appState) {
        this.appState = appState;
        const tags = context.value || [];
        this.hasLatestTag = tags.some(tag => tag === 'latest');
        const appSpecificTags = tags
            .filter(tag => tag.startsWith('app-'))
            .map(tag => tag.replace('app-', ''));
        this.appContextPathsOrApps$ = this.getAppContextPathsOrApps$(appSpecificTags);
    }
    getAppContextPathsOrApps$(appContextPaths) {
        if (!appContextPaths.length) {
            return of([]);
        }
        return this.appState.currentAppsOfUser.pipe(map(apps => {
            return appContextPaths.map(tag => {
                const app = apps.find(app => app.contextPath === tag);
                return app || tag;
            });
        }), startWith(appContextPaths));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BrandingTagsCellRendererComponent, deps: [{ token: i3.CellRendererContext }, { token: i3.AppStateService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: BrandingTagsCellRendererComponent, isStandalone: true, selector: "c8y-branding-tags-cell-renderer", ngImport: i0, template: "<div class=\"d-flex a-i-center gap-4 flex-wrap\">\n  <div\n    class=\"tag tag--success\"\n    *ngIf=\"hasLatestTag\"\n    translate\n  >\n    Global\n  </div>\n  <div\n    class=\"tag tag--info\"\n    *ngFor=\"let tag of appContextPathsOrApps$ | async\"\n    [attr.data-cy]=\"'branding-tags-cell-renderer--tag-' + (tag.contextPath ? tag.contextPath : tag)\"\n  >\n    {{ tag | humanizeAppName | async }}\n  </div>\n</div>\n", dependencies: [{ kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "pipe", type: HumanizeAppNamePipe, name: "humanizeAppName" }, { kind: "pipe", type: AsyncPipe, name: "async" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BrandingTagsCellRendererComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-branding-tags-cell-renderer', standalone: true, imports: [NgIf, NgForOf, HumanizeAppNamePipe, AsyncPipe], template: "<div class=\"d-flex a-i-center gap-4 flex-wrap\">\n  <div\n    class=\"tag tag--success\"\n    *ngIf=\"hasLatestTag\"\n    translate\n  >\n    Global\n  </div>\n  <div\n    class=\"tag tag--info\"\n    *ngFor=\"let tag of appContextPathsOrApps$ | async\"\n    [attr.data-cy]=\"'branding-tags-cell-renderer--tag-' + (tag.contextPath ? tag.contextPath : tag)\"\n  >\n    {{ tag | humanizeAppName | async }}\n  </div>\n</div>\n" }]
        }], ctorParameters: () => [{ type: i3.CellRendererContext }, { type: i3.AppStateService }] });

class BrandingImportModalComponent {
    constructor(addBrandingModalService, zip, staticAssets, brandings) {
        this.addBrandingModalService = addBrandingModalService;
        this.zip = zip;
        this.staticAssets = staticAssets;
        this.brandings = brandings;
        this.result = new Promise((resolve, reject) => {
            this._resovle = resolve;
            this._reject = reject;
        });
        this.files = [];
        this.loading = false;
    }
    async droppedFile(event) {
        this.loading = true;
        try {
            this.files = event;
            await this.import(event[0].file);
        }
        catch (e) {
            console.error(e);
            this.files = [];
            this.loading = false;
            return;
        }
        this.modal._close();
        this._resovle();
    }
    async import(file) {
        const versionDetails = await this.addBrandingModalService.openAddBrandingModal();
        if (!versionDetails) {
            throw Error('No version details provided');
        }
        // verify if branding is already present
        const { variants } = await this.brandings.loadBrandingVariants();
        if (!variants?.length) {
            await this.brandings.getStartedUsingBranding();
        }
        const importedZipEntries = await firstValueFrom(this.zip.getEntries(file));
        const staticAssetsEntry = importedZipEntries.find(entry => entry.filename === this.staticAssets.fileNames.exportZipName);
        if (!staticAssetsEntry) {
            throw Error(`Missing "${this.staticAssets.fileNames.exportZipName}" file in the uploaded zip.`);
        }
        const staticAssetsZip = await firstValueFrom(this.zip.getData(staticAssetsEntry));
        const staticAssetsZipFile = new File([staticAssetsZip], staticAssetsEntry.filename);
        const staticAssetsZipEntries = await firstValueFrom(this.zip.getEntries(staticAssetsZipFile));
        const filesToAdd = new Array();
        let oldAssets;
        let newAssets;
        for (const entry of staticAssetsZipEntries) {
            if (entry.filename === this.brandings.fileNames.manifest) {
                continue;
            }
            if (entry.filename === this.staticAssets.fileNames.contents) {
                const fileContent = await (await firstValueFrom(this.zip.getData(entry))).text();
                oldAssets = JSON.parse(fileContent);
                continue;
            }
            const file = await firstValueFrom(this.zip.getData(entry));
            filesToAdd.push(new File([file], entry.filename));
        }
        if (filesToAdd.length > 0) {
            const currentStaticAssets = await this.staticAssets.listFilesCached('branding', true);
            newAssets = await this.staticAssets.addFilesToStaticAssets('branding', filesToAdd, currentStaticAssets, false);
        }
        const publicOptionsEntry = importedZipEntries.find(entry => entry.filename === this.brandings.fileNames.exportZipName);
        if (!publicOptionsEntry) {
            throw Error(`Missing "${this.brandings.fileNames.exportZipName}" file in the uploaded zip.`);
        }
        const publicOptionsZip = await firstValueFrom(this.zip.getData(publicOptionsEntry));
        const publicOptionsZipFile = new File([publicOptionsZip], publicOptionsEntry.filename);
        const publicOptionsFiles = await firstValueFrom(this.zip.getEntries(publicOptionsZipFile));
        const optionsFileEntry = publicOptionsFiles.find(entry => entry.filename === this.brandings.fileNames.options);
        if (!optionsFileEntry) {
            throw Error(`Missing "${this.brandings.fileNames.options}" file in "${this.brandings.fileNames.exportZipName}" file of the uploaded zip.`);
        }
        const optionsFile = await firstValueFrom(this.zip.getData(optionsFileEntry));
        let options = JSON.parse(await optionsFile.text());
        if (oldAssets.length && newAssets.length) {
            options = this.brandings.replaceBrandingAssetsInBrandingOptions(options, oldAssets, newAssets);
        }
        const zip = await this.brandings.getBrandingZip(options);
        await this.brandings.saveBranding(zip, `${versionDetails.brandingName}-1`, [
            versionDetails.brandingName
        ]);
    }
    cancel() {
        this._reject();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BrandingImportModalComponent, deps: [{ token: i1$1.AddBrandingModalService }, { token: i3.ZipService }, { token: i3$1.StaticAssetsService }, { token: i1$2.StoreBrandingService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: BrandingImportModalComponent, isStandalone: true, selector: "c8y-branding-import-modal", viewQueries: [{ propertyName: "modal", first: true, predicate: ModalComponent, descendants: true, static: true }], ngImport: i0, template: "<c8y-modal\n  [title]=\"'Import branding variant'\"\n  [headerClasses]=\"'dialog-header'\"\n  (onDismiss)=\"cancel()\"\n  [labels]=\"{ cancel: 'Cancel' }\"\n>\n  <ng-container c8y-modal-title>\n    <span c8yIcon=\"import\"></span>\n  </ng-container>\n  <div class=\"p-t-16 p-b-16 p-l-24 p-r-24 separator-bottom\">\n    <p\n      class=\"text-medium text-center text-16\"\n      translate\n    >\n      Easily copy any branding variant from any tenant\n    </p>\n    <p translate class=\"p-t-8\">\n      Export the branding variant from the source tenant and import the .zip file here. This process\n      allows you to maintain consistent branding across multiple tenants efficiently.\n    </p>\n  </div>\n  <div\n    class=\"p-24 m-r-auto m-l-auto\"\n    style=\"max-width: 300px\"\n  >\n    <c8y-drop-area\n      [icon]=\"'upload'\"\n      (dropped)=\"droppedFile($event)\"\n      [files]=\"files\"\n      [accept]=\"'.zip'\"\n      [maxAllowedFiles]=\"1\"\n      [loading]=\"loading\"\n    ></c8y-drop-area>\n  </div>\n</c8y-modal>\n", dependencies: [{ kind: "ngmodule", type: CoreModule }, { kind: "directive", type: i3.IconDirective, selector: "[c8yIcon]", inputs: ["c8yIcon"] }, { kind: "directive", type: i3.C8yTranslateDirective, selector: "[translate],[ngx-translate]" }, { kind: "component", type: i3.DropAreaComponent, selector: "c8y-drop-area", inputs: ["formControl", "title", "message", "icon", "loadingMessage", "forceHideList", "alwaysShow", "clickToOpen", "loading", "progress", "maxAllowedFiles", "files", "maxFileSizeInMegaBytes", "accept"], outputs: ["dropped"] }, { kind: "component", type: i3.ModalComponent, selector: "c8y-modal", inputs: ["disabled", "close", "dismiss", "title", "body", "customFooter", "headerClasses", "labels"], outputs: ["onDismiss", "onClose"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BrandingImportModalComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-branding-import-modal', standalone: true, imports: [CoreModule], template: "<c8y-modal\n  [title]=\"'Import branding variant'\"\n  [headerClasses]=\"'dialog-header'\"\n  (onDismiss)=\"cancel()\"\n  [labels]=\"{ cancel: 'Cancel' }\"\n>\n  <ng-container c8y-modal-title>\n    <span c8yIcon=\"import\"></span>\n  </ng-container>\n  <div class=\"p-t-16 p-b-16 p-l-24 p-r-24 separator-bottom\">\n    <p\n      class=\"text-medium text-center text-16\"\n      translate\n    >\n      Easily copy any branding variant from any tenant\n    </p>\n    <p translate class=\"p-t-8\">\n      Export the branding variant from the source tenant and import the .zip file here. This process\n      allows you to maintain consistent branding across multiple tenants efficiently.\n    </p>\n  </div>\n  <div\n    class=\"p-24 m-r-auto m-l-auto\"\n    style=\"max-width: 300px\"\n  >\n    <c8y-drop-area\n      [icon]=\"'upload'\"\n      (dropped)=\"droppedFile($event)\"\n      [files]=\"files\"\n      [accept]=\"'.zip'\"\n      [maxAllowedFiles]=\"1\"\n      [loading]=\"loading\"\n    ></c8y-drop-area>\n  </div>\n</c8y-modal>\n" }]
        }], ctorParameters: () => [{ type: i1$1.AddBrandingModalService }, { type: i3.ZipService }, { type: i3$1.StaticAssetsService }, { type: i1$2.StoreBrandingService }], propDecorators: { modal: [{
                type: ViewChild,
                args: [ModalComponent, { static: true }]
            }] } });

class BrandingImportModalService {
    constructor(modal) {
        this.modal = modal;
    }
    async openBrandingImportModal() {
        let versionDetails;
        try {
            const modalRef = this.modal.show(BrandingImportModalComponent, {
                class: 'modal-sm',
                ignoreBackdropClick: true,
                keyboard: false
            });
            versionDetails = await modalRef.content.result;
        }
        catch (e) {
            // modal closed
            return;
        }
        return versionDetails;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BrandingImportModalService, deps: [{ token: i1$3.BsModalService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BrandingImportModalService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BrandingImportModalService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: i1$3.BsModalService }] });

class BrandingNameCellRendererComponent {
    constructor(context, router) {
        this.router = router;
        this.name = context.value;
        this.routerLink = `${this.router.url}/${context.item.name}`;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BrandingNameCellRendererComponent, deps: [{ token: i3.CellRendererContext }, { token: i2$1.Router }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: BrandingNameCellRendererComponent, isStandalone: true, selector: "c8y-branding-name-cell-renderer", ngImport: i0, template: "<a [routerLink]=\"routerLink\">{{ name }}</a>\n", dependencies: [{ kind: "directive", type: RouterLink, selector: "[routerLink]", inputs: ["target", "queryParams", "fragment", "queryParamsHandling", "state", "info", "relativeTo", "preserveFragment", "skipLocationChange", "replaceUrl", "routerLink"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BrandingNameCellRendererComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-branding-name-cell-renderer', standalone: true, imports: [RouterLink], template: "<a [routerLink]=\"routerLink\">{{ name }}</a>\n" }]
        }], ctorParameters: () => [{ type: i3.CellRendererContext }, { type: i2$1.Router }] });

class BrandingTagsHeaderCellRendererComponent {
    constructor() {
        this.heading = gettext('Applied to');
        this.popoverContent = gettext(`<p class="m-b-8">Branding can be applied at two levels</p>
    <ul class="list-unstyled m-b-0">
      <li class="m-b-4">
        <strong>Global: </strong>
        <span>Applied to the entire platform, affecting all apps and interfaces.</span>
      </li>
      <li>
        <strong>App-specific: </strong>
        <span>Applied only to selected apps within the platform.</span>
      </li>
    </ul>`);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BrandingTagsHeaderCellRendererComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: BrandingTagsHeaderCellRendererComponent, isStandalone: true, selector: "c8y-branding-tags-header-cell-renderer", ngImport: i0, template: "<div class=\"d-flex\">\n  <span\n    class=\"text-truncate\"\n    [title]=\"heading | translate\"\n  >\n    {{ heading | translate }}\n  </span>\n  <button\n    class=\"btn-help btn-help--sm a-s-center\"\n    [attr.aria-label]=\"'Help' | translate\"\n    [popover]=\"applyBrandingPopover\"\n    placement=\"bottom\"\n    triggers=\"focus\"\n    container=\"body\"\n    type=\"button\"\n    (click)=\"$event.stopPropagation()\"\n  >\n    <i c8yIcon=\"question-circle-o\"></i>\n  </button>\n  <ng-template #applyBrandingPopover>\n    <div [innerHTML]=\"popoverContent | translate\"></div>\n  </ng-template>\n</div>\n", dependencies: [{ kind: "ngmodule", type: PopoverModule }, { kind: "directive", type: i1$4.PopoverDirective, selector: "[popover]", inputs: ["adaptivePosition", "boundariesElement", "popover", "popoverContext", "popoverTitle", "placement", "outsideClick", "triggers", "container", "containerClass", "isOpen", "delay"], outputs: ["onShown", "onHidden"], exportAs: ["bs-popover"] }, { kind: "pipe", type: C8yTranslatePipe, name: "translate" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BrandingTagsHeaderCellRendererComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-branding-tags-header-cell-renderer', standalone: true, imports: [PopoverModule, C8yTranslatePipe], template: "<div class=\"d-flex\">\n  <span\n    class=\"text-truncate\"\n    [title]=\"heading | translate\"\n  >\n    {{ heading | translate }}\n  </span>\n  <button\n    class=\"btn-help btn-help--sm a-s-center\"\n    [attr.aria-label]=\"'Help' | translate\"\n    [popover]=\"applyBrandingPopover\"\n    placement=\"bottom\"\n    triggers=\"focus\"\n    container=\"body\"\n    type=\"button\"\n    (click)=\"$event.stopPropagation()\"\n  >\n    <i c8yIcon=\"question-circle-o\"></i>\n  </button>\n  <ng-template #applyBrandingPopover>\n    <div [innerHTML]=\"popoverContent | translate\"></div>\n  </ng-template>\n</div>\n" }]
        }] });

class BrandingComponent {
    constructor(brandings, activatedRoute, appState, applicationService, zip, staticAssets, router, modal, confirmModal, brandingVersionService, addBrandingModalService, alert, brandingImportModalService, brandingTracking) {
        this.brandings = brandings;
        this.activatedRoute = activatedRoute;
        this.appState = appState;
        this.applicationService = applicationService;
        this.zip = zip;
        this.staticAssets = staticAssets;
        this.router = router;
        this.modal = modal;
        this.confirmModal = confirmModal;
        this.brandingVersionService = brandingVersionService;
        this.addBrandingModalService = addBrandingModalService;
        this.alert = alert;
        this.brandingImportModalService = brandingImportModalService;
        this.brandingTracking = brandingTracking;
        this.pagination = {
            pageSize: 10,
            currentPage: 1
        };
        this.displayOptions = {
            bordered: false,
            striped: true,
            filter: true,
            gridHeader: true,
            hover: true
        };
        this.actionControls = [
            {
                type: BuiltInActionType.Edit,
                callback: (entry, _reload) => {
                    this.editBranding(entry.name);
                }
            },
            {
                type: BuiltInActionType.Export,
                callback: async (entry, _reload) => {
                    await this.exportBranding(entry);
                }
            },
            {
                type: 'preview',
                icon: 'external-link',
                text: gettext$1('Open preview'),
                callback: async (entry, _reload) => {
                    this.brandings.openPreviewForBranding(entry.name);
                }
            },
            {
                type: 'duplicate',
                icon: 'copy',
                text: gettext$1('Duplicate'),
                callback: async (entry, _reload) => {
                    await this.duplicateVersion(entry);
                    this.refresh();
                }
            },
            {
                type: 'apply-to-app',
                icon: 'form',
                text: gettext$1('Apply to specific apps'),
                callback: async (entry, _reload) => {
                    await this.applyToApps(entry);
                    this.refresh();
                }
            },
            {
                type: 'set-as-default',
                icon: 'globe1',
                text: gettext$1('Set as global'),
                showIf: (entry) => {
                    if (entry.tags?.includes('latest')) {
                        return false;
                    }
                    return true;
                },
                callback: async (entry, _reload) => {
                    try {
                        await this.confirmModal.confirm(gettext$1('Set as global branding'), gettext$1('Are you sure that you want to set this variant as the global branding? By doing so, this variant will be applied to all apps that do not have a specific branding applied. Do you want to proceed?'), Status.INFO);
                    }
                    catch {
                        // did not confirm
                        return;
                    }
                    await this.brandings.markAsActive(entry);
                    this.refresh();
                }
            },
            {
                type: BuiltInActionType.Delete,
                showIf: (entry) => {
                    if (entry.tags?.includes('latest')) {
                        return false;
                    }
                    return true;
                },
                callback: async (entry, _reload) => {
                    try {
                        await this.confirmModal.confirm(gettext$1('Delete branding variant'), gettext$1('You are about to delete this branding variant. This action cannot be undone. Do you want to proceed?'), Status.DANGER);
                    }
                    catch {
                        // did not confirm
                        return;
                    }
                    this.brandingTracking.deleteBrandingVariant();
                    await this.applicationService.deleteVersionPackage(entry.publicOptionsApp, {
                        version: entry.version
                    });
                    this.refresh();
                }
            }
        ];
        this.columns = [
            {
                name: 'name',
                header: gettext$1('Name'),
                path: 'name',
                filterable: true,
                cellRendererComponent: BrandingNameCellRendererComponent
            },
            {
                name: gettext$1('Applied to`Applications a branding applies to (table column header)`'),
                path: 'tags',
                filterable: false,
                cellCSSClassName: 'small',
                cellRendererComponent: BrandingTagsCellRendererComponent,
                headerCellRendererComponent: BrandingTagsHeaderCellRendererComponent
            },
            {
                name: 'owner',
                header: gettext$1('Owner'),
                path: 'owner',
                filterable: false
            },
            {
                name: 'lastUpdated',
                header: gettext$1('Last updated'),
                path: 'lastUpdated',
                filterable: false
            }
        ];
        this.currentAppContextPath = 'administration';
        this.reloadTrigger = new BehaviorSubject(undefined);
        this.currentAppContextPath = this.appState.state.app?.contextPath || this.currentAppContextPath;
        this.availableBrandingVariants$ = this.reloadTrigger.pipe(switchMap(() => this.brandings.loadBrandingVariants()), 
        // hide the fallback from users
        map(variants => {
            variants.variants = variants.variants.filter(v => !v.tags?.includes('fallback'));
            return variants;
        }), shareReplay({ refCount: true, bufferSize: 1 }));
    }
    async deleteAllBrandings(publicOptions) {
        const result = await this.confirmModal.confirm(gettext$1('Delete all branding variants'), gettext$1(`<p class="m-b-8">
          This action will permanently remove all custom branding variants. Your tenant will revert
          to the default branding.
        </p>
        <p class="m-b-8">
          Consider exporting your custom branding variants before proceeding, as this action cannot
          be undone.
        </p>
        <p>
          Are you sure you want to continue?
        </p>`), Status.DANGER, { cancel: gettext$1('Cancel'), ok: gettext$1('Delete all') });
        if (result === false || (typeof result === 'object' && !result.confirmed)) {
            return;
        }
        this.brandingTracking.deleteAllBrandings();
        await this.brandings.deleteAllBrandings(publicOptions);
        this.refresh();
    }
    async exportBranding(variant) {
        this.brandingTracking.exportBranding();
        const branding = await firstValueFrom(this.brandings.getZipForBinary(variant.id));
        const staticAssetsApp = await this.staticAssets.getAppForTenant('branding');
        const staticAssetsZip = await firstValueFrom(this.brandings.getZipForBinary(staticAssetsApp.activeVersionId, this.staticAssets.fileNames.exportZipName));
        const blob = await this.zip.createZip([
            { fileName: this.brandings.fileNames.exportZipName, blob: branding },
            { fileName: this.staticAssets.fileNames.exportZipName, blob: staticAssetsZip }
        ]);
        saveAs(blob, `branding-export-${variant.name}-${variant.revision}-${new Date().getTime()}.zip`);
    }
    refresh() {
        this.reloadTrigger.next();
    }
    async addNewVersion() {
        const versionDetails = await this.addBrandingModalService.openAddBrandingModal();
        if (!versionDetails) {
            this.refresh();
            return;
        }
        let fallBackBranding = {};
        try {
            fallBackBranding = await this.brandings.getBrandingOptionsForVersion('latest');
        }
        catch (e) {
            console.warn(`Failed to load latest branding`);
        }
        this.brandingTracking.addNewVersion();
        try {
            await this.brandings.addBranding(this.brandingVersionService.createInitialBrandingVersion(versionDetails.brandingName), fallBackBranding, [versionDetails.brandingName]);
            await this.brandings.waitForBrandingToBePresent(versionDetails.brandingName);
            this.editBranding(versionDetails.brandingName);
        }
        catch (e) {
            this.alert.addServerFailure(e, 'danger');
        }
    }
    async duplicateVersion(version) {
        const options = await this.brandings.getBrandingOptionsForVersion(version.version);
        const versionDetails = await this.addBrandingModalService.openDuplicateBrandingModal();
        if (!versionDetails) {
            return;
        }
        this.brandingTracking.duplicateVersion();
        try {
            await this.brandings.addBranding(this.brandingVersionService.createInitialBrandingVersion(versionDetails.brandingName), options, [versionDetails.brandingName]);
            await this.brandings.waitForBrandingToBePresent(versionDetails.brandingName);
            this.editBranding(versionDetails.brandingName);
        }
        catch (e) {
            this.alert.addServerFailure(e, 'danger');
        }
    }
    async editBranding(brandingName) {
        return this.router.navigate([brandingName, 'edit'], { relativeTo: this.activatedRoute });
    }
    async getStartedUsingBranding() {
        const result = await this.confirmModal.confirm(gettext$1(`Get started using branding variants`), gettext$1(`<p class="m-b-8">Confirming this action creates two branding variants:</p>
        <ul class="m-b-8 p-l-16">
          <li>A default copy of your current global branding</li>
          <li>Your new customizable variant.</li>
        </ul>
        <p class="m-b-8">
          After customization, you can set your new variant as global or apply it to specific apps.
        </p>
        <p>
          To revert changes, simply set the default branding as global or use the "Delete all variants" button at any time.
        </p>`));
        if (result === false || (typeof result === 'object' && !result.confirmed)) {
            return;
        }
        this.brandingTracking.getStartedUsingBranding();
        await this.brandings.getStartedUsingBranding();
        await this.addNewVersion();
    }
    async applyToApps(version) {
        const prefix = 'app-';
        const currentTags = version.tags
            .filter(tag => tag.startsWith(prefix))
            .map(tag => tag.replace(prefix, ''));
        const otherTags = version.tags.filter(tag => !tag.startsWith(prefix));
        let selectedTags;
        try {
            const modalRef = this.modal.show(ApplyBrandingToAppModalComponent, {
                initialState: { currentTags },
                ignoreBackdropClick: true,
                keyboard: false
            });
            selectedTags = await modalRef.content.result;
        }
        catch (e) {
            // modal closed
            return;
        }
        const selectedApps = Object.keys(selectedTags).filter(key => selectedTags[key]);
        this.brandingTracking.applyToApps(selectedApps);
        const tagsToSet = [...otherTags, ...selectedApps.map(tag => `${prefix}${tag}`)];
        await this.removeTagsFromOtherVersions(version.publicOptionsApp, tagsToSet, version.version);
        await this.applicationService.setPackageVersionTag(version.publicOptionsApp, version.version, tagsToSet);
    }
    async importBranding() {
        try {
            await this.brandingImportModalService.openBrandingImportModal();
            this.brandings.refreshTriggerBrandingVariants.next();
            this.reloadTrigger.next();
        }
        catch (e) {
            // modal closed
        }
    }
    async removeTagsFromOtherVersions(publicOptionsApp, tagsToRemove, versionToIgnore) {
        for (const version of publicOptionsApp.applicationVersions) {
            if (version.version === versionToIgnore) {
                continue;
            }
            const removedTags = version.tags.filter(tag => !tagsToRemove.includes(tag));
            if (removedTags.length === version.tags.length) {
                continue;
            }
            await this.applicationService.setPackageVersionTag(publicOptionsApp, version.version, removedTags);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BrandingComponent, deps: [{ token: i1$2.StoreBrandingService }, { token: i2$1.ActivatedRoute }, { token: i3.AppStateService }, { token: i1.ApplicationService }, { token: i3.ZipService }, { token: i3$1.StaticAssetsService }, { token: i2$1.Router }, { token: i1$3.BsModalService }, { token: i3.ModalService }, { token: i1$2.BrandingVersionService }, { token: i1$1.AddBrandingModalService }, { token: i3.AlertService }, { token: BrandingImportModalService }, { token: i1$2.BrandingTrackingService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: BrandingComponent, isStandalone: true, selector: "c8y-branding", ngImport: i0, template: "<c8y-title translate>Branding</c8y-title>\n\n<c8y-breadcrumb>\n  <c8y-breadcrumb-item\n    [icon]=\"'palette'\"\n    [label]=\"'Branding' | translate\"\n    [path]=\"'/branding-editor'\"\n  ></c8y-breadcrumb-item>\n</c8y-breadcrumb>\n\n<ng-container *ngIf=\"availableBrandingVariants$ | async as brandingVariant; else loading\">\n  <c8y-action-bar-item\n    *ngIf=\"brandingVariant.publicOptions\"\n    [placement]=\"'right'\"\n    [priority]=\"30\"\n  >\n    <button\n      class=\"btn btn-link\"\n      (click)=\"addNewVersion()\"\n      data-cy=\"branding-add-branding-variant\"\n    >\n      <i c8yIcon=\"plus-circle\"></i>\n      <span translate>Add variant</span>\n    </button>\n  </c8y-action-bar-item>\n  <c8y-action-bar-item\n    [placement]=\"'right'\"\n    [priority]=\"20\"\n  >\n    <button\n      class=\"btn btn-link\"\n      data-cy=\"branding-import-branding\"\n      (click)=\"importBranding()\"\n    >\n      <i [c8yIcon]=\"'data-import'\"></i>\n      <span translate>Import variant</span>\n    </button>\n  </c8y-action-bar-item>\n\n  <c8y-action-bar-item\n    *ngIf=\"brandingVariant.publicOptions\"\n    [placement]=\"'right'\"\n    [priority]=\"10\"\n  >\n    <button\n      class=\"btn btn-link\"\n      (click)=\"deleteAllBrandings(brandingVariant.publicOptions)\"\n      data-cy=\"branding-remove-all-brandings\"\n    >\n      <i [c8yIcon]=\"'trash-o'\"></i>\n      <span translate>Delete all variants</span>\n    </button>\n  </c8y-action-bar-item>\n\n  <div class=\"content-fullpage d-flex d-col border-top\">\n    <c8y-data-grid\n      [title]=\"'Branding variants' | translate\"\n      [columns]=\"columns\"\n      [actionControls]=\"actionControls\"\n      [pagination]=\"pagination\"\n      [displayOptions]=\"displayOptions\"\n      (onReload)=\"refresh()\"\n      [rows]=\"brandingVariant.variants\"\n    >\n      <c8y-ui-empty-state\n        [icon]=\"'palette'\"\n        [title]=\"'No branding variants' | translate\"\n        [subtitle]=\"\n          'Personalize your experience with a theme-able interface. Create a unique look that aligns with your brand identity.'\n            | translate\n        \"\n        *ngIf=\"!brandingVariant.publicOptions\"\n        [horizontal]=\"false\"\n      >\n        <button\n          class=\"btn btn-default\"\n          data-cy=\"branding-get-started-using-branding\"\n          (click)=\"getStartedUsingBranding()\"\n          translate\n        >\n          Add branding variant\n        </button>\n      </c8y-ui-empty-state>\n    </c8y-data-grid>\n  </div>\n</ng-container>\n\n<ng-template #loading>\n  <c8y-loading></c8y-loading>\n</ng-template>\n", dependencies: [{ kind: "ngmodule", type: CoreModule }, { kind: "component", type: i3.ActionBarItemComponent, selector: "c8y-action-bar-item", inputs: ["placement", "priority", "itemClass", "injector", "groupId", "inGroupPriority"] }, { kind: "component", type: i3.BreadcrumbComponent, selector: "c8y-breadcrumb" }, { kind: "component", type: i3.BreadcrumbItemComponent, selector: "c8y-breadcrumb-item", inputs: ["icon", "translate", "label", "path", "injector"] }, { kind: "component", type: i3.EmptyStateComponent, selector: "c8y-ui-empty-state", inputs: ["icon", "title", "subtitle", "horizontal"] }, { kind: "directive", type: i3.IconDirective, selector: "[c8yIcon]", inputs: ["c8yIcon"] }, { kind: "pipe", type: i3.C8yTranslatePipe, name: "translate" }, { kind: "directive", type: i3.C8yTranslateDirective, selector: "[translate],[ngx-translate]" }, { kind: "directive", type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "pipe", type: i4.AsyncPipe, name: "async" }, { kind: "component", type: i3.LoadingComponent, selector: "c8y-loading", inputs: ["layout", "progress", "message"] }, { kind: "component", type: i3.DataGridComponent, selector: "c8y-data-grid", inputs: ["title", "loadMoreItemsLabel", "loadingItemsLabel", "showSearch", "refresh", "columns", "rows", "pagination", "infiniteScroll", "serverSideDataCallback", "selectable", "singleSelection", "selectionPrimaryKey", "displayOptions", "actionControls", "bulkActionControls", "headerActionControls", "searchText", "configureColumnsEnabled", "showCounterWarning", "activeClassName", "expandableRows", "hideReload"], outputs: ["rowMouseOver", "rowMouseLeave", "rowClick", "onConfigChange", "onBeforeFilter", "onBeforeSearch", "onFilter", "itemsSelect", "onReload", "onAddCustomColumn", "onRemoveCustomColumn", "onColumnFilterReset", "onSort", "onPageSizeChange", "onColumnReordered", "onColumnVisibilityChange"] }, { kind: "component", type: i3.TitleComponent, selector: "c8y-title", inputs: ["pageTitleUpdate"] }, { kind: "ngmodule", type: DataGridModule }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BrandingComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-branding', standalone: true, imports: [CoreModule, DataGridModule], template: "<c8y-title translate>Branding</c8y-title>\n\n<c8y-breadcrumb>\n  <c8y-breadcrumb-item\n    [icon]=\"'palette'\"\n    [label]=\"'Branding' | translate\"\n    [path]=\"'/branding-editor'\"\n  ></c8y-breadcrumb-item>\n</c8y-breadcrumb>\n\n<ng-container *ngIf=\"availableBrandingVariants$ | async as brandingVariant; else loading\">\n  <c8y-action-bar-item\n    *ngIf=\"brandingVariant.publicOptions\"\n    [placement]=\"'right'\"\n    [priority]=\"30\"\n  >\n    <button\n      class=\"btn btn-link\"\n      (click)=\"addNewVersion()\"\n      data-cy=\"branding-add-branding-variant\"\n    >\n      <i c8yIcon=\"plus-circle\"></i>\n      <span translate>Add variant</span>\n    </button>\n  </c8y-action-bar-item>\n  <c8y-action-bar-item\n    [placement]=\"'right'\"\n    [priority]=\"20\"\n  >\n    <button\n      class=\"btn btn-link\"\n      data-cy=\"branding-import-branding\"\n      (click)=\"importBranding()\"\n    >\n      <i [c8yIcon]=\"'data-import'\"></i>\n      <span translate>Import variant</span>\n    </button>\n  </c8y-action-bar-item>\n\n  <c8y-action-bar-item\n    *ngIf=\"brandingVariant.publicOptions\"\n    [placement]=\"'right'\"\n    [priority]=\"10\"\n  >\n    <button\n      class=\"btn btn-link\"\n      (click)=\"deleteAllBrandings(brandingVariant.publicOptions)\"\n      data-cy=\"branding-remove-all-brandings\"\n    >\n      <i [c8yIcon]=\"'trash-o'\"></i>\n      <span translate>Delete all variants</span>\n    </button>\n  </c8y-action-bar-item>\n\n  <div class=\"content-fullpage d-flex d-col border-top\">\n    <c8y-data-grid\n      [title]=\"'Branding variants' | translate\"\n      [columns]=\"columns\"\n      [actionControls]=\"actionControls\"\n      [pagination]=\"pagination\"\n      [displayOptions]=\"displayOptions\"\n      (onReload)=\"refresh()\"\n      [rows]=\"brandingVariant.variants\"\n    >\n      <c8y-ui-empty-state\n        [icon]=\"'palette'\"\n        [title]=\"'No branding variants' | translate\"\n        [subtitle]=\"\n          'Personalize your experience with a theme-able interface. Create a unique look that aligns with your brand identity.'\n            | translate\n        \"\n        *ngIf=\"!brandingVariant.publicOptions\"\n        [horizontal]=\"false\"\n      >\n        <button\n          class=\"btn btn-default\"\n          data-cy=\"branding-get-started-using-branding\"\n          (click)=\"getStartedUsingBranding()\"\n          translate\n        >\n          Add branding variant\n        </button>\n      </c8y-ui-empty-state>\n    </c8y-data-grid>\n  </div>\n</ng-container>\n\n<ng-template #loading>\n  <c8y-loading></c8y-loading>\n</ng-template>\n" }]
        }], ctorParameters: () => [{ type: i1$2.StoreBrandingService }, { type: i2$1.ActivatedRoute }, { type: i3.AppStateService }, { type: i1.ApplicationService }, { type: i3.ZipService }, { type: i3$1.StaticAssetsService }, { type: i2$1.Router }, { type: i1$3.BsModalService }, { type: i3.ModalService }, { type: i1$2.BrandingVersionService }, { type: i1$1.AddBrandingModalService }, { type: i3.AlertService }, { type: BrandingImportModalService }, { type: i1$2.BrandingTrackingService }] });

class BrandingFormComponent {
    constructor(formBuilder, messageBannerService) {
        this.formBuilder = formBuilder;
        this.messageBannerService = messageBannerService;
        this.messageBannerHelp = gettext$1('Supports markdown. Use {{ headerMark }} for headers, {{ listMark }} for lists, {{ boldMark }} for bold, {{ italicMark }} for italic, and {{ linkMark }} for links.');
        this.messageBannerHelpParams = {
            headerMark: '`#`',
            listMark: '`*`',
            boldMark: '`**`',
            italicMark: '`_`',
            linkMark: '`[]()`'
        };
        this.externalValue = {};
        this.formGroup = this.initForm();
        this.formGroupValueChanges$ = this.formGroup.valueChanges.pipe(takeUntilDestroyed());
    }
    writeValue(obj) {
        try {
            const parsedObj = JSON.parse(obj);
            this.externalValue = parsedObj;
            this.applyStateToForm(parsedObj);
        }
        catch (e) {
            // failed to parse
        }
    }
    registerOnChange(fn) {
        this.formGroupValueChanges$.subscribe(value => fn(this.convertFormToState(value)));
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    cockieBannerChange(toggleState) {
        this.formGroup.controls.cookieBanner.patchValue({ cookieBannerDisabled: !toggleState });
    }
    onBlur() {
        this.onTouched();
    }
    initForm() {
        return createGenericBrandingForm(this.formBuilder);
    }
    applyStateToForm(branding) {
        if (!branding) {
            return;
        }
        let toBePatched = brandingFormGroupTopLevelEntries.reduceRight((prev, curr) => {
            if (brandingFormGroupTopLevelEntriesToUnpack.includes(curr)) {
                return Object.assign(prev, { [curr]: branding });
            }
            return Object.assign(prev, { [curr]: branding[curr] });
        }, {});
        toBePatched = Object.keys(this.formGroup.controls)
            .filter(key => !brandingFormGroupTopLevelEntries.includes(key))
            .reduceRight((prev, curr) => {
            return Object.assign(prev, { [curr]: branding.brandingCssVars || {} });
        }, toBePatched);
        this.formGroup.patchValue(toBePatched);
    }
    convertFormToState(value) {
        const topLevel = brandingFormGroupTopLevelEntries.reduceRight((prev, curr) => {
            if (brandingFormGroupTopLevelEntriesToUnpack.includes(curr)) {
                return Object.assign(prev, value[curr]);
            }
            return Object.assign(prev, { [curr]: value[curr] });
        }, {});
        const newBrandingCssVars = Object.entries(value).reduceRight((prev, [key, value]) => {
            if (brandingFormGroupTopLevelEntries.includes(key)) {
                return prev;
            }
            return Object.assign(prev, value);
        }, {});
        const externalValue = cloneDeep(this.externalValue || {});
        Object.assign(externalValue, topLevel);
        const currentCSSVars = externalValue['brandingCssVars'] || {};
        const assignedNewValues = Object.assign(currentCSSVars, newBrandingCssVars);
        externalValue['brandingCssVars'] = assignedNewValues;
        return JSON.stringify(externalValue, null, 2);
    }
    previewBanner() {
        this.messageBannerService.showBanner();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BrandingFormComponent, deps: [{ token: i2.FormBuilder }, { token: i3.MessageBannerService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: BrandingFormComponent, isStandalone: true, selector: "c8y-branding-form", host: { classAttribute: "d-contents" }, ngImport: i0, template: "<div\n  class=\"inner-scroll\"\n  [formGroup]=\"formGroup\"\n>\n  <!--  Title & Favicon-->\n  <div class=\"card-block\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4 class=\"text-normal text-right text-left-xs m-b-16\">\n          {{ 'Title & favicon' | translate }}\n        </h4>\n      </div>\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <div\n          class=\"row p-t-16 p-b-16\"\n          [formGroupName]=\"'genericApplicationOptions'\"\n        >\n          <div class=\"col-md-6\">\n            <c8y-form-group class=\"m-b-32\">\n              <label\n                for=\"globalTitle\"\n                translate\n              >\n                Title\n              </label>\n              <input\n                class=\"form-control\"\n                id=\"globalTitle\"\n                name=\"globalTitle\"\n                type=\"text\"\n                formControlName=\"globalTitle\"\n              />\n              <c8y-messages\n                [helpMessage]=\"'Title to display in the browser tab' | translate\"\n              ></c8y-messages>\n            </c8y-form-group>\n          </div>\n          <div class=\"col-md-6\">\n            <c8y-form-group>\n              <label translate>Favicon</label>\n              <c8y-static-assets-file-picker\n                name=\"faviconUrl\"\n                [supportedFileExtensions]=\"['ico']\"\n                [isCSSURL]=\"false\"\n                formControlName=\"faviconUrl\"\n              ></c8y-static-assets-file-picker>\n              <c8y-messages [helpMessage]=\"'Supported files: *.ico'\"></c8y-messages>\n            </c8y-form-group>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n\n  <div class=\"card-block separator-top\">\n    <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n      <h4\n        class=\"text-normal text-right text-left-xs m-b-16\"\n        translate\n      >\n        Dark theme\n      </h4>\n    </div>\n    <div class=\"col-xs-12 col-sm-9 col-md-10\">\n      <c8y-form-group class=\"m-b-32 p-t-8 m-t-4\">\n        <label class=\"c8y-switch\">\n          <input\n            class=\"form-control\"\n            name=\"darkThemeAvailable\"\n            type=\"checkbox\"\n            formControlName=\"darkThemeAvailable\"\n          />\n          <span></span>\n          <span translate>Enable dark theme support</span>\n        </label>\n      </c8y-form-group>\n    </div>\n  </div>\n  <!-- Typography -->\n  <div class=\"card-block separator-top\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4\n          class=\"text-normal text-right text-left-xs m-b-16\"\n          translate\n        >\n          Typography\n        </h4>\n      </div>\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <div class=\"row\">\n          <div class=\"col-md-6\">\n            <fieldset\n              class=\"c8y-fieldset p-24\"\n              [formGroupName]=\"'baseTypography'\"\n            >\n              <legend translate>Base typography</legend>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  for=\"font-url\"\n                  translate\n                >\n                  Fonts URL\n                </label>\n                <input\n                  class=\"form-control\"\n                  id=\"font-url\"\n                  placeholder=\"{{\n                    'e.g. {{ example }}' | translate : { example: 'https://fonts.googleapis.com/css?family=Roboto:400,500,700' }\n                  }}\"\n                  type=\"text\"\n                  formControlName=\"font-url\"\n                />\n                <c8y-messages [helpMessage]=\"'The Google fonts URL' | translate\"></c8y-messages>\n              </c8y-form-group>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"font-family-base\"\n                  for=\"font-family-base\"\n                  translate\n                >\n                  Base font stack\n                </label>\n                <input\n                  class=\"form-control\"\n                  id=\"font-family-base\"\n                  placeholder=\"{{ 'e.g. {{ example }}' | translate : {example: '&quot;Roboto&quot;, Arial, sans-serif'} }}\"\n                  name=\"font-family-base\"\n                  type=\"text\"\n                  formControlName=\"font-family-base\"\n                />\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n          <div class=\"col-md-6\">\n            <fieldset\n              class=\"c8y-fieldset p-24\"\n              [formGroupName]=\"'headingsAndNavigatorTypography'\"\n            >\n              <legend>{{ 'Headings & navigator' | translate }}</legend>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"font-family-headings\"\n                  for=\"font-family-headings\"\n                  translate\n                >\n                  Headings font stack\n                </label>\n                <input\n                  class=\"form-control\"\n                  id=\"font-family-headings\"\n                  placeholder=\"{{ 'e.g. {{ example }}' | translate : {example: '&quot;Roboto&quot;, Arial, sans-serif'} }}\"\n                  type=\"text\"\n                  formControlName=\"font-family-headings\"\n                />\n                <c8y-messages\n                  [helpMessage]=\"\n                    'Leave empty to use the same font as the base font stack' | translate\n                  \"\n                ></c8y-messages>\n              </c8y-form-group>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"navigator-font-family\"\n                  translate\n                >\n                  Navigator font stack\n                </label>\n                <div class=\"form-control-static\">\n                  <label class=\"c8y-radio radio-inline\">\n                    <input\n                      name=\"navigator-font-family\"\n                      type=\"radio\"\n                      formControlName=\"navigator-font-family\"\n                      [value]=\"'var(--font-family-base)'\"\n                    />\n                    <span></span>\n                    <span translate>Match base font stack</span>\n                  </label>\n                  <label\n                    class=\"c8y-radio radio-inline\"\n                    title=\"Radio Two\"\n                  >\n                    <input\n                      name=\"navigator-font-family\"\n                      type=\"radio\"\n                      formControlName=\"navigator-font-family\"\n                      [value]=\"'var(--font-family-headings)'\"\n                    />\n                    <span></span>\n                    <span translate>Match headings font stack</span>\n                  </label>\n                </div>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n  <!-- Cookie banner -->\n  <div class=\"card-block separator-top\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4\n          class=\"text-normal text-right text-left-xs m-b-16\"\n          translate\n        >\n          Cookie banner\n        </h4>\n      </div>\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <fieldset\n          class=\"c8y-fieldset p-24\"\n          [formGroupName]=\"'cookieBanner'\"\n        >\n          <legend translate>Cookie banner</legend>\n          <label class=\"c8y-switch\">\n            <input\n              class=\"form-control\"\n              name=\"cookieBannerEnabled\"\n              type=\"checkbox\"\n              [ngModelOptions]=\"{ standalone: true }\"\n              [ngModel]=\"!formGroup.value.cookieBanner.cookieBannerDisabled\"\n              (ngModelChange)=\"cockieBannerChange($event)\"\n            />\n            <span></span>\n            <span translate>Enable cookie banner</span>\n          </label>\n\n          <div\n            class=\"collapse\"\n            [collapse]=\"formGroup.value.cookieBanner.cookieBannerDisabled\"\n            [isAnimated]=\"true\"\n          >\n            <div\n              class=\"row\"\n              style=\"min-height: 227px\"\n            >\n              <ng-container *ngIf=\"formGroup.value.cookieBanner.cookieBannerDisabled !== true\">\n                <div class=\"col-md-6\">\n                  <c8y-form-group class=\"m-b-32\">\n                    <label\n                      for=\"cookieBannerTitle\"\n                      translate\n                    >\n                      Title\n                    </label>\n                    <input\n                      class=\"form-control\"\n                      id=\"cookieBannerTitle\"\n                      name=\"cookieBannerTitle\"\n                      type=\"text\"\n                      formControlName=\"cookieBannerTitle\"\n                    />\n                    <c8y-messages></c8y-messages>\n                  </c8y-form-group>\n                  <c8y-form-group class=\"m-b-32\">\n                    <label\n                      for=\"policyUrl\"\n                      translate\n                    >\n                      Link to privacy policy\n                    </label>\n                    <input\n                      class=\"form-control\"\n                      id=\"policyUrl\"\n                      name=\"policyUrl\"\n                      type=\"text\"\n                      formControlName=\"policyUrl\"\n                    />\n                    <c8y-messages></c8y-messages>\n                  </c8y-form-group>\n                  <c8y-form-group class=\"m-b-32\">\n                    <label\n                      for=\"policyVersion\"\n                      translate\n                    >\n                      Version of privacy policy\n                    </label>\n                    <input\n                      class=\"form-control\"\n                      id=\"policyVersion\"\n                      name=\"policyVersion\"\n                      type=\"text\"\n                      formControlName=\"policyVersion\"\n                    />\n                    <c8y-messages\n                      [helpMessage]=\"\n                        'Changing the version of the privacy policy invalidates already existing cookie consents.'\n                          | translate\n                      \"\n                    ></c8y-messages>\n                  </c8y-form-group>\n                </div>\n\n                <div class=\"col-md-6\">\n                  <c8y-form-group class=\"m-b-32\">\n                    <label\n                      for=\"cookieBannerText\"\n                      translate\n                    >\n                      Text\n                    </label>\n                    <textarea\n                      class=\"form-control\"\n                      id=\"cookieBannerText\"\n                      name=\"cookieBannerText\"\n                      rows=\"8\"\n                      formControlName=\"cookieBannerText\"\n                    ></textarea>\n                    <c8y-messages></c8y-messages>\n                  </c8y-form-group>\n                </div>\n              </ng-container>\n            </div>\n          </div>\n        </fieldset>\n      </div>\n    </div>\n  </div>\n  <!-- Message banner -->\n  <div class=\"card-block separator-top\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4\n          class=\"text-normal text-right text-left-xs m-b-16\"\n          translate\n        >\n          Message banner\n        </h4>\n      </div>\n\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <fieldset\n          class=\"c8y-fieldset p-24\"\n          [formGroupName]=\"'messageBanner'\"\n        >\n          <legend translate>Message banner</legend>\n\n          <label class=\"c8y-switch\">\n            <input\n              class=\"form-control\"\n              name=\"messageBannerEnabled\"\n              type=\"checkbox\"\n              formControlName=\"messageBannerEnabled\"\n            />\n            <span></span>\n            <span translate>Enable message banner</span>\n          </label>\n          <div\n            class=\"collapse\"\n            [collapse]=\"!formGroup.value.messageBanner.messageBannerEnabled\"\n            [isAnimated]=\"true\"\n          >\n            <div class=\"d-flex a-i-center gap-8 p-t-16 p-b-16\">\n              <fieldset class=\"c8y-fieldset p-16\">\n                <legend>{{ 'Message type' | translate }}</legend>\n                <label\n                  class=\"c8y-radio radio-inline\"\n                  title=\"{{ 'Info' | translate }}\"\n                >\n                  <input\n                    type=\"radio\"\n                    value=\"info\"\n                    formControlName=\"messageBannerType\"\n                  />\n                  <span></span>\n                  <span class=\"d-flex a-i-center\">\n                    <i\n                      class=\"text-info icon-16 m-r-4\"\n                      c8yIcon=\"info-circle\"\n                    ></i>\n                    Info\n                  </span>\n                </label>\n                <label\n                  class=\"c8y-radio radio-inline\"\n                  title=\"{{ 'Warning' | translate }}\"\n                >\n                  <input\n                    type=\"radio\"\n                    value=\"warning\"\n                    formControlName=\"messageBannerType\"\n                  />\n                  <span></span>\n                  <span class=\"d-flex a-i-center\">\n                    <i\n                      class=\"text-warning icon-16 m-r-4\"\n                      c8yIcon=\"warning\"\n                    ></i>\n                    {{ 'Warning' | translate }}\n                  </span>\n                </label>\n                <label\n                  class=\"c8y-radio radio-inline\"\n                  title=\"{{ 'Danger' | translate }}\"\n                >\n                  <input\n                    type=\"radio\"\n                    value=\"danger\"\n                    formControlName=\"messageBannerType\"\n                  />\n                  <span></span>\n                  <span class=\"d-flex a-i-center\">\n                    <i\n                      class=\"text-danger icon-16 m-r-4\"\n                      c8yIcon=\"exclamation-circle\"\n                    ></i>\n                    {{ 'Danger' | translate }}\n                  </span>\n                </label>\n                <label\n                  class=\"c8y-radio radio-inline\"\n                  title=\"{{ 'Success' | translate }}\"\n                >\n                  <input\n                    type=\"radio\"\n                    value=\"success\"\n                    formControlName=\"messageBannerType\"\n                  />\n                  <span></span>\n                  <span class=\"d-flex a-i-center\">\n                    <i\n                      class=\"text-success icon-16 m-r-4\"\n                      c8yIcon=\"check-circle\"\n                    ></i>\n                    {{ 'Success' | translate }}\n                  </span>\n                </label>\n                <label\n                  class=\"c8y-radio radio-inline\"\n                  title=\"{{ 'System' | translate }}\"\n                >\n                  <input\n                    type=\"radio\"\n                    value=\"system\"\n                    formControlName=\"messageBannerType\"\n                  />\n                  <span></span>\n                  <span>\n                    <i\n                      class=\"text-primary icon-16 m-r4\"\n                      c8yIcon=\"wrench\"\n                    ></i>\n                    {{ 'System' | translate }}\n                  </span>\n                </label>\n              </fieldset>\n            </div>\n\n            <c8y-form-group\n              class=\"m-b-32 p-b-32\"\n              [style]=\"{ height: '300px' }\"\n              *ngIf=\"formGroup.value.messageBanner.messageBannerEnabled\"\n            >\n              <label\n                for=\"messageBannerContent\"\n                translate\n              >\n                Message content\n              </label>\n              <c8y-editor\n                class=\"flex-grow form-control\"\n                style=\"height: 100%\"\n                formControlName=\"messageBannerContent\"\n                [editorOptions]=\"{language: 'markdown'}\"\n                monacoEditorMarkerValidator\n              ></c8y-editor>\n              <c8y-messages\n                [helpMessage]=\"messageBannerHelp | translate: messageBannerHelpParams\"\n              ></c8y-messages>\n              <c8y-messages></c8y-messages>\n            </c8y-form-group>\n\n            <button\n              class=\"btn btn-default\"\n              type=\"button\"\n              (click)=\"previewBanner()\"\n            >\n              <i\n                class=\"m-r-4\"\n                c8yIcon=\"eye\"\n              ></i>\n              <span translate>Preview banner</span>\n            </button>\n          </div>\n        </fieldset>\n      </div>\n    </div>\n  </div>\n</div>\n", dependencies: [{ kind: "ngmodule", type: CoreModule }, { kind: "directive", type: i3.IconDirective, selector: "[c8yIcon]", inputs: ["c8yIcon"] }, { kind: "pipe", type: i3.C8yTranslatePipe, name: "translate" }, { kind: "directive", type: i3.C8yTranslateDirective, selector: "[translate],[ngx-translate]" }, { kind: "directive", type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.CheckboxControlValueAccessor, selector: "input[type=checkbox][formControlName],input[type=checkbox][formControl],input[type=checkbox][ngModel]" }, { kind: "directive", type: i2.RadioControlValueAccessor, selector: "input[type=radio][formControlName],input[type=radio][formControl],input[type=radio][ngModel]", inputs: ["name", "formControlName", "value"] }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: i3.FormGroupComponent, selector: "c8y-form-group", inputs: ["hasError", "hasWarning", "hasSuccess", "novalidation", "status"] }, { kind: "component", type: i3.MessagesComponent, selector: "c8y-messages", inputs: ["show", "defaults", "helpMessage"] }, { kind: "directive", type: i3.RequiredInputPlaceholderDirective, selector: "input[required], input[formControlName]" }, { kind: "directive", type: i2.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i2.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "directive", type: i2.FormGroupName, selector: "[formGroupName]", inputs: ["formGroupName"] }, { kind: "ngmodule", type: FormsModule }, { kind: "ngmodule", type: CollapseModule }, { kind: "directive", type: i4$1.CollapseDirective, selector: "[collapse]", inputs: ["display", "isAnimated", "collapse"], outputs: ["collapsed", "collapses", "expanded", "expands"], exportAs: ["bs-collapse"] }, { kind: "component", type: StaticAssetsFilePickerComponent, selector: "c8y-static-assets-file-picker", inputs: ["isCSSURL", "staticAssetType", "supportedFileExtensions", "layout", "size"] }, { kind: "component", type: EditorComponent, selector: "c8y-editor", inputs: ["editorOptions"], outputs: ["editorInit"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BrandingFormComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-branding-form', standalone: true, host: { class: 'd-contents' }, imports: [
                        CoreModule,
                        FormsModule,
                        CollapseModule,
                        StaticAssetsFilePickerComponent,
                        EditorComponent
                    ], template: "<div\n  class=\"inner-scroll\"\n  [formGroup]=\"formGroup\"\n>\n  <!--  Title & Favicon-->\n  <div class=\"card-block\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4 class=\"text-normal text-right text-left-xs m-b-16\">\n          {{ 'Title & favicon' | translate }}\n        </h4>\n      </div>\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <div\n          class=\"row p-t-16 p-b-16\"\n          [formGroupName]=\"'genericApplicationOptions'\"\n        >\n          <div class=\"col-md-6\">\n            <c8y-form-group class=\"m-b-32\">\n              <label\n                for=\"globalTitle\"\n                translate\n              >\n                Title\n              </label>\n              <input\n                class=\"form-control\"\n                id=\"globalTitle\"\n                name=\"globalTitle\"\n                type=\"text\"\n                formControlName=\"globalTitle\"\n              />\n              <c8y-messages\n                [helpMessage]=\"'Title to display in the browser tab' | translate\"\n              ></c8y-messages>\n            </c8y-form-group>\n          </div>\n          <div class=\"col-md-6\">\n            <c8y-form-group>\n              <label translate>Favicon</label>\n              <c8y-static-assets-file-picker\n                name=\"faviconUrl\"\n                [supportedFileExtensions]=\"['ico']\"\n                [isCSSURL]=\"false\"\n                formControlName=\"faviconUrl\"\n              ></c8y-static-assets-file-picker>\n              <c8y-messages [helpMessage]=\"'Supported files: *.ico'\"></c8y-messages>\n            </c8y-form-group>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n\n  <div class=\"card-block separator-top\">\n    <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n      <h4\n        class=\"text-normal text-right text-left-xs m-b-16\"\n        translate\n      >\n        Dark theme\n      </h4>\n    </div>\n    <div class=\"col-xs-12 col-sm-9 col-md-10\">\n      <c8y-form-group class=\"m-b-32 p-t-8 m-t-4\">\n        <label class=\"c8y-switch\">\n          <input\n            class=\"form-control\"\n            name=\"darkThemeAvailable\"\n            type=\"checkbox\"\n            formControlName=\"darkThemeAvailable\"\n          />\n          <span></span>\n          <span translate>Enable dark theme support</span>\n        </label>\n      </c8y-form-group>\n    </div>\n  </div>\n  <!-- Typography -->\n  <div class=\"card-block separator-top\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4\n          class=\"text-normal text-right text-left-xs m-b-16\"\n          translate\n        >\n          Typography\n        </h4>\n      </div>\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <div class=\"row\">\n          <div class=\"col-md-6\">\n            <fieldset\n              class=\"c8y-fieldset p-24\"\n              [formGroupName]=\"'baseTypography'\"\n            >\n              <legend translate>Base typography</legend>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  for=\"font-url\"\n                  translate\n                >\n                  Fonts URL\n                </label>\n                <input\n                  class=\"form-control\"\n                  id=\"font-url\"\n                  placeholder=\"{{\n                    'e.g. {{ example }}' | translate : { example: 'https://fonts.googleapis.com/css?family=Roboto:400,500,700' }\n                  }}\"\n                  type=\"text\"\n                  formControlName=\"font-url\"\n                />\n                <c8y-messages [helpMessage]=\"'The Google fonts URL' | translate\"></c8y-messages>\n              </c8y-form-group>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"font-family-base\"\n                  for=\"font-family-base\"\n                  translate\n                >\n                  Base font stack\n                </label>\n                <input\n                  class=\"form-control\"\n                  id=\"font-family-base\"\n                  placeholder=\"{{ 'e.g. {{ example }}' | translate : {example: '&quot;Roboto&quot;, Arial, sans-serif'} }}\"\n                  name=\"font-family-base\"\n                  type=\"text\"\n                  formControlName=\"font-family-base\"\n                />\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n          <div class=\"col-md-6\">\n            <fieldset\n              class=\"c8y-fieldset p-24\"\n              [formGroupName]=\"'headingsAndNavigatorTypography'\"\n            >\n              <legend>{{ 'Headings & navigator' | translate }}</legend>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"font-family-headings\"\n                  for=\"font-family-headings\"\n                  translate\n                >\n                  Headings font stack\n                </label>\n                <input\n                  class=\"form-control\"\n                  id=\"font-family-headings\"\n                  placeholder=\"{{ 'e.g. {{ example }}' | translate : {example: '&quot;Roboto&quot;, Arial, sans-serif'} }}\"\n                  type=\"text\"\n                  formControlName=\"font-family-headings\"\n                />\n                <c8y-messages\n                  [helpMessage]=\"\n                    'Leave empty to use the same font as the base font stack' | translate\n                  \"\n                ></c8y-messages>\n              </c8y-form-group>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"navigator-font-family\"\n                  translate\n                >\n                  Navigator font stack\n                </label>\n                <div class=\"form-control-static\">\n                  <label class=\"c8y-radio radio-inline\">\n                    <input\n                      name=\"navigator-font-family\"\n                      type=\"radio\"\n                      formControlName=\"navigator-font-family\"\n                      [value]=\"'var(--font-family-base)'\"\n                    />\n                    <span></span>\n                    <span translate>Match base font stack</span>\n                  </label>\n                  <label\n                    class=\"c8y-radio radio-inline\"\n                    title=\"Radio Two\"\n                  >\n                    <input\n                      name=\"navigator-font-family\"\n                      type=\"radio\"\n                      formControlName=\"navigator-font-family\"\n                      [value]=\"'var(--font-family-headings)'\"\n                    />\n                    <span></span>\n                    <span translate>Match headings font stack</span>\n                  </label>\n                </div>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n  <!-- Cookie banner -->\n  <div class=\"card-block separator-top\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4\n          class=\"text-normal text-right text-left-xs m-b-16\"\n          translate\n        >\n          Cookie banner\n        </h4>\n      </div>\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <fieldset\n          class=\"c8y-fieldset p-24\"\n          [formGroupName]=\"'cookieBanner'\"\n        >\n          <legend translate>Cookie banner</legend>\n          <label class=\"c8y-switch\">\n            <input\n              class=\"form-control\"\n              name=\"cookieBannerEnabled\"\n              type=\"checkbox\"\n              [ngModelOptions]=\"{ standalone: true }\"\n              [ngModel]=\"!formGroup.value.cookieBanner.cookieBannerDisabled\"\n              (ngModelChange)=\"cockieBannerChange($event)\"\n            />\n            <span></span>\n            <span translate>Enable cookie banner</span>\n          </label>\n\n          <div\n            class=\"collapse\"\n            [collapse]=\"formGroup.value.cookieBanner.cookieBannerDisabled\"\n            [isAnimated]=\"true\"\n          >\n            <div\n              class=\"row\"\n              style=\"min-height: 227px\"\n            >\n              <ng-container *ngIf=\"formGroup.value.cookieBanner.cookieBannerDisabled !== true\">\n                <div class=\"col-md-6\">\n                  <c8y-form-group class=\"m-b-32\">\n                    <label\n                      for=\"cookieBannerTitle\"\n                      translate\n                    >\n                      Title\n                    </label>\n                    <input\n                      class=\"form-control\"\n                      id=\"cookieBannerTitle\"\n                      name=\"cookieBannerTitle\"\n                      type=\"text\"\n                      formControlName=\"cookieBannerTitle\"\n                    />\n                    <c8y-messages></c8y-messages>\n                  </c8y-form-group>\n                  <c8y-form-group class=\"m-b-32\">\n                    <label\n                      for=\"policyUrl\"\n                      translate\n                    >\n                      Link to privacy policy\n                    </label>\n                    <input\n                      class=\"form-control\"\n                      id=\"policyUrl\"\n                      name=\"policyUrl\"\n                      type=\"text\"\n                      formControlName=\"policyUrl\"\n                    />\n                    <c8y-messages></c8y-messages>\n                  </c8y-form-group>\n                  <c8y-form-group class=\"m-b-32\">\n                    <label\n                      for=\"policyVersion\"\n                      translate\n                    >\n                      Version of privacy policy\n                    </label>\n                    <input\n                      class=\"form-control\"\n                      id=\"policyVersion\"\n                      name=\"policyVersion\"\n                      type=\"text\"\n                      formControlName=\"policyVersion\"\n                    />\n                    <c8y-messages\n                      [helpMessage]=\"\n                        'Changing the version of the privacy policy invalidates already existing cookie consents.'\n                          | translate\n                      \"\n                    ></c8y-messages>\n                  </c8y-form-group>\n                </div>\n\n                <div class=\"col-md-6\">\n                  <c8y-form-group class=\"m-b-32\">\n                    <label\n                      for=\"cookieBannerText\"\n                      translate\n                    >\n                      Text\n                    </label>\n                    <textarea\n                      class=\"form-control\"\n                      id=\"cookieBannerText\"\n                      name=\"cookieBannerText\"\n                      rows=\"8\"\n                      formControlName=\"cookieBannerText\"\n                    ></textarea>\n                    <c8y-messages></c8y-messages>\n                  </c8y-form-group>\n                </div>\n              </ng-container>\n            </div>\n          </div>\n        </fieldset>\n      </div>\n    </div>\n  </div>\n  <!-- Message banner -->\n  <div class=\"card-block separator-top\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4\n          class=\"text-normal text-right text-left-xs m-b-16\"\n          translate\n        >\n          Message banner\n        </h4>\n      </div>\n\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <fieldset\n          class=\"c8y-fieldset p-24\"\n          [formGroupName]=\"'messageBanner'\"\n        >\n          <legend translate>Message banner</legend>\n\n          <label class=\"c8y-switch\">\n            <input\n              class=\"form-control\"\n              name=\"messageBannerEnabled\"\n              type=\"checkbox\"\n              formControlName=\"messageBannerEnabled\"\n            />\n            <span></span>\n            <span translate>Enable message banner</span>\n          </label>\n          <div\n            class=\"collapse\"\n            [collapse]=\"!formGroup.value.messageBanner.messageBannerEnabled\"\n            [isAnimated]=\"true\"\n          >\n            <div class=\"d-flex a-i-center gap-8 p-t-16 p-b-16\">\n              <fieldset class=\"c8y-fieldset p-16\">\n                <legend>{{ 'Message type' | translate }}</legend>\n                <label\n                  class=\"c8y-radio radio-inline\"\n                  title=\"{{ 'Info' | translate }}\"\n                >\n                  <input\n                    type=\"radio\"\n                    value=\"info\"\n                    formControlName=\"messageBannerType\"\n                  />\n                  <span></span>\n                  <span class=\"d-flex a-i-center\">\n                    <i\n                      class=\"text-info icon-16 m-r-4\"\n                      c8yIcon=\"info-circle\"\n                    ></i>\n                    Info\n                  </span>\n                </label>\n                <label\n                  class=\"c8y-radio radio-inline\"\n                  title=\"{{ 'Warning' | translate }}\"\n                >\n                  <input\n                    type=\"radio\"\n                    value=\"warning\"\n                    formControlName=\"messageBannerType\"\n                  />\n                  <span></span>\n                  <span class=\"d-flex a-i-center\">\n                    <i\n                      class=\"text-warning icon-16 m-r-4\"\n                      c8yIcon=\"warning\"\n                    ></i>\n                    {{ 'Warning' | translate }}\n                  </span>\n                </label>\n                <label\n                  class=\"c8y-radio radio-inline\"\n                  title=\"{{ 'Danger' | translate }}\"\n                >\n                  <input\n                    type=\"radio\"\n                    value=\"danger\"\n                    formControlName=\"messageBannerType\"\n                  />\n                  <span></span>\n                  <span class=\"d-flex a-i-center\">\n                    <i\n                      class=\"text-danger icon-16 m-r-4\"\n                      c8yIcon=\"exclamation-circle\"\n                    ></i>\n                    {{ 'Danger' | translate }}\n                  </span>\n                </label>\n                <label\n                  class=\"c8y-radio radio-inline\"\n                  title=\"{{ 'Success' | translate }}\"\n                >\n                  <input\n                    type=\"radio\"\n                    value=\"success\"\n                    formControlName=\"messageBannerType\"\n                  />\n                  <span></span>\n                  <span class=\"d-flex a-i-center\">\n                    <i\n                      class=\"text-success icon-16 m-r-4\"\n                      c8yIcon=\"check-circle\"\n                    ></i>\n                    {{ 'Success' | translate }}\n                  </span>\n                </label>\n                <label\n                  class=\"c8y-radio radio-inline\"\n                  title=\"{{ 'System' | translate }}\"\n                >\n                  <input\n                    type=\"radio\"\n                    value=\"system\"\n                    formControlName=\"messageBannerType\"\n                  />\n                  <span></span>\n                  <span>\n                    <i\n                      class=\"text-primary icon-16 m-r4\"\n                      c8yIcon=\"wrench\"\n                    ></i>\n                    {{ 'System' | translate }}\n                  </span>\n                </label>\n              </fieldset>\n            </div>\n\n            <c8y-form-group\n              class=\"m-b-32 p-b-32\"\n              [style]=\"{ height: '300px' }\"\n              *ngIf=\"formGroup.value.messageBanner.messageBannerEnabled\"\n            >\n              <label\n                for=\"messageBannerContent\"\n                translate\n              >\n                Message content\n              </label>\n              <c8y-editor\n                class=\"flex-grow form-control\"\n                style=\"height: 100%\"\n                formControlName=\"messageBannerContent\"\n                [editorOptions]=\"{language: 'markdown'}\"\n                monacoEditorMarkerValidator\n              ></c8y-editor>\n              <c8y-messages\n                [helpMessage]=\"messageBannerHelp | translate: messageBannerHelpParams\"\n              ></c8y-messages>\n              <c8y-messages></c8y-messages>\n            </c8y-form-group>\n\n            <button\n              class=\"btn btn-default\"\n              type=\"button\"\n              (click)=\"previewBanner()\"\n            >\n              <i\n                class=\"m-r-4\"\n                c8yIcon=\"eye\"\n              ></i>\n              <span translate>Preview banner</span>\n            </button>\n          </div>\n        </fieldset>\n      </div>\n    </div>\n  </div>\n</div>\n" }]
        }], ctorParameters: () => [{ type: i2.FormBuilder }, { type: i3.MessageBannerService }] });

const formStructure = {
    brandColors: {
        label: gettext('Brand colors'),
        brandColors: {
            label: gettext('Brand colors'),
            colors: [
                {
                    label: gettext('Brand primary'),
                    formControlName: 'brand-primary'
                },
                {
                    label: gettext('Brand light'),
                    formControlName: 'brand-light'
                },
                {
                    label: gettext('Brand dark'),
                    formControlName: 'brand-dark'
                }
            ]
        },
        shades: {
            label: gettext('Shades'),
            colorColumn: [
                [
                    {
                        label: 'c8y-brand-10',
                        formControlName: 'c8y-brand-10'
                    },
                    {
                        label: 'c8y-brand-20',
                        formControlName: 'c8y-brand-20'
                    },
                    {
                        label: 'c8y-brand-30',
                        formControlName: 'c8y-brand-30'
                    },
                    {
                        label: 'c8y-brand-40',
                        formControlName: 'c8y-brand-40'
                    }
                ],
                [
                    {
                        label: 'c8y-brand-50',
                        formControlName: 'c8y-brand-50'
                    },
                    {
                        label: 'c8y-brand-60',
                        formControlName: 'c8y-brand-60'
                    },
                    {
                        label: 'c8y-brand-70',
                        formControlName: 'c8y-brand-70'
                    },
                    {
                        label: 'c8y-brand-80',
                        formControlName: 'c8y-brand-80'
                    }
                ]
            ]
        }
    },
    statusColors: {
        label: gettext('Status colors'),
        subCategories: [
            {
                label: gettext('Info colors'),
                colors: [
                    {
                        label: gettext('Info'),
                        formControlName: 'palette-status-info'
                    },
                    {
                        label: gettext('Info light'),
                        formControlName: 'palette-status-info-light'
                    },
                    {
                        label: gettext('Info dark'),
                        formControlName: 'palette-status-info-dark'
                    }
                ]
            },
            {
                label: gettext('Warning colors'),
                colors: [
                    {
                        label: gettext('Warning'),
                        formControlName: 'palette-status-warning'
                    },
                    {
                        label: gettext('Warning light'),
                        formControlName: 'palette-status-warning-light'
                    },
                    {
                        label: gettext('Warning dark'),
                        formControlName: 'palette-status-warning-dark'
                    }
                ]
            },
            {
                label: gettext('Danger colors'),
                colors: [
                    {
                        label: gettext('Danger'),
                        formControlName: 'palette-status-danger'
                    },
                    {
                        label: gettext('Danger light'),
                        formControlName: 'palette-status-danger-light'
                    },
                    {
                        label: gettext('Danger dark'),
                        formControlName: 'palette-status-danger-dark'
                    }
                ]
            },
            {
                label: gettext('Success colors'),
                colors: [
                    {
                        label: gettext('Success'),
                        formControlName: 'palette-status-success'
                    },
                    {
                        label: gettext('Success light'),
                        formControlName: 'palette-status-success-light'
                    },
                    {
                        label: gettext('Success dark'),
                        formControlName: 'palette-status-success-dark'
                    }
                ]
            }
        ]
    },
    actionBar: {
        label: gettext('Action bar'),
        colorColumns: [
            {
                label: gettext('Action bar'),
                colorColumns: [
                    [
                        {
                            label: gettext('Background color'),
                            formControlName: 'action-bar-background-default'
                        },
                        {
                            label: gettext('Text color'),
                            formControlName: 'action-bar-color-default'
                        },
                        {
                            label: gettext('Icon color'),
                            formControlName: 'action-bar-icon-color'
                        }
                    ],
                    [
                        {
                            label: gettext('Button color'),
                            formControlName: 'action-bar-color-actions'
                        },
                        {
                            label: gettext('Button hover color'),
                            formControlName: 'action-bar-color-actions-hover'
                        }
                    ]
                ]
            }
        ]
    },
    mainHeader: {
        label: gettext('Main header'),
        colorColumns: [
            {
                label: gettext('Main header'),
                colorColumns: [
                    [
                        {
                            label: gettext('Background color'),
                            formControlName: 'header-color'
                        },
                        {
                            label: gettext('Text color'),
                            formControlName: 'header-text-color'
                        }
                    ],
                    [
                        {
                            label: gettext('Button hover color'),
                            formControlName: 'header-hover-color'
                        }
                    ]
                ]
            }
        ]
    },
    navigator: {
        label: gettext('Navigator'),
        colorColumns: [
            {
                label: gettext('Navigation'),
                colors: [
                    {
                        label: gettext('Background color'),
                        formControlName: 'navigator-bg-color'
                    },
                    {
                        label: gettext('Text color'),
                        formControlName: 'navigator-text-color'
                    },
                    {
                        label: gettext('Separator color'),
                        formControlName: 'navigator-separator-color'
                    }
                ]
            },
            {
                label: gettext('Header'),
                colors: [
                    {
                        label: gettext('Header background color'),
                        formControlName: 'navigator-header-bg'
                    },
                    {
                        label: gettext('Title color'),
                        formControlName: 'navigator-title-color'
                    }
                ]
            },
            {
                label: gettext('Active node'),
                colors: [
                    {
                        label: gettext('Active background color'),
                        formControlName: 'navigator-active-bg'
                    },
                    {
                        label: gettext('Active border color'),
                        formControlName: 'navigator-border-active'
                    },
                    {
                        label: gettext('Active text color'),
                        formControlName: 'navigator-color-active'
                    }
                ]
            }
        ]
    },
    rightDrawer: {
        label: gettext('Right drawer'),
        colorColumns: [
            {
                label: gettext('Panel'),
                colors: [
                    {
                        label: gettext('Background color'),
                        formControlName: 'right-drawer-background-default'
                    },
                    {
                        label: gettext('Text color'),
                        formControlName: 'right-drawer-text-color-default'
                    },
                    {
                        label: gettext('Text muted color'),
                        formControlName: 'right-drawer-text-muted'
                    },
                    {
                        label: gettext('Separator color'),
                        formControlName: 'right-drawer-separator-color'
                    }
                ]
            },
            {
                label: gettext('Interactive'),
                colors: [
                    {
                        label: gettext('Link color'),
                        formControlName: 'right-drawer-link-color'
                    },
                    {
                        label: gettext('Link hover color'),
                        formControlName: 'right-drawer-link-color-hover'
                    }
                ]
            }
        ]
    }
};

class BrandingThemeFormComponent {
    constructor(activatedRoute, formBuilder, filesService, brandingShades, themeSwitcher) {
        this.activatedRoute = activatedRoute;
        this.formBuilder = formBuilder;
        this.filesService = filesService;
        this.brandingShades = brandingShades;
        this.themeSwitcher = themeSwitcher;
        this.formStructure = formStructure;
        this.externalValue = {};
        this.addDarkThemePrefix = false;
        this.varsToConvertToHeight = [
            'navigator-platform-logo-height',
            'dark-navigator-platform-logo-height'
        ];
        this.addDarkThemePrefix = !!this.activatedRoute.snapshot.data.dark;
        this.themeSwitcher.temporaryChangeTheme(this.addDarkThemePrefix ? 'dark' : 'light');
        this.formGroup = this.initForm();
        this.formGroupValueChanges$ = this.formGroup.valueChanges.pipe(takeUntilDestroyed());
        this.imageFileExtensions = this.filesService
            .mapGenericFileTypesToExtensions([GENERIC_FILE_TYPE.IMAGE])
            .filter(ext => ext !== 'ico');
        const hasCustomShades$ = merge(this.formGroup.valueChanges, defer(() => of(this.formGroup.value))).pipe(takeUntilDestroyed(), map(tmp => this.brandingShades.hasCustomShadesSet(tmp['brand-primary'], tmp)), distinctUntilChanged());
        this.resetShadesButtonEnabled$ = merge(defer(() => of(this.formGroup.controls['brand-primary'].status)), this.formGroup.controls['brand-primary'].statusChanges).pipe(
        // statusChanges emits 'PENDING' when the form control is async validating
        // https://github.com/angular/angular/issues/41519
        switchMap(status => {
            if (status === 'PENDING') {
                return interval(200).pipe(map(() => this.formGroup.controls['brand-primary'].status), filter(stat => stat !== 'PENDING'), take(1), startWith(status));
            }
            return of(status);
        }), switchMap(status => {
            if (status !== 'VALID') {
                return of(false);
            }
            return hasCustomShades$;
        }));
        const brandPrimaryFormControl = this.formGroup.controls['brand-primary'];
        brandPrimaryFormControl.valueChanges
            .pipe(filter(color => this.brandingShades.isValidShadeColor(color)), takeUntilDestroyed(), distinctUntilChanged(), pairwise(), delay(5))
            .subscribe(([prev, curr]) => {
            try {
                if (!this.brandingShades.hasCustomShadesSet(prev, this.formGroup.value)) {
                    this.regenerateShadesBasedOnPrimaryColor(curr);
                }
            }
            catch (e) {
                console.log(e);
            }
        });
    }
    ngOnDestroy() {
        this.themeSwitcher.resetTemporaryTheme();
    }
    regenerateShadesBasedOnPrimaryColor(color) {
        const newShades = this.brandingShades.getShadeColorBrandingCssVars(color || this.formGroup.value['brand-primary']);
        this.formGroup.patchValue(newShades);
    }
    writeValue(obj) {
        try {
            const parsedObj = JSON.parse(obj);
            this.externalValue = parsedObj;
            this.applyStateToForm(parsedObj);
        }
        catch (e) {
            // failed to parse
        }
    }
    registerOnChange(fn) {
        this.formGroupValueChanges$.subscribe(value => fn(this.convertFormToState(value)));
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    onBlur() {
        this.onTouched();
    }
    initForm() {
        return createBrandingForm(this.formBuilder);
    }
    applyStateToForm(branding) {
        if (!branding) {
            return;
        }
        const toBePatched = {};
        const prefix = this.getPrefix();
        Object.entries(branding.brandingCssVars || {}).forEach(([key, value]) => {
            if (prefix && !key.startsWith(prefix)) {
                return;
            }
            const keyInForm = key.replace(prefix, '');
            if (this.varsToConvertToHeight.includes(keyInForm) && typeof value === 'string') {
                toBePatched[keyInForm] = Number.parseInt(value.replace(/[a-zA-Z%]/, '') || '0');
                return;
            }
            toBePatched[keyInForm] = value;
        });
        this.formGroup.patchValue(toBePatched);
    }
    convertFormToState(value) {
        const prefixedBrandingCssVars = {};
        const prefix = this.getPrefix();
        Object.entries(value).forEach(([key, value]) => {
            prefixedBrandingCssVars[`${prefix}${key}`] = value;
        });
        const externalValue = cloneDeep(this.externalValue || {});
        const currentCSSVars = externalValue['brandingCssVars'] || {};
        const assignedNewValues = Object.assign(currentCSSVars, prefixedBrandingCssVars);
        for (const key of this.varsToConvertToHeight) {
            const value = assignedNewValues[key];
            if (typeof value === 'number') {
                assignedNewValues[key] += 'px';
            }
        }
        externalValue['brandingCssVars'] = assignedNewValues;
        return JSON.stringify(externalValue, null, 2);
    }
    getPrefix() {
        return this.addDarkThemePrefix ? 'dark-' : '';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BrandingThemeFormComponent, deps: [{ token: i2$1.ActivatedRoute }, { token: i2.FormBuilder }, { token: i3.FilesService }, { token: i1$2.BrandingShadesService }, { token: i3.ThemeSwitcherService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: BrandingThemeFormComponent, isStandalone: true, selector: "c8y-branding-theme-form", host: { classAttribute: "d-contents" }, ngImport: i0, template: "<div\n  class=\"inner-scroll\"\n  [formGroup]=\"formGroup\"\n>\n  <!--   Logos -->\n  <div class=\"card-block\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4\n          class=\"text-normal text-right text-left-xs m-b-16\"\n          translate\n        >\n          Logos\n        </h4>\n      </div>\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <div class=\"row\">\n          <div class=\"col-md-6\">\n            <fieldset class=\"c8y-fieldset p-24\">\n              <legend translate>Brand logo</legend>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"brand-logo-img\"\n                  translate\n                >\n                  Brand logo file\n                </label>\n                <c8y-static-assets-file-picker\n                  name=\"brand-logo-img\"\n                  [supportedFileExtensions]=\"imageFileExtensions\"\n                  [isCSSURL]=\"true\"\n                  size=\"150\"\n                  formControlName=\"brand-logo-img\"\n                ></c8y-static-assets-file-picker>\n                <c8y-messages [helpMessage]=\"'Supported files: *.png, *.svg, *.jpg'\"></c8y-messages>\n              </c8y-form-group>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"brand-logo-img-height\"\n                  for=\"brand-logo-img-height\"\n                  translate\n                >\n                  Brand logo height\n                </label>\n                <input\n                  class=\"form-control\"\n                  id=\"brand-logo-img-height\"\n                  placeholder=\"{{ 'e.g. {{ example }}' | translate: { example: '50' } }}\"\n                  name=\"brand-logo-img-height\"\n                  type=\"number\"\n                  formControlName=\"brand-logo-img-height\"\n                />\n                <c8y-messages [helpMessage]=\"'Value is applied in px'\"></c8y-messages>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n          <div class=\"col-md-6\">\n            <fieldset class=\"c8y-fieldset p-24\">\n              <legend translate>Navigator logo</legend>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"navigator-platform-logo\"\n                  translate\n                >\n                  Navigator logo file\n                </label>\n                <c8y-static-assets-file-picker\n                  name=\"navigator-platform-logo\"\n                  [supportedFileExtensions]=\"imageFileExtensions\"\n                  [isCSSURL]=\"true\"\n                  size=\"150\"\n                  formControlName=\"navigator-platform-logo\"\n                ></c8y-static-assets-file-picker>\n                <c8y-messages [helpMessage]=\"'Supported files: *.png, *.svg, *.jpg'\"></c8y-messages>\n              </c8y-form-group>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"navigator-platform-logo-height\"\n                  for=\"navigator-platform-logo-height\"\n                  translate\n                >\n                  Navigator logo height\n                </label>\n                <input\n                  class=\"form-control\"\n                  id=\"navigator-platform-logo-height\"\n                  placeholder=\"{{ 'e.g. {{ example }}' | translate: { example: '50' } }}\"\n                  name=\"navigator-platform-logo-height\"\n                  type=\"number\"\n                  formControlName=\"navigator-platform-logo-height\"\n                />\n                <c8y-messages [helpMessage]=\"'Value is applied in px'\"></c8y-messages>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n  <!--  Brand colors -->\n  <div class=\"card-block separator-top\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4\n          class=\"text-normal text-right text-left-xs m-b-16\"\n        >\n          {{ formStructure.brandColors.label | translate}}\n        </h4>\n      </div>\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <div class=\"row\">\n          <div class=\"col-md-4\">\n            <fieldset class=\"c8y-fieldset p-24\">\n              <legend>{{ formStructure.brandColors.brandColors.label | translate}}</legend>\n              <c8y-form-group class=\"m-b-32\" *ngFor=\"let color of formStructure.brandColors.brandColors.colors\">\n                <label\n                  [title]=\"color.formControlName\"\n                  [for]=\"color.formControlName\"\n                >\n                  {{ color.label | translate }}\n                </label>\n                <c8y-color-input\n                  [attr.data-cy]=\"'branding-theme-form-color-input-' + color.formControlName\"\n                  [formControlName]=\"color.formControlName\"\n                ></c8y-color-input>\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n          <div class=\"col-md-8\">\n            <fieldset class=\"c8y-fieldset p-24\">\n              <legend>{{ formStructure.brandColors.shades.label | translate }}</legend>\n              <div class=\"row\">\n                <div class=\"col-md-6\" *ngFor=\"let colorColumn of formStructure.brandColors.shades.colorColumn\">\n                  <c8y-form-group class=\"m-b-32\" *ngFor=\"let color of colorColumn\">\n                    <label\n                      [title]=\"color.formControlName\"\n                      [for]=\"color.formControlName\"\n                    >\n                      {{ color.label | translate }}\n                    </label>\n                    <c8y-color-input\n                      [attr.data-cy]=\"'branding-theme-form-color-input-' + color.formControlName\"\n                      [formControlName]=\"color.formControlName\"\n                    ></c8y-color-input>\n                    <c8y-messages></c8y-messages>\n                  </c8y-form-group>\n                </div>\n              </div>\n              <button\n                class=\"btn btn-default btn-sm\"\n                type=\"button\"\n                data-cy=\"branding-reset-shades-button\"\n                (click)=\"regenerateShadesBasedOnPrimaryColor()\"\n                [disabled]=\"!(resetShadesButtonEnabled$ | async)\"\n              >\n                <i [c8yIcon]=\"'reset'\"></i>\n                <span translate>Reset shades</span>\n              </button>\n            </fieldset>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n  <!-- Status colors -->\n  <div class=\"card-block separator-top\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4\n          class=\"text-normal text-right text-left-xs m-b-16\"\n        >\n          {{ formStructure.statusColors.label | translate }}\n        </h4>\n      </div>\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <div class=\"row\">\n          <div class=\"col-md-6\" *ngFor=\"let subCategory of formStructure.statusColors.subCategories\">\n            <fieldset class=\"c8y-fieldset p-24\">\n              <legend>{{ subCategory.label | translate }}</legend>\n              <c8y-form-group class=\"m-b-32\" *ngFor=\"let color of subCategory.colors\">\n                <label\n                  [title]=\"color.formControlName\"\n                  [for]=\"color.formControlName\"\n                >\n                  {{ color.label | translate }}\n                </label>\n                <c8y-color-input\n                  [attr.data-cy]=\"'branding-theme-form-color-input-' + color.formControlName\"\n                  [formControlName]=\"color.formControlName\"\n                ></c8y-color-input>\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n  <!-- Generic -->\n  <div class=\"card-block separator-top\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4\n          class=\"text-normal text-right text-left-xs m-b-16\"\n          translate\n        >\n          Generic\n        </h4>\n      </div>\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <div class=\"row\">\n          <div class=\"col-md-6\">\n            <fieldset class=\"c8y-fieldset p-24\">\n              <legend translate>Generic colors</legend>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"body-background-color\"\n                  for=\"body-background-color\"\n                  translate\n                >\n                  Body background color\n                </label>\n                <c8y-color-input\n                  name=\"body-background-color\"\n                  formControlName=\"body-background-color\"\n                ></c8y-color-input>\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"text-color\"\n                  for=\"text-color\"\n                  translate\n                >\n                  Text color\n                </label>\n                <c8y-color-input\n                  name=\"text-color\"\n                  formControlName=\"text-color\"\n                ></c8y-color-input>\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"text-muted\"\n                  for=\"text-muted\"\n                  translate\n                >\n                  Text muted color\n                </label>\n                <c8y-color-input\n                  name=\"text-muted\"\n                  formControlName=\"text-muted\"\n                ></c8y-color-input>\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n          <div class=\"col-md-6\">\n            <fieldset class=\"c8y-fieldset p-24\">\n              <legend translate>Interactive</legend>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"link-color\"\n                  for=\"link-color\"\n                  translate\n                >\n                  Link color\n                </label>\n                <c8y-color-input\n                  name=\"link-color\"\n                  formControlName=\"link-color\"\n                ></c8y-color-input>\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"link-hover-color\"\n                  for=\"link-hover-color\"\n                  translate\n                >\n                  Link hover color\n                </label>\n                <c8y-color-input\n                  name=\"link-hover-color\"\n                  formControlName=\"link-hover-color\"\n                ></c8y-color-input>\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"btn-border-radius-base\"\n                  for=\"btn-border-radius-base\"\n                  translate\n                >\n                  Button border-radius\n                </label>\n                <input\n                  class=\"form-control\"\n                  placeholder=\"{{ 'e.g. 4' | translate }}\"\n                  name=\"btn-border-radius-base\"\n                  type=\"number\"\n                  formControlName=\"btn-border-radius-base\"\n                />\n                <c8y-messages [helpMessage]=\"'Value is applied in px'\"></c8y-messages>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n  <!-- Action bar -->\n  <div class=\"card-block separator-top\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4\n          class=\"text-normal text-right text-left-xs m-b-16\"\n        >\n          {{ formStructure.actionBar.label | translate }}\n        </h4>\n      </div>\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <fieldset class=\"c8y-fieldset p-24\" *ngFor=\"let colorColumn of formStructure.actionBar.colorColumns\">\n          <legend>{{ colorColumn.label | translate }}</legend>\n          <div class=\"row\">\n            <div class=\"col-md-6\" *ngFor=\"let subColorColumn of colorColumn.colorColumns\">\n              <c8y-form-group class=\"m-b-32\" *ngFor=\"let color of subColorColumn\">\n                <label\n                  [title]=\"color.formControlName\"\n                  [for]=\"color.formControlName\"\n                >\n                  {{ color.label | translate }}\n                </label>\n                <c8y-color-input\n                  [attr.data-cy]=\"'branding-theme-form-color-input-' + color.formControlName\"\n                  [formControlName]=\"color.formControlName\"\n                ></c8y-color-input>\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n            </div>\n          </div>\n        </fieldset>\n      </div>\n    </div>\n  </div>\n  <!-- Main header -->\n  <div class=\"card-block separator-top\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4\n          class=\"text-normal text-right text-left-xs m-b-16\"\n        >\n          {{ formStructure.mainHeader.label | translate }}\n        </h4>\n      </div>\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <fieldset class=\"c8y-fieldset p-24\" *ngFor=\"let colorColumn of formStructure.mainHeader.colorColumns\">\n          <legend>{{ colorColumn.label | translate }}</legend>\n          <div class=\"row\">\n            <div class=\"col-md-6\" *ngFor=\"let subColorColumn of colorColumn.colorColumns\">\n              <c8y-form-group class=\"m-b-32\" *ngFor=\"let color of subColorColumn\">\n                <label\n                  [title]=\"color.formControlName\"\n                  [for]=\"color.formControlName\"\n                >\n                  {{ color.label | translate }}\n                </label>\n                <c8y-color-input\n                  [attr.data-cy]=\"'branding-theme-form-color-input-' + color.formControlName\"\n                  [formControlName]=\"color.formControlName\"\n                ></c8y-color-input>\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n            </div>\n          </div>\n        </fieldset>\n      </div>\n    </div>\n  </div>\n  <!-- Navigator -->\n  <div class=\"card-block separator-top\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4\n          class=\"text-normal text-right text-left-xs m-b-16\"\n        >\n          {{ formStructure.navigator.label }}\n        </h4>\n      </div>\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <div class=\"row\">\n          <div class=\"col-md-4\" *ngFor=\"let colorColumn of formStructure.navigator.colorColumns\">\n            <fieldset class=\"c8y-fieldset p-24\">\n              <legend>{{ colorColumn.label | translate }}</legend>\n              <c8y-form-group class=\"m-b-32\" *ngFor=\"let color of colorColumn.colors\">\n                <label\n                  [title]=\"color.formControlName\"\n                  [for]=\"color.formControlName\"\n                >\n                  {{ color.label | translate }}\n                </label>\n                <c8y-color-input\n                  [attr.data-cy]=\"'branding-theme-form-color-input-' + color.formControlName\"\n                  [formControlName]=\"color.formControlName\"\n                ></c8y-color-input>\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n  <!-- Right drawer -->\n  <div class=\"card-block separator-top\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4\n          class=\"text-normal text-right text-left-xs m-b-16\"\n        >\n          {{ formStructure.rightDrawer.label | translate }}\n        </h4>\n      </div>\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <div class=\"row\">\n          <div class=\"col-md-6\" *ngFor=\"let colorColumn of formStructure.rightDrawer.colorColumns\">\n            <fieldset class=\"c8y-fieldset p-24\">\n              <legend>{{ colorColumn.label | translate }}</legend>\n              <c8y-form-group class=\"m-b-32\" *ngFor=\"let color of colorColumn.colors\">\n                <label\n                  [title]=\"color.formControlName\"\n                  [for]=\"color.formControlName\"\n                >\n                  {{ color.label | translate }}\n                </label>\n                <c8y-color-input\n                  [attr.data-cy]=\"'branding-theme-form-color-input-' + color.formControlName\"\n                  [formControlName]=\"color.formControlName\"\n                ></c8y-color-input>\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n</div>\n", dependencies: [{ kind: "ngmodule", type: CoreModule }, { kind: "directive", type: i3.IconDirective, selector: "[c8yIcon]", inputs: ["c8yIcon"] }, { kind: "pipe", type: i3.C8yTranslatePipe, name: "translate" }, { kind: "directive", type: i3.C8yTranslateDirective, selector: "[translate],[ngx-translate]" }, { kind: "directive", type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "pipe", type: i4.AsyncPipe, name: "async" }, { kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.NumberValueAccessor, selector: "input[type=number][formControlName],input[type=number][formControl],input[type=number][ngModel]" }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "component", type: i3.FormGroupComponent, selector: "c8y-form-group", inputs: ["hasError", "hasWarning", "hasSuccess", "novalidation", "status"] }, { kind: "component", type: i3.MessagesComponent, selector: "c8y-messages", inputs: ["show", "defaults", "helpMessage"] }, { kind: "directive", type: i3.RequiredInputPlaceholderDirective, selector: "input[required], input[formControlName]" }, { kind: "directive", type: i2.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i2.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "component", type: i3.ColorInputComponent, selector: "c8y-color-input" }, { kind: "ngmodule", type: FormsModule }, { kind: "component", type: StaticAssetsFilePickerComponent, selector: "c8y-static-assets-file-picker", inputs: ["isCSSURL", "staticAssetType", "supportedFileExtensions", "layout", "size"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BrandingThemeFormComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-branding-theme-form', standalone: true, host: { class: 'd-contents' }, imports: [CoreModule, FormsModule, StaticAssetsFilePickerComponent, ColorInputComponent], template: "<div\n  class=\"inner-scroll\"\n  [formGroup]=\"formGroup\"\n>\n  <!--   Logos -->\n  <div class=\"card-block\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4\n          class=\"text-normal text-right text-left-xs m-b-16\"\n          translate\n        >\n          Logos\n        </h4>\n      </div>\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <div class=\"row\">\n          <div class=\"col-md-6\">\n            <fieldset class=\"c8y-fieldset p-24\">\n              <legend translate>Brand logo</legend>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"brand-logo-img\"\n                  translate\n                >\n                  Brand logo file\n                </label>\n                <c8y-static-assets-file-picker\n                  name=\"brand-logo-img\"\n                  [supportedFileExtensions]=\"imageFileExtensions\"\n                  [isCSSURL]=\"true\"\n                  size=\"150\"\n                  formControlName=\"brand-logo-img\"\n                ></c8y-static-assets-file-picker>\n                <c8y-messages [helpMessage]=\"'Supported files: *.png, *.svg, *.jpg'\"></c8y-messages>\n              </c8y-form-group>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"brand-logo-img-height\"\n                  for=\"brand-logo-img-height\"\n                  translate\n                >\n                  Brand logo height\n                </label>\n                <input\n                  class=\"form-control\"\n                  id=\"brand-logo-img-height\"\n                  placeholder=\"{{ 'e.g. {{ example }}' | translate: { example: '50' } }}\"\n                  name=\"brand-logo-img-height\"\n                  type=\"number\"\n                  formControlName=\"brand-logo-img-height\"\n                />\n                <c8y-messages [helpMessage]=\"'Value is applied in px'\"></c8y-messages>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n          <div class=\"col-md-6\">\n            <fieldset class=\"c8y-fieldset p-24\">\n              <legend translate>Navigator logo</legend>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"navigator-platform-logo\"\n                  translate\n                >\n                  Navigator logo file\n                </label>\n                <c8y-static-assets-file-picker\n                  name=\"navigator-platform-logo\"\n                  [supportedFileExtensions]=\"imageFileExtensions\"\n                  [isCSSURL]=\"true\"\n                  size=\"150\"\n                  formControlName=\"navigator-platform-logo\"\n                ></c8y-static-assets-file-picker>\n                <c8y-messages [helpMessage]=\"'Supported files: *.png, *.svg, *.jpg'\"></c8y-messages>\n              </c8y-form-group>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"navigator-platform-logo-height\"\n                  for=\"navigator-platform-logo-height\"\n                  translate\n                >\n                  Navigator logo height\n                </label>\n                <input\n                  class=\"form-control\"\n                  id=\"navigator-platform-logo-height\"\n                  placeholder=\"{{ 'e.g. {{ example }}' | translate: { example: '50' } }}\"\n                  name=\"navigator-platform-logo-height\"\n                  type=\"number\"\n                  formControlName=\"navigator-platform-logo-height\"\n                />\n                <c8y-messages [helpMessage]=\"'Value is applied in px'\"></c8y-messages>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n  <!--  Brand colors -->\n  <div class=\"card-block separator-top\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4\n          class=\"text-normal text-right text-left-xs m-b-16\"\n        >\n          {{ formStructure.brandColors.label | translate}}\n        </h4>\n      </div>\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <div class=\"row\">\n          <div class=\"col-md-4\">\n            <fieldset class=\"c8y-fieldset p-24\">\n              <legend>{{ formStructure.brandColors.brandColors.label | translate}}</legend>\n              <c8y-form-group class=\"m-b-32\" *ngFor=\"let color of formStructure.brandColors.brandColors.colors\">\n                <label\n                  [title]=\"color.formControlName\"\n                  [for]=\"color.formControlName\"\n                >\n                  {{ color.label | translate }}\n                </label>\n                <c8y-color-input\n                  [attr.data-cy]=\"'branding-theme-form-color-input-' + color.formControlName\"\n                  [formControlName]=\"color.formControlName\"\n                ></c8y-color-input>\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n          <div class=\"col-md-8\">\n            <fieldset class=\"c8y-fieldset p-24\">\n              <legend>{{ formStructure.brandColors.shades.label | translate }}</legend>\n              <div class=\"row\">\n                <div class=\"col-md-6\" *ngFor=\"let colorColumn of formStructure.brandColors.shades.colorColumn\">\n                  <c8y-form-group class=\"m-b-32\" *ngFor=\"let color of colorColumn\">\n                    <label\n                      [title]=\"color.formControlName\"\n                      [for]=\"color.formControlName\"\n                    >\n                      {{ color.label | translate }}\n                    </label>\n                    <c8y-color-input\n                      [attr.data-cy]=\"'branding-theme-form-color-input-' + color.formControlName\"\n                      [formControlName]=\"color.formControlName\"\n                    ></c8y-color-input>\n                    <c8y-messages></c8y-messages>\n                  </c8y-form-group>\n                </div>\n              </div>\n              <button\n                class=\"btn btn-default btn-sm\"\n                type=\"button\"\n                data-cy=\"branding-reset-shades-button\"\n                (click)=\"regenerateShadesBasedOnPrimaryColor()\"\n                [disabled]=\"!(resetShadesButtonEnabled$ | async)\"\n              >\n                <i [c8yIcon]=\"'reset'\"></i>\n                <span translate>Reset shades</span>\n              </button>\n            </fieldset>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n  <!-- Status colors -->\n  <div class=\"card-block separator-top\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4\n          class=\"text-normal text-right text-left-xs m-b-16\"\n        >\n          {{ formStructure.statusColors.label | translate }}\n        </h4>\n      </div>\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <div class=\"row\">\n          <div class=\"col-md-6\" *ngFor=\"let subCategory of formStructure.statusColors.subCategories\">\n            <fieldset class=\"c8y-fieldset p-24\">\n              <legend>{{ subCategory.label | translate }}</legend>\n              <c8y-form-group class=\"m-b-32\" *ngFor=\"let color of subCategory.colors\">\n                <label\n                  [title]=\"color.formControlName\"\n                  [for]=\"color.formControlName\"\n                >\n                  {{ color.label | translate }}\n                </label>\n                <c8y-color-input\n                  [attr.data-cy]=\"'branding-theme-form-color-input-' + color.formControlName\"\n                  [formControlName]=\"color.formControlName\"\n                ></c8y-color-input>\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n  <!-- Generic -->\n  <div class=\"card-block separator-top\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4\n          class=\"text-normal text-right text-left-xs m-b-16\"\n          translate\n        >\n          Generic\n        </h4>\n      </div>\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <div class=\"row\">\n          <div class=\"col-md-6\">\n            <fieldset class=\"c8y-fieldset p-24\">\n              <legend translate>Generic colors</legend>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"body-background-color\"\n                  for=\"body-background-color\"\n                  translate\n                >\n                  Body background color\n                </label>\n                <c8y-color-input\n                  name=\"body-background-color\"\n                  formControlName=\"body-background-color\"\n                ></c8y-color-input>\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"text-color\"\n                  for=\"text-color\"\n                  translate\n                >\n                  Text color\n                </label>\n                <c8y-color-input\n                  name=\"text-color\"\n                  formControlName=\"text-color\"\n                ></c8y-color-input>\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"text-muted\"\n                  for=\"text-muted\"\n                  translate\n                >\n                  Text muted color\n                </label>\n                <c8y-color-input\n                  name=\"text-muted\"\n                  formControlName=\"text-muted\"\n                ></c8y-color-input>\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n          <div class=\"col-md-6\">\n            <fieldset class=\"c8y-fieldset p-24\">\n              <legend translate>Interactive</legend>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"link-color\"\n                  for=\"link-color\"\n                  translate\n                >\n                  Link color\n                </label>\n                <c8y-color-input\n                  name=\"link-color\"\n                  formControlName=\"link-color\"\n                ></c8y-color-input>\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"link-hover-color\"\n                  for=\"link-hover-color\"\n                  translate\n                >\n                  Link hover color\n                </label>\n                <c8y-color-input\n                  name=\"link-hover-color\"\n                  formControlName=\"link-hover-color\"\n                ></c8y-color-input>\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n              <c8y-form-group class=\"m-b-32\">\n                <label\n                  title=\"btn-border-radius-base\"\n                  for=\"btn-border-radius-base\"\n                  translate\n                >\n                  Button border-radius\n                </label>\n                <input\n                  class=\"form-control\"\n                  placeholder=\"{{ 'e.g. 4' | translate }}\"\n                  name=\"btn-border-radius-base\"\n                  type=\"number\"\n                  formControlName=\"btn-border-radius-base\"\n                />\n                <c8y-messages [helpMessage]=\"'Value is applied in px'\"></c8y-messages>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n  <!-- Action bar -->\n  <div class=\"card-block separator-top\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4\n          class=\"text-normal text-right text-left-xs m-b-16\"\n        >\n          {{ formStructure.actionBar.label | translate }}\n        </h4>\n      </div>\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <fieldset class=\"c8y-fieldset p-24\" *ngFor=\"let colorColumn of formStructure.actionBar.colorColumns\">\n          <legend>{{ colorColumn.label | translate }}</legend>\n          <div class=\"row\">\n            <div class=\"col-md-6\" *ngFor=\"let subColorColumn of colorColumn.colorColumns\">\n              <c8y-form-group class=\"m-b-32\" *ngFor=\"let color of subColorColumn\">\n                <label\n                  [title]=\"color.formControlName\"\n                  [for]=\"color.formControlName\"\n                >\n                  {{ color.label | translate }}\n                </label>\n                <c8y-color-input\n                  [attr.data-cy]=\"'branding-theme-form-color-input-' + color.formControlName\"\n                  [formControlName]=\"color.formControlName\"\n                ></c8y-color-input>\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n            </div>\n          </div>\n        </fieldset>\n      </div>\n    </div>\n  </div>\n  <!-- Main header -->\n  <div class=\"card-block separator-top\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4\n          class=\"text-normal text-right text-left-xs m-b-16\"\n        >\n          {{ formStructure.mainHeader.label | translate }}\n        </h4>\n      </div>\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <fieldset class=\"c8y-fieldset p-24\" *ngFor=\"let colorColumn of formStructure.mainHeader.colorColumns\">\n          <legend>{{ colorColumn.label | translate }}</legend>\n          <div class=\"row\">\n            <div class=\"col-md-6\" *ngFor=\"let subColorColumn of colorColumn.colorColumns\">\n              <c8y-form-group class=\"m-b-32\" *ngFor=\"let color of subColorColumn\">\n                <label\n                  [title]=\"color.formControlName\"\n                  [for]=\"color.formControlName\"\n                >\n                  {{ color.label | translate }}\n                </label>\n                <c8y-color-input\n                  [attr.data-cy]=\"'branding-theme-form-color-input-' + color.formControlName\"\n                  [formControlName]=\"color.formControlName\"\n                ></c8y-color-input>\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n            </div>\n          </div>\n        </fieldset>\n      </div>\n    </div>\n  </div>\n  <!-- Navigator -->\n  <div class=\"card-block separator-top\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4\n          class=\"text-normal text-right text-left-xs m-b-16\"\n        >\n          {{ formStructure.navigator.label }}\n        </h4>\n      </div>\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <div class=\"row\">\n          <div class=\"col-md-4\" *ngFor=\"let colorColumn of formStructure.navigator.colorColumns\">\n            <fieldset class=\"c8y-fieldset p-24\">\n              <legend>{{ colorColumn.label | translate }}</legend>\n              <c8y-form-group class=\"m-b-32\" *ngFor=\"let color of colorColumn.colors\">\n                <label\n                  [title]=\"color.formControlName\"\n                  [for]=\"color.formControlName\"\n                >\n                  {{ color.label | translate }}\n                </label>\n                <c8y-color-input\n                  [attr.data-cy]=\"'branding-theme-form-color-input-' + color.formControlName\"\n                  [formControlName]=\"color.formControlName\"\n                ></c8y-color-input>\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n  <!-- Right drawer -->\n  <div class=\"card-block separator-top\">\n    <div class=\"row\">\n      <div class=\"col-xs-12 col-sm-3 col-md-2 p-t-16\">\n        <h4\n          class=\"text-normal text-right text-left-xs m-b-16\"\n        >\n          {{ formStructure.rightDrawer.label | translate }}\n        </h4>\n      </div>\n      <div class=\"col-xs-12 col-sm-9 col-md-10\">\n        <div class=\"row\">\n          <div class=\"col-md-6\" *ngFor=\"let colorColumn of formStructure.rightDrawer.colorColumns\">\n            <fieldset class=\"c8y-fieldset p-24\">\n              <legend>{{ colorColumn.label | translate }}</legend>\n              <c8y-form-group class=\"m-b-32\" *ngFor=\"let color of colorColumn.colors\">\n                <label\n                  [title]=\"color.formControlName\"\n                  [for]=\"color.formControlName\"\n                >\n                  {{ color.label | translate }}\n                </label>\n                <c8y-color-input\n                  [attr.data-cy]=\"'branding-theme-form-color-input-' + color.formControlName\"\n                  [formControlName]=\"color.formControlName\"\n                ></c8y-color-input>\n                <c8y-messages></c8y-messages>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n</div>\n" }]
        }], ctorParameters: () => [{ type: i2$1.ActivatedRoute }, { type: i2.FormBuilder }, { type: i3.FilesService }, { type: i1$2.BrandingShadesService }, { type: i3.ThemeSwitcherService }] });

class EditBrandingRouterOutletComponent {
    constructor(activatedRoute, store, router, alert, applyBrandingService, appState) {
        this.activatedRoute = activatedRoute;
        this.store = store;
        this.router = router;
        this.alert = alert;
        this.applyBrandingService = applyBrandingService;
        this.appState = appState;
        this.formControl = new FormControl(undefined);
        this.newBranding = new BehaviorSubject(null);
        this.currentlyDisplayedComponent = new BehaviorSubject(null);
        this.isGlobalBranding$ = this.activatedRoute.data.pipe(map(({ tags }) => {
            return tags?.includes('latest');
        }));
        this.tabName$ = this.currentlyDisplayedComponent.pipe(switchMap(() => this.activatedRoute.firstChild.data), map(data => data.tabName));
        this.brandingName$ = this.activatedRoute.params.pipe(map(params => params.name));
        this.formControl.addValidators(control => {
            try {
                JSON.parse(control.value);
                return null;
            }
            catch (e) {
                return { invalidJson: true };
            }
        });
        this.fallbackBranding$ = this.activatedRoute.data.pipe(map(data => data.fallbackBranding));
        this.activatedRoute.data
            .pipe(takeUntilDestroyed(), distinctUntilChanged())
            .subscribe(({ branding }) => {
            this.applyBrandingService.applyBranding(branding);
            this.formControl.setValue(JSON.stringify(branding, null, 2));
        });
        this.currentlyDisplayedComponent.pipe(takeUntilDestroyed()).subscribe(component => {
            if (!component) {
                return;
            }
            this.formControl.clearAsyncValidators();
            component.registerOnChange(value => this.onBrandingVarChanges(value));
            component.writeValue(this.formControl.value);
            if (component.validate) {
                this.formControl.addAsyncValidators(form => component.validate(form));
                if (component.registerOnValidatorChange) {
                    component.registerOnValidatorChange(() => this.formControl.updateValueAndValidity());
                }
            }
            this.formControl.updateValueAndValidity();
        });
    }
    ngOnDestroy() {
        this.applyBrandingService.resetBranding();
    }
    routeActivated(event) {
        this.currentlyDisplayedComponent.next(event);
    }
    async saveBranding() {
        try {
            const currentBranding = this.newBranding.value;
            const tagsOfCurrentVersion = await firstValueFrom(this.activatedRoute.data.pipe(map(data => data.tags)));
            const currentBrandingName = this.activatedRoute.snapshot.params.name;
            const { variants } = await this.store.loadBrandingVariants();
            const currentBrandingObj = variants.find(v => v.tags.includes(currentBrandingName));
            const currentVersion = currentBrandingObj.version;
            await this.store.saveExistingBranding(currentBranding, currentVersion, tagsOfCurrentVersion);
            this.router.navigate(['../../', currentBrandingName, this.activatedRoute.snapshot.routeConfig.path], {
                relativeTo: this.activatedRoute,
                replaceUrl: true
            });
            this.alert.success(gettext$1('Branding saved. To apply this branding, refresh any open window that might be affected.'));
        }
        catch (e) {
            this.alert.addServerFailure(e, 'danger');
            console.warn(e);
        }
    }
    cancel() {
        this.router.navigate(['branding-editor']);
    }
    async openPreview() {
        const name = this.activatedRoute.snapshot.params.name;
        this.store.openPreviewForBranding(name);
    }
    async markAsActive() {
        const currentBrandingName = this.activatedRoute.snapshot.params.name;
        const { variants } = await this.store.loadBrandingVariants();
        const currentBrandingObj = variants.find(v => v.tags.includes(currentBrandingName));
        await this.store.markAsActive(currentBrandingObj);
    }
    async onBrandingVarChanges(value) {
        this.formControl.setValue(value);
        try {
            const parsedValue = JSON.parse(value);
            const fallbackBranding = cloneDeep(await firstValueFrom(this.fallbackBranding$));
            this.cleanUpObjects(parsedValue);
            this.cleanUpObjects(parsedValue.brandingCssVars);
            for (const key in fallbackBranding) {
                if (parsedValue[key] === undefined) {
                    parsedValue[key] = fallbackBranding[key];
                }
                if (typeof parsedValue[key] === 'object' && typeof fallbackBranding[key] === 'object') {
                    parsedValue[key] = Object.assign(fallbackBranding[key], parsedValue[key]);
                }
            }
            this.applyBrandingService.applyBranding(parsedValue);
            this.newBranding.next(parsedValue);
        }
        catch (e) {
            // not valid JSON;
        }
    }
    cleanUpObjects(value) {
        if (!value) {
            return;
        }
        Object.keys(value).forEach(key => {
            if (value[key] === null || value[key] === '') {
                delete value[key];
            }
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EditBrandingRouterOutletComponent, deps: [{ token: i2$1.ActivatedRoute }, { token: i1$2.StoreBrandingService }, { token: i2$1.Router }, { token: i3.AlertService }, { token: i1$2.ApplyBrandingLocallyService }, { token: i3.AppStateService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: EditBrandingRouterOutletComponent, isStandalone: true, selector: "c8y-edit-branding-router-outlet", ngImport: i0, template: "<c8y-title>{{ brandingName$ | async }}</c8y-title>\n\n<c8y-breadcrumb>\n  <c8y-breadcrumb-item\n    [icon]=\"'palette'\"\n    [label]=\"'Branding' | translate\"\n    [path]=\"'/branding-editor'\"\n  ></c8y-breadcrumb-item>\n  <c8y-breadcrumb-item\n    [icon]=\"'cog'\"\n    [label]=\"brandingName$ | async\"\n  ></c8y-breadcrumb-item>\n</c8y-breadcrumb>\n\n<div class=\"card card--fullpage content-fullpage\">\n  <div class=\"card-header separator\">\n    <div class=\"card-title\">{{ brandingName$ | async }} \u2014 {{ tabName$ | async | translate }}</div>\n  </div>\n  <router-outlet\n    class=\"d-contents\"\n    (activate)=\"routeActivated($event)\"\n  ></router-outlet>\n\n  <div class=\"card-footer separator\">\n    <!-- footer content -->\n    <button\n      class=\"btn btn-default\"\n      data-cy=\"branding-cancel\"\n      (click)=\"cancel()\"\n      translate\n    >\n      Cancel\n    </button>\n    <button\n      class=\"btn btn-primary\"\n      data-cy=\"branding-save\"\n      [disabled]=\"formControl.invalid\"\n      (click)=\"saveBranding()\"\n      translate\n    >\n      Save\n    </button>\n    <button\n      class=\"btn btn-default\"\n      data-cy=\"branding-save-as\"\n      [disabled]=\"formControl.invalid\"\n      (click)=\"openPreview()\"\n      translate\n    >\n      Open preview\n    </button>\n    <button\n      class=\"btn btn-default\"\n      data-cy=\"branding-set-as-latest\"\n      (click)=\"markAsActive()\"\n      [disabled]=\"isGlobalBranding$ | async\"\n      translate\n    >\n      Set as global\n    </button>\n  </div>\n</div>\n", dependencies: [{ kind: "directive", type: RouterOutlet, selector: "router-outlet", inputs: ["name"], outputs: ["activate", "deactivate", "attach", "detach"], exportAs: ["outlet"] }, { kind: "ngmodule", type: CoreModule }, { kind: "component", type: i3.BreadcrumbComponent, selector: "c8y-breadcrumb" }, { kind: "component", type: i3.BreadcrumbItemComponent, selector: "c8y-breadcrumb-item", inputs: ["icon", "translate", "label", "path", "injector"] }, { kind: "pipe", type: i3.C8yTranslatePipe, name: "translate" }, { kind: "directive", type: i3.C8yTranslateDirective, selector: "[translate],[ngx-translate]" }, { kind: "pipe", type: i4.AsyncPipe, name: "async" }, { kind: "component", type: i3.TitleComponent, selector: "c8y-title", inputs: ["pageTitleUpdate"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EditBrandingRouterOutletComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-edit-branding-router-outlet', standalone: true, imports: [RouterOutlet, CoreModule], template: "<c8y-title>{{ brandingName$ | async }}</c8y-title>\n\n<c8y-breadcrumb>\n  <c8y-breadcrumb-item\n    [icon]=\"'palette'\"\n    [label]=\"'Branding' | translate\"\n    [path]=\"'/branding-editor'\"\n  ></c8y-breadcrumb-item>\n  <c8y-breadcrumb-item\n    [icon]=\"'cog'\"\n    [label]=\"brandingName$ | async\"\n  ></c8y-breadcrumb-item>\n</c8y-breadcrumb>\n\n<div class=\"card card--fullpage content-fullpage\">\n  <div class=\"card-header separator\">\n    <div class=\"card-title\">{{ brandingName$ | async }} \u2014 {{ tabName$ | async | translate }}</div>\n  </div>\n  <router-outlet\n    class=\"d-contents\"\n    (activate)=\"routeActivated($event)\"\n  ></router-outlet>\n\n  <div class=\"card-footer separator\">\n    <!-- footer content -->\n    <button\n      class=\"btn btn-default\"\n      data-cy=\"branding-cancel\"\n      (click)=\"cancel()\"\n      translate\n    >\n      Cancel\n    </button>\n    <button\n      class=\"btn btn-primary\"\n      data-cy=\"branding-save\"\n      [disabled]=\"formControl.invalid\"\n      (click)=\"saveBranding()\"\n      translate\n    >\n      Save\n    </button>\n    <button\n      class=\"btn btn-default\"\n      data-cy=\"branding-save-as\"\n      [disabled]=\"formControl.invalid\"\n      (click)=\"openPreview()\"\n      translate\n    >\n      Open preview\n    </button>\n    <button\n      class=\"btn btn-default\"\n      data-cy=\"branding-set-as-latest\"\n      (click)=\"markAsActive()\"\n      [disabled]=\"isGlobalBranding$ | async\"\n      translate\n    >\n      Set as global\n    </button>\n  </div>\n</div>\n" }]
        }], ctorParameters: () => [{ type: i2$1.ActivatedRoute }, { type: i1$2.StoreBrandingService }, { type: i2$1.Router }, { type: i3.AlertService }, { type: i1$2.ApplyBrandingLocallyService }, { type: i3.AppStateService }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ApplyBrandingToAppService, BrandingComponent, BrandingFormComponent, BrandingImportModalComponent, BrandingImportModalService, BrandingTagsCellRendererComponent, BrandingTagsHeaderCellRendererComponent, BrandingThemeFormComponent, EditBrandingRouterOutletComponent };
//# sourceMappingURL=c8y-ngx-components-branding-shared-lazy.mjs.map
