import * as i0 from '@angular/core';
import { Injectable, Component, Input, EventEmitter, inject, Output, ViewChild } from '@angular/core';
import { defer, from, merge, interval, BehaviorSubject, of, lastValueFrom, forkJoin } from 'rxjs';
import { switchMap, finalize, mergeMap, map, throttleTime, tap, buffer } from 'rxjs/operators';
import * as i1 from '@c8y/client';
import { MeasurementService, AlarmStatus, aggregationType } from '@c8y/client';
import { fromFetch } from 'rxjs/fetch';
import * as i2 from '@c8y/ngx-components/api';
import { cloneDeep } from 'lodash-es';
import * as i1$1 from '@c8y/ngx-components';
import { gettext, CommonModule, WidgetTimeContextDateRangeService, DismissAlertStrategy, DynamicComponentAlert, MeasurementRealtimeService, AlarmRealtimeService, EventRealtimeService, CoreModule } from '@c8y/ngx-components';
import * as i6 from '@angular/router';
import * as i4 from '@c8y/ngx-components/alarms';
import { AlarmSeverityToIconPipe, AlarmSeverityToLabelPipe, AlarmsModule } from '@c8y/ngx-components/alarms';
import { INTERVALS } from '@c8y/ngx-components/interval-picker';
import * as i5 from '@ngx-translate/core';
import * as i2$1 from '@angular/common';
import { CommonModule as CommonModule$1 } from '@angular/common';
import * as i3 from 'ngx-echarts';
import { NGX_ECHARTS_CONFIG, NgxEchartsModule } from 'ngx-echarts';
import { TooltipModule } from 'ngx-bootstrap/tooltip';
import { PopoverModule } from 'ngx-bootstrap/popover';

class CustomMeasurementService extends MeasurementService {
    constructor(client, realtime, apiService) {
        super(client, realtime);
        this.apiService = apiService;
    }
    listSeries$(params) {
        const url = `/${this.baseUrl}/${this.listUrl}/series`;
        const fetchOptions = {
            params: {
                revert: true,
                ...params
            }
        };
        const options = this.client.getFetchOptions(fetchOptions);
        const fullUrl = this.client.getUrl(url, fetchOptions);
        const callOnStart = {
            options,
            method: 'GET',
            url
        };
        const callOnFinish = {
            ...cloneDeep(callOnStart),
            response: { status: null }
        };
        return defer(() => {
            this.apiService.onStart(callOnStart);
            return fromFetch(fullUrl, options);
        }).pipe(switchMap(async (res) => {
            callOnFinish.response = res;
            const data = await res.json();
            return { res: res, data };
        }), finalize(() => {
            this.apiService.onFinish(callOnFinish);
        }));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CustomMeasurementService, deps: [{ token: i1.FetchClient }, { token: i1.Realtime }, { token: i2.ApiService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CustomMeasurementService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CustomMeasurementService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.FetchClient }, { type: i1.Realtime }, { type: i2.ApiService }] });

class YAxisService {
    constructor(appStateService) {
        this.appStateService = appStateService;
        this.Y_AXIS_OFFSET = 48;
        this.intlNumberFormatCompliantLocale = this.appStateService.state.lang.replace('_', '-');
    }
    getYAxis(datapointsWithValues, YAxisOptions) {
        const YAxisPlacement = this.getYAxisPlacement(datapointsWithValues);
        const matchingDpSet = new Set();
        const firstOccurrence = new Set();
        return datapointsWithValues.map((dp, index) => {
            const isDefined = (value) => value !== null && value !== undefined;
            const isMatchingDp = (dp1, dp2) => dp1.min === dp2.min &&
                dp1.max === dp2.max &&
                isDefined(dp1.min) &&
                isDefined(dp1.max) &&
                isDefined(dp2.min) &&
                isDefined(dp2.max);
            const matchingDpRange = datapointsWithValues.some((dp2, index2) => isMatchingDp(dp, dp2) && index2 < index);
            const anyMatchingDp = datapointsWithValues.some((dp2, index2) => isMatchingDp(dp, dp2) && index2 !== index);
            if (anyMatchingDp &&
                !matchingDpRange &&
                YAxisOptions.mergeMatchingDatapoints &&
                !firstOccurrence.has(dp)) {
                firstOccurrence.add(dp);
            }
            if (firstOccurrence.has(dp)) {
                datapointsWithValues.forEach(dp2 => {
                    if (isMatchingDp(dp, dp2)) {
                        matchingDpSet.add(dp2);
                    }
                });
            }
            return {
                name: YAxisOptions.showLabelAndUnit
                    ? YAxisOptions.mergeMatchingDatapoints
                        ? firstOccurrence.has(dp)
                            ? Array.from(matchingDpSet)
                                .map(dp => `{${dp.__target?.id}|${dp.unit}}`)
                                .join(' /')
                            : matchingDpRange
                                ? ''
                                : `${dp.label} [${dp.unit}]`
                        : `${dp.label} [${dp.unit}]`
                    : '',
                nameLocation: 'middle',
                nameGap: 20,
                nameTextStyle: {
                    // add rich text to support multiple colors for different dp units
                    rich: {
                        ...Array.from(matchingDpSet).reduce((acc, dp) => {
                            const accKey = `${dp.__target?.id}`;
                            acc[accKey] = {
                                color: dp.color
                            };
                            return acc;
                        }, {})
                    }
                },
                type: 'value',
                animation: true,
                axisLine: {
                    show: matchingDpRange && YAxisOptions.mergeMatchingDatapoints ? false : true,
                    lineStyle: {
                        color: firstOccurrence.has(dp) ? 'black' : dp.color
                    },
                    onZero: false
                },
                axisLabel: {
                    fontSize: 10,
                    show: !matchingDpRange || !YAxisOptions.mergeMatchingDatapoints,
                    formatter: val => {
                        if (dp.min != undefined && dp.max != undefined) {
                            const range = dp.max - dp.min;
                            const decimalPlaces = this.getDecimalPlaces(range);
                            return val.toFixed(decimalPlaces);
                        }
                        return new Intl.NumberFormat(this.intlNumberFormatCompliantLocale, {
                            notation: 'compact',
                            compactDisplay: 'short'
                        }).format(val);
                    }
                },
                splitLine: {
                    show: YAxisOptions.showSplitLines && !matchingDpRange,
                    lineStyle: { color: dp.color, opacity: 0.4, type: 'dashed' }
                },
                position: YAxisPlacement.get(dp)?.position,
                offset: YAxisPlacement.get(dp)?.offset,
                axisTick: {
                    show: !matchingDpRange || !YAxisOptions.mergeMatchingDatapoints
                },
                axisPointer: {
                    show: false,
                    label: {
                        show: false
                    }
                },
                ...(dp.min && { min: dp.min }),
                ...(dp.max && { max: dp.max })
            };
        });
    }
    getDecimalPlaces(num) {
        const numStr = num.toString();
        const decimalIndex = numStr.indexOf('.');
        if (decimalIndex === -1) {
            return 0;
        }
        return numStr.length - decimalIndex - 1;
    }
    getYAxisPlacement(datapointsWithValues) {
        const YAxisPositions = new Map();
        datapointsWithValues.forEach(dp => {
            const position = this.getYAxisPosition(dp, datapointsWithValues);
            YAxisPositions.set(dp, { position });
        });
        const dpLeft = datapointsWithValues.filter(dp => YAxisPositions.get(dp).position === 'left');
        const dpRight = datapointsWithValues.filter(dp => YAxisPositions.get(dp).position === 'right');
        const YAxisPlacement = new Map();
        YAxisPositions.forEach(({ position }, key) => {
            const offset = (position === 'left' ? dpLeft : dpRight).indexOf(key) * this.Y_AXIS_OFFSET;
            YAxisPlacement.set(key, { position: position, offset });
        });
        return YAxisPlacement;
    }
    getYAxisPosition(datapoint, datapointsWithValues) {
        if (datapoint.yAxisType) {
            return datapoint.yAxisType;
        }
        const currentIndex = datapointsWithValues.indexOf(datapoint);
        const otherIndexLeft = datapointsWithValues.findIndex(dp => dp !== datapoint && (!dp.yAxisType || dp.yAxisType === 'left'));
        if (otherIndexLeft > -1 && otherIndexLeft < currentIndex) {
            return 'right';
        }
        else {
            return 'left';
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: YAxisService, deps: [{ token: i1$1.AppStateService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: YAxisService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: YAxisService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1$1.AppStateService }] });

function assertUnreachable(_) {
    throw new Error('Case unreachable.');
}
class ChartTypesService {
    constructor() {
        this.RENDER_TYPE_SYMBOL = {
            min: { symbol: 'triangle', symbolRotate: 0 },
            max: { symbol: 'triangle', symbolRotate: 180 }
        };
    }
    getSeriesOptions({ lineType, color }, isMinMaxChart = false, renderType) {
        switch (lineType) {
            case 'points':
                return this.pointsSeriesOption(color, isMinMaxChart, renderType);
            case 'linePoints':
                return this.linePointsSeriesOption(color, isMinMaxChart, renderType);
            case 'bars':
                return this.barsSeriesOption(color, isMinMaxChart, renderType);
            case 'step-before':
                return this.stepBeforeSeriesOption(color, isMinMaxChart, renderType);
            case 'step-after':
                return this.stepAfterSeriesOption(color, isMinMaxChart, renderType);
            case 'line':
            case undefined:
                return this.lineSeriesOption(color, isMinMaxChart, renderType);
        }
        return assertUnreachable(lineType);
    }
    pointsSeriesOption(color, isMinMaxChart, renderType) {
        const baseOption = this.linePointsSeriesOption(color, isMinMaxChart, renderType);
        return {
            ...baseOption,
            lineStyle: { opacity: 0 }
        };
    }
    lineSeriesOption(color, isMinMaxChart, renderType) {
        let baseOption = {
            type: 'line',
            lineStyle: {
                color: color,
                width: 1,
                type: 'solid'
            },
            itemStyle: {
                color: color
            },
            emphasis: {
                scale: 1.2,
                itemStyle: {
                    color: color
                }
            },
            showSymbol: false,
            symbolSize: 4 // symbol is visible on hover
        };
        if (isMinMaxChart) {
            baseOption = {
                ...baseOption,
                ...this.RENDER_TYPE_SYMBOL[renderType],
                symbolSize: 8
            };
        }
        return baseOption;
    }
    linePointsSeriesOption(color, isMinMaxChart, renderType) {
        const baseOption = this.lineSeriesOption(color, isMinMaxChart, renderType);
        return {
            ...baseOption,
            showSymbol: true
        };
    }
    barsSeriesOption(color, isMinMaxChart, renderType) {
        const baseOption = {
            type: 'bar',
            barMinWidth: 1,
            barMaxWidth: 20,
            itemStyle: {
                color
            }
        };
        if (isMinMaxChart) {
            baseOption.itemStyle.opacity = renderType === 'max' ? 0.6 : 1.0;
        }
        return baseOption;
    }
    stepBeforeSeriesOption(color, isMinMaxChart, renderType) {
        const baseOption = this.lineSeriesOption(color, isMinMaxChart, renderType);
        return { ...baseOption, step: 'start' };
    }
    stepAfterSeriesOption(color, isMinMaxChart, renderType) {
        const baseOption = this.lineSeriesOption(color, isMinMaxChart, renderType);
        return { ...baseOption, step: 'end' };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChartTypesService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChartTypesService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChartTypesService, decorators: [{
            type: Injectable
        }] });

var ICONS;
(function (ICONS) {
    ICONS["ALARM"] = "path://M18.375 15.8462L20.4423 17.9135V18.9231H4V17.9135L6.06731 15.8462V10.75C6.06731 9.14744 6.47596 7.75321 7.29327 6.56731C8.11058 5.38141 9.24038 4.61218 10.6827 4.25962V3.53846C10.6827 3.12179 10.8269 2.76122 11.1154 2.45673C11.4038 2.15224 11.7724 2 12.2212 2C12.6699 2 13.0385 2.15224 13.3269 2.45673C13.6154 2.76122 13.7596 3.12179 13.7596 3.53846V4.25962C15.2019 4.61218 16.3317 5.38141 17.149 6.56731C17.9663 7.75321 18.375 9.14744 18.375 10.75V15.8462ZM12.2212 22C11.6442 22 11.1554 21.8077 10.7548 21.4231C10.3542 21.0385 10.1538 20.5577 10.1538 19.9808H14.2885C14.2885 20.5256 14.0801 20.9984 13.6635 21.399C13.2468 21.7997 12.766 22 12.2212 22Z";
    ICONS["EVENT"] = "path://M97.3013 63L128.939 95.1315C79.296 134.335 47.7653 191.526 47.7653 255.276C47.7653 319.027 79.296 376.218 128.917 415.421L97.28 447.574C37.76 400.552 0 331.93 0 255.276C0 178.622 37.76 110.001 97.3013 63ZM414.72 63C474.24 110.001 512 178.622 512 255.276C512 331.93 474.24 400.552 414.72 447.574L383.083 415.421C432.704 376.218 464.235 319.027 464.235 255.276C464.235 191.526 432.704 134.335 383.083 95.1315L414.72 63ZM160.405 127.092L192 159.181C162.24 182.681 143.317 217.013 143.317 255.276C143.317 293.539 162.219 327.871 192 351.372L160.405 383.461C120.725 352.119 95.552 306.379 95.552 255.276C95.552 204.174 120.725 158.433 160.405 127.092ZM351.595 127.092C391.296 158.433 416.448 204.174 416.448 255.276C416.448 306.379 391.275 352.119 351.595 383.461L320 351.372C349.781 327.871 368.683 293.539 368.683 255.276C368.683 217.013 349.781 182.703 320 159.181L351.595 127.092ZM256 192.722C291.505 192.722 320.287 221.504 320.287 257.009C320.287 292.514 291.505 321.296 256 321.296C220.495 321.296 191.713 292.514 191.713 257.009C191.713 221.504 220.495 192.722 256 192.722Z";
    ICONS["ACKNOWLEDGED"] = "path://M10.4795 2H13.4807V4.18054C14.1215 4.35248 14.7155 4.61821 15.2626 4.97773C15.8097 5.35287 16.2864 5.79836 16.6928 6.31419C17.0993 6.81438 17.4119 7.3771 17.6307 8.00234C17.8652 8.62759 17.9824 9.29191 17.9824 9.99531V13.7702L16.9742 12.762V12.7855L9.72919 5.54045C9.74482 5.54045 9.75264 5.54045 9.75264 5.54045L9.00234 4.79015C9.22118 4.64947 9.45565 4.53224 9.70574 4.43845C9.95584 4.34467 10.2138 4.25869 10.4795 4.18054V2ZM4.4068 3.03165L21.4291 20.0305L19.9988 21.4373L17.5604 18.9988H13.6917C13.7855 19.1551 13.8558 19.3193 13.9027 19.4912C13.9496 19.6475 13.973 19.8195 13.973 20.007C13.973 20.5541 13.7776 21.0231 13.3869 21.4138C12.9961 21.8046 12.5272 22 11.9801 22C11.4174 22 10.9406 21.8046 10.5498 21.4138C10.159 21.0231 9.96366 20.5541 9.96366 20.007C9.96366 19.8195 9.9871 19.6475 10.034 19.4912C10.0809 19.3193 10.1512 19.1551 10.245 18.9988H3.96131V17.9906L5.97773 15.9977V9.99531C5.97773 9.60453 6.00899 9.22939 6.07151 8.86987C6.14967 8.51036 6.25127 8.15866 6.37632 7.81477L3 4.43845L4.4068 3.03165Z";
    ICONS["CLEARED"] = "path://M9.09375 19.5977C9.09375 20.2617 9.32812 20.8281 9.79688 21.2969C10.2786 21.7656 10.8516 22 11.5156 22C12.1927 22 12.7656 21.7656 13.2344 21.2969C13.7161 20.8281 13.957 20.2617 13.957 19.5977H9.09375ZM16.8672 10.418C16.3203 10.5091 15.7995 10.6784 15.3047 10.9258C14.8229 11.1732 14.3867 11.4922 13.9961 11.8828C13.5013 12.3776 13.1172 12.944 12.8438 13.582C12.5833 14.2201 12.4531 14.8841 12.4531 15.5742C12.4531 16.0299 12.5052 16.4727 12.6094 16.9023C12.7266 17.332 12.8958 17.7422 13.1172 18.1328H3V16.375C4.04167 16.0495 4.74479 15.3919 5.10938 14.4023C5.47396 13.4128 5.76693 12.3385 5.98828 11.1797C6.20964 10.0208 6.48958 8.88802 6.82812 7.78125C7.16667 6.6875 7.83724 5.85417 8.83984 5.28125C9.11328 5.125 9.32812 4.91667 9.48438 4.65625C9.64062 4.38281 9.71875 4.08984 9.71875 3.77734C9.71875 3.28255 9.88802 2.86589 10.2266 2.52734C10.5781 2.17578 11.0013 2 11.4961 2C11.9909 2 12.4076 2.17578 12.7461 2.52734C13.0977 2.86589 13.2734 3.28255 13.2734 3.77734C13.2734 4.08984 13.3516 4.38281 13.5078 4.65625C13.6771 4.91667 13.8984 5.125 14.1719 5.28125C15.0443 5.78906 15.6562 6.51172 16.0078 7.44922C16.3724 8.38672 16.6589 9.3763 16.8672 10.418ZM11.4961 4.48047C11.6914 4.48047 11.8607 4.41536 12.0039 4.28516C12.1471 4.14193 12.2188 3.97266 12.2188 3.77734C12.2188 3.56901 12.1471 3.39974 12.0039 3.26953C11.8607 3.1263 11.6914 3.05469 11.4961 3.05469C11.3008 3.05469 11.1315 3.1263 10.9883 3.26953C10.8451 3.39974 10.7734 3.56901 10.7734 3.77734C10.7734 3.97266 10.8451 4.14193 10.9883 4.28516C11.1315 4.41536 11.3008 4.48047 11.4961 4.48047ZM16.9062 17.6055L19.9922 14.5195L19.2305 13.7773L16.9062 16.1016L15.8906 15.0859L15.1289 15.8477L16.9062 17.6055ZM17.5312 11.8633C18.5599 11.8633 19.4388 12.2279 20.168 12.957C20.8971 13.6862 21.2617 14.5651 21.2617 15.5938C21.2617 16.6224 20.8971 17.5013 20.168 18.2305C19.4388 18.9596 18.5599 19.3242 17.5312 19.3242C16.5026 19.3242 15.6237 18.9596 14.8945 18.2305C14.1654 17.5013 13.8008 16.6224 13.8008 15.5938C13.8008 14.5651 14.1654 13.6862 14.8945 12.957C15.6237 12.2279 16.5026 11.8633 17.5312 11.8633Z";
    ICONS["MINOR"] = "path://M21.9787 11.9894L11.9894 22L2 11.9894L11.9894 2L21.9787 11.9894ZM12.9052 16.5474V14.7157H11.0735V16.5474H12.9052ZM12.9052 12.9052V7.45261H11.0735V12.9052H12.9052Z";
    ICONS["MAJOR"] = "path://M12.8936 13.8936V10.234H11.1064V13.8936H12.8936ZM12.8936 17.5106V15.6809H11.1064V17.5106H12.8936ZM2 20.234L12 3L22 20.234H2Z";
    ICONS["CRITICAL"] = "path://M12.0117 22C10.6362 22 9.3388 21.7343 8.11958 21.2028C6.90035 20.687 5.83744 19.9758 4.93083 19.0692C4.02423 18.1626 3.31301 17.0996 2.79719 15.8804C2.26573 14.6768 2 13.3794 2 11.9883C2 10.6127 2.26573 9.31536 2.79719 8.09613C3.31301 6.89254 4.02423 5.83744 4.93083 4.93083C5.83744 4.02423 6.90035 3.3052 8.11958 2.77374C9.3388 2.25791 10.6362 2 12.0117 2C13.3873 2 14.6846 2.25791 15.9039 2.77374C17.1231 3.3052 18.186 4.02423 19.0926 4.93083C19.9992 5.83744 20.7104 6.89254 21.2263 8.09613C21.7577 9.31536 22.0234 10.6127 22.0234 11.9883C22.0234 13.3794 21.7577 14.6768 21.2263 15.8804C20.7104 17.0996 19.9992 18.1626 19.0926 19.0692C18.186 19.9758 17.1231 20.687 15.9039 21.2028C14.6846 21.7343 13.3873 22 12.0117 22ZM13.0199 6.99414H11.0035V12.9965H13.0199V6.99414ZM13.0199 14.9894H11.0035V17.0059H13.0199V14.9894Z";
    ICONS["WARNING"] = "path://M12 2C13.3772 2 14.6761 2.25822 15.8967 2.77465C17.1174 3.29108 18.1815 4.00313 19.0892 4.9108C19.9969 5.81847 20.7089 6.88263 21.2254 8.10329C21.7418 9.32394 22 10.6228 22 12C22 13.3772 21.7418 14.6761 21.2254 15.8967C20.7089 17.1174 19.9969 18.1815 19.0892 19.0892C18.1815 19.9969 17.1174 20.7089 15.8967 21.2254C14.6761 21.7418 13.3772 22 12 22C10.6228 22 9.32394 21.7418 8.10329 21.2254C6.88263 20.7089 5.81847 19.9969 4.9108 19.0892C4.00313 18.1815 3.29108 17.1174 2.77465 15.8967C2.25822 14.6761 2 13.3772 2 12C2 10.6228 2.25822 9.32394 2.77465 8.10329C3.29108 6.88263 4.00313 5.81847 4.9108 4.9108C5.81847 4.00313 6.88263 3.29108 8.10329 2.77465C9.32394 2.25822 10.6228 2 12 2Z";
})(ICONS || (ICONS = {}));
const ICONS_MAP = {
    ALARM: ICONS.ALARM,
    EVENT: ICONS.EVENT,
    ACKNOWLEDGED: ICONS.ACKNOWLEDGED,
    CLEARED: ICONS.CLEARED,
    MINOR: ICONS.MINOR,
    MAJOR: ICONS.MAJOR,
    CRITICAL: ICONS.CRITICAL,
    WARNING: ICONS.WARNING
};

/* eslint-disable @typescript-eslint/no-explicit-any */
const INDEX_HTML = '/index.html';
class EchartsOptionsService {
    constructor(datePipe, yAxisService, chartTypesService, severityIconPipe, severityLabelPipe, translate, router) {
        this.datePipe = datePipe;
        this.yAxisService = yAxisService;
        this.chartTypesService = chartTypesService;
        this.severityIconPipe = severityIconPipe;
        this.severityLabelPipe = severityLabelPipe;
        this.translate = translate;
        this.router = router;
        this.TOOLTIP_WIDTH = 300;
    }
    getChartOptions(datapointsWithValues, timeRange, showSplitLines, events, alarms, displayOptions, selectedTimeRange, aggregatedDatapoints, sliderZoomUsed = false) {
        const yAxis = this.yAxisService.getYAxis(datapointsWithValues, {
            showSplitLines: showSplitLines.YAxis,
            mergeMatchingDatapoints: displayOptions.mergeMatchingDatapoints,
            showLabelAndUnit: displayOptions.showLabelAndUnit
        });
        const leftAxis = yAxis.filter(yx => yx.position === 'left');
        const gridLeft = leftAxis.length ? leftAxis.length * this.yAxisService.Y_AXIS_OFFSET : 16;
        const rightAxis = yAxis.filter(yx => yx.position === 'right');
        const gridRight = rightAxis.length ? rightAxis.length * this.yAxisService.Y_AXIS_OFFSET : 16;
        let intervalInMs = this.calculateExtendedIntervalInMs(selectedTimeRange?.interval || timeRange.interval || 'hours', selectedTimeRange || timeRange);
        if (sliderZoomUsed) {
            intervalInMs = this.calculateExtendedIntervalInMs(timeRange.interval || 'hours', timeRange);
        }
        return {
            grid: {
                containLabel: false, // axis labels are not taken into account to calculate graph grid
                left: gridLeft,
                top: 16,
                right: gridRight,
                bottom: 68
            },
            dataZoom: [
                {
                    type: 'inside',
                    // TODO: use 'none' only when this bug is fixed https://github.com/apache/echarts/issues/17858
                    filterMode: datapointsWithValues.some(dp => dp.lineType === 'bars') ? 'filter' : 'none',
                    zoomOnMouseWheel: true,
                    startValue: selectedTimeRange
                        ? selectedTimeRange.dateFrom.valueOf()
                        : timeRange.dateFrom.valueOf(),
                    endValue: selectedTimeRange
                        ? selectedTimeRange.dateTo.valueOf()
                        : timeRange.dateTo.valueOf()
                },
                {
                    type: 'slider',
                    show: displayOptions.showSlider,
                    bottom: 8,
                    realtime: false
                }
            ], // on realtime, 'none' will cause extending chart line to left edge of the chart
            animation: false,
            toolbox: {
                show: true,
                itemSize: 0, // toolbox is needed for zooming in action, but we provide our own buttons
                feature: {
                    dataZoom: {
                        yAxisIndex: 'none'
                    }
                }
            },
            tooltip: {
                trigger: 'axis',
                axisPointer: {
                    type: 'cross',
                    snap: true
                },
                backgroundColor: 'rgba(255, 255, 255, 0.9)',
                formatter: this.getTooltipFormatter(),
                appendToBody: true,
                position: this.tooltipPosition(),
                transitionDuration: 0
            },
            legend: {
                show: false
            },
            xAxis: {
                min: new Date(timeRange.dateFrom).valueOf() - intervalInMs,
                max: timeRange.dateTo,
                type: 'time',
                animation: false,
                axisPointer: {
                    label: {
                        show: false
                    }
                },
                axisLine: {
                    // align X axis to 0 of Y axis of datapoint with lineType 'bars'
                    onZeroAxisIndex: datapointsWithValues.findIndex(dp => dp.lineType === 'bars')
                },
                axisLabel: {
                    hideOverlap: true,
                    borderWidth: 2, // as there is no margin for labels spacing, transparent border is a workaround
                    borderColor: 'transparent'
                },
                splitLine: {
                    show: showSplitLines.XAxis,
                    lineStyle: { opacity: 0.8, type: 'dashed', width: 2 }
                }
            },
            yAxis,
            series: [
                ...this.getAggregatedSeries(aggregatedDatapoints || []).filter(series => series !== undefined),
                ...this.getChartSeries(datapointsWithValues, events, alarms, displayOptions)
            ]
        };
    }
    calculateExtendedIntervalInMs(interval, selectedTimeRange) {
        let intervalInMs = INTERVALS.find(i => i.id === interval).timespanInMs;
        switch (interval) {
            case 'minutes':
                intervalInMs = INTERVALS.find(i => i.id === interval).timespanInMs * 60;
                break;
            case 'hours':
                intervalInMs = INTERVALS.find(i => i.id === interval).timespanInMs * 24;
                break;
            case 'days':
                intervalInMs = INTERVALS.find(i => i.id === interval).timespanInMs * 28;
                break;
            case 'weeks':
                intervalInMs = INTERVALS.find(i => i.id === interval).timespanInMs * 12;
                break;
            case 'months':
                intervalInMs = INTERVALS.find(i => i.id === interval).timespanInMs * 12;
                break;
            case 'custom':
                intervalInMs =
                    (new Date(selectedTimeRange.dateTo).valueOf() -
                        new Date(selectedTimeRange.dateFrom).valueOf()) *
                        12;
                break;
            default:
                intervalInMs = INTERVALS.find(i => i.id === interval).timespanInMs;
                break;
        }
        return intervalInMs;
    }
    getAggregatedSeries(aggregatedDatapoints) {
        const series = [];
        aggregatedDatapoints.forEach((dp, idx) => {
            const renderType = dp.renderType || 'min';
            if (renderType === 'area') {
                series.push(this.getSingleSeries(dp, 'min', idx, true, 'aggr'));
                series.push(this.getSingleSeries(dp, 'max', idx, true, 'aggr'));
            }
            else {
                series.push(this.getSingleSeries(dp, renderType, idx, false, 'aggr'));
            }
        });
        series.forEach((s) => {
            s.datapointId = 'aggregated';
            s.typeOfSeries = 'fake';
            s.itemStyle = {
                ...s.itemStyle,
                opacity: 0
            };
            s.lineStyle = {
                ...s.lineStyle,
                opacity: 0
            };
        });
        return [series[0]];
    }
    /**
     * This method is used to get the series for alarms and events.
     * @param dp - The data point.
     * @param renderType - The render type.
     * @param isMinMaxChart - If the chart is min max chart.
     * @param items - All alarms or events which should be displayed on the chart.
     * @param itemType - The item type.
     * @param id - The id of the device
     */
    getAlarmOrEventSeries(dp, renderType, isMinMaxChart = false, items = [], itemType = 'alarm', displayOptions = { displayMarkedLine: true, displayMarkedPoint: true }, id, idx, realtime) {
        if (!items.length) {
            return [];
        }
        if (!displayOptions.displayMarkedLine && !displayOptions.displayMarkedPoint) {
            return [];
        }
        //filter items that are not __hidden
        const filteredItems = items.filter(item => !item['__hidden']);
        const itemsByType = this.groupByType(filteredItems, 'type');
        const isAlarm = itemType === 'alarm';
        return Object.entries(itemsByType).flatMap(([type, itemsOfType]) => {
            // Main series data
            const mainData = itemsOfType.map(item => [item.creationTime, null, 'markLineFlag']);
            // Is a specific datapoint template selected for this alarm/event type?
            let isDpTemplateSelected = false;
            // MarkPoint data
            const markPointData = itemsOfType.reduce((acc, item) => {
                isDpTemplateSelected =
                    item['selectedDatapoint'] &&
                        dp['__target'] &&
                        item['selectedDatapoint']['fragment'] === dp['fragment'] &&
                        item['selectedDatapoint']['series'] === dp['series'] &&
                        item['selectedDatapoint']['target'] === dp['__target']['id'];
                if (dp.__target?.id === item.source.id) {
                    const isCleared = isAlarm && item.status === AlarmStatus.CLEARED;
                    const isEvent = !isAlarm;
                    return acc.concat(this.createMarkPoint(item, dp, isCleared, isEvent, realtime));
                }
                else {
                    if (!item.creationTime) {
                        return [];
                    }
                    return acc.concat([
                        {
                            coord: [item.creationTime, null],
                            name: item.type,
                            itemType: item.type,
                            itemStyle: { color: item['color'] }
                        }
                    ]);
                }
            }, []);
            // Construct series with markPoint
            const seriesWithMarkPoint = {
                id: `${type}/${dp.__target?.id}+${id ? id : ''}-markPoint`,
                name: `${type}-markPoint`,
                typeOfSeries: itemType,
                data: mainData,
                isDpTemplateSelected,
                position: 'bottom',
                silent: true,
                markPoint: {
                    showSymbol: true,
                    symbolKeepAspect: true,
                    data: markPointData
                },
                yAxisIndex: idx,
                ...this.chartTypesService.getSeriesOptions(dp, isMinMaxChart, renderType)
            };
            const markLineData = this.createMarkLine(itemsOfType, itemType);
            // Construct series with markLine
            const seriesWithMarkLine = {
                id: `${type}/${dp.__target?.id}+${id ? id : ''}-markLine`,
                name: `${type}-markLine`,
                typeOfSeries: itemType,
                isDpTemplateSelected,
                data: mainData,
                markLine: {
                    showSymbol: false,
                    symbol: ['none', 'none'], // no symbol at the start/end of the line
                    data: markLineData
                },
                ...this.chartTypesService.getSeriesOptions(dp, isMinMaxChart, renderType)
            };
            //depending on the options return only the required series
            if (displayOptions.displayMarkedLine && displayOptions.displayMarkedPoint) {
                return [seriesWithMarkLine, seriesWithMarkPoint];
            }
            else if (displayOptions.displayMarkedLine) {
                return [seriesWithMarkLine];
            }
            else if (displayOptions.displayMarkedPoint) {
                return [seriesWithMarkPoint];
            }
            else {
                return null;
            }
        });
    }
    /**
     * This method is used to get tooltip formatter for alarms and events.
     * @param tooltipParams - The tooltip parameters.
     * @param params - The parameters data.
     * @param allEvents - All events.
     * @param allAlarms - All alarms.
     * @returns The formatted string for the tooltip.
     */
    getTooltipFormatterForAlarmAndEvents(tooltipParams, params, allEvents, allAlarms) {
        if (!Array.isArray(tooltipParams)) {
            return '';
        }
        const XAxisValue = tooltipParams[0].data[0];
        const YAxisReadings = [];
        const allSeries = this.echartsInstance?.getOption()['series'];
        // filter out alarm and event series
        const allDataPointSeries = allSeries.filter(series => series['typeOfSeries'] !== 'alarm' && series['typeOfSeries'] !== 'event');
        this.processSeries(allDataPointSeries, XAxisValue, YAxisReadings);
        // find event and alarm of the same type as the hovered markedLine or markedPoint
        const event = allEvents.find(e => e.type === params.data.itemType);
        const alarm = allAlarms.find(a => a.type === params.data.itemType);
        let value = '';
        if (event) {
            value = this.processEvent(event, XAxisValue);
        }
        if (alarm) {
            this.processAlarm(alarm).then(alarmVal => {
                value = alarmVal;
                YAxisReadings.push(value);
                const options = this.echartsInstance?.getOption();
                if (!options.tooltip || !Array.isArray(options.tooltip)) {
                    return;
                }
                const updatedOptions = {
                    tooltip: options['tooltip'][0]
                };
                if (!updatedOptions.tooltip) {
                    return;
                }
                updatedOptions.tooltip.formatter = `<div style="width: ${this.TOOLTIP_WIDTH}px">${YAxisReadings.join('')}</div>`;
                updatedOptions.tooltip.transitionDuration = 0;
                updatedOptions.tooltip.position = this.tooltipPosition();
                this.echartsInstance?.setOption(updatedOptions);
                return;
            });
        }
        YAxisReadings.push(value);
        return `<div style="width: 300px">${YAxisReadings.join('')}</div>`;
    }
    tooltipPosition() {
        let lastPositionOfTooltip = {};
        if (this.tooltipPositionCallback) {
            return this.tooltipPositionCallback;
        }
        this.tooltipPositionCallback = (point, // position of mouse in chart [X, Y]; 0,0 is top left corner
        _, // tooltip data
        dom, // tooltip element
        __, size // size of chart
        ) => {
            const offset = 10;
            const [mouseX, mouseY] = point;
            const chartWidth = size?.viewSize[0] || 0;
            const chartHeight = size?.viewSize[1] || 0;
            const tooltipWidth = size?.contentSize[0] || 0;
            const tooltipHeight = size?.contentSize[1] || 0;
            const tooltipRect = dom?.getBoundingClientRect();
            const tooltipOverflowsBottomEdge = tooltipRect.bottom > window.innerHeight;
            const tooltipOverflowsRightEdge = tooltipRect.right > window.innerWidth;
            const tooltipWouldOverflowBottomEdgeOnPositionChange = !lastPositionOfTooltip.top &&
                tooltipRect.bottom + 2 * offset + tooltipHeight > window.innerHeight;
            const tooltipWouldOverflowRightEdgeOnPositionChange = !lastPositionOfTooltip.left &&
                tooltipRect.right + 2 * offset + tooltipWidth > window.innerWidth;
            let verticalPosition = {
                top: mouseY + offset
            };
            let horizontalPosition = {
                left: mouseX + offset
            };
            if (tooltipOverflowsBottomEdge || tooltipWouldOverflowBottomEdgeOnPositionChange) {
                verticalPosition = {
                    bottom: chartHeight - mouseY + offset
                };
            }
            if (tooltipOverflowsRightEdge || tooltipWouldOverflowRightEdgeOnPositionChange) {
                horizontalPosition = {
                    right: chartWidth - mouseX + offset
                };
            }
            lastPositionOfTooltip = {
                ...verticalPosition,
                ...horizontalPosition
            };
            return lastPositionOfTooltip;
        };
        return this.tooltipPositionCallback;
    }
    /**
     * This method is used to add the data point info to the tooltip.
     * @param allDataPointSeries - All the data point series.
     * @param XAxisValue - The X Axis value.
     * @param YAxisReadings - The Y Axis readings.
     */
    processSeries(allDataPointSeries, XAxisValue, YAxisReadings) {
        allDataPointSeries.forEach((series) => {
            if (series.datapointId === 'aggregated') {
                return;
            }
            let value = '';
            if (series.id.endsWith('/min')) {
                value = this.processMinSeries(series, allDataPointSeries, XAxisValue);
            }
            else if (!series.id.endsWith('/max')) {
                value = this.processRegularSeries(series, XAxisValue);
            }
            if (value) {
                YAxisReadings.push(`<div class="d-flex a-i-center p-b-8"><span class='dlt-c8y-icon-circle m-r-4' style='color: ${series.itemStyle.color};'></span>` + // color circle
                    `<strong>${series.datapointLabel}</strong></div>` + // name
                    `${value}` // single value or min-max range
                );
            }
        });
    }
    /**
     * This method is used to process the min series.
     * @param series - The series.
     * @param allDataPointSeries - All the data point series.
     * @param XAxisValue - The X Axis value.
     * @returns The processed value.
     */
    processMinSeries(series, allDataPointSeries, XAxisValue) {
        const minValue = this.findValueForExactOrEarlierTimestamp(series.data, XAxisValue);
        if (!minValue) {
            return '';
        }
        const maxSeries = allDataPointSeries.find(s => s['id'] === series.id.replace('/min', '/max'));
        const maxValue = this.findValueForExactOrEarlierTimestamp(maxSeries?.['data'], XAxisValue);
        return (`<div class="d-flex a-i-center separator-top p-t-8 p-b-8"><label class="text-12 m-r-8 m-b-0">${this.datePipe.transform(minValue[0])}</label>` +
            `<span class="m-l-auto text-12">${minValue[1]} — ${maxValue?.[1]}` +
            (series.datapointUnit ? ` ${series.datapointUnit}` : '') +
            `</span></div>`);
    }
    /**
     * This method is used to process the regular series.
     * @param series - The series.
     * @param XAxisValue - The X Axis value.
     * @returns The processed value.
     */
    processRegularSeries(series, XAxisValue) {
        const seriesValue = this.findValueForExactOrEarlierTimestamp(series.data, XAxisValue);
        if (!seriesValue) {
            return '';
        }
        return (`<div class="d-flex a-i-center p-t-8 p-b-8 separator-top">` +
            `<label class="m-b-0 m-r-8 text-12">${this.datePipe.transform(seriesValue[0])}</label><span class="m-l-auto text-12">` +
            seriesValue[1]?.toString() +
            (series.datapointUnit ? ` ${series.datapointUnit}` : '') +
            `</span></div>`);
    }
    /**
     * This method is used to process the event tooltip.
     * @param event - The event object.
     * @returns The processed value.
     */
    processEvent(event, XAxisValue) {
        let value = `<ul class="list-unstyled small separator-top">`;
        value += `<li class="p-t-4 p-b-4 d-flex separator-bottom text-no-wrap"><label class="small m-b-0 m-r-8">Event type</label><code class="m-l-auto">${event.type}</code></li>`;
        value += `<li class="p-t-4 p-b-4 d-flex separator-bottom text-no-wrap"><label class="small m-b-0 m-r-8">Event text</label><span class="m-l-auto">${event.text}<span></li>`;
        value += `<li class="p-t-4 p-b-4 d-flex separator-bottom text-no-wrap"><label class="small m-b-0 m-r-8">Event time</label><span class="m-l-auto">${this.datePipe.transform(XAxisValue)}<span></li>`;
        value += `</ul>`;
        return value;
    }
    /**
     * This method is used to process the alarm tooltip.
     * @param alarm - The alarm object.
     * @returns The processed value.
     */
    async processAlarm(alarm) {
        let value = `<ul class="list-unstyled small separator-top m-0">`;
        value += `<li class="p-t-4 p-b-4 d-flex a-i-center separator-bottom text-no-wrap"><label class="text-label-small m-b-0 m-r-8">Alarm Severity</label>`;
        value += `<span class="small d-inline-flex a-i-center gap-4 m-l-auto"><i class="stroked-icon icon-14 status dlt-c8y-icon-${this.severityIconPipe.transform(alarm.severity)} ${alarm.severity.toLowerCase()}" > </i> ${this.severityLabelPipe.transform(alarm.severity)} </span></li>`;
        value += `<li class="p-t-4 p-b-4 d-flex separator-bottom text-no-wrap"><label class="text-label-small m-b-0 m-r-8">Alarm Type</label><span class="small m-l-auto"><code>${alarm.type}</code></span></li>`;
        value += `<li class="p-t-4 p-b-4 d-flex separator-bottom text-no-wrap"><label class="text-label-small m-b-0 m-r-8">Message</label><span class="small m-l-auto" style="overflow: hidden; text-overflow: ellipsis;" title="${alarm.text}">${alarm.text}</span></li>`;
        value += `<li class="p-t-4 p-b-4 d-flex separator-bottom text-no-wrap"><label class="text-label-small m-b-0 m-r-8">Last Updated</label><span class="small m-l-auto">${this.datePipe.transform(alarm['lastUpdated'])}</span></li>`;
        const exists = await this.alarmRouteExists();
        if (exists) {
            const currentUrl = window.location.href;
            const baseUrlIndex = currentUrl.indexOf(INDEX_HTML);
            const baseUrl = currentUrl.substring(0, baseUrlIndex + INDEX_HTML.length);
            value += `<li class="p-t-4 p-b-4 d-flex separator-bottom text-no-wrap"><label class="text-label-small m-b-0 m-r-8">Link</label><span class="small m-l-auto"><a href="${baseUrl}#/alarms/${alarm.id}/details?showCleared=true">${this.translate.instant(gettext('Alarm details'))}</a></span></li>`;
        }
        value += `<li class="p-t-4 p-b-4 d-flex text-no-wrap"><label class="text-label-small m-b-0 m-r-8">Alarm count</label><span class="small m-l-auto"><span class="badge badge-info">${alarm.count}</span></span></li>`;
        value += `</ul>`;
        return value;
    }
    async alarmRouteExists() {
        const exists = this.router.config.some(route => {
            return `${route.path}` === 'alarms';
        });
        return exists;
    }
    getChartSeries(datapointsWithValues, events, alarms, displayOptions) {
        const series = [];
        let eventSeries = [];
        let alarmSeries = [];
        datapointsWithValues.forEach((dp, idx) => {
            const renderType = dp.renderType || 'min';
            if (renderType === 'area') {
                series.push(this.getSingleSeries(dp, 'min', idx, true));
                series.push(this.getSingleSeries(dp, 'max', idx, true));
            }
            else {
                series.push(this.getSingleSeries(dp, renderType, idx, false));
            }
            const newEventSeries = this.getAlarmOrEventSeries(dp, renderType, false, events, 'event', displayOptions, null, idx);
            const newAlarmSeries = this.getAlarmOrEventSeries(dp, renderType, false, alarms, 'alarm', displayOptions, null, idx);
            eventSeries = [...eventSeries, ...newEventSeries];
            alarmSeries = [...alarmSeries, ...newAlarmSeries];
        });
        const deduplicateFilterCallback = (obj1, i, arr) => {
            const duplicates = arr.filter(obj2 => obj1['id'] === obj2['id'] && i !== arr.indexOf(obj2));
            if (duplicates.length > 0) {
                return obj1['isDpTemplateSelected'];
            }
            return true;
        };
        const deduplicateFilterCallbackFallback = (obj1, i, arr) => arr.findIndex(obj2 => obj2['id'] === obj1['id']) === i;
        let deduplicatedEvents = eventSeries.filter(deduplicateFilterCallback);
        let deduplicatedAlarms = alarmSeries.filter(deduplicateFilterCallback);
        if (deduplicatedAlarms.length === 0) {
            deduplicatedAlarms = alarmSeries.filter(deduplicateFilterCallbackFallback);
        }
        if (deduplicatedEvents.length === 0) {
            deduplicatedEvents = eventSeries.filter(deduplicateFilterCallbackFallback);
        }
        return [...series, ...deduplicatedEvents, ...deduplicatedAlarms];
    }
    groupByType(items, typeField) {
        return items.reduce((grouped, item) => {
            (grouped[item[typeField]] = grouped[item[typeField]] || []).push(item);
            return grouped;
        }, {});
    }
    /**
     * This method interpolates between two data points. The goal is to place the markPoint on the chart in the right place.
     * @param dpValuesArray array of data points
     * @param targetTime time of the alarm or event
     * @returns interpolated data point
     */
    interpolateBetweenTwoDps(dpValuesArray, targetTime) {
        let maxValue;
        let minValue;
        return dpValuesArray.reduce((acc, curr, idx, arr) => {
            if (new Date(curr.time).getTime() <= targetTime) {
                if (idx === arr.length - 1) {
                    return {
                        time: targetTime,
                        values: [{ min: minValue, max: maxValue }]
                    };
                }
                const nextDp = arr[idx + 1];
                if (new Date(nextDp.time).getTime() >= targetTime) {
                    const timeDiff = new Date(nextDp.time).getTime() - new Date(curr.time).getTime();
                    const targetTimeDiff = targetTime - new Date(curr.time).getTime();
                    const minValueDiff = nextDp.values[0]?.min - curr.values[0]?.min;
                    const maxValueDiff = nextDp.values[0]?.max - curr.values[0]?.max;
                    minValue = curr.values[0]?.min + (minValueDiff * targetTimeDiff) / timeDiff;
                    maxValue = curr.values[0]?.max + (maxValueDiff * targetTimeDiff) / timeDiff;
                    return {
                        time: targetTime,
                        values: [{ min: minValue, max: maxValue }]
                    };
                }
            }
            return acc;
        });
    }
    getClosestDpValueToTargetTime(dpValuesArray, targetTime) {
        return dpValuesArray.reduce((prev, curr) => 
        //should take the value closest to the target time, for realtime the current time would always change
        Math.abs(new Date(curr.time).getTime() - targetTime) <
            Math.abs(new Date(prev.time).getTime() - targetTime)
            ? curr
            : prev);
    }
    /**
     * This method creates a markPoint on the chart which represents the icon of the alarm or event.
     * @param item Single alarm or event
     * @param dp Data point
     * @param isCleared If the alarm is cleared in case of alarm
     * @param isEvent If the item is an event
     * @param realtime If the chart is in realtime mode
     * @returns MarkPointDataItemOption[]
     */
    createMarkPoint(item, dp, isCleared, isEvent, realtime) {
        // check if dp.values object is empty
        if (!item.creationTime || Object.keys(dp.values).length === 0) {
            return [];
        }
        const dpValuesArray = Object.entries(dp.values).map(([time, values]) => ({
            time: new Date(time).getTime(),
            values
        }));
        const creationTime = new Date(item.creationTime).getTime();
        const lastUpdatedTime = new Date(item['lastUpdated']).getTime();
        let coordCreationTime;
        let coordLastUpdatedTime;
        if (realtime) {
            const lastValue = dpValuesArray[dpValuesArray.length - 1];
            coordCreationTime = [
                item.creationTime,
                lastValue?.values[0]?.min ?? lastValue?.values[1] ?? null
            ];
            coordLastUpdatedTime = [
                item['lastUpdated'],
                lastValue?.values[0]?.min ?? lastValue?.values[1] ?? null
            ];
        }
        else {
            const closestDpValue = this.interpolateBetweenTwoDps(dpValuesArray, creationTime);
            const dpValuesForNewAlarms = this.getClosestDpValueToTargetTime(dpValuesArray, creationTime);
            const closestDpValueLastUpdated = this.interpolateBetweenTwoDps(dpValuesArray, lastUpdatedTime);
            const dpValuesForNewAlarmsLastUpdated = this.getClosestDpValueToTargetTime(dpValuesArray, lastUpdatedTime);
            coordCreationTime = [
                item.creationTime,
                closestDpValue?.values[0]?.min ??
                    closestDpValue?.values[1] ??
                    dpValuesForNewAlarms?.values[0]?.min ??
                    dpValuesForNewAlarms?.values[1] ??
                    null
            ];
            coordLastUpdatedTime = [
                item['lastUpdated'],
                closestDpValueLastUpdated?.values[0]?.min ??
                    closestDpValueLastUpdated?.values[1] ??
                    dpValuesForNewAlarmsLastUpdated?.values[0]?.min ??
                    dpValuesForNewAlarmsLastUpdated?.values[1] ??
                    null
            ];
        }
        if (isEvent) {
            return [
                {
                    coord: coordCreationTime,
                    name: item.type,
                    itemType: item.type,
                    itemStyle: {
                        color: item['color']
                    },
                    symbol: 'circle',
                    symbolSize: 24
                },
                {
                    coord: coordCreationTime,
                    name: item.type,
                    itemType: item.type,
                    itemStyle: { color: 'white' },
                    symbol: ICONS_MAP.EVENT,
                    symbolSize: 16
                }
            ];
        }
        return isCleared
            ? [
                {
                    coord: coordCreationTime,
                    name: item.type,
                    itemType: item.type,
                    itemStyle: {
                        color: item['color']
                    },
                    symbol: 'circle',
                    symbolSize: 24
                },
                {
                    coord: coordCreationTime,
                    name: item.type,
                    itemType: item.type,
                    itemStyle: { color: 'white' },
                    symbol: ICONS_MAP[item.severity],
                    symbolSize: 16
                },
                {
                    coord: coordLastUpdatedTime,
                    name: item.type,
                    itemType: item.type,
                    itemStyle: {
                        color: item['color']
                    },
                    symbol: 'circle',
                    symbolSize: 24
                },
                {
                    coord: coordLastUpdatedTime,
                    name: item.type,
                    itemType: item.type,
                    itemStyle: { color: 'white' },
                    symbol: ICONS_MAP.CLEARED,
                    symbolSize: 16
                }
            ]
            : [
                {
                    coord: coordCreationTime,
                    name: item.type,
                    itemType: item.type,
                    itemStyle: {
                        color: item['color']
                    },
                    symbol: 'circle',
                    symbolSize: 24
                },
                {
                    coord: coordCreationTime,
                    name: item.type,
                    itemType: item.type,
                    itemStyle: { color: 'white' },
                    symbol: ICONS_MAP[item.severity],
                    symbolSize: 16
                },
                {
                    coord: coordLastUpdatedTime,
                    name: item.type,
                    itemType: item.type,
                    itemStyle: {
                        color: item['color']
                    },
                    symbol: 'circle',
                    symbolSize: 24
                },
                {
                    coord: coordLastUpdatedTime,
                    name: item.type,
                    itemType: item.type,
                    itemStyle: { color: 'white' },
                    symbol: ICONS_MAP[item.severity],
                    symbolSize: 16
                }
            ];
    }
    /**
     * This method creates a markLine on the chart which represents the line between every alarm or event on the chart.
     * @param items Array of alarms or events
     * @returns MarkLineDataItemOptionBase[]
     */
    createMarkLine(items, itemType) {
        return items.reduce((acc, item) => {
            if (!item.creationTime) {
                return acc;
            }
            if (itemType === 'event') {
                return acc.concat([
                    {
                        xAxis: item.time,
                        itemType: item.type,
                        label: { show: false, formatter: () => item.type },
                        itemStyle: { color: item['color'] }
                    }
                ]);
            }
            if (item.creationTime === item['lastUpdated']) {
                return acc.concat([
                    {
                        xAxis: item.creationTime,
                        itemType: item.type,
                        label: { show: false, formatter: () => item.type },
                        itemStyle: { color: item['color'] }
                    }
                ]);
            }
            else {
                return acc.concat([
                    {
                        xAxis: item.creationTime,
                        itemType: item.type,
                        label: { show: false, formatter: () => item.type },
                        itemStyle: { color: item['color'] }
                    },
                    {
                        xAxis: item['lastUpdated'],
                        itemType: item.type,
                        label: { show: false, formatter: () => item.type },
                        itemStyle: { color: item['color'] }
                    }
                ]);
            }
        }, []);
    }
    getSingleSeries(dp, renderType, idx, isMinMaxChart = false, seriesType = '') {
        const datapointId = dp.__target?.id + dp.fragment + dp.series;
        return {
            datapointId,
            datapointUnit: dp.unit || '',
            // 'id' property is needed as 'seriesId' in tooltip formatter
            id: isMinMaxChart
                ? `${datapointId}/${renderType}${seriesType}`
                : `${datapointId}${seriesType}`,
            name: `${dp.label} (${dp.__target?.['name']})`,
            // datapointLabel used to proper display of tooltip
            datapointLabel: dp.label || '',
            data: Object.entries(dp.values).map(([dateString, values]) => {
                return [dateString, values[0][renderType]];
            }),
            yAxisIndex: idx,
            ...this.chartTypesService.getSeriesOptions(dp, isMinMaxChart, renderType)
        };
    }
    /**
     * This method creates a general tooltip formatter for the chart.
     * @returns TooltipFormatterCallback<TopLevelFormatterParams>
     */
    getTooltipFormatter() {
        return params => {
            if (!Array.isArray(params) || !params[0]?.data) {
                return '';
            }
            const data = params[0].data;
            const XAxisValue = data[0];
            const YAxisReadings = [];
            const allSeries = this.echartsInstance?.getOption()['series'];
            const allDataPointSeries = allSeries.filter(series => series['typeOfSeries'] !== 'alarm' &&
                series['typeOfSeries'] !== 'event' &&
                series['typeOfSeries'] !== 'fake');
            allDataPointSeries.forEach((series) => {
                let value;
                const id = series['id'];
                if (id.endsWith('/min')) {
                    const minValue = this.findValueForExactOrEarlierTimestamp(series['data'], XAxisValue);
                    if (!minValue) {
                        return;
                    }
                    const maxSeries = allDataPointSeries.find(s => s['id'] === id.replace('/min', '/max'));
                    if (!maxSeries) {
                        return;
                    }
                    const maxValue = this.findValueForExactOrEarlierTimestamp(maxSeries['data'], XAxisValue);
                    if (maxValue === null) {
                        return;
                    }
                    value =
                        `<div class="d-flex a-i-center separator-top p-t-8 p-b-8">` +
                            `<label class="text-12 m-r-8 m-b-0">${this.datePipe.transform(minValue[0])}</label>` +
                            `<div class="m-l-auto text-12" >${minValue[1]} — ${maxValue[1]}` +
                            (series['datapointUnit'] ? ` ${series['datapointUnit']}` : '') +
                            `</div></div>`;
                }
                else if (id.endsWith('/max')) {
                    // do nothing, value is handled  in 'min' case
                    return;
                }
                else {
                    const seriesValue = this.findValueForExactOrEarlierTimestamp(series['data'], XAxisValue);
                    if (!seriesValue) {
                        return;
                    }
                    value =
                        `<div class="d-flex a-i-center separator-top p-t-8 p-b-8">` +
                            `<label class="text-12 m-r-8 m-b-0">${this.datePipe.transform(seriesValue[0])}</label>` +
                            `<div class="m-l-auto text-12" >${seriesValue[1]?.toString()}` +
                            (series['datapointUnit'] ? ` ${series['datapointUnit']}` : '') +
                            `</div></div>`;
                }
                const itemStyle = series['itemStyle'];
                YAxisReadings.push(`<div class="d-flex a-i-center p-b-8"><span class='dlt-c8y-icon-circle m-r-4' style='color: ${itemStyle.color}'></span>` + // color circle
                    `<strong>${series['datapointLabel']} </strong></div>` + // name
                    `${value}` // single value or min-max range
                );
            });
            return `<div style="width: ${this.TOOLTIP_WIDTH}px">${YAxisReadings.join('')}</div>`;
        };
    }
    findValueForExactOrEarlierTimestamp(values, timestampString) {
        const timestamp = new Date(timestampString).valueOf();
        return values.reduce((acc, curr) => {
            if (new Date(curr[0]).valueOf() <= timestamp) {
                if (acc === null ||
                    Math.abs(new Date(curr[0]).valueOf() - timestamp) <
                        Math.abs(new Date(acc[0]).valueOf() - timestamp)) {
                    return curr;
                }
            }
            return acc;
        }, null);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EchartsOptionsService, deps: [{ token: i1$1.DatePipe }, { token: YAxisService }, { token: ChartTypesService }, { token: i4.AlarmSeverityToIconPipe }, { token: i4.AlarmSeverityToLabelPipe }, { token: i5.TranslateService }, { token: i6.Router }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EchartsOptionsService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EchartsOptionsService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1$1.DatePipe }, { type: YAxisService }, { type: ChartTypesService }, { type: i4.AlarmSeverityToIconPipe }, { type: i4.AlarmSeverityToLabelPipe }, { type: i5.TranslateService }, { type: i6.Router }] });

class ChartRealtimeService {
    constructor(measurementRealtime, alarmRealtimeService, eventRealtimeService, echartsOptionsService) {
        this.measurementRealtime = measurementRealtime;
        this.alarmRealtimeService = alarmRealtimeService;
        this.eventRealtimeService = eventRealtimeService;
        this.echartsOptionsService = echartsOptionsService;
        this.INTERVAL = 1000;
        this.MIN_REALTIME_TIMEOUT = 250;
        this.MAX_REALTIME_TIMEOUT = 5_000;
        this.lastMeasurements = new Map();
    }
    startRealtime(echartsInstance, datapoints, timeRange, datapointOutOfSyncCallback, timeRangeChangedCallback, alarmOrEventConfig = [], displayOptions) {
        this.echartsInstance = echartsInstance;
        this.currentTimeRange = {
            dateFrom: new Date(timeRange.dateFrom),
            dateTo: new Date(timeRange.dateTo)
        };
        const activeAlarmsOrEvents = alarmOrEventConfig.filter(alarmOrEvent => alarmOrEvent.__active && !alarmOrEvent.__hidden);
        const uniqueAlarmOrEventTargets = Array.from(new Set(activeAlarmsOrEvents.map(aOrE => aOrE.__target.id)));
        const allAlarmsAndEvents$ = from(uniqueAlarmOrEventTargets).pipe(mergeMap(targetId => {
            const alarmsRealtime$ = this.alarmRealtimeService.onAll$(targetId);
            const eventsRealtime$ = this.eventRealtimeService.onAll$(targetId);
            return merge(alarmsRealtime$, eventsRealtime$).pipe(map(realtimeMessage => realtimeMessage.data));
        }));
        const measurementsForDatapoints = datapoints.map(dp => {
            const source$ = this.measurementRealtime.onCreateOfSpecificMeasurement$(dp.fragment, dp.series, dp.__target?.id);
            return source$.pipe(map((measurement) => ({ datapoint: dp, measurement })));
        });
        const updateThrottleTime = this.getRealtimeUpdateThrottleTime(timeRange);
        const measurement$ = merge(...measurementsForDatapoints);
        const bufferReset$ = merge(measurement$.pipe(throttleTime(updateThrottleTime)), interval(this.INTERVAL).pipe(tap(() => {
            this.currentTimeRange = {
                dateFrom: new Date((this.currentTimeRange?.dateFrom?.valueOf() || 0) + this.INTERVAL),
                dateTo: new Date((this.currentTimeRange?.dateTo?.valueOf() || 0) + this.INTERVAL)
            };
            timeRangeChangedCallback(this.currentTimeRange);
        }), throttleTime(updateThrottleTime))).pipe(throttleTime(this.MIN_REALTIME_TIMEOUT));
        this.realtimeSubscriptionMeasurements = measurement$
            .pipe(buffer(bufferReset$))
            .subscribe(measurements => {
            this.updateChartInstance(measurements, null, displayOptions, datapointOutOfSyncCallback);
            // Store the last measurements
            measurements.forEach(measurement => {
                this.lastMeasurements.set(measurement.datapoint.fragment, measurement);
            });
        });
        this.realtimeSubscriptionAlarmsEvents = allAlarmsAndEvents$
            .pipe(map(alarmOrEvent => {
            const foundAlarmOrEvent = activeAlarmsOrEvents.find(aOrE => {
                return aOrE.filters.type === alarmOrEvent.type;
            });
            if (foundAlarmOrEvent) {
                alarmOrEvent['color'] = foundAlarmOrEvent.color;
                alarmOrEvent['selectedDatapoint'] = foundAlarmOrEvent.selectedDatapoint;
            }
            if (foundAlarmOrEvent) {
                const fragment = alarmOrEvent['selectedDatapoint'].fragment;
                if (this.lastMeasurements.has(fragment)) {
                    const lastMeasurement = this.lastMeasurements.get(fragment);
                    this.updateChartInstance([lastMeasurement], alarmOrEvent, displayOptions, datapointOutOfSyncCallback);
                }
            }
            return foundAlarmOrEvent ? alarmOrEvent : null;
        }))
            .subscribe();
    }
    stopRealtime() {
        this.realtimeSubscriptionMeasurements?.unsubscribe();
        this.realtimeSubscriptionAlarmsEvents?.unsubscribe();
    }
    removeValuesBeforeTimeRange(series) {
        const firstValidValueByDateIndex = series.data.findIndex(([dateString, _]) => {
            return new Date(dateString) >= (this.currentTimeRange?.dateFrom || new Date());
        });
        if (firstValidValueByDateIndex > 1) {
            // we need one value before dateFrom for chart lines to be extended to the left edge of the graph
            series.data = series.data.slice(firstValidValueByDateIndex - 1);
        }
        return series.data;
    }
    getRealtimeUpdateThrottleTime(timeRange) {
        const timeRangeInMs = new Date(timeRange.dateTo).valueOf() - new Date(timeRange.dateFrom).valueOf();
        const calculatedThrottleTime = Math.round(timeRangeInMs / 1000);
        if (calculatedThrottleTime < this.MIN_REALTIME_TIMEOUT) {
            return this.MIN_REALTIME_TIMEOUT;
        }
        else if (calculatedThrottleTime > this.MAX_REALTIME_TIMEOUT) {
            return this.MAX_REALTIME_TIMEOUT;
        }
        return calculatedThrottleTime;
    }
    updateChartInstance(receivedMeasurements, alarmOrEvent, displayOptions, datapointOutOfSyncCallback) {
        const isEvent = (item) => !('severity' in item);
        const isAlarm = (item) => 'severity' in item;
        const seriesDataToUpdate = new Map();
        receivedMeasurements.forEach(({ datapoint, measurement }) => {
            if (!seriesDataToUpdate.has(datapoint)) {
                seriesDataToUpdate.set(datapoint, []);
            }
            seriesDataToUpdate.get(datapoint)?.push(measurement);
        });
        let allDataSeries = this.echartsInstance?.getOption()['series'];
        seriesDataToUpdate.forEach((measurements, datapoint) => {
            const newValues = measurements.map(m => [
                m.time,
                m[datapoint.fragment][datapoint.series].value
            ]);
            const datapointId = datapoint.__target?.id + datapoint.fragment + datapoint.series;
            const seriesMatchingDatapoint = allDataSeries.find(s => s['datapointId'] === datapointId);
            if (!seriesMatchingDatapoint) {
                return;
            }
            const seriesDataToUpdate = seriesMatchingDatapoint['data'];
            seriesDataToUpdate.push(...newValues);
            seriesMatchingDatapoint['data'] = this.removeValuesBeforeTimeRange(seriesMatchingDatapoint);
            if (alarmOrEvent) {
                const renderType = datapoint.renderType || 'min';
                const dp = {
                    ...datapoint,
                    values: seriesMatchingDatapoint['data']
                };
                if (isEvent(alarmOrEvent)) {
                    // if event series with the same id already exists, return
                    const eventExists = allDataSeries.some(series => series['data'].some(data => data[0] === alarmOrEvent.creationTime));
                    if (eventExists) {
                        return;
                    }
                    const newEventSeries = this.echartsOptionsService.getAlarmOrEventSeries(dp, renderType, false, [alarmOrEvent], 'event', displayOptions, alarmOrEvent.creationTime, null, true);
                    allDataSeries.push(...newEventSeries);
                }
                else if (isAlarm(alarmOrEvent)) {
                    const alarmExists = allDataSeries.some((series) => {
                        const seriesData = series['data'];
                        return seriesData.some((data) => data[0] === alarmOrEvent.creationTime);
                    });
                    if (alarmExists) {
                        const alarmSeries = allDataSeries.filter((series) => {
                            const seriesData = series['data'];
                            return seriesData.some((data) => data[0] === alarmOrEvent.creationTime);
                        });
                        // remove all matching alarm series which are in the array
                        alarmSeries.forEach(series => {
                            allDataSeries = allDataSeries.filter(s => s['id'] !== series['id']);
                        });
                        const newAlarmSeries = this.echartsOptionsService.getAlarmOrEventSeries(dp, renderType, false, [alarmOrEvent], 'alarm', displayOptions, alarmOrEvent.creationTime, null, true);
                        allDataSeries.push(...newAlarmSeries);
                    }
                    else {
                        const newAlarmSeries = this.echartsOptionsService.getAlarmOrEventSeries(dp, renderType, false, [alarmOrEvent], 'alarm', displayOptions, alarmOrEvent.id, null, true);
                        allDataSeries.push(...newAlarmSeries);
                    }
                }
            }
            this.checkForValuesAfterTimeRange(seriesMatchingDatapoint['data'], datapoint, datapointOutOfSyncCallback);
        });
        this.echartsInstance?.setOption({
            dataZoom: [
                {
                    type: 'inside',
                    startValue: this.currentTimeRange?.dateFrom.valueOf(),
                    endValue: this.currentTimeRange?.dateTo.valueOf()
                }
            ],
            xAxis: {
                max: this.currentTimeRange?.dateTo
            },
            series: allDataSeries
        });
    }
    checkForValuesAfterTimeRange(data, datapoint, datapointOutOfSyncCallback) {
        const now = new Date();
        const valueAfterNowExists = data.some(([dateString, _]) => {
            return new Date(dateString).valueOf() > now.valueOf();
        });
        if (valueAfterNowExists) {
            datapointOutOfSyncCallback(datapoint);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChartRealtimeService, deps: [{ token: i1$1.MeasurementRealtimeService }, { token: i1$1.AlarmRealtimeService }, { token: i1$1.EventRealtimeService }, { token: EchartsOptionsService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChartRealtimeService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChartRealtimeService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1$1.MeasurementRealtimeService }, { type: i1$1.AlarmRealtimeService }, { type: i1$1.EventRealtimeService }, { type: EchartsOptionsService }] });

class ChartAlertsComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChartAlertsComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: ChartAlertsComponent, isStandalone: true, selector: "c8y-chart-alerts", inputs: { alerts: "alerts" }, ngImport: i0, template: "<div\n  class=\"overlay-center-vertically d-flex d-col a-i-stretch j-c-start p-16 p-r-24 p-l-24\"\n  *ngIf=\"alerts?.anyAlertExists$ | async\"\n>\n  <ng-container *ngFor=\"let alertGroup of alerts?.alertGroups\">\n    <div\n      *ngIf=\"alertGroup.value.alerts.length\"\n      class=\"alert\"\n      role=\"alert\"\n      [ngClass]=\"'alert-' + alertGroup.type\"\n    >\n      <button\n        class=\"close\"\n        type=\"button\"\n        (click)=\"\n          alerts.dismissAlertGroup(alertGroup.type, dismissPermanently.checked)\n        \"\n      >\n        <span aria-hidden=\"true\">\u00D7</span>\n        <span class=\"sr-only\">{{ 'Close' | translate }}</span>\n      </button>\n      <p *ngFor=\"let alertItem of alertGroup.value.alerts\">\n        {{ alertItem.text | translate }}\n      </p>\n      <label\n        title=\"{{ 'Don\\'t show again' | translate }}\"\n        class=\"c8y-checkbox m-t-16\"\n      >\n        <input type=\"checkbox\" #dismissPermanently />\n        <span></span>\n        <span>{{ \"Don't show again\" | translate }}</span>\n      </label>\n    </div>\n  </ng-container>\n</div>\n", dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "pipe", type: i1$1.C8yTranslatePipe, name: "translate" }, { kind: "directive", type: i2$1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i2$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i2$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "pipe", type: i2$1.AsyncPipe, name: "async" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChartAlertsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-chart-alerts', standalone: true, imports: [CommonModule], template: "<div\n  class=\"overlay-center-vertically d-flex d-col a-i-stretch j-c-start p-16 p-r-24 p-l-24\"\n  *ngIf=\"alerts?.anyAlertExists$ | async\"\n>\n  <ng-container *ngFor=\"let alertGroup of alerts?.alertGroups\">\n    <div\n      *ngIf=\"alertGroup.value.alerts.length\"\n      class=\"alert\"\n      role=\"alert\"\n      [ngClass]=\"'alert-' + alertGroup.type\"\n    >\n      <button\n        class=\"close\"\n        type=\"button\"\n        (click)=\"\n          alerts.dismissAlertGroup(alertGroup.type, dismissPermanently.checked)\n        \"\n      >\n        <span aria-hidden=\"true\">\u00D7</span>\n        <span class=\"sr-only\">{{ 'Close' | translate }}</span>\n      </button>\n      <p *ngFor=\"let alertItem of alertGroup.value.alerts\">\n        {{ alertItem.text | translate }}\n      </p>\n      <label\n        title=\"{{ 'Don\\'t show again' | translate }}\"\n        class=\"c8y-checkbox m-t-16\"\n      >\n        <input type=\"checkbox\" #dismissPermanently />\n        <span></span>\n        <span>{{ \"Don't show again\" | translate }}</span>\n      </label>\n    </div>\n  </ng-container>\n</div>\n" }]
        }], propDecorators: { alerts: [{
                type: Input
            }] } });

class ChartEventsService {
    constructor(eventService) {
        this.eventService = eventService;
    }
    /**
     * List events for the given event details.
     * @param params Additonal fetchOptions
     * @param events List of event types with details like color, target, etc.
     * @returns List of events for the given event details
     */
    async listEvents(params, events) {
        if (!events) {
            return [];
        }
        const promises = events.map(event => {
            const fetchOptions = {
                source: event.__target.id,
                type: event.filters.type,
                withTotalPages: true,
                pageSize: 1000,
                ...params
            };
            return this.eventService.list(fetchOptions).then(result => {
                result.data.forEach(iEvent => {
                    iEvent['color'] = event.color;
                    iEvent['selectedDatapoint'] = event.selectedDatapoint;
                });
                return result.data;
            });
        });
        const result = await Promise.all(promises);
        return result.flat();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChartEventsService, deps: [{ token: i1.EventService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChartEventsService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChartEventsService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.EventService }] });

class ChartAlarmsService {
    constructor(alarmService) {
        this.alarmService = alarmService;
    }
    /**
     * List alarms for the given alarm details.
     * @param params Additonal fetchOptions
     * @param alarms List of alarm types with details like color, target, etc.
     * @returns List of alarms for the given alarm details
     */
    async listAlarms(params, alarms) {
        if (!alarms) {
            return [];
        }
        const promises = alarms.map(alarm => {
            if (alarm.__severity && alarm.__severity?.length > 0) {
                const severities = alarm.__severity.join(',');
                params = {
                    ...params,
                    severity: severities
                };
            }
            if (alarm.__status && alarm.__status?.length > 0) {
                const statuses = alarm.__status.join(',');
                params = {
                    ...params,
                    status: statuses
                };
            }
            const fetchOptions = {
                source: alarm.__target.id,
                type: alarm.filters.type,
                withTotalPages: true,
                pageSize: 1000,
                ...params
            };
            return this.alarmService.list(fetchOptions).then(result => {
                result.data.forEach(iAlarm => {
                    iAlarm['color'] = alarm.color;
                    iAlarm['selectedDatapoint'] = alarm.selectedDatapoint;
                });
                return result.data;
            });
        });
        const result = await Promise.all(promises);
        return result.flat();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChartAlarmsService, deps: [{ token: i1.AlarmService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChartAlarmsService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChartAlarmsService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.AlarmService }] });

/* eslint-disable @typescript-eslint/no-explicit-any */
class ChartsComponent {
    constructor() {
        this.showLoadMore = false;
        this.alarms = [];
        this.events = [];
        this.sliderZoomUsed = false;
        this.configChangeOnZoomOut = new EventEmitter();
        this.timeRangeChangeOnRealtime = new EventEmitter();
        this.datapointOutOfSync = new EventEmitter();
        this.updateAlarmsAndEvents = new EventEmitter();
        this.isMarkedAreaEnabled = new EventEmitter();
        this.configChangedSubject = new BehaviorSubject(null);
        this.measurementService = inject(CustomMeasurementService);
        this.echartsOptionsService = inject(EchartsOptionsService);
        this.chartRealtimeService = inject(ChartRealtimeService);
        this.chartEventsService = inject(ChartEventsService);
        this.chartAlarmsService = inject(ChartAlarmsService);
        this.widgetTimeContextDateRangeService = inject(WidgetTimeContextDateRangeService);
        this.loadedTimeRange = null;
        this.chartOption$ = this.configChangedSubject.pipe(switchMap(() => this.loadAlarmsAndEvents()), switchMap(() => this.fetchSeriesForDatapoints$()), switchMap((datapointsWithValues) => {
            if (datapointsWithValues.length === 0) {
                this.echartsInstance?.clear();
                this.showLoadMore = false;
                return of(this.getDefaultChartOptions());
            }
            this.loadedTimeRange = { ...this.getTimeRange() };
            return this.getChartOptions(datapointsWithValues);
        }), tap(v => {
            if (v['empty']) {
                return;
            }
            this.chartRealtimeService.stopRealtime();
            this.startRealtimeIfPossible();
            if (this.echartsInstance) {
                /**
                 * * Set the chart options
                 * First parameter is the options to set
                 * Second parameter is a boolean to indicate that the chart should be re-rendered as we do not want to merge.
                 * Third parameter is a boolean to indicate that we want to lazy load the chart.
                 */
                this.echartsInstance.setOption(v, true, true);
                const options = this.echartsInstance.getOption();
                const dataZoom = options['dataZoom'][0];
                if (dataZoom.start !== 0) {
                    this.showLoadMore = false;
                }
            }
            this.sliderZoomUsed = false;
        }));
    }
    ngOnChanges(changes) {
        const currentTimeRange = this.getTimeRange();
        // Check if the current time range is within the loaded time range to avoid unnecessary updates
        if (this.loadedTimeRange &&
            new Date(currentTimeRange.dateFrom) >= new Date(this.loadedTimeRange.dateFrom) &&
            new Date(currentTimeRange.dateTo) <= new Date(this.loadedTimeRange.dateTo) &&
            changes.config.previousValue?.dateFrom !== changes.config.currentValue.dateFrom &&
            changes.config.previousValue?.dateTo !== changes.config.currentValue.dateTo) {
            return;
        }
        this.configChangedSubject.next();
    }
    ngOnInit() {
        if (this.alerts) {
            this.alerts.setAlertGroupDismissStrategy('warning', DismissAlertStrategy.TEMPORARY_OR_PERMANENT);
        }
    }
    ngOnDestroy() {
        this.chartRealtimeService.stopRealtime();
    }
    onChartInit(ec) {
        this.echartsInstance = ec;
        this.echartsOptionsService.echartsInstance = this.echartsInstance;
        this.startRealtimeIfPossible();
        const dataZoomHandler = (evt) => {
            if (evt.batch?.[0]?.start === 0 || evt['start'] === 0) {
                this.showLoadMore = true;
            }
            const options = this.echartsInstance.getOption();
            const dataZoom = options['dataZoom'][0];
            this.sliderZoomUsed = true;
            this.configChangeOnZoomOut.emit({
                dateFrom: new Date(dataZoom['startValue']),
                dateTo: new Date(dataZoom['endValue']),
                interval: 'custom'
            });
            this.echartsInstance.setOption(options);
            this.chartRealtimeService.stopRealtime();
        };
        const debouncedDataZoomHandler = this.config.realtime
            ? dataZoomHandler
            : this.debounce(dataZoomHandler, 1000);
        this.echartsInstance.on('dataZoom', debouncedDataZoomHandler);
        this.echartsInstance.on('click', this.onChartClick.bind(this));
        let originalFormatter = null;
        this.echartsInstance.on('mouseover', (params) => {
            if (params?.componentType !== 'markLine' && params?.componentType !== 'markPoint') {
                return;
            }
            const options = this.echartsInstance.getOption();
            if (!options.tooltip || !Array.isArray(options.tooltip) || !options.tooltip[0]) {
                return;
            }
            originalFormatter = originalFormatter ?? options['tooltip'][0].formatter;
            const updatedOptions = { tooltip: options['tooltip'][0] };
            if (!updatedOptions.tooltip) {
                return;
            }
            updatedOptions.tooltip.formatter = (tooltipParams) => {
                return this.echartsOptionsService.getTooltipFormatterForAlarmAndEvents(tooltipParams, params, this.events, this.alarms);
            };
            this.echartsInstance.setOption(updatedOptions);
        });
        this.echartsInstance.on('mouseout', () => {
            const options = this.echartsInstance.getOption();
            if (originalFormatter) {
                options['tooltip'][0].formatter = originalFormatter;
                this.echartsInstance.setOption(options);
            }
        });
    }
    onChartClick(params) {
        const options = this.echartsInstance.getOption();
        if (!this.isAlarmClick(params)) {
            this.echartsInstance.setOption({
                tooltip: { triggerOn: 'mousemove' },
                series: [{ markArea: { data: [] }, markLine: { data: [] } }]
            });
            return;
        }
        const clickedAlarms = this.alarms.filter(alarm => alarm.type === params.data.itemType);
        this.isMarkedAreaEnabled.emit(this.hasMarkArea(options));
        const updatedOptions = !this.hasMarkArea(options)
            ? {
                tooltip: { enterable: true, triggerOn: 'click' },
                series: [
                    {
                        markArea: { label: { show: false }, data: this.getMarkedAreaData(clickedAlarms) },
                        markLine: {
                            showSymbol: true,
                            symbol: ['none', 'none'],
                            data: this.getMarkedLineData(clickedAlarms)
                        }
                    }
                ]
            }
            : // if markArea already exists, remove it and remove lastUpdated from markLine
                {
                    tooltip: { triggerOn: 'mousemove' },
                    series: [{ markArea: { data: [] }, markLine: { data: [] } }]
                };
        this.echartsInstance.setOption(updatedOptions);
    }
    isAlarmClick(params) {
        return this.alarms.some(alarm => alarm.type === params.data.itemType);
    }
    hasMarkArea(options) {
        return options?.series?.[0]?.markArea?.data?.length > 0;
    }
    saveAsImage() {
        this.echartsInstance.setOption({ legend: { show: true } });
        const url = this.echartsInstance.getDataURL({
            pixelRatio: 2,
            backgroundColor: '#fff',
            type: 'png'
        });
        const link = document.createElement('a');
        link.href = url;
        link.download = 'datapoints-graph-screenshot';
        document.body.appendChild(link);
        link.click();
        document.body.removeChild(link);
        this.echartsInstance.setOption({ legend: { show: false } });
    }
    loadMoreData() {
        const currentTimeRangeInMs = this.echartsOptionsService.calculateExtendedIntervalInMs(this.config.interval || 'custom', {
            dateTo: this.widgetTimeContextDateRangeService.initialTimeRange().dateTo,
            dateFrom: this.widgetTimeContextDateRangeService.initialTimeRange().dateFrom
        });
        this.widgetTimeContextDateRangeService.updateInitialTimeRange({
            dateFrom: new Date(new Date(this.widgetTimeContextDateRangeService.initialTimeRange().dateFrom).valueOf() -
                currentTimeRangeInMs / 4).toISOString(),
            dateTo: this.widgetTimeContextDateRangeService.initialTimeRange().dateTo,
            interval: 'custom'
        });
        const options = this.echartsInstance.getOption();
        const dataZoom = options['dataZoom'][0];
        this.configChangeOnZoomOut.emit({
            dateFrom: new Date(dataZoom['startValue']),
            dateTo: new Date(dataZoom['endValue']),
            interval: 'custom'
        });
        this.showLoadMore = false;
    }
    debounce(func, wait) {
        let timeout;
        return (...args) => {
            clearTimeout(timeout);
            timeout = setTimeout(() => func(...args), wait);
        };
    }
    /**
     * Toggles the visibility of a series in the chart based on the provided datapoint.
     * @param datapoint - The datapoint to toggle visibility for.
     */
    toggleDatapointSeriesVisibility(datapoint) {
        const series = this.echartsInstance.getOption().series;
        const seriesToUpdate = series.find(s => s.datapointLabel === datapoint.label);
        if (seriesToUpdate) {
            this.echartsInstance.dispatchAction({
                type: 'legendToggleSelect',
                name: seriesToUpdate.name
            });
        }
    }
    /**
     * Toggles the visibility of a series in the chart based on the provided alarm or event.
     * @param alarmOrEvent - The alarm or event to toggle visibility for.
     */
    toggleAlarmEventSeriesVisibility(alarmOrEvent) {
        const series = this.echartsInstance.getOption().series;
        const seriesToUpdate = series.filter(s => s.name === `${alarmOrEvent.label}-markPoint` || s.name === `${alarmOrEvent.label}-markLine`);
        if (seriesToUpdate) {
            seriesToUpdate.forEach(s => {
                this.echartsInstance.dispatchAction({
                    type: 'legendToggleSelect',
                    name: s.name
                });
            });
        }
    }
    getDefaultChartOptions() {
        return {
            title: {
                text: gettext('No data available.'),
                left: 'center',
                top: 'center',
                textStyle: { fontSize: 30 }
            },
            empty: true,
            xAxis: { type: 'category', data: [] },
            yAxis: { type: 'value' },
            series: []
        };
    }
    getMarkedAreaData(clickedAlarms) {
        const timeRange = this.getTimeRange();
        const clearedAlarmColor = 'rgba(221,255,221,1.00)';
        const activeAlarmColor = 'rgba(255, 173, 177, 0.4)';
        return clickedAlarms.map(clickedAlarm => {
            return [
                {
                    name: clickedAlarm.type,
                    xAxis: clickedAlarm.creationTime,
                    itemStyle: {
                        color: clickedAlarm.status === AlarmStatus.CLEARED ? clearedAlarmColor : activeAlarmColor
                    }
                },
                {
                    xAxis: clickedAlarm['lastUpdated'] === clickedAlarm.creationTime ||
                        clickedAlarm.status !== AlarmStatus.CLEARED
                        ? timeRange.dateTo
                        : clickedAlarm['lastUpdated']
                }
            ];
        });
    }
    getMarkedLineData(clickedAlarms) {
        return clickedAlarms.reduce((acc, alarm) => {
            const isClickedAlarmCleared = alarm.status === AlarmStatus.CLEARED;
            if (isClickedAlarmCleared) {
                return acc.concat([
                    {
                        xAxis: alarm.creationTime,
                        itemType: alarm.type,
                        label: { show: false, formatter: () => alarm.type },
                        itemStyle: { color: alarm['color'] }
                    },
                    {
                        xAxis: alarm['lastUpdated'],
                        itemType: alarm.type,
                        label: { show: false, formatter: () => alarm.type },
                        itemStyle: { color: alarm['color'] }
                    }
                ]);
            }
            return acc.concat([
                {
                    xAxis: alarm.creationTime,
                    itemType: alarm.type,
                    label: { show: false, formatter: () => alarm.type },
                    itemStyle: { color: alarm['color'] }
                }
            ]);
        }, []);
    }
    async loadAlarmsAndEvents(customTimeRange) {
        const timeRange = this.getTimeRange();
        const updatedTimeRange = {
            lastUpdatedFrom: customTimeRange ? customTimeRange.dateFrom : timeRange.dateFrom,
            createdTo: customTimeRange ? customTimeRange.dateTo : timeRange.dateTo
        };
        if (!this.config.alarmsEventsConfigs)
            return;
        const visibleAlarmsOrEvents = this.config.alarmsEventsConfigs?.filter(alarmOrEvent => !alarmOrEvent.__hidden && alarmOrEvent.__active);
        const alarms = visibleAlarmsOrEvents?.filter(alarmOrEvent => alarmOrEvent.timelineType === 'ALARM');
        const events = visibleAlarmsOrEvents?.filter(alarmOrEvent => alarmOrEvent.timelineType === 'EVENT');
        const [listedEvents, listedAlarms] = await Promise.all([
            this.chartEventsService.listEvents(updatedTimeRange, events),
            this.chartAlarmsService.listAlarms(updatedTimeRange, alarms)
        ]);
        this.events = listedEvents;
        this.alarms = listedAlarms;
        await this.addActiveAlarms(alarms);
        this.updateAlarmsAndEvents.emit(this.config.alarmsEventsConfigs);
    }
    startRealtimeIfPossible() {
        const activeDatapoints = this.config?.datapoints?.filter(dp => dp.__active);
        if (activeDatapoints && this.config.realtime && this.echartsInstance) {
            this.chartRealtimeService.startRealtime(this.echartsInstance, activeDatapoints, this.getTimeRange(), dp => this.datapointOutOfSync.emit(dp), timeRange => this.timeRangeChangeOnRealtime.emit(timeRange), this.config.alarmsEventsConfigs, {
                displayMarkedLine: this.config.displayMarkedLine || false,
                displayMarkedPoint: this.config.displayMarkedPoint || false
            });
        }
    }
    /*
    This method should check and add active alarms from the begining of time to the alarm array
    */
    async addActiveAlarms(alarms) {
        const timeRange = this.getTimeRange();
        const params = {
            dateFrom: '1970-01-01T01:00:00+01:00',
            dateTo: timeRange.dateTo,
            status: AlarmStatus.ACTIVE
        };
        const activeAlarms = await this.chartAlarmsService.listAlarms(params, alarms);
        this.config.activeAlarmTypesOutOfRange = [];
        // iterate through the activeAlarms and check if the alarm is in the alarms array, if not update the config.activeAlarmTypesOutOfRange prop
        activeAlarms.forEach(activeAlarm => {
            const alarmType = activeAlarm.type;
            const alarm = this.alarms.find(alarm => alarm.type === alarmType);
            if (!alarm && this.config.activeAlarmTypesOutOfRange) {
                this.config.activeAlarmTypesOutOfRange.push(alarmType);
            }
        });
    }
    async getChartOptions(datapointsWithValues) {
        const timeRange = { ...this.getTimeRange(), interval: this.config.interval };
        if (!this.widgetTimeContextDateRangeService.initialTimeRange()) {
            this.widgetTimeContextDateRangeService.updateInitialTimeRange(timeRange);
            const aggregatedDatapoints = await lastValueFrom(this.fetchSeriesForDatapoints$({
                dateFrom: new Date(new Date(timeRange.dateFrom).valueOf() -
                    this.echartsOptionsService.calculateExtendedIntervalInMs(this.config.interval || 'custom', { dateFrom: timeRange.dateFrom, dateTo: timeRange.dateTo })).toISOString(),
                dateTo: timeRange.dateTo
            }));
            return this.echartsOptionsService.getChartOptions(datapointsWithValues, timeRange, {
                YAxis: this.config.yAxisSplitLines || false,
                XAxis: this.config.xAxisSplitLines || false
            }, this.events, this.alarms, {
                displayMarkedLine: this.config.displayMarkedLine || false,
                displayMarkedPoint: this.config.displayMarkedPoint || false,
                mergeMatchingDatapoints: this.config.mergeMatchingDatapoints || false,
                showLabelAndUnit: this.config.showLabelAndUnit || false,
                showSlider: this.config.showSlider || false
            }, undefined, aggregatedDatapoints);
        }
        else {
            const aggregatedDatapoints = await lastValueFrom(this.fetchSeriesForDatapoints$({
                dateFrom: new Date(new Date(this.widgetTimeContextDateRangeService.initialTimeRange().dateFrom).valueOf() -
                    this.echartsOptionsService.calculateExtendedIntervalInMs(this.config.interval || 'custom', {
                        dateFrom: this.widgetTimeContextDateRangeService.initialTimeRange().dateFrom,
                        dateTo: this.widgetTimeContextDateRangeService.initialTimeRange().dateTo
                    })).toISOString(),
                dateTo: new Date(this.widgetTimeContextDateRangeService.initialTimeRange().dateTo).toISOString()
            }));
            return this.echartsOptionsService.getChartOptions(datapointsWithValues, this.widgetTimeContextDateRangeService.initialTimeRange(), {
                YAxis: this.config.yAxisSplitLines || false,
                XAxis: this.config.xAxisSplitLines || false
            }, this.events, this.alarms, {
                displayMarkedLine: this.config.displayMarkedLine || false,
                displayMarkedPoint: this.config.displayMarkedPoint || false,
                mergeMatchingDatapoints: this.config.mergeMatchingDatapoints || false,
                showLabelAndUnit: this.config.showLabelAndUnit || false,
                showSlider: this.config.showSlider || false
            }, timeRange, aggregatedDatapoints, true);
        }
    }
    fetchSeriesForDatapoints$(customTimeRange) {
        const activeDatapoints = this.config?.datapoints?.filter(dp => dp.__active);
        if (!activeDatapoints || activeDatapoints.length === 0) {
            return of([]);
        }
        const datapointsWithValuesRequests = [];
        const timeRange = this.getTimeRange(60_000);
        for (const dp of activeDatapoints) {
            const request = this.measurementService
                .listSeries$({
                ...(customTimeRange ? customTimeRange : timeRange),
                source: dp.__target?.id || '',
                series: [`${dp.fragment}.${dp.series}`],
                ...(this.config.aggregation || customTimeRange
                    ? {
                        aggregationType: customTimeRange ? aggregationType.HOURLY : this.config.aggregation
                    }
                    : {})
            })
                .pipe(map(res => {
                const values = res.data.values;
                if (res.data.truncated && this.config.dateFrom) {
                    values[new Date(this.config.dateFrom).toISOString()] = [{ min: null, max: null }];
                }
                else {
                    if (this.alerts) {
                        this.alerts.clear();
                    }
                }
                return { ...dp, values, truncated: res.data.truncated };
            }));
            datapointsWithValuesRequests.push(request);
        }
        return forkJoin(datapointsWithValuesRequests).pipe(tap((dpsWithValues) => {
            if (dpsWithValues.some(dp => dp['truncated'])) {
                this.addTruncatedDataAlert();
            }
        }));
    }
    addTruncatedDataAlert() {
        if (this.alerts?.alertGroups.find(a => a.type === 'warning')?.value?.alerts?.length) {
            return;
        }
        const alert = new DynamicComponentAlert({
            type: 'warning',
            text: gettext('Truncated data. Change aggregation or select shorter date range.')
        });
        this.alerts?.addAlerts(alert);
    }
    getTimeRange(additionalPadding) {
        let timeRange;
        if (this.config.widgetInstanceGlobalTimeContext ||
            (this.config.interval === 'custom' && !this.config.realtime)) {
            timeRange = {
                dateFrom: new Date(this.config.dateFrom),
                dateTo: new Date(this.config.dateTo)
            };
        }
        else {
            let timeRangeInMs = 0;
            if (this.config.interval && this.config.interval !== 'custom') {
                timeRangeInMs = INTERVALS.find(i => i.id === this.config.interval)?.timespanInMs || 0;
            }
            else if (this.config.realtime) {
                timeRangeInMs =
                    new Date(this.config.dateTo).valueOf() -
                        new Date(this.config.dateFrom).valueOf();
            }
            const now = new Date();
            timeRange = { dateFrom: new Date(now.valueOf() - timeRangeInMs), dateTo: now };
        }
        if (additionalPadding) {
            timeRange.dateFrom = new Date(timeRange.dateFrom.valueOf() - additionalPadding);
            timeRange.dateTo = new Date(timeRange.dateTo.valueOf() + additionalPadding);
        }
        return { dateFrom: timeRange.dateFrom.toISOString(), dateTo: timeRange.dateTo.toISOString() };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChartsComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: ChartsComponent, isStandalone: true, selector: "c8y-charts", inputs: { config: "config", alerts: "alerts" }, outputs: { configChangeOnZoomOut: "configChangeOnZoomOut", timeRangeChangeOnRealtime: "timeRangeChangeOnRealtime", datapointOutOfSync: "datapointOutOfSync", updateAlarmsAndEvents: "updateAlarmsAndEvents", isMarkedAreaEnabled: "isMarkedAreaEnabled" }, providers: [
            { provide: NGX_ECHARTS_CONFIG, useFactory: () => ({ echarts: () => import('echarts') }) },
            ChartRealtimeService,
            MeasurementRealtimeService,
            AlarmRealtimeService,
            EventRealtimeService,
            ChartTypesService,
            EchartsOptionsService,
            CustomMeasurementService,
            YAxisService,
            AlarmSeverityToIconPipe,
            AlarmSeverityToLabelPipe
        ], viewQueries: [{ propertyName: "chart", first: true, predicate: ["chart"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "<div\n  class=\"p-relative fit-h chart-container\"\n>\n  <div\n    class=\"fit-w fit-h\"\n    #chart\n    echarts\n    [options]=\"chartOption$ | async\"\n    (chartInit)=\"onChartInit($event)\"\n  ></div>\n\n  <c8y-chart-alerts [alerts]=\"alerts\"></c8y-chart-alerts>\n\n  <div *ngIf=\"showLoadMore\" class=\"chart-load-more\">\n    <button\n      class=\"btn btn-primary btn-sm btn-block\"\n      (click)=\"loadMoreData()\"\n    >\n      <i c8yIcon=\"restore\"></i>\n      {{ 'Load more' | translate }}\n    </button>\n  </div>\n</div>\n", dependencies: [{ kind: "ngmodule", type: CommonModule$1 }, { kind: "directive", type: i2$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "pipe", type: i2$1.AsyncPipe, name: "async" }, { kind: "ngmodule", type: CoreModule }, { kind: "directive", type: i1$1.IconDirective, selector: "[c8yIcon]", inputs: ["c8yIcon"] }, { kind: "pipe", type: i1$1.C8yTranslatePipe, name: "translate" }, { kind: "ngmodule", type: NgxEchartsModule }, { kind: "directive", type: i3.NgxEchartsDirective, selector: "echarts, [echarts]", inputs: ["options", "theme", "initOpts", "merge", "autoResize", "loading", "loadingType", "loadingOpts"], outputs: ["chartInit", "optionsError", "chartClick", "chartDblClick", "chartMouseDown", "chartMouseMove", "chartMouseUp", "chartMouseOver", "chartMouseOut", "chartGlobalOut", "chartContextMenu", "chartHighlight", "chartDownplay", "chartSelectChanged", "chartLegendSelectChanged", "chartLegendSelected", "chartLegendUnselected", "chartLegendLegendSelectAll", "chartLegendLegendInverseSelect", "chartLegendScroll", "chartDataZoom", "chartDataRangeSelected", "chartGraphRoam", "chartGeoRoam", "chartTreeRoam", "chartTimelineChanged", "chartTimelinePlayChanged", "chartRestore", "chartDataViewChanged", "chartMagicTypeChanged", "chartGeoSelectChanged", "chartGeoSelected", "chartGeoUnselected", "chartAxisAreaSelected", "chartBrush", "chartBrushEnd", "chartBrushSelected", "chartGlobalCursorTaken", "chartRendered", "chartFinished"], exportAs: ["echarts"] }, { kind: "ngmodule", type: TooltipModule }, { kind: "ngmodule", type: PopoverModule }, { kind: "component", type: ChartAlertsComponent, selector: "c8y-chart-alerts", inputs: ["alerts"] }, { kind: "ngmodule", type: AlarmsModule }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ChartsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-charts', providers: [
                        { provide: NGX_ECHARTS_CONFIG, useFactory: () => ({ echarts: () => import('echarts') }) },
                        ChartRealtimeService,
                        MeasurementRealtimeService,
                        AlarmRealtimeService,
                        EventRealtimeService,
                        ChartTypesService,
                        EchartsOptionsService,
                        CustomMeasurementService,
                        YAxisService,
                        AlarmSeverityToIconPipe,
                        AlarmSeverityToLabelPipe
                    ], standalone: true, imports: [
                        CommonModule$1,
                        CoreModule,
                        NgxEchartsModule,
                        TooltipModule,
                        PopoverModule,
                        ChartAlertsComponent,
                        AlarmsModule
                    ], template: "<div\n  class=\"p-relative fit-h chart-container\"\n>\n  <div\n    class=\"fit-w fit-h\"\n    #chart\n    echarts\n    [options]=\"chartOption$ | async\"\n    (chartInit)=\"onChartInit($event)\"\n  ></div>\n\n  <c8y-chart-alerts [alerts]=\"alerts\"></c8y-chart-alerts>\n\n  <div *ngIf=\"showLoadMore\" class=\"chart-load-more\">\n    <button\n      class=\"btn btn-primary btn-sm btn-block\"\n      (click)=\"loadMoreData()\"\n    >\n      <i c8yIcon=\"restore\"></i>\n      {{ 'Load more' | translate }}\n    </button>\n  </div>\n</div>\n" }]
        }], ctorParameters: () => [], propDecorators: { config: [{
                type: Input
            }], alerts: [{
                type: Input
            }], configChangeOnZoomOut: [{
                type: Output
            }], timeRangeChangeOnRealtime: [{
                type: Output
            }], datapointOutOfSync: [{
                type: Output
            }], updateAlarmsAndEvents: [{
                type: Output
            }], isMarkedAreaEnabled: [{
                type: Output
            }], chart: [{
                type: ViewChild,
                args: ['chart']
            }] } });

var DATE_SELECTION_EXTENDED;
(function (DATE_SELECTION_EXTENDED) {
    DATE_SELECTION_EXTENDED["CONFIG"] = "config";
    DATE_SELECTION_EXTENDED["DASHBOARD_CONTEXT"] = "dashboard_context";
})(DATE_SELECTION_EXTENDED || (DATE_SELECTION_EXTENDED = {}));
const REALTIME_TEXTS = {
    ACTIVE: gettext('Realtime active'),
    INACTIVE: gettext('Realtime inactive')
};
const SEVERITY_LABELS = {
    CRITICAL: gettext('Critical`alarm`'),
    MAJOR: gettext('Major`alarm`'),
    MINOR: gettext('Minor`alarm`'),
    WARNING: gettext('Warning`alarm`')
};

/**
 * Generated bundle index. Do not edit.
 */

export { ChartAlarmsService, ChartEventsService, ChartsComponent, DATE_SELECTION_EXTENDED, ICONS_MAP, REALTIME_TEXTS, SEVERITY_LABELS };
//# sourceMappingURL=c8y-ngx-components-echart.mjs.map
