import { gettext, DynamicComponentErrorStrategy, hookWidget } from '@c8y/ngx-components';
import { defaultWidgetIds } from '@c8y/ngx-components/widgets/definitions';

const alarmListWidgetDefinition = {
    id: defaultWidgetIds.ALARM_LIST,
    label: gettext('Alarm list'),
    description: gettext(`Displays a list of alarms filtered by object, severity, status and date`),
    loadComponent: () => import('@c8y/ngx-components/widgets/implementations/alarms').then(m => m.AlarmListWidgetComponent),
    loadConfigComponent: () => import('@c8y/ngx-components/widgets/implementations/alarms').then(m => m.AlarmListWidgetConfigComponent),
    previewImage: 'c8y-style-assets/alarms/alarm-list-widget.png',
    errorStrategy: DynamicComponentErrorStrategy.OVERLAY_ERROR,
    data: {
        schema: () => import('c8y-schema-loader?interfaceName=AlarmListWidgetConfig!@c8y/ngx-components/widgets/implementations/alarms'),
        settings: {
            alarmListWidget: true,
            noNewWidgets: false,
            widgetDefaults: {
                _width: 8,
                _height: 4
            },
            ng1: {
                options: {
                    noDeviceTarget: false,
                    groupsSelectable: true,
                    deviceTargetNotRequired: true
                }
            }
        },
        displaySettings: {
            globalTimeContext: true,
            globalAutoRefreshContext: true
        }
    }
};
const alarmListWidgetProviders = [hookWidget(alarmListWidgetDefinition)];

/**
 * Generated bundle index. Do not edit.
 */

export { alarmListWidgetDefinition, alarmListWidgetProviders };
//# sourceMappingURL=c8y-ngx-components-widgets-definitions-alarms-alarm-list.mjs.map
