import { gettext, DynamicDatapointsResolver, hookWidget } from '@c8y/ngx-components';
import { defaultWidgetIds } from '@c8y/ngx-components/widgets/definitions';

const radialGaugeWidgetDefinition = {
    id: defaultWidgetIds.RADIAL_GAUGE,
    label: gettext('Radial gauge'),
    // Info gauge config and view components are used for the radial gauge. Eventually both will be merged into one component.
    description: gettext('Shows the device measurements in a radial gauge.'),
    loadComponent: () => import('@c8y/ngx-components/widgets/implementations/info-gauge').then(m => m.InfoGaugeWidgetViewComponent),
    // Gauge type is determined in the component
    loadConfigComponent: () => import('@c8y/ngx-components/widgets/implementations/info-gauge').then(m => m.InfoGaugeWidgetConfigComponent),
    previewImage: 'c8y-style-assets/radial-gauge-pr.png',
    resolve: {
        datapoints: DynamicDatapointsResolver
    },
    data: {
        schema: () => import('c8y-schema-loader?interfaceName=InfoGaugeWidgetConfig!@c8y/ngx-components/widgets/implementations/info-gauge'),
        settings: {
            noNewWidgets: false,
            widgetDefaults: {
                _width: 8,
                _height: 4
            },
            ng1: {
                options: {
                    noDeviceTarget: true,
                    groupsSelectable: false
                }
            }
        }
    }
};
const radialGaugeWidgetProviders = [hookWidget(radialGaugeWidgetDefinition)];

/**
 * Generated bundle index. Do not edit.
 */

export { radialGaugeWidgetDefinition, radialGaugeWidgetProviders };
//# sourceMappingURL=c8y-ngx-components-widgets-definitions-radial-gauge.mjs.map
