import * as i0 from '@angular/core';
import { Injectable, EventEmitter, inject, Component, ChangeDetectionStrategy, Input, Output, Pipe, ViewChild, Directive, signal } from '@angular/core';
import * as i3 from '@angular/forms';
import { ControlContainer, ReactiveFormsModule, FormControl, Validators } from '@angular/forms';
import * as i1$1 from '@c8y/ngx-components';
import { gettext, CoreModule, AGGREGATION_LABELS, AGGREGATION_VALUES_ARR, AGGREGATION_VALUES, IntervalBasedReload, WIDGET_TYPE_VALUES, CountdownIntervalComponent, CommonModule as CommonModule$1, CountdownIntervalModule, ListGroupModule, DynamicComponentAlertAggregator, DynamicComponentAlert, DocsModule, DynamicComponentModule, DismissAlertStrategy, globalAutoRefreshLoading } from '@c8y/ngx-components';
import * as i4 from '@c8y/ngx-components/context-dashboard';
import * as i6 from '@c8y/ngx-components/datapoint-selector';
import { DatapointSelectorModule } from '@c8y/ngx-components/datapoint-selector';
import * as i1 from '@c8y/ngx-components/datapoints-export-selector';
import { dateRangeValidator, DatapointsExportSelectorComponent } from '@c8y/ngx-components/datapoints-export-selector';
import { INTERVAL_VALUES } from '@c8y/ngx-components/interval-picker';
import * as i7 from 'ngx-bootstrap/popover';
import { PopoverModule } from 'ngx-bootstrap/popover';
import { Subject, takeUntil, merge, tap, BehaviorSubject, debounceTime } from 'rxjs';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';
import { aggregationType } from '@c8y/client';
import * as i1$2 from '@ngx-translate/core';
import * as i4$1 from 'ngx-bootstrap/tooltip';
import { TooltipModule } from 'ngx-bootstrap/tooltip';

const DEFAULT_DPT_REFRESH_INTERVAL_VALUE = 30_000;
const DATE_SELECTION_VALUES = {
    dashboard_context: 'dashboard_context',
    config: 'config',
    view_and_config: 'view_and_config'
};
const DATE_SELECTION_VALUES_ARR = [
    DATE_SELECTION_VALUES.dashboard_context,
    DATE_SELECTION_VALUES.config,
    DATE_SELECTION_VALUES.view_and_config
];
const DATE_SELECTION_LABELS = {
    config: gettext('Widget configuration'),
    view_and_config: gettext('Widget and widget configuration'),
    dashboard_context: gettext('Dashboard time range')
};
const REFRESH_INTERVAL_VALUES_ARR = [5_000, 10_000, 15_000, 30_000, 60_000];
const RENDER_TYPES_LABELS = {
    min: gettext('Minimum'),
    max: gettext('Maximum'),
    area: gettext('Area')
};
const INTERVAL_VALUES_ARR = [
    INTERVAL_VALUES.minutes,
    INTERVAL_VALUES.hours,
    INTERVAL_VALUES.days,
    INTERVAL_VALUES.weeks,
    INTERVAL_VALUES.months,
    INTERVAL_VALUES.custom
];
const TIME_RANGE_INTERVAL_LABELS = {
    minutes: gettext('Last minute'),
    hours: gettext('Last hour'),
    days: gettext('Last day'),
    weeks: gettext('Last week'),
    months: gettext('Last month'),
    custom: gettext('Custom')
};
const DURATION_OPTIONS = [
    {
        id: INTERVAL_VALUES.minutes,
        label: TIME_RANGE_INTERVAL_LABELS.minutes,
        unit: INTERVAL_VALUES.minutes,
        amount: 1
    },
    {
        id: INTERVAL_VALUES.hours,
        label: TIME_RANGE_INTERVAL_LABELS.hours,
        unit: INTERVAL_VALUES.hours,
        amount: 1
    },
    {
        id: INTERVAL_VALUES.days,
        label: TIME_RANGE_INTERVAL_LABELS.days,
        unit: INTERVAL_VALUES.days,
        amount: 1
    },
    {
        id: INTERVAL_VALUES.weeks,
        label: TIME_RANGE_INTERVAL_LABELS.weeks,
        unit: INTERVAL_VALUES.weeks,
        amount: 1
    },
    {
        id: INTERVAL_VALUES.months,
        label: TIME_RANGE_INTERVAL_LABELS.months,
        unit: INTERVAL_VALUES.months,
        amount: 1
    },
    { id: INTERVAL_VALUES.custom, label: TIME_RANGE_INTERVAL_LABELS.custom }
];

class DatapointsTableService {
    constructor(dataFetchingService) {
        this.dataFetchingService = dataFetchingService;
    }
    calculateDateRange(interval) {
        const now = new Date();
        const nowString = now.toISOString();
        let dateFrom;
        switch (interval) {
            case INTERVAL_VALUES.minutes:
                dateFrom = this.dataFetchingService.adjustDate(nowString, -1, true);
                break;
            case INTERVAL_VALUES.hours:
                const minutesInAnHourNegative = -60;
                dateFrom = this.dataFetchingService.adjustDate(nowString, minutesInAnHourNegative, true);
                break;
            case INTERVAL_VALUES.days:
                const minutesInADayNegative = -24 * 60;
                dateFrom = this.dataFetchingService.adjustDate(nowString, minutesInADayNegative, true);
                break;
            case INTERVAL_VALUES.weeks:
                const minutesInAWeekNegative = -7 * 24 * 60;
                dateFrom = this.dataFetchingService.adjustDate(nowString, minutesInAWeekNegative, true);
                break;
            case INTERVAL_VALUES.months:
                const oneMonthAgo = new Date(now);
                oneMonthAgo.setMonth(oneMonthAgo.getMonth() - 1);
                dateFrom = this.dataFetchingService.adjustDate(oneMonthAgo.toISOString(), 0, true);
                break;
            default:
                throw new Error('Invalid time interval');
        }
        return {
            dateFrom: dateFrom,
            dateTo: this.dataFetchingService.adjustDate(nowString, 0, true)
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DatapointsTableService, deps: [{ token: i1.DataFetchingService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DatapointsTableService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DatapointsTableService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: i1.DataFetchingService }] });

class DateRangePickerComponent {
    constructor() {
        /**
         * If set to true, the component will be reactive and will emit the updatedDate on every change.
         * Otherwise, the component will use a non emitting variant of a template.
         */
        this.isEmittingDateChange = false;
        /**
         * Determines the display of from and to date picker labels.
         */
        this.showLabel = true;
        this.updatedDate = new EventEmitter();
        this.DATE_FROM = 'dateFrom';
        this.DATE_TO = 'dateTo';
        this.FROM_DATE = gettext('From`date`');
        this.HAS_ERROR = 'has-error';
        this.INVALID_DATE_TIME = 'invalidDateTime';
        this.THIS_DATE_IS_INVALID = gettext('This date is invalid.');
        this.THIS_DATE_IS_AFTER_THE_LAST_ALLOWED_DATE = gettext('This date is after the latest allowed date.');
        this.THIS_DATE_IS_BEFORE_THE_EARLIEST_ALLOWED_DATE = gettext('This date is before the earliest allowed date.');
        this.TO_DATE = gettext('To`date`');
        this.parentContainer = inject(ControlContainer);
    }
    onDateFromChange(dateFrom) {
        this.updatedDate.emit({
            dateFrom
        });
    }
    onDateToChange(dateTo) {
        this.updatedDate.emit({
            dateTo
        });
    }
    get parentFormGroup() {
        return this.parentContainer.control;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DateRangePickerComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: DateRangePickerComponent, isStandalone: true, selector: "c8y-date-range-picker", inputs: { isEmittingDateChange: "isEmittingDateChange", showLabel: "showLabel" }, outputs: { updatedDate: "updatedDate" }, ngImport: i0, template: "<div class=\"d-flex gap-8 a-i-center flex-wrap\">\n  <c8y-form-group\n    [ngClass]=\"[\n      parentFormGroup?.controls.dateFrom.errors ? HAS_ERROR : '',\n      isEmittingDateChange ? 'd-flex a-i-center gap-4 m-b-0' : ''\n    ]\"\n  >\n    <ng-container *ngIf=\"showLabel\">\n      <label\n        [title]=\"FROM_DATE | translate\"\n        [for]=\"DATE_FROM\"\n      >\n        {{ FROM_DATE | translate }}\n      </label>\n    </ng-container>\n    <c8y-date-time-picker\n      id=\"DATE_FROM\"\n      [maxDate]=\"parentFormGroup?.value.dateTo\"\n      [placeholder]=\"FROM_DATE | translate\"\n      [formControl]=\"parentFormGroup?.controls.dateFrom\"\n      [ngClass]=\"parentFormGroup?.controls.dateFrom.errors ? HAS_ERROR : ''\"\n      (ngModelChange)=\"onDateFromChange($event)\"\n    ></c8y-date-time-picker>\n    <c8y-messages\n      class=\"text-nowrap\"\n      [show]=\"parentFormGroup?.controls.dateFrom.errors\"\n    >\n      <c8y-message\n        name=\"dateAfterRangeMax\"\n        [text]=\"THIS_DATE_IS_AFTER_THE_LAST_ALLOWED_DATE | translate\"\n      ></c8y-message>\n      <c8y-message\n        name=\"INVALID_DATE_TIME\"\n        [text]=\"THIS_DATE_IS_INVALID | translate\"\n      ></c8y-message>\n    </c8y-messages>\n  </c8y-form-group>\n  <c8y-form-group\n    [ngClass]=\"[\n      parentFormGroup?.controls.dateTo.errors ? HAS_ERROR : '',\n      isEmittingDateChange ? 'd-flex a-i-center gap-4 m-b-0' : ''\n    ]\"\n  >\n    <ng-container *ngIf=\"showLabel\">\n      <label\n        [title]=\"TO_DATE | translate\"\n        [for]=\"DATE_TO\"\n      >\n        {{ TO_DATE | translate }}\n      </label>\n    </ng-container>\n    <c8y-date-time-picker\n      id=\"DATE_TO\"\n      [minDate]=\"parentFormGroup?.value.dateFrom\"\n      [placeholder]=\"TO_DATE | translate\"\n      [formControl]=\"parentFormGroup?.controls.dateTo\"\n      [ngClass]=\"parentFormGroup?.controls.dateTo.errors ? HAS_ERROR : ''\"\n      (ngModelChange)=\"onDateToChange($event)\"\n    ></c8y-date-time-picker>\n    <c8y-messages [show]=\"parentFormGroup?.controls.dateTo.errors\">\n      <c8y-message\n        name=\"dateBeforeRangeMin\"\n        [text]=\"THIS_DATE_IS_BEFORE_THE_EARLIEST_ALLOWED_DATE | translate\"\n      ></c8y-message>\n      <c8y-message\n        name=\"INVALID_DATE_TIME\"\n        [text]=\"THIS_DATE_IS_INVALID | translate\"\n      ></c8y-message>\n    </c8y-messages>\n  </c8y-form-group>\n</div>\n", dependencies: [{ kind: "ngmodule", type: CoreModule }, { kind: "pipe", type: i1$1.C8yTranslatePipe, name: "translate" }, { kind: "directive", type: i2.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i3.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "component", type: i1$1.FormGroupComponent, selector: "c8y-form-group", inputs: ["hasError", "hasWarning", "hasSuccess", "novalidation", "status"] }, { kind: "directive", type: i1$1.MessageDirective, selector: "c8y-message", inputs: ["name", "text"] }, { kind: "component", type: i1$1.MessagesComponent, selector: "c8y-messages", inputs: ["show", "defaults", "helpMessage"] }, { kind: "directive", type: i3.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: i1$1.DateTimePickerComponent, selector: "c8y-date-time-picker", inputs: ["minDate", "maxDate", "placeholder", "dateInputFormat", "adaptivePosition", "size", "dateType", "config"], outputs: ["onDateSelected"] }, { kind: "ngmodule", type: CommonModule }, { kind: "ngmodule", type: ReactiveFormsModule }], viewProviders: [
            {
                provide: ControlContainer,
                useFactory: () => inject(ControlContainer, { skipSelf: true })
            }
        ], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DateRangePickerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-date-range-picker', standalone: true, imports: [CoreModule, CommonModule, ReactiveFormsModule], changeDetection: ChangeDetectionStrategy.OnPush, viewProviders: [
                        {
                            provide: ControlContainer,
                            useFactory: () => inject(ControlContainer, { skipSelf: true })
                        }
                    ], template: "<div class=\"d-flex gap-8 a-i-center flex-wrap\">\n  <c8y-form-group\n    [ngClass]=\"[\n      parentFormGroup?.controls.dateFrom.errors ? HAS_ERROR : '',\n      isEmittingDateChange ? 'd-flex a-i-center gap-4 m-b-0' : ''\n    ]\"\n  >\n    <ng-container *ngIf=\"showLabel\">\n      <label\n        [title]=\"FROM_DATE | translate\"\n        [for]=\"DATE_FROM\"\n      >\n        {{ FROM_DATE | translate }}\n      </label>\n    </ng-container>\n    <c8y-date-time-picker\n      id=\"DATE_FROM\"\n      [maxDate]=\"parentFormGroup?.value.dateTo\"\n      [placeholder]=\"FROM_DATE | translate\"\n      [formControl]=\"parentFormGroup?.controls.dateFrom\"\n      [ngClass]=\"parentFormGroup?.controls.dateFrom.errors ? HAS_ERROR : ''\"\n      (ngModelChange)=\"onDateFromChange($event)\"\n    ></c8y-date-time-picker>\n    <c8y-messages\n      class=\"text-nowrap\"\n      [show]=\"parentFormGroup?.controls.dateFrom.errors\"\n    >\n      <c8y-message\n        name=\"dateAfterRangeMax\"\n        [text]=\"THIS_DATE_IS_AFTER_THE_LAST_ALLOWED_DATE | translate\"\n      ></c8y-message>\n      <c8y-message\n        name=\"INVALID_DATE_TIME\"\n        [text]=\"THIS_DATE_IS_INVALID | translate\"\n      ></c8y-message>\n    </c8y-messages>\n  </c8y-form-group>\n  <c8y-form-group\n    [ngClass]=\"[\n      parentFormGroup?.controls.dateTo.errors ? HAS_ERROR : '',\n      isEmittingDateChange ? 'd-flex a-i-center gap-4 m-b-0' : ''\n    ]\"\n  >\n    <ng-container *ngIf=\"showLabel\">\n      <label\n        [title]=\"TO_DATE | translate\"\n        [for]=\"DATE_TO\"\n      >\n        {{ TO_DATE | translate }}\n      </label>\n    </ng-container>\n    <c8y-date-time-picker\n      id=\"DATE_TO\"\n      [minDate]=\"parentFormGroup?.value.dateFrom\"\n      [placeholder]=\"TO_DATE | translate\"\n      [formControl]=\"parentFormGroup?.controls.dateTo\"\n      [ngClass]=\"parentFormGroup?.controls.dateTo.errors ? HAS_ERROR : ''\"\n      (ngModelChange)=\"onDateToChange($event)\"\n    ></c8y-date-time-picker>\n    <c8y-messages [show]=\"parentFormGroup?.controls.dateTo.errors\">\n      <c8y-message\n        name=\"dateBeforeRangeMin\"\n        [text]=\"THIS_DATE_IS_BEFORE_THE_EARLIEST_ALLOWED_DATE | translate\"\n      ></c8y-message>\n      <c8y-message\n        name=\"INVALID_DATE_TIME\"\n        [text]=\"THIS_DATE_IS_INVALID | translate\"\n      ></c8y-message>\n    </c8y-messages>\n  </c8y-form-group>\n</div>\n" }]
        }], propDecorators: { isEmittingDateChange: [{
                type: Input
            }], showLabel: [{
                type: Input
            }], updatedDate: [{
                type: Output
            }] } });

function minOneDatapointActive() {
    return (control) => {
        const datapoints = control.value;
        if (!datapoints || !datapoints.length) {
            return null;
        }
        const activeDatapoints = datapoints.filter(datapoint => datapoint.__active);
        if (activeDatapoints.length >= 1) {
            return null;
        }
        return { exactlyOneDatapointNeedsToBeActive: true };
    };
}
class DatapointsTableWidgetConfigComponent {
    constructor(aggregationService, datapointsTableService, formBuilder, form, widgetConfig) {
        this.aggregationService = aggregationService;
        this.datapointsTableService = datapointsTableService;
        this.formBuilder = formBuilder;
        this.form = form;
        this.widgetConfig = widgetConfig;
        this.AGGREGATION_LABELS = AGGREGATION_LABELS;
        this.DATE_SELECTION_LABELS = DATE_SELECTION_LABELS;
        this.DEFAULT_DATE_SELECTOR_VALUE = DATE_SELECTION_VALUES.dashboard_context;
        this.DEFAULT_INTERVAL_VALUE = INTERVAL_VALUES.hours;
        this.TIME_RANGE_INTERVAL_LABELS = TIME_RANGE_INTERVAL_LABELS;
        this.AGGREGATION_VALUES_ARR = AGGREGATION_VALUES_ARR;
        this.DATE_SELECTION_VALUES_ARR = DATE_SELECTION_VALUES_ARR;
        this.INTERVAL_VALUES_ARR = INTERVAL_VALUES_ARR;
        this.REFRESH_INTERVAL_VALUES_ARR = REFRESH_INTERVAL_VALUES_ARR;
        this.datapointSelectionConfig = {};
        this.disabledAggregationOptions = {};
        this.defaultFormOptions = {
            selectableChartLineTypes: [],
            selectableAxisTypes: [],
            showRedRange: true,
            showYellowRange: true
        };
        this.decimalLimits = {
            numberOfDecimalPlacesMin: 0,
            numberOfDecimalPlacesMax: 10
        };
        /**
         * Indicate when the time interval selector item has been changed programmatically.
         *
         * This property is used to track changes in the time interval selector
         * that are not triggered by direct user interaction, but by the application itself.
         *
         * In our case, the date selector and the interval selector are linked.
         * So, when one of them changes, it affects the other.
         * For example, selecting "Last hour" in the interval selector should automatically update the date range to the last hour.
         * But without this flag, changing the date range would also update the interval selector, resulting in "Custom date" being selected.
         * This happens because the system would interpret the behavior this way.
         */
        this.isIntervalSelectorChangedProgrammatically = false;
        this.destroy$ = new Subject();
    }
    ngOnInit() {
        if (this.widgetConfig.context?.id) {
            this.datapointSelectionConfig.contextAsset = this.widgetConfig?.context;
        }
        this.isWidgetLinkedToGlobalTimeContext =
            this.config.widgetInstanceGlobalAutoRefreshContext ?? true;
        this.initForm();
        this.handleAutoRefreshToggleChanges();
        this.handleIntervalSelectorChanges();
        this.handleDateSelectorChanges();
        this.handleGlobalDateSelectorChanges();
        this.updateDisabledAggregationOptions();
    }
    ngOnDestroy() {
        this.destroy$.next();
        this.destroy$.complete();
    }
    onBeforeSave(config) {
        if (this.formGroup.value.aggregation === AGGREGATION_VALUES.none ||
            (!this.formGroup.value.aggregation && config.aggregation === AGGREGATION_VALUES.none)) {
            // The 'NONE' aggregation type is not handled by a backend, so it simply needs to be deleted to get data without aggregation.
            this.deleteAggregationProperty(config);
        }
        this.updateTimeContext(config, this.formGroup.value.globalDateSelector);
        Object.assign(config, this.formGroup.value);
    }
    toggleRefreshIntervalControl() {
        this.formGroup.controls.isAutoRefreshEnabled.value
            ? this.formGroup.controls.refreshInterval.disable()
            : this.formGroup.controls.refreshInterval.enable();
    }
    updateTimeContext(config, selectedDateContext) {
        switch (selectedDateContext) {
            case DATE_SELECTION_VALUES.dashboard_context:
                config.displayDateSelection = false;
                config.widgetInstanceGlobalAutoRefreshContext = true;
                if (config.aggregation !== 'NONE') {
                    this.deleteAggregationProperty(config);
                }
                break;
            case DATE_SELECTION_VALUES.view_and_config:
                config.displayDateSelection = true;
                config.widgetInstanceGlobalAutoRefreshContext = false;
                break;
            case DATE_SELECTION_VALUES.config:
            default:
                config.displayDateSelection = false;
                config.widgetInstanceGlobalAutoRefreshContext = false;
        }
    }
    initForm() {
        this.formGroup = this.createForm();
        // When the 'NONE' aggregation is removed at the 'onBeforeSave' block,
        // and a Global Date Context forces widgets auto refresh to be enabled
        // then, the aggregation selector will be empty on initial load.
        this.config.aggregation = this.config.aggregation ?? AGGREGATION_VALUES.none;
        this.form.form.addControl('config', this.formGroup);
        this.formGroup.patchValue(this.config);
    }
    createForm() {
        const { dateFrom, dateTo } = this.datapointsTableService.calculateDateRange(this.DEFAULT_INTERVAL_VALUE);
        const isLegacyWidget = this.config.hasOwnProperty('widgetInstanceGlobalTimeContext') &&
            !this.config.hasOwnProperty('decimalPlaces');
        return this.formBuilder.group({
            aggregation: new FormControl({
                value: AGGREGATION_VALUES.none,
                disabled: !this.isAutoRefershDisabled()
            }),
            datapoints: this.formBuilder.control(new Array(), [
                Validators.required,
                Validators.minLength(1),
                minOneDatapointActive()
            ]),
            globalDateSelector: new FormControl(isLegacyWidget
                ? this.determineGlobalDateSelectorValueForLegacyWidget()
                : this.DEFAULT_DATE_SELECTOR_VALUE),
            dateFrom: new FormControl(dateFrom),
            dateTo: new FormControl(dateTo),
            decimalPlaces: [
                2,
                [
                    Validators.required,
                    Validators.min(this.decimalLimits.numberOfDecimalPlacesMin),
                    Validators.max(this.decimalLimits.numberOfDecimalPlacesMax),
                    Validators.pattern('^[0-9]+$')
                ]
            ],
            interval: new FormControl(this.DEFAULT_INTERVAL_VALUE),
            isAutoRefreshEnabled: isLegacyWidget ? this.config.realtime : [true],
            refreshInterval: new FormControl({
                value: DEFAULT_DPT_REFRESH_INTERVAL_VALUE,
                disabled: this.isAutoRefershDisabled()
            })
        }, { validators: dateRangeValidator });
    }
    determineGlobalDateSelectorValueForLegacyWidget() {
        const { displayDateSelection, widgetInstanceGlobalAutoRefreshContext } = this.config;
        // State of widgetInstanceGlobalTimeContext was converted to widgetInstanceGlobalAutoRefreshContext.
        // That is why it use here in a legacy widget context.
        if (widgetInstanceGlobalAutoRefreshContext) {
            return DATE_SELECTION_VALUES.dashboard_context;
        }
        return displayDateSelection
            ? DATE_SELECTION_VALUES.view_and_config
            : DATE_SELECTION_VALUES.config;
    }
    isAutoRefershDisabled() {
        const isInitialWidgetCreation = Object.keys(this.config).length === 1 && this.config['settings'];
        if (isInitialWidgetCreation) {
            return false;
        }
        const isLegacyWidgetRealtimeNotActive = !this.config.realtime &&
            !this.config.hasOwnProperty('decimalPlaces') &&
            !this.config.hasOwnProperty('refreshInterval') &&
            !this.config.hasOwnProperty('isAutoRefreshEnabled');
        if (isLegacyWidgetRealtimeNotActive) {
            return true;
        }
        return !this.config.isAutoRefreshEnabled;
    }
    /**
     * Handles changes to the auto-refresh toggle control and updates the aggregation control accordingly.
     *
     * This method subscribes to the value changes of the auto-refresh toggle form control.
     * When auto-refresh is enabled, the aggregation control's value is set to 'none' and the control is
     * visually disabled (but not programmatically disabled to ensure the value is saved).
     * When auto-refresh is disabled, the aggregation control is enabled.
     */
    handleAutoRefreshToggleChanges() {
        this.formGroup.controls.isAutoRefreshEnabled.valueChanges
            .pipe(takeUntil(this.destroy$))
            .subscribe((isAutoRefreshEnabled) => {
            const aggregationControl = this.formGroup.controls.aggregation;
            if (isAutoRefreshEnabled) {
                aggregationControl.setValue(AGGREGATION_VALUES.none);
                // Do not disable the control programmatically to ensure the value is saved.
            }
            else {
                aggregationControl.enable();
            }
        });
    }
    /**
     * Handles changes in the interval selector form control.
     */
    handleIntervalSelectorChanges() {
        this.formGroup.controls.interval.valueChanges
            .pipe(takeUntil(this.destroy$))
            .subscribe((selectedInterval) => {
            if (selectedInterval === INTERVAL_VALUES.custom) {
                this.updateDisabledAggregationOptions();
                return;
            }
            this.handleNonCustomInterval(selectedInterval);
        });
    }
    handleNonCustomInterval(selectedInterval) {
        this.isIntervalSelectorChangedProgrammatically = true;
        this.updateDateRange(selectedInterval);
        this.updateDisabledAggregationOptions();
        this.updateAggregationIfAutoRefreshDisabled(selectedInterval);
    }
    updateDateRange(selectedInterval) {
        const dateRange = this.datapointsTableService.calculateDateRange(selectedInterval);
        this.formGroup.controls.dateTo.setValue(dateRange.dateTo);
        // MTM-61351
        // Use requestAnimationFrame to queue the dateFrom update.
        // This prevents timing issues where rapid setValue calls might
        // cause the view to go out of sync with form control values,
        // especially during the first change after initialization.
        // requestAnimationFrame(() => {
        /**
         * Without this requestAnimationFrame or setTimeout, dateFrom won't change to a correct value after first selector change.
         * When form is saved it saves with a correct value, even without with this fix.
         * How to reproduce:
         * 1. set date values to e.g.: 01.05.2024-30.05.2024 and save it
         * 2. reopen a config and switch interval to last month
         */
        // This fix brakes a logic behind disabling non available aggregations.
        // Form will be still saved with correct date value, only view is out of a sync.
        this.formGroup.controls.dateFrom.setValue(dateRange.dateFrom);
        this.isIntervalSelectorChangedProgrammatically = false;
        // });
    }
    updateDisabledAggregationOptions() {
        this.disabledAggregationOptions = this.aggregationService.getDisabledAggregationOptions(this.formGroup.controls.dateFrom.value, this.formGroup.controls.dateTo.value);
    }
    updateAggregationIfAutoRefreshDisabled(selectedInterval) {
        const isAutoRefreshDisabled = !this.formGroup.controls.isAutoRefreshEnabled.value;
        if (isAutoRefreshDisabled) {
            this.setAggregationValue(selectedInterval);
        }
    }
    setAggregationValue(interval) {
        const aggregationControl = this.formGroup.controls.aggregation;
        const newAggregationValue = this.aggregationService.determineAggregationValue(interval);
        aggregationControl.setValue(newAggregationValue);
    }
    /**
     * Handles changes in the date selector form control.
     */
    handleDateSelectorChanges() {
        merge(this.formGroup.controls.dateFrom.valueChanges, this.formGroup.controls.dateTo.valueChanges)
            .pipe(takeUntil(this.destroy$))
            .subscribe(() => this.handleDateChange());
    }
    handleDateChange() {
        if (this.isIntervalSelectorChangedProgrammatically) {
            return;
        }
        const intervalControl = this.formGroup.controls.interval;
        if (intervalControl.value === INTERVAL_VALUES.custom) {
            this.handleCustomIntervalDateChange();
        }
        else {
            this.setIntervalToCustom(intervalControl);
        }
        this.setToFirstAvailableAggregationOptionIfCurrentAggregationIsDisabled();
    }
    handleCustomIntervalDateChange() {
        this.updateDisabledAggregationOptions();
    }
    setIntervalToCustom(intervalControl) {
        intervalControl.setValue(INTERVAL_VALUES.custom);
    }
    /**
     * Handles changes in the global date selector form control.
     */
    handleGlobalDateSelectorChanges() {
        this.formGroup.controls.globalDateSelector.valueChanges
            .pipe(takeUntil(this.destroy$))
            .subscribe((selected) => {
            if (selected === DATE_SELECTION_VALUES.dashboard_context) {
                this.handleDashboardContext();
            }
            else {
                this.handleNonDashboardContext();
            }
        });
    }
    handleDashboardContext() {
        this.isWidgetLinkedToGlobalTimeContext = true;
    }
    handleNonDashboardContext() {
        this.isWidgetLinkedToGlobalTimeContext = false;
        if (this.isConfigSavedWithoutDashboardTimeOption()) {
            return;
        }
        this.updateAggregationIfNecessary();
        this.setIntervalToCustom(this.formGroup.controls.interval);
    }
    isConfigSavedWithoutDashboardTimeOption() {
        return !this.config.widgetInstanceGlobalAutoRefreshContext;
    }
    updateAggregationIfNecessary() {
        const aggregationControl = this.formGroup.controls.aggregation;
        const isDashboardTimeOptionSetAggregationToNull = !aggregationControl.value;
        if (isDashboardTimeOptionSetAggregationToNull) {
            aggregationControl.setValue(AGGREGATION_VALUES.none);
        }
    }
    /**
     * Sets the aggregation control to the first available (non-disabled) option if the current option is disabled.
     *
     * This method:
     * - Retrieves the current value of the aggregation control.
     * - Checks if the current aggregation option is disabled.
     * - If the current option is disabled, sets the control to the first available (non-disabled) option based on the following order:
     *   - If the current value is `DAILY`, it switches to `HOURLY` if it's not disabled, otherwise to `MINUTELY` if `HOURLY` is also disabled.
     *   - If the current value is `HOURLY`, it switches to `MINUTELY` if it's not disabled.
     *   - If all options are disabled, it sets the value to `NONE`.
     *
     * The disabled state is stored in the `disabledAggregationOptions` object,
     * where the key is the aggregation value and the value is a boolean indicating whether the option is disabled.
     *
     * The `AGGREGATION_VALUES` object defines the possible aggregation values.
     */
    setToFirstAvailableAggregationOptionIfCurrentAggregationIsDisabled() {
        const aggregationControl = this.formGroup.controls.aggregation;
        const currentValue = aggregationControl.value;
        const newAggregationValue = this.aggregationService.determineFirstNewAvailableAggregationValue(currentValue, this.disabledAggregationOptions);
        if (newAggregationValue !== currentValue) {
            aggregationControl.setValue(newAggregationValue);
        }
    }
    deleteAggregationProperty(config) {
        delete this.formGroup.value.aggregation;
        delete config.aggregation;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DatapointsTableWidgetConfigComponent, deps: [{ token: i1$1.AggregationService }, { token: DatapointsTableService }, { token: i3.FormBuilder }, { token: i3.NgForm }, { token: i4.WidgetConfigComponent }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: DatapointsTableWidgetConfigComponent, isStandalone: true, selector: "c8y-datapoints-table-view-config", inputs: { config: "config" }, ngImport: i0, template: "<div class=\"p-l-24 p-r-24\">\n  <form\n    class=\"no-card-context\"\n    [formGroup]=\"formGroup\"\n  >\n    <!-- <datapoints-selector> -->\n    <div class=\"col-md-6\">\n      <div class=\"row\">\n        <!-- global-time-context-selector -->\n        <div class=\"form-group m-b-0 p-b-16 separator-bottom\">\n          <label\n            class=\"d-flex a-i-center p-t-4\"\n            for=\"dateSelection\"\n          >\n            {{ 'Date selection' | translate }}\n            <button\n              class=\"btn-help btn-help--sm\"\n              [attr.aria-label]=\"'Help' | translate\"\n              [popover]=\"popoverTemplate\"\n              placement=\"right\"\n              triggers=\"focus\"\n              container=\"body\"\n              type=\"button\"\n              [adaptivePosition]=\"true\"\n            ></button>\n          </label>\n          <ng-template #popoverTemplate>\n            <span translate>\n              Choose how to select a date range, the available options are:\n              <ul class=\"m-l-0 p-l-8 m-t-8 m-b-0\">\n                <li>\n                  <b>Dashboard time range:</b>\n                  restricts date selection to the global dashboard configuration only\n                </li>\n                <li>\n                  <b>Widget configuration:</b>\n                  restricts the date selection only to the widget configuration\n                </li>\n                <li>\n                  <b>Widget and widget configuration:</b>\n                  restricts the date selection to the widget view and widget configuration only\n                </li>\n              </ul>\n            </span>\n          </ng-template>\n          <div class=\"c8y-select-wrapper\">\n            <select\n              class=\"form-control text-12\"\n              [title]=\"'Date selection' | translate\"\n              [attr.aria-label]=\"'Date selection' | translate\"\n              id=\"globalDateSelector\"\n              formControlName=\"globalDateSelector\"\n            >\n              <option\n                *ngFor=\"let dataSelectionValue of DATE_SELECTION_VALUES_ARR\"\n                [ngValue]=\"dataSelectionValue\"\n              >\n                {{ DATE_SELECTION_LABELS[dataSelectionValue] | translate }}\n              </option>\n            </select>\n          </div>\n        </div>\n      </div>\n      <div class=\"row\">\n        <c8y-datapoint-selection-list\n          class=\"bg-inherit separator-top p-t-16 d-block\"\n          listTitle=\"{{ 'Data points' | translate }}\"\n          name=\"datapoints\"\n          [defaultFormOptions]=\"defaultFormOptions\"\n          [config]=\"datapointSelectionConfig\"\n          [minActiveCount]=\"1\"\n          formControlName=\"datapoints\"\n        ></c8y-datapoint-selection-list>\n      </div>\n    </div>\n    <div class=\"col-md-6\">\n      <div class=\"row\">\n        <ng-container *ngIf=\"!isWidgetLinkedToGlobalTimeContext\">\n          <div class=\"col-md-6\">\n            <!-- interval selector -->\n            <fieldset class=\"c8y-fieldset\">\n              <legend class=\"d-flex a-i-center\">\n                {{ 'Auto refresh' | translate }}\n                <button\n                  class=\"btn-help btn-help--sm\"\n                  [attr.aria-label]=\"'Help' | translate\"\n                  [popover]=\"\n                    'Change the state of interval automatic refresh and set the refresh frequency.'\n                      | translate\n                  \"\n                  placement=\"top\"\n                  triggers=\"focus\"\n                  container=\"body\"\n                  type=\"button\"\n                  [adaptivePosition]=\"true\"\n                ></button>\n              </legend>\n              <c8y-form-group class=\"m-b-16 form-group-sm\">\n                <div class=\"d-flex gap-4 m-t-8 m-b-8 a-i-center\">\n                  <label class=\"c8y-switch\">\n                    <input\n                      id=\"refreshToggle\"\n                      name=\"isAutoRefreshEnabled\"\n                      type=\"checkbox\"\n                      formControlName=\"isAutoRefreshEnabled\"\n                      (click)=\"toggleRefreshIntervalControl()\"\n                    />\n                    <span></span>\n                    <span class=\"sr-only\">{{ 'Auto refresh' | translate }}</span>\n                  </label>\n                  <label\n                    class=\"m-b-0\"\n                    for=\"refreshInterval\"\n                  >\n                    {{ 'Interval' | translate }}\n                  </label>\n                  <div class=\"c8y-select-wrapper\">\n                    <select\n                      class=\"form-control text-12\"\n                      [title]=\"'Refresh interval in seconds' | translate\"\n                      id=\"refreshInterval\"\n                      formControlName=\"refreshInterval\"\n                    >\n                      <option\n                        *ngFor=\"let refreshInterval of REFRESH_INTERVAL_VALUES_ARR\"\n                        [ngValue]=\"refreshInterval\"\n                      >\n                        {{ '{{ seconds }} s' | translate: { seconds: refreshInterval / 1000 } }}\n                      </option>\n                    </select>\n                  </div>\n                </div>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n        </ng-container>\n        <!-- decimal input -->\n        <div class=\"col-md-6\">\n          <fieldset class=\"c8y-fieldset\">\n            <legend>\n              {{ 'Decimal places' | translate }}\n            </legend>\n            <c8y-form-group class=\"p-t-8\">\n              <input\n                class=\"form-control\"\n                name=\"decimalPlaces\"\n                type=\"number\"\n                formControlName=\"decimalPlaces\"\n                step=\"1\"\n              />\n            </c8y-form-group>\n          </fieldset>\n        </div>\n      </div>\n      <!-- aggregation selector -->\n      <div class=\"row\">\n        <ng-container *ngIf=\"!isWidgetLinkedToGlobalTimeContext\">\n          <div class=\"col-md-6\">\n            <fieldset class=\"c8y-fieldset\">\n              <legend>\n                {{ 'Aggregation' | translate }}\n              </legend>\n              <c8y-form-group class=\"p-t-8\">\n                <div class=\"c8y-select-wrapper\">\n                  <!-- Setting below [attr.disabled] ensures that the control is visually disabled and user interaction is prevented,\n               while still allowing the value to be updated and saved correctly in the form.\n               This solution covers the case where the user enables auto-refresh, in which case aggregation must be set to NONE. -->\n                  <select\n                    class=\"form-control text-12\"\n                    [title]=\"'Aggregation' | translate\"\n                    id=\"aggregation\"\n                    formControlName=\"aggregation\"\n                    [attr.disabled]=\"formGroup.value.isAutoRefreshEnabled ? true : null\"\n                  >\n                    <option\n                      *ngFor=\"let aggregationValue of AGGREGATION_VALUES_ARR\"\n                      [ngValue]=\"aggregationValue\"\n                      [disabled]=\"disabledAggregationOptions[aggregationValue]\"\n                    >\n                      {{ AGGREGATION_LABELS[aggregationValue] | translate }}\n                    </option>\n                  </select>\n                </div>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n        </ng-container>\n        <!-- time interval selector -->\n        <div class=\"col-md-6\">\n          <fieldset class=\"c8y-fieldset\">\n            <legend>\n              {{ 'Time interval' | translate }}\n            </legend>\n            <c8y-form-group class=\"p-t-8\">\n              <div class=\"c8y-select-wrapper\">\n                <select\n                  class=\"form-control text-12\"\n                  [title]=\"'Interval' | translate\"\n                  id=\"interval\"\n                  formControlName=\"interval\"\n                >\n                  <option\n                    *ngFor=\"let intervalValue of INTERVAL_VALUES_ARR\"\n                    [ngValue]=\"intervalValue\"\n                  >\n                    {{ TIME_RANGE_INTERVAL_LABELS[intervalValue] | translate }}\n                  </option>\n                </select>\n              </div>\n            </c8y-form-group>\n          </fieldset>\n        </div>\n      </div>\n      <!-- date pickers -->\n      <fieldset class=\"c8y-fieldset\">\n        <legend>\n          {{ 'Date range' | translate }}\n        </legend>\n        <c8y-date-range-picker></c8y-date-range-picker>\n      </fieldset>\n    </div>\n  </form>\n</div>\n", dependencies: [{ kind: "ngmodule", type: CoreModule }, { kind: "pipe", type: i1$1.C8yTranslatePipe, name: "translate" }, { kind: "directive", type: i1$1.C8yTranslateDirective, selector: "[translate],[ngx-translate]" }, { kind: "directive", type: i2.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i3.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i3.NgSelectOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i3.ɵNgSelectMultipleOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i3.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i3.NumberValueAccessor, selector: "input[type=number][formControlName],input[type=number][formControl],input[type=number][ngModel]" }, { kind: "directive", type: i3.CheckboxControlValueAccessor, selector: "input[type=checkbox][formControlName],input[type=checkbox][formControl],input[type=checkbox][ngModel]" }, { kind: "directive", type: i3.SelectControlValueAccessor, selector: "select:not([multiple])[formControlName],select:not([multiple])[formControl],select:not([multiple])[ngModel]", inputs: ["compareWith"] }, { kind: "directive", type: i3.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i3.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "component", type: i1$1.FormGroupComponent, selector: "c8y-form-group", inputs: ["hasError", "hasWarning", "hasSuccess", "novalidation", "status"] }, { kind: "directive", type: i1$1.RequiredInputPlaceholderDirective, selector: "input[required], input[formControlName]" }, { kind: "directive", type: i3.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i3.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "ngmodule", type: DatapointSelectorModule }, { kind: "component", type: i6.DatapointSelectionListComponent, selector: "c8y-datapoint-selection-list", inputs: ["actions", "allowDragAndDrop", "config", "defaultFormOptions", "maxActiveCount", "minActiveCount", "resolveContext", "listTitle"], outputs: ["isValid", "change"] }, { kind: "component", type: DateRangePickerComponent, selector: "c8y-date-range-picker", inputs: ["isEmittingDateChange", "showLabel"], outputs: ["updatedDate"] }, { kind: "ngmodule", type: PopoverModule }, { kind: "directive", type: i7.PopoverDirective, selector: "[popover]", inputs: ["adaptivePosition", "boundariesElement", "popover", "popoverContext", "popoverTitle", "placement", "outsideClick", "triggers", "container", "containerClass", "isOpen", "delay"], outputs: ["onShown", "onHidden"], exportAs: ["bs-popover"] }, { kind: "ngmodule", type: ReactiveFormsModule }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DatapointsTableWidgetConfigComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-datapoints-table-view-config', standalone: true, imports: [
                        CoreModule,
                        DatapointSelectorModule,
                        DateRangePickerComponent,
                        PopoverModule,
                        ReactiveFormsModule
                    ], template: "<div class=\"p-l-24 p-r-24\">\n  <form\n    class=\"no-card-context\"\n    [formGroup]=\"formGroup\"\n  >\n    <!-- <datapoints-selector> -->\n    <div class=\"col-md-6\">\n      <div class=\"row\">\n        <!-- global-time-context-selector -->\n        <div class=\"form-group m-b-0 p-b-16 separator-bottom\">\n          <label\n            class=\"d-flex a-i-center p-t-4\"\n            for=\"dateSelection\"\n          >\n            {{ 'Date selection' | translate }}\n            <button\n              class=\"btn-help btn-help--sm\"\n              [attr.aria-label]=\"'Help' | translate\"\n              [popover]=\"popoverTemplate\"\n              placement=\"right\"\n              triggers=\"focus\"\n              container=\"body\"\n              type=\"button\"\n              [adaptivePosition]=\"true\"\n            ></button>\n          </label>\n          <ng-template #popoverTemplate>\n            <span translate>\n              Choose how to select a date range, the available options are:\n              <ul class=\"m-l-0 p-l-8 m-t-8 m-b-0\">\n                <li>\n                  <b>Dashboard time range:</b>\n                  restricts date selection to the global dashboard configuration only\n                </li>\n                <li>\n                  <b>Widget configuration:</b>\n                  restricts the date selection only to the widget configuration\n                </li>\n                <li>\n                  <b>Widget and widget configuration:</b>\n                  restricts the date selection to the widget view and widget configuration only\n                </li>\n              </ul>\n            </span>\n          </ng-template>\n          <div class=\"c8y-select-wrapper\">\n            <select\n              class=\"form-control text-12\"\n              [title]=\"'Date selection' | translate\"\n              [attr.aria-label]=\"'Date selection' | translate\"\n              id=\"globalDateSelector\"\n              formControlName=\"globalDateSelector\"\n            >\n              <option\n                *ngFor=\"let dataSelectionValue of DATE_SELECTION_VALUES_ARR\"\n                [ngValue]=\"dataSelectionValue\"\n              >\n                {{ DATE_SELECTION_LABELS[dataSelectionValue] | translate }}\n              </option>\n            </select>\n          </div>\n        </div>\n      </div>\n      <div class=\"row\">\n        <c8y-datapoint-selection-list\n          class=\"bg-inherit separator-top p-t-16 d-block\"\n          listTitle=\"{{ 'Data points' | translate }}\"\n          name=\"datapoints\"\n          [defaultFormOptions]=\"defaultFormOptions\"\n          [config]=\"datapointSelectionConfig\"\n          [minActiveCount]=\"1\"\n          formControlName=\"datapoints\"\n        ></c8y-datapoint-selection-list>\n      </div>\n    </div>\n    <div class=\"col-md-6\">\n      <div class=\"row\">\n        <ng-container *ngIf=\"!isWidgetLinkedToGlobalTimeContext\">\n          <div class=\"col-md-6\">\n            <!-- interval selector -->\n            <fieldset class=\"c8y-fieldset\">\n              <legend class=\"d-flex a-i-center\">\n                {{ 'Auto refresh' | translate }}\n                <button\n                  class=\"btn-help btn-help--sm\"\n                  [attr.aria-label]=\"'Help' | translate\"\n                  [popover]=\"\n                    'Change the state of interval automatic refresh and set the refresh frequency.'\n                      | translate\n                  \"\n                  placement=\"top\"\n                  triggers=\"focus\"\n                  container=\"body\"\n                  type=\"button\"\n                  [adaptivePosition]=\"true\"\n                ></button>\n              </legend>\n              <c8y-form-group class=\"m-b-16 form-group-sm\">\n                <div class=\"d-flex gap-4 m-t-8 m-b-8 a-i-center\">\n                  <label class=\"c8y-switch\">\n                    <input\n                      id=\"refreshToggle\"\n                      name=\"isAutoRefreshEnabled\"\n                      type=\"checkbox\"\n                      formControlName=\"isAutoRefreshEnabled\"\n                      (click)=\"toggleRefreshIntervalControl()\"\n                    />\n                    <span></span>\n                    <span class=\"sr-only\">{{ 'Auto refresh' | translate }}</span>\n                  </label>\n                  <label\n                    class=\"m-b-0\"\n                    for=\"refreshInterval\"\n                  >\n                    {{ 'Interval' | translate }}\n                  </label>\n                  <div class=\"c8y-select-wrapper\">\n                    <select\n                      class=\"form-control text-12\"\n                      [title]=\"'Refresh interval in seconds' | translate\"\n                      id=\"refreshInterval\"\n                      formControlName=\"refreshInterval\"\n                    >\n                      <option\n                        *ngFor=\"let refreshInterval of REFRESH_INTERVAL_VALUES_ARR\"\n                        [ngValue]=\"refreshInterval\"\n                      >\n                        {{ '{{ seconds }} s' | translate: { seconds: refreshInterval / 1000 } }}\n                      </option>\n                    </select>\n                  </div>\n                </div>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n        </ng-container>\n        <!-- decimal input -->\n        <div class=\"col-md-6\">\n          <fieldset class=\"c8y-fieldset\">\n            <legend>\n              {{ 'Decimal places' | translate }}\n            </legend>\n            <c8y-form-group class=\"p-t-8\">\n              <input\n                class=\"form-control\"\n                name=\"decimalPlaces\"\n                type=\"number\"\n                formControlName=\"decimalPlaces\"\n                step=\"1\"\n              />\n            </c8y-form-group>\n          </fieldset>\n        </div>\n      </div>\n      <!-- aggregation selector -->\n      <div class=\"row\">\n        <ng-container *ngIf=\"!isWidgetLinkedToGlobalTimeContext\">\n          <div class=\"col-md-6\">\n            <fieldset class=\"c8y-fieldset\">\n              <legend>\n                {{ 'Aggregation' | translate }}\n              </legend>\n              <c8y-form-group class=\"p-t-8\">\n                <div class=\"c8y-select-wrapper\">\n                  <!-- Setting below [attr.disabled] ensures that the control is visually disabled and user interaction is prevented,\n               while still allowing the value to be updated and saved correctly in the form.\n               This solution covers the case where the user enables auto-refresh, in which case aggregation must be set to NONE. -->\n                  <select\n                    class=\"form-control text-12\"\n                    [title]=\"'Aggregation' | translate\"\n                    id=\"aggregation\"\n                    formControlName=\"aggregation\"\n                    [attr.disabled]=\"formGroup.value.isAutoRefreshEnabled ? true : null\"\n                  >\n                    <option\n                      *ngFor=\"let aggregationValue of AGGREGATION_VALUES_ARR\"\n                      [ngValue]=\"aggregationValue\"\n                      [disabled]=\"disabledAggregationOptions[aggregationValue]\"\n                    >\n                      {{ AGGREGATION_LABELS[aggregationValue] | translate }}\n                    </option>\n                  </select>\n                </div>\n              </c8y-form-group>\n            </fieldset>\n          </div>\n        </ng-container>\n        <!-- time interval selector -->\n        <div class=\"col-md-6\">\n          <fieldset class=\"c8y-fieldset\">\n            <legend>\n              {{ 'Time interval' | translate }}\n            </legend>\n            <c8y-form-group class=\"p-t-8\">\n              <div class=\"c8y-select-wrapper\">\n                <select\n                  class=\"form-control text-12\"\n                  [title]=\"'Interval' | translate\"\n                  id=\"interval\"\n                  formControlName=\"interval\"\n                >\n                  <option\n                    *ngFor=\"let intervalValue of INTERVAL_VALUES_ARR\"\n                    [ngValue]=\"intervalValue\"\n                  >\n                    {{ TIME_RANGE_INTERVAL_LABELS[intervalValue] | translate }}\n                  </option>\n                </select>\n              </div>\n            </c8y-form-group>\n          </fieldset>\n        </div>\n      </div>\n      <!-- date pickers -->\n      <fieldset class=\"c8y-fieldset\">\n        <legend>\n          {{ 'Date range' | translate }}\n        </legend>\n        <c8y-date-range-picker></c8y-date-range-picker>\n      </fieldset>\n    </div>\n  </form>\n</div>\n" }]
        }], ctorParameters: () => [{ type: i1$1.AggregationService }, { type: DatapointsTableService }, { type: i3.FormBuilder }, { type: i3.NgForm }, { type: i4.WidgetConfigComponent }], propDecorators: { config: [{
                type: Input
            }] } });

/**
 * A pipe that adjusts the aggregated time range based on the aggregation type.
 *
 * ```html
 * '9:00' | adjustAggregatedTimeRange: config.aggregation (e.g.:HOURLY)
 * ```
 * The output will be '9:00-10:00'.
 */
class AdjustAggregatedTimeRangePipe {
    /**
     * Transforms the input time based on the aggregation type.
     * @param inputTime The input time string.
     * @param aggregationType The type of aggregation (optional).
     * @returns The transformed time string.
     */
    transform(inputTime, aggregationType$1) {
        if (!aggregationType$1) {
            return inputTime;
        }
        if (aggregationType$1 === aggregationType.DAILY) {
            return '';
        }
        const date = this.createDateFromInput(inputTime);
        const isTwelveHoursFormat = this.isTwelveHoursFormat(inputTime);
        switch (aggregationType$1) {
            case aggregationType.HOURLY:
                return this.getHourlyTimeRange(date, isTwelveHoursFormat);
            case aggregationType.MINUTELY:
                return this.getMinutelyTimeRange(date, isTwelveHoursFormat);
            default:
                throw new Error('Unsupported aggregation type');
        }
    }
    /**
     * Creates a date object from the input time string.
     * @param inputTime The input time string.
     * @returns The created Date object.
     */
    createDateFromInput(inputTime) {
        const defaultDate = '1970-01-01 ';
        const isPM = /PM/i.test(inputTime);
        const cleanedTime = inputTime.replace(/AM|PM/i, '').trim();
        this.validateTimeFormat(cleanedTime, inputTime);
        const dateTimeString = `${defaultDate}${cleanedTime}`;
        const date = new Date(dateTimeString);
        if (isNaN(date.getTime())) {
            throw new Error('Invalid input time');
        }
        return this.adjustForPMTime(date, isPM);
    }
    /**
     * Validates if the time string matches the required format and has valid values.
     * @param time The time string to validate.
     * @param originalInput The original input string (including AM/PM if present).
     * @throws Error if the time format is invalid or values are out of range.
     */
    validateTimeFormat(time, originalInput) {
        const parts = time.split(':');
        this.validateTimeParts(parts);
        const [hoursStr, minutesStr, secondsStr] = parts;
        this.validateTimeDigits(hoursStr, minutesStr, secondsStr);
        const { hours, minutes, seconds } = this.parseTimeComponents(hoursStr, minutesStr, secondsStr);
        this.validateTimeRanges(hours, minutes, seconds);
        this.validateTimeFormat24Hour(hours, originalInput);
    }
    validateTimeParts(parts) {
        if (parts.length < 2 || parts.length > 3) {
            throw new Error('Invalid input time');
        }
    }
    validateTimeDigits(hoursStr, minutesStr, secondsStr) {
        if (!this.isValidNumberString(hoursStr) ||
            !this.isValidNumberString(minutesStr) ||
            (secondsStr !== undefined && !this.isValidNumberString(secondsStr))) {
            throw new Error('Invalid input time');
        }
    }
    parseTimeComponents(hoursStr, minutesStr, secondsStr) {
        return {
            hours: Number(hoursStr),
            minutes: Number(minutesStr),
            seconds: secondsStr ? Number(secondsStr) : 0
        };
    }
    validateTimeRanges(hours, minutes, seconds) {
        if (hours > 23 || hours < 0 || minutes > 59 || minutes < 0 || seconds > 59 || seconds < 0) {
            throw new Error('Invalid input time');
        }
    }
    validateTimeFormat24Hour(hours, originalInput) {
        if (hours > 12 && this.hasAmPm(originalInput)) {
            throw new Error('Invalid input time');
        }
    }
    /**
     * Checks if string contains only digits and is 1-2 characters long.
     * @param value String to check
     * @returns boolean indicating if string is valid
     */
    isValidNumberString(value) {
        return (value.length > 0 &&
            value.length <= 2 &&
            value.split('').every(char => char >= '0' && char <= '9'));
    }
    /**
     * Checks if the input time has AM/PM markers.
     * @param input The input time string to check.
     * @returns boolean indicating if the input contains AM/PM.
     */
    hasAmPm(input) {
        return /AM|PM/i.test(input);
    }
    /**
     * Adjusts the date for PM times by adding 12 hours when necessary.
     * @param date The date object to adjust.
     * @param isPM Boolean indicating if the time is PM.
     * @returns The adjusted Date object.
     */
    adjustForPMTime(date, isPM) {
        const hours = date.getHours();
        if (isPM && hours < 12) {
            date.setHours(hours + 12);
        }
        else if (!isPM && hours === 12) {
            date.setHours(0);
        }
        return date;
    }
    /**
     * Checks if the input time is in twelve hours format.
     * @param inputTime The input time string.
     * @returns True if the input time is in twelve hours format, false otherwise.
     */
    isTwelveHoursFormat(inputTime) {
        return /AM|PM/i.test(inputTime);
    }
    /**
     * Gets the hourly time range for the given date.
     * @param date The date object.
     * @param twelveHoursFormat Indicates whether to use twelve hours format.
     * @returns The hourly time range string.
     */
    getHourlyTimeRange(date, twelveHoursFormat) {
        const nextHour = new Date(date.getTime());
        nextHour.setHours(date.getHours() + 1);
        return `${this.formatTime(date, twelveHoursFormat, true)}-${this.formatTime(nextHour, twelveHoursFormat, true)}`;
    }
    /**
     * Gets the minutely time range for the given date.
     * @param date The date object.
     * @param twelveHoursFormat Indicates whether to use twelve hours format.
     * @returns The minutely time range string.
     */
    getMinutelyTimeRange(date, twelveHoursFormat) {
        const nextMinute = new Date(date.getTime());
        nextMinute.setMinutes(date.getMinutes() + 1);
        return `${this.formatTime(date, twelveHoursFormat, false)}-${this.formatTime(nextMinute, twelveHoursFormat, false)}`;
    }
    /**
     * Formats the given date into a time string.
     * @param date The date to format.
     * @param usePeriod Indicates whether to include the period (AM/PM) in the formatted time.
     * @param useHourOnly Indicates whether to include only the hour part in the formatted time.
     * @returns The formatted time string.
     */
    formatTime(date, usePeriod, useHourOnly) {
        const hours = date.getHours();
        const minutes = date.getMinutes().toString().padStart(2, '0');
        if (usePeriod) {
            const period = hours >= 12 ? 'PM' : 'AM';
            const formattedHours = hours % 12 === 0 ? 12 : hours % 12;
            return `${formattedHours}:${useHourOnly ? '00' : minutes} ${period}`;
        }
        else {
            return `${hours.toString().padStart(2, '0')}:${useHourOnly ? '00' : minutes}`;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AdjustAggregatedTimeRangePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: AdjustAggregatedTimeRangePipe, isStandalone: true, name: "adjustAggregatedTimeRange" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AdjustAggregatedTimeRangePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'adjustAggregatedTimeRange',
                    standalone: true
                }]
        }] });

/**
 * Applies CSS classes based on the value's range.
 */
class ApplyRangeClassPipe {
    /**
     * Transforms the input value based on the specified ranges.
     *
     * @param value - Initial value used to determine the CSS class.
     * @param ranges - An object containing the min and max range values for yellow and red colors.
     * @returns The CSS class to be applied.
     */
    transform(value, ranges) {
        if (value == null) {
            return;
        }
        if (value >= ranges.yellowRangeMin && value < ranges.yellowRangeMax) {
            return 'text-warning';
        }
        else if (value >= ranges.redRangeMin && value <= ranges.redRangeMax) {
            return 'text-danger';
        }
        return 'default';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ApplyRangeClassPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: ApplyRangeClassPipe, isStandalone: true, name: "applyRangeClass" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ApplyRangeClassPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'applyRangeClass',
                    standalone: true
                }]
        }] });

class DatapointsReloadComponent extends IntervalBasedReload {
    constructor(cdRef, translateService, widgetGlobalAutoRefreshService, gainsightService) {
        super();
        this.cdRef = cdRef;
        this.translateService = translateService;
        this.widgetGlobalAutoRefreshService = widgetGlobalAutoRefreshService;
        this.gainsightService = gainsightService;
        this.WIDGET_TYPE_VALUES = WIDGET_TYPE_VALUES;
        /**
         * @inheritdoc
         */
        this.isRefreshDisabled = false;
        /**
         * @inheritdoc
         */
        this.onCountdownEnded = new EventEmitter();
        /**
         * @inheritdoc
         */
        this.manuallyDisabledCountdown = false;
        this.destroy$ = new Subject();
    }
    ngAfterViewInit() {
        if (this.widgetInstanceGlobalAutoRefreshContext) {
            this.widgetGlobalAutoRefreshService.countdownActions.countdownEnded$
                .pipe(takeUntil(this.destroy$), tap(() => this.onCountdownEnded.emit()))
                .subscribe();
        }
    }
    ngOnChanges(changes) {
        if (this.isRefreshDisabled && this.isAutoRefreshEnabled) {
            this.isIntervalRefreshToggleOn = false;
            this.disableCountdown();
            return;
        }
        if (this.isExportModalOpen && this.canDisableCountdownWhenModalIsOpen()) {
            this.isIntervalRefreshToggleOn = !this.isIntervalRefreshToggleOn;
            this.disableCountdown();
        }
        else {
            if (this.canStartCountdown(changes)) {
                this.isIntervalRefreshToggleOn = true;
                this.startCountdown();
            }
            if (this.canHandleScrolling()) {
                this.handleScrolling();
            }
        }
    }
    ngOnDestroy() {
        if (this.countdownSubscription) {
            this.countdownSubscription.unsubscribe();
        }
        this.destroy$.next();
        this.destroy$.complete();
    }
    /**
     * @inheritdoc
     */
    countdownEnded() {
        /**
         * @inheritdoc
         */
        this.autoRefreshList();
    }
    reload() {
        /**
         * @inheritdoc
         */
        this.autoRefreshList();
    }
    /**
     * @inheritdoc
     */
    enableCountdown() {
        this.hideCountdown = false;
        // Prevents the countdown from getting stuck on an initial value.
        this.cdRef.detectChanges();
        this.startCountdown();
    }
    /**
     * @inheritdoc
     */
    updateCountdownButtonTooltipText() {
        this.toggleCountdownButtonTooltipText = this.isIntervalRefreshToggleOn
            ? this.translateService.instant(gettext('Disable auto refresh'))
            : this.translateService.instant(gettext('Enable auto refresh'));
    }
    canStartCountdown(changes) {
        const { isAutoRefreshEnabled, refreshInterval } = changes;
        return ((isAutoRefreshEnabled || refreshInterval) &&
            (this.isAutoRefreshEnabled || !!this.refreshInterval));
    }
    canHandleScrolling() {
        return !this.manuallyDisabledCountdown && this.isAutoRefreshEnabled;
    }
    canDisableCountdownWhenModalIsOpen() {
        return (this.isAutoRefreshEnabled &&
            !!this.refreshInterval &&
            !this.manuallyDisabledCountdown &&
            !this.isScrolling &&
            !this.hideCountdown);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DatapointsReloadComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: i1$2.TranslateService }, { token: i1$1.WidgetGlobalAutoRefreshService }, { token: i1$1.GainsightService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: DatapointsReloadComponent, isStandalone: true, selector: "c8y-datapoints-reload", inputs: { isAutoRefreshEnabled: "isAutoRefreshEnabled", isRefreshDisabled: "isRefreshDisabled", isLoading: "isLoading", isScrolling: "isScrolling", isExportModalOpen: "isExportModalOpen", refreshInterval: "refreshInterval", widgetInstanceGlobalAutoRefreshContext: "widgetInstanceGlobalAutoRefreshContext" }, outputs: { onCountdownEnded: "onCountdownEnded" }, viewQueries: [{ propertyName: "countdownIntervalComponent", first: true, predicate: CountdownIntervalComponent, descendants: true }], usesInheritance: true, usesOnChanges: true, ngImport: i0, template: "<ng-container *ngIf=\"!widgetInstanceGlobalAutoRefreshContext\">\n  <div class=\"a-i-center input-group p-t-4 p-b-4 max-width-fit m-l-auto\">\n    <label\n      class=\"m-b-0 m-r-8 text-label-small text-truncate flex-no-shrink\"\n      title=\" {{ 'Auto refresh' | translate }}\"\n      *ngIf=\"refreshInterval && isAutoRefreshEnabled\"\n    >\n      {{ 'Auto refresh' | translate }}\n    </label>\n    <div class=\"input-group\">\n      <label\n        class=\"toggle-countdown\"\n        [class.toggle-countdown-disabled]=\"isRefreshDisabled\"\n        [attr.aria-label]=\"toggleCountdownButtonTooltipText\"\n        [tooltip]=\"toggleCountdownButtonTooltipText\"\n        placement=\"bottom\"\n        *ngIf=\"refreshInterval && isAutoRefreshEnabled\"\n        [adaptivePosition]=\"false\"\n        [container]=\"'body'\"\n        [delay]=\"500\"\n      >\n        <input\n          type=\"checkbox\"\n          [checked]=\"isIntervalRefreshToggleOn\"\n          [disabled]=\"isRefreshDisabled\"\n          data-cy=\"c8y-data-points-table-widget--interval-toggle-button\"\n          (click)=\"onToggleCountdownButtonState($event, WIDGET_TYPE_VALUES.DATA_POINTS_TABLE)\"\n        />\n\n        <c8y-countdown-interval\n          *ngIf=\"isIntervalRefreshToggleOn\"\n          [countdownInterval]=\"refreshInterval\"\n          (countdownEnded)=\"countdownEnded()\"\n        ></c8y-countdown-interval>\n        <i\n          c8yIcon=\"pause\"\n          *ngIf=\"!isIntervalRefreshToggleOn\"\n        ></i>\n      </label>\n\n      <div class=\"input-group-btn\">\n        <button\n          class=\"btn btn-default\"\n          [attr.aria-label]=\"'Refresh' | translate\"\n          [tooltip]=\"'Refresh' | translate\"\n          placement=\"bottom\"\n          type=\"button\"\n          [adaptivePosition]=\"false\"\n          [container]=\"'body'\"\n          [delay]=\"500\"\n          [disabled]=\"isRefreshDisabled || (isLoading | async)\"\n          (click)=\"reload()\"\n          data-cy=\"c8y-data-points-table-widget--reload-button\"\n        >\n          <i\n            c8yIcon=\"refresh\"\n            [ngClass]=\"{ 'icon-spin': isLoading | async }\"\n          ></i>\n        </button>\n      </div>\n    </div>\n  </div>\n</ng-container>\n", dependencies: [{ kind: "ngmodule", type: CommonModule$1 }, { kind: "directive", type: i1$1.IconDirective, selector: "[c8yIcon]", inputs: ["c8yIcon"] }, { kind: "pipe", type: i1$1.C8yTranslatePipe, name: "translate" }, { kind: "directive", type: i2.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "pipe", type: i2.AsyncPipe, name: "async" }, { kind: "ngmodule", type: CountdownIntervalModule }, { kind: "component", type: i1$1.CountdownIntervalComponent, selector: "c8y-countdown-interval", inputs: ["countdownInterval"], outputs: ["countdownEnded"] }, { kind: "ngmodule", type: ListGroupModule }, { kind: "ngmodule", type: TooltipModule }, { kind: "directive", type: i4$1.TooltipDirective, selector: "[tooltip], [tooltipHtml]", inputs: ["adaptivePosition", "tooltip", "placement", "triggers", "container", "containerClass", "boundariesElement", "isOpen", "isDisabled", "delay", "tooltipHtml", "tooltipPlacement", "tooltipIsOpen", "tooltipEnable", "tooltipAppendToBody", "tooltipAnimation", "tooltipClass", "tooltipContext", "tooltipPopupDelay", "tooltipFadeDuration", "tooltipTrigger"], outputs: ["tooltipChange", "onShown", "onHidden", "tooltipStateChanged"], exportAs: ["bs-tooltip"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DatapointsReloadComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-datapoints-reload', standalone: true, imports: [CommonModule$1, CountdownIntervalModule, ListGroupModule, TooltipModule], template: "<ng-container *ngIf=\"!widgetInstanceGlobalAutoRefreshContext\">\n  <div class=\"a-i-center input-group p-t-4 p-b-4 max-width-fit m-l-auto\">\n    <label\n      class=\"m-b-0 m-r-8 text-label-small text-truncate flex-no-shrink\"\n      title=\" {{ 'Auto refresh' | translate }}\"\n      *ngIf=\"refreshInterval && isAutoRefreshEnabled\"\n    >\n      {{ 'Auto refresh' | translate }}\n    </label>\n    <div class=\"input-group\">\n      <label\n        class=\"toggle-countdown\"\n        [class.toggle-countdown-disabled]=\"isRefreshDisabled\"\n        [attr.aria-label]=\"toggleCountdownButtonTooltipText\"\n        [tooltip]=\"toggleCountdownButtonTooltipText\"\n        placement=\"bottom\"\n        *ngIf=\"refreshInterval && isAutoRefreshEnabled\"\n        [adaptivePosition]=\"false\"\n        [container]=\"'body'\"\n        [delay]=\"500\"\n      >\n        <input\n          type=\"checkbox\"\n          [checked]=\"isIntervalRefreshToggleOn\"\n          [disabled]=\"isRefreshDisabled\"\n          data-cy=\"c8y-data-points-table-widget--interval-toggle-button\"\n          (click)=\"onToggleCountdownButtonState($event, WIDGET_TYPE_VALUES.DATA_POINTS_TABLE)\"\n        />\n\n        <c8y-countdown-interval\n          *ngIf=\"isIntervalRefreshToggleOn\"\n          [countdownInterval]=\"refreshInterval\"\n          (countdownEnded)=\"countdownEnded()\"\n        ></c8y-countdown-interval>\n        <i\n          c8yIcon=\"pause\"\n          *ngIf=\"!isIntervalRefreshToggleOn\"\n        ></i>\n      </label>\n\n      <div class=\"input-group-btn\">\n        <button\n          class=\"btn btn-default\"\n          [attr.aria-label]=\"'Refresh' | translate\"\n          [tooltip]=\"'Refresh' | translate\"\n          placement=\"bottom\"\n          type=\"button\"\n          [adaptivePosition]=\"false\"\n          [container]=\"'body'\"\n          [delay]=\"500\"\n          [disabled]=\"isRefreshDisabled || (isLoading | async)\"\n          (click)=\"reload()\"\n          data-cy=\"c8y-data-points-table-widget--reload-button\"\n        >\n          <i\n            c8yIcon=\"refresh\"\n            [ngClass]=\"{ 'icon-spin': isLoading | async }\"\n          ></i>\n        </button>\n      </div>\n    </div>\n  </div>\n</ng-container>\n" }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }, { type: i1$2.TranslateService }, { type: i1$1.WidgetGlobalAutoRefreshService }, { type: i1$1.GainsightService }], propDecorators: { countdownIntervalComponent: [{
                type: ViewChild,
                args: [CountdownIntervalComponent, { static: false }]
            }], isAutoRefreshEnabled: [{
                type: Input
            }], isRefreshDisabled: [{
                type: Input
            }], isLoading: [{
                type: Input
            }], isScrolling: [{
                type: Input
            }], isExportModalOpen: [{
                type: Input
            }], refreshInterval: [{
                type: Input
            }], widgetInstanceGlobalAutoRefreshContext: [{
                type: Input
            }], onCountdownEnded: [{
                type: Output
            }] } });

function mapToSourceValueObject([key, value]) {
    return { key, value };
}
class DatapointsTableViewService {
    constructor(dataFetchingService) {
        this.dataFetchingService = dataFetchingService;
    }
    /**
     * Filters out inactive data points from the given array.
     *
     * @param datapoints - The array of data points to filter.
     * @returns An array of data points that are active.
     */
    filterOutInactiveDatapoints(datapoints) {
        return datapoints.filter((datapoint) => datapoint.__active);
    }
    hasMultipleDatapoints(datapoints) {
        const ids = datapoints.map(dp => dp.__target.id);
        return ids.length > 1;
    }
    /**
     * Returns a map of active data points device IDs with their corresponding series.
     *
     * Example output:
     * ```typescript
     * new Map([
     *   [
     *     "844657202",
     *     [
     *       "c8y_Temperature.T"
     *     ]
     *   ],
     *   [
     *     "32666427",
     *     [
     *       "c8y_Battery.Battery"
     *     ]
     *   ]
     * ]);
     * ```
     * @param datapoints - An array of data points.
     * @returns A map where the key is the data point ID and the value is an array of data point series.
     */
    groupSeriesByDeviceId(activeDatapoints) {
        return activeDatapoints.reduce((map, { fragment, series, __target: { id } }) => {
            const value = `${fragment}.${series}`;
            const existingValue = map.get(id) ?? [];
            map.set(id, [...existingValue, value]);
            return map;
        }, new Map());
    }
    /**
     * Retrieves the active data points series data and returns it as a map.
     *
     * @param datapointsValuesDataMap - A map of data point sources with their associated series.
     * @param config - The configuration of the data points table.
     * @param roundSeconds - Whether to round the seconds or not.
     *                       If true, the seconds will be rounded to 0.
     *                       If false, the seconds will be displayed as they are.
     * @returns A Promise that resolves to a Map object with data point IDs as keys and DataObject as values or undefined when all series has forbidden access.
     */
    async getAllActiveSeriesDataMap(datapointsValuesDataMap, config, roundSeconds) {
        const promises = Array.from(datapointsValuesDataMap).map(async ([source, series]) => {
            const params = {
                dateFrom: config.dateFrom,
                dateTo: config.dateTo,
                source,
                series,
                aggregationType: config.aggregation
            };
            const { data, res } = await this.dataFetchingService.fetchSeriesData(params, roundSeconds);
            return { source, data, res };
        });
        const results = await Promise.all(promises);
        const allSeriesHasForbiddenAccess = results.every(item => item.res?.status === 403);
        if (allSeriesHasForbiddenAccess) {
            throw new Error('Access forbidden: All series have a 403 status code');
        }
        const filteredResults = this.filterOutElementsWithForbiddenResponses(results);
        const resultMap = new Map();
        filteredResults.forEach(result => resultMap.set(result.source, result.data));
        return resultMap;
    }
    /**
     * Creates an array of DatapointsWithValues based on the provided datapoints and datapointsSeriesDataMap.
     *
     * Finds an index of a current data point within series object and based on that index filters values array.
     *
     * @param datapoints - An array of data points.
     * @param datapointsSeriesDataMap - A map containing series data for data points.
     * @returns An array of DatapointsWithValues.
     */
    getDatapointsWithValues(datapoints, datapointsSeriesDataMap) {
        return datapoints.map((dp) => {
            const seriesData = datapointsSeriesDataMap.get(dp.__target.id);
            if (!seriesData) {
                return { ...dp, values: {} };
            }
            // Find an index of a corresponding datapoint data, within series object.
            const datapointSeriesArrayIndex = seriesData.series.findIndex(s => s.name === dp.series && s.type === dp.fragment);
            const valuesFilteredByDatapointSeriesArrayIndex = Object.fromEntries(Object.entries(seriesData.values).map(([key, arr]) => [
                key,
                arr.filter((_, index) => index === datapointSeriesArrayIndex)
            ]));
            return {
                ...dp,
                seriesUnit: seriesData.series[datapointSeriesArrayIndex]?.unit,
                values: valuesFilteredByDatapointSeriesArrayIndex
            };
        });
    }
    /**
     * Creates the column headers for the devices in the data points table.
     *
     * @param datapointsWithValues - An array of data points.
     * @returns An array of column headers for the devices.
     */
    getColumnHeaders(datapointsWithValues) {
        return datapointsWithValues.map(({ __target: { name }, label, renderType, unit }) => {
            return { deviceName: name, label, renderType, unit };
        });
    }
    mapDatapointsWithValuesToList(datapointsWithValues) {
        return datapointsWithValues.flatMap(dp => {
            if (!dp.values) {
                return [];
            }
            return Object.entries(dp.values).flatMap(([date, valuesArray]) => {
                const value = this.findMinMaxValues(valuesArray);
                if (value == null) {
                    return [];
                }
                return [
                    {
                        dateAndTime: date,
                        deviceName: dp.__target.name,
                        fragment: dp.fragment,
                        label: dp.label,
                        redRangeMax: dp.redRangeMax,
                        redRangeMin: dp.redRangeMin,
                        renderType: dp.renderType,
                        series: dp.series,
                        value: value,
                        yellowRangeMax: dp.yellowRangeMax,
                        yellowRangeMin: dp.yellowRangeMin
                    }
                ];
            });
        });
    }
    /**
     * Finds the overall minimum and maximum values from an array of objects containing 'min' and 'max' properties.
     *
     * If the array contains only one object, that object's 'min' and 'max' values will be returned.
     *
     * @param valuesArray - An array with objects, where each contains 'min' and 'max' properties.
     * @returns An object with the smallest 'min' and largest 'max' values found in the array.
     *
     * @example
     * const values = [
     *   { min: 1, max: 10 }
     * ];
     *
     * const result = findMinMaxValues(values);
     * // result is { min: 1, max: 10 }
     */
    findMinMaxValues(valuesArray) {
        const validItems = valuesArray.filter((item) => item && item.min != null && item.max != null);
        if (validItems.length === 0) {
            return null;
        }
        const initialValue = { min: validItems[0].min, max: validItems[0].max };
        return validItems.reduce((acc, item) => ({
            min: Math.min(acc.min, item.min),
            max: Math.max(acc.max, item.max)
        }), initialValue);
    }
    /**
     * Groups a list of data points by date and device, based on given references.
     *
     * @param dataList - The list of data points to be grouped.
     * @param references - The column headers that serve as references for grouping.
     * @returns An array of grouped data points, where each group corresponds to a unique date and device.
     */
    groupByDateAndDevice(dataList, references) {
        const map = this.generateDataPointMap(dataList, references);
        return this.mergeDatapoints(map);
    }
    /**
     * Generates and populates a map with data points.
     *
     * This function processes the provided data points and organizes them into a map structure
     * where each key is a unique combination of date and device identifiers, and the value is an
     * array of data points (or null values) associated with that key. This structured data is then
     * used in the data point table to render the data appropriately.
     *
     * @param dataList - The list of data point table items to be processed.
     * @param columnsHeadersReferences - The list of column headers used to determine the order and structure of the map values.
     * @returns A map where the key is a datapoint identifier containing the date and device name, and the value is an array of data point table items or null.
     */
    generateDataPointMap(dataList, columnsHeadersReferences) {
        // Map to store the data points indexed by a unique identifier.
        const map = new Map();
        dataList.forEach(obj => {
            // Generate a unique identifier for each data point using the date and device name.
            const dateKey = this.toISOFormat(obj.dateAndTime);
            const datapointIdentifier = `${dateKey}_${obj.deviceName}`;
            // Initialize the map entry if it does not exist with a unique identifier.
            if (!map.has(datapointIdentifier)) {
                map.set(datapointIdentifier, Array(columnsHeadersReferences.length).fill(null));
            }
            // Find the index of the reference that matches the current data point.
            const matchingColumnIndex = columnsHeadersReferences.findIndex(ref => ref.deviceName === obj.deviceName && ref.label === obj.label);
            // Update the map entry with the data point.
            const tableItem = map.get(datapointIdentifier);
            if (tableItem) {
                tableItem[matchingColumnIndex] = { ...obj };
            }
        });
        return map;
    }
    /**
     * Merges the data points from the given map into an array of grouped data point table items.
     *
     * @param map - The map containing the data points to be merged.
     * @returns An array of grouped data point table items.
     */
    mergeDatapoints(map) {
        const mergedData = [];
        map.forEach((values, datapointIdentifier) => {
            const [dateKey, deviceName] = datapointIdentifier.split('_');
            const validDataPoint = values.some(item => item && Object.keys(item.value).length > 0);
            if (validDataPoint) {
                mergedData.push({
                    dateAndTime: dateKey,
                    deviceName: deviceName,
                    rowItems: values.map(item => (item ? { ...item } : null))
                });
            }
        });
        return mergedData;
    }
    sortDataByDateDescending(data) {
        return data.sort((a, b) => new Date(b.dateAndTime).getTime() - new Date(a.dateAndTime).getTime());
    }
    /**
     * Prepares the updated time range based on the selected interval.
     *
     * In case of a 'custom' interval or no quantity, the original date range is returned.
     *
     * @param interval - The selected interval type.
     * @returns An object containing the `dateFrom` and `dateTo` in ISO string format.
     */
    prepareTimeRange(interval, dateFromInput, dateToInput) {
        if (!interval || interval === INTERVAL_VALUES.custom) {
            return { dateFrom: dateFromInput, dateTo: dateToInput };
        }
        const selected = DURATION_OPTIONS.find(selectedDuration => selectedDuration.id === interval);
        if (!selected?.amount) {
            return { dateFrom: dateFromInput, dateTo: dateToInput };
        }
        const now = new Date();
        return {
            dateFrom: this.subtractTime(now, selected.amount, selected.unit).toISOString(),
            dateTo: now.toISOString()
        };
    }
    /**
     * Subtracts an amount of time from a given date.
     *
     * @param date - The original date.
     * @param amount - The amount of time units to subtract.
     * @param unit - The unit of time to subtract (e.g., minutes, hours, days, weeks, months).
     * @returns A new date with the specified time subtracted.
     */
    subtractTime(date, amount, unit) {
        const newDate = new Date(date);
        switch (unit) {
            case INTERVAL_VALUES.minutes:
                newDate.setUTCMinutes(newDate.getUTCMinutes() - amount);
                break;
            case INTERVAL_VALUES.hours:
                newDate.setUTCHours(newDate.getUTCHours() - amount);
                break;
            case INTERVAL_VALUES.days:
                newDate.setUTCDate(newDate.getUTCDate() - amount);
                break;
            case INTERVAL_VALUES.weeks:
                newDate.setUTCDate(newDate.getUTCDate() - amount * 7);
                break;
            case INTERVAL_VALUES.months:
                this.subtractMonthsAndAdjustDay(newDate, amount);
                break;
        }
        return newDate;
    }
    getSeriesWithoutPermissionToRead(activeDatapointsSeriesData, activeDatapointsIdsWithSeries) {
        if (!activeDatapointsSeriesData) {
            // Returns all activeDatapointsIdsWithSeries entries if activeDatapointsSeriesData is undefined.
            // It means that the user does not have permission to see any of the selected datapoints data.
            return Array.from(activeDatapointsIdsWithSeries, mapToSourceValueObject);
        }
        const availableSources = new Set(activeDatapointsSeriesData.keys());
        return Array.from(activeDatapointsIdsWithSeries)
            .filter(([source]) => !availableSources.has(source))
            .map(mapToSourceValueObject);
    }
    hasSecondsAndMillisecondsEqualZero(timeString) {
        if (!timeString) {
            return false;
        }
        const date = new Date(timeString);
        if (isNaN(date.getTime())) {
            return false;
        }
        return date.getUTCSeconds() === 0 && date.getUTCMilliseconds() === 0;
    }
    /**
     * Converts a date string to ISO format.
     *
     * @param dateStr - The date string to convert.
     * @returns The ISO format of the given date string.
     */
    toISOFormat(dateStr) {
        return new Date(dateStr).toISOString();
    }
    filterOutElementsWithForbiddenResponses(seriesDataWithResponse) {
        return seriesDataWithResponse.filter(item => {
            return !(item.res?.status === 403);
        });
    }
    subtractMonthsAndAdjustDay(date, monthsToSubtract) {
        const currentMonth = date.getUTCMonth();
        const expectedTargetMonth = this.calculateTargetMonth(currentMonth, monthsToSubtract);
        date.setUTCMonth(currentMonth - monthsToSubtract);
        const actualMonth = date.getUTCMonth();
        const dayDoesNotExistInTargetMonth = actualMonth !== expectedTargetMonth;
        if (dayDoesNotExistInTargetMonth) {
            this.setToLastDayOfPreviousMonth(date);
        }
    }
    /**
     * Calculates the target month number (0-11) after subtracting months from the current month.
     * Handles negative month numbers by normalizing them to the valid 0-11 range.
     *
     * Examples:
     * - January(0) - 1 month = December(11)
     * - March(2) - 4 months = November(10)
     * - December(11) - 1 month = November(10)
     *
     * @param currentMonth - Current month (0-11, where 0 is January)
     * @param monthsToSubtract - Number of months to subtract
     * @returns Normalized month number in range 0-11
     */
    calculateTargetMonth(currentMonth, monthsToSubtract) {
        return (currentMonth - monthsToSubtract + 12) % 12;
    }
    /**
     * Sets the date to the last day of the previous month.
     * Using 0 as dateValue makes JavaScript automatically calculate
     * last day of previous month, per JavaScript Date API behavior.
     * @param date - Date to modify
     */
    setToLastDayOfPreviousMonth(date) {
        date.setUTCDate(0);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DatapointsTableViewService, deps: [{ token: i1.DataFetchingService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DatapointsTableViewService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DatapointsTableViewService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: i1.DataFetchingService }] });

/**
 * Creates a column header title message.
 *
 * ```html
 * title="{{ header | columnTitle }}"
 * ```
 * The output will be e.g.: 'c8y_Temperature → T [T] (Area)'.
 */
class ColumnTitlePipe {
    constructor(translateService) {
        this.translateService = translateService;
    }
    /**
     * Transforms the column header into a formatted string with label and optionally unit and render type.
     *
     * @param columnHeader - The column header object.
     * @returns The formatted string with label, unit, and render type.
     */
    transform(columnHeader) {
        const label = columnHeader.label.trim();
        const unit = columnHeader.unit ? `[${columnHeader.unit.trim()}]` : '';
        const renderType = columnHeader.renderType
            ? this.translateService.instant(RENDER_TYPES_LABELS[columnHeader.renderType])
            : '';
        if (!renderType) {
            return `${label} ${unit}`.trim();
        }
        return `${label} ${unit} (${renderType})`.trim();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ColumnTitlePipe, deps: [{ token: i1$2.TranslateService }], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: ColumnTitlePipe, isStandalone: true, name: "columnTitle" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ColumnTitlePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'columnTitle',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i1$2.TranslateService }] });

/**
 * Directive to listen for scroll events on a virtual scroll container.
 * Emits `scrolled` and `scrolledToTop` events.
 *
 * The directive listens for scroll events on a virtual scroll container.
 * - When the container is scrolled by at least 50 pixels (or a custom threshold), the `scrolled` event is emitted.
 * - When the container is scrolled to the top, the `scrolledToTop` event is emitted.
 *
 */
class VirtualScrollListenerDirective {
    constructor(el, ngZone) {
        this.el = el;
        this.ngZone = ngZone;
        /**
         * Pixel threshold for emitting the scrolled event.
         */
        this.scrollThreshold = 50;
        /**
         * Event emitted when the virtual scroll container is scrolled by at least 50 pixels.
         */
        this.scrolled = new EventEmitter();
        /**
         * Event emitted when the virtual scroll container is scrolled to the top.
         */
        this.scrolledToTop = new EventEmitter();
        this.lastScrollTop = 0;
    }
    ngAfterViewInit() {
        this.virtualScrollContainer = this.el.nativeElement.querySelector('.cdk-virtual-scroll-viewport');
        if (this.virtualScrollContainer) {
            this.ngZone.runOutsideAngular(() => {
                this.virtualScrollContainer.addEventListener('scroll', this.onScroll.bind(this));
            });
        }
    }
    ngOnDestroy() {
        if (this.virtualScrollContainer) {
            this.virtualScrollContainer.removeEventListener('scroll', this.onScroll.bind(this));
        }
    }
    /**
     * Handles the scroll event. Emits `scrolled` event if scrolled by at least `scrollThreshold` pixels
     * and `scrolledToTop` event if scrolled to the top.
     * @param event - The scroll event.
     */
    onScroll(event) {
        const target = event.target;
        const scrollTop = target.scrollTop;
        if (Math.abs(scrollTop - this.lastScrollTop) > this.scrollThreshold) {
            this.lastScrollTop = scrollTop;
            this.ngZone.run(() => this.scrolled.emit());
        }
        if (scrollTop === 0) {
            this.ngZone.run(() => this.scrolledToTop.emit());
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: VirtualScrollListenerDirective, deps: [{ token: i0.ElementRef }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "18.2.13", type: VirtualScrollListenerDirective, isStandalone: true, selector: "[c8yVirtualScrollListener]", inputs: { scrollThreshold: "scrollThreshold" }, outputs: { scrolled: "scrolled", scrolledToTop: "scrolledToTop" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: VirtualScrollListenerDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[c8yVirtualScrollListener]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.NgZone }], propDecorators: { scrollThreshold: [{
                type: Input
            }], scrolled: [{
                type: Output
            }], scrolledToTop: [{
                type: Output
            }] } });

class DynamicColumnDirective {
    constructor(el, renderer) {
        this.el = el;
        this.renderer = renderer;
    }
    ngOnInit() {
        this.updateColumnClass();
    }
    updateColumnClass() {
        let className = '';
        switch (this.numberOfColumns) {
            case 1:
                className = 'col-md-12';
                break;
            case 2:
                className = 'col-md-6';
                break;
            default:
                if (this.numberOfColumns >= 3) {
                    className = 'col-md-3';
                }
                break;
        }
        if (className) {
            this.renderer.addClass(this.el.nativeElement, className);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DynamicColumnDirective, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "18.2.13", type: DynamicColumnDirective, isStandalone: true, selector: "[c8yDynamicColumn]", inputs: { numberOfColumns: ["c8yDynamicColumn", "numberOfColumns"] }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DynamicColumnDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[c8yDynamicColumn]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.Renderer2 }], propDecorators: { numberOfColumns: [{
                type: Input,
                args: ['c8yDynamicColumn']
            }] } });

class DatapointsTableComponent {
    constructor() {
        this.isScrolling = new EventEmitter();
        this.hasNoPermissionsToReadAnyMeasurement = false;
        this.missingAllPermissionsAlert = new DynamicComponentAlertAggregator();
        /**
         * Default fraction size format for numbers with decimal places.
         */
        this.fractionSize = '1.2-2';
    }
    ngOnInit() {
        if (typeof this.decimalPlaces === 'number' && !Number.isNaN(this.decimalPlaces)) {
            this.fractionSize = `1.${this.decimalPlaces}-${this.decimalPlaces}`;
        }
    }
    ngOnChanges() {
        if (!this.seriesWithoutPermissionToReadCount) {
            return;
        }
        this.missingAllPermissionsAlert.clear();
        this.handleNoPermissionErrorMessage();
    }
    onListScrolled() {
        this.isScrolling.emit(true);
    }
    onListScrolledToTop() {
        this.isScrolling.emit(false);
    }
    getRangeValues(row) {
        return {
            yellowRangeMin: row.yellowRangeMin,
            yellowRangeMax: row.yellowRangeMax,
            redRangeMin: row.redRangeMin,
            redRangeMax: row.redRangeMax
        };
    }
    /**
     * Determines the fraction size format based on whether the number is an integer or has decimal places.
     *
     * @param value - The number to be formatted.
     * @returns Returns '1.0-0' if the number is an integer, otherwise returns the current fraction size.
     */
    getFractionSize(value) {
        return value % 1 === 0 ? '1.0-0' : this.fractionSize;
    }
    handleNoPermissionErrorMessage() {
        this.hasNoPermissionsToReadAnyMeasurement =
            this.seriesWithoutPermissionToReadCount === this.devicesColumnHeaders.length;
        if (this.hasNoPermissionsToReadAnyMeasurement) {
            this.showMessageForMissingPermissionsForAllSeries();
        }
    }
    showMessageForMissingPermissionsForAllSeries() {
        this.missingAllPermissionsAlert.addAlerts(new DynamicComponentAlert({
            allowHtml: true,
            text: gettext(`<p>To view data, you must meet at least one of these criteria:</p>
        <ul>
          <li>
            Have
            <b>READ permission for "Measurements" permission type</b>
            (either as a global role or for the specific source)
          </li>
          <li>
            Be the
            <b>owner of the source</b>
            you want to export data from
          </li>
        </ul>
        <p>Don't meet these requirements? Contact your system administrator for assistance.</p>`),
            type: 'system'
        }));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DatapointsTableComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: DatapointsTableComponent, isStandalone: true, selector: "c8y-datapoints-table", inputs: { aggregationType: "aggregationType", datapointsTableItems: "datapointsTableItems", devicesColumnHeaders: "devicesColumnHeaders", decimalPlaces: "decimalPlaces", hasMultipleDatapoints: "hasMultipleDatapoints", isLoading: "isLoading", seriesWithoutPermissionToReadCount: "seriesWithoutPermissionToReadCount" }, outputs: { isScrolling: "isScrolling" }, host: { classAttribute: "d-col flex-grow" }, usesOnChanges: true, ngImport: i0, template: "<ng-container *ngIf=\"!hasNoPermissionsToReadAnyMeasurement; else missingAllPermissions\">\n  <div class=\"c8y-cq-440\">\n    <div\n      class=\"hidden-xs c8y-list__item c8y-list--timeline hidden-cq\"\n      [ngClass]=\"{ 'separator-top-bottom': devicesColumnHeaders.length > 0 }\"\n    >\n      <div class=\"d-flex container-fluid\">\n        <div class=\"c8y-list--timeline__item__date\"></div>\n        <div class=\"c8y-list__item__block flex-grow min-width-0\">\n          <div class=\"c8y-list__item__body\">\n            <div class=\"d-flex row\">\n              <ng-container *ngIf=\"hasMultipleDatapoints\">\n                <div\n                  class=\"min-width-0\"\n                  [title]=\"'Device' | translate\"\n                  [c8yDynamicColumn]=\"devicesColumnHeaders.length\"\n                >\n                  <span class=\"text-medium text-truncate\">\n                    {{ 'Device' | translate }}\n                  </span>\n                </div>\n              </ng-container>\n              <!-- Data points column headers -->\n              <ng-container *ngFor=\"let header of devicesColumnHeaders\">\n                <div\n                  class=\"min-width-0\"\n                  title=\"{{ header | columnTitle }}\"\n                  [c8yDynamicColumn]=\"devicesColumnHeaders.length\"\n                >\n                  <span class=\"text-medium text-truncate\">\n                    {{ header.label }} {{ header.unit }}\n                  </span>\n                </div>\n              </ng-container>\n            </div>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n  <!-- The record list -->\n  <ng-container *ngIf=\"!isLoading; else loading\">\n    <ng-container *ngIf=\"datapointsTableItems.length; else emptyState\">\n      <c8y-list-group\n        class=\"p-t-8 flex-grow c8y-cq-440\"\n        c8yVirtualScrollListener\n        (scrolled)=\"onListScrolled()\"\n        (scrolledToTop)=\"onListScrolledToTop()\"\n      >\n        <c8y-li-timeline\n          *c8yFor=\"\n            let tableItem of { data: datapointsTableItems, res: null };\n            enableVirtualScroll: true;\n            virtualScrollElementSize: 40;\n            virtualScrollStrategy: 'fixed'\n          \"\n        >\n          {{ tableItem.dateAndTime | c8yDate: 'mediumDate' }}\n          {{\n            tableItem.dateAndTime\n              | c8yDate: 'mediumTime'\n              | adjustAggregatedTimeRange: aggregationType\n          }}\n          <c8y-li>\n            <c8y-li-body>\n              <div class=\"d-flex row\">\n                <div\n                  class=\"min-width-0\"\n                  [c8yDynamicColumn]=\"devicesColumnHeaders.length\"\n                  *ngIf=\"devicesColumnHeaders.length > 1\"\n                  [attr.data-label]=\"'Device' | translate\"\n                >\n                  <div\n                    class=\"text-truncate\"\n                    title=\"{{ tableItem.deviceName }}\"\n                  >\n                    {{ tableItem.deviceName }}\n                  </div>\n                </div>\n                <!-- Data point value row cells -->\n                <ng-container *ngFor=\"let row of tableItem.rowItems\">\n                  <ng-container *ngIf=\"row !== null; else emptyRowContent\">\n                    <ng-container [ngSwitch]=\"row.renderType\">\n                      <div\n                        [c8yDynamicColumn]=\"devicesColumnHeaders.length\"\n                        [ngClass]=\"row.value.min ?? null | applyRangeClass: getRangeValues(row)\"\n                        *ngSwitchCase=\"'min'\"\n                        [attr.data-label]=\"row.label\"\n                      >\n                        <div\n                          class=\"text-truncate\"\n                          title=\"{{ row.value.min ?? '' | number: getFractionSize(row.value.min) }}\"\n                        >\n                          {{ row.value.min ?? '' | number: getFractionSize(row.value.min) }}\n                        </div>\n                      </div>\n                      <div\n                        class=\"col-md-4\"\n                        [ngClass]=\"row.value.min ?? null | applyRangeClass: getRangeValues(row)\"\n                        *ngSwitchCase=\"'max'\"\n                      >\n                        <div\n                          class=\"text-truncate\"\n                          title=\"{{ row.value.min ?? '' | number: getFractionSize(row.value.min) }}\"\n                        >\n                          {{ row.value.min ?? '' | number: getFractionSize(row.value.min) }}\n                        </div>\n                      </div>\n                      <div\n                        [c8yDynamicColumn]=\"devicesColumnHeaders.length\"\n                        *ngSwitchCase=\"'area'\"\n                      >\n                        <span\n                          class=\"text-truncate\"\n                          title=\"{{ row.value.min ?? '' | number: getFractionSize(row.value.min) }}\"\n                          [ngClass]=\"row.value.min ?? null | applyRangeClass: getRangeValues(row)\"\n                        >\n                          {{ row.value.min ?? '' | number: getFractionSize(row.value.min) }}\n                        </span>\n                        ...\n                        <span\n                          class=\"text-truncate\"\n                          title=\"{{ row.value.min ?? '' | number: getFractionSize(row.value.min) }}\"\n                          [ngClass]=\"row.value.max ?? null | applyRangeClass: getRangeValues(row)\"\n                        >\n                          {{ row.value.min ?? '' | number: getFractionSize(row.value.min) }}\n                        </span>\n                      </div>\n                      <div\n                        [c8yDynamicColumn]=\"devicesColumnHeaders.length\"\n                        *ngSwitchDefault\n                      >\n                        <span\n                          class=\"text-truncate\"\n                          title=\"{{ row.value.min ?? '' | number: getFractionSize(row.value.min) }}\"\n                          [ngClass]=\"row.value.min ?? null | applyRangeClass: getRangeValues(row)\"\n                        >\n                          {{ row.value.min ?? '' | number: getFractionSize(row.value.min) }}\n                        </span>\n                      </div>\n                    </ng-container>\n                  </ng-container>\n                  <ng-template #emptyRowContent>\n                    <div [c8yDynamicColumn]=\"devicesColumnHeaders.length\"></div>\n                  </ng-template>\n                </ng-container>\n              </div>\n            </c8y-li-body>\n          </c8y-li>\n        </c8y-li-timeline>\n      </c8y-list-group>\n    </ng-container>\n  </ng-container>\n</ng-container>\n<ng-template #loading>\n  <c8y-loading></c8y-loading>\n</ng-template>\n<ng-template #emptyState>\n  <div class=\"p-relative p-l-24\">\n    <c8y-ui-empty-state\n      [icon]=\"'c8y-alert-idle'\"\n      [title]=\"'No data to display.' | translate\"\n      [horizontal]=\"true\"\n      data-cy=\"datapoints-table-list--empty-state\"\n    >\n      <p c8y-guide-docs>\n        <small translate>\n          Find out more in the\n          <a c8y-guide-href=\"/docs/cockpit/widgets-collection/#data-point-table\">\n            user documentation\n          </a>\n          .\n        </small>\n      </p>\n    </c8y-ui-empty-state>\n  </div>\n</ng-template>\n<ng-template #missingAllPermissions>\n  <div class=\"p-t-24 p-r-16 p-l-16 p-b-16 d-flex\">\n    <div class=\"center-block\">\n      <c8y-dynamic-component-alerts\n        [alerts]=\"missingAllPermissionsAlert\"\n      ></c8y-dynamic-component-alerts>\n    </div>\n  </div>\n</ng-template>\n", dependencies: [{ kind: "pipe", type: AdjustAggregatedTimeRangePipe, name: "adjustAggregatedTimeRange" }, { kind: "pipe", type: ApplyRangeClassPipe, name: "applyRangeClass" }, { kind: "pipe", type: ColumnTitlePipe, name: "columnTitle" }, { kind: "ngmodule", type: CommonModule$1 }, { kind: "component", type: i1$1.EmptyStateComponent, selector: "c8y-ui-empty-state", inputs: ["icon", "title", "subtitle", "horizontal"] }, { kind: "pipe", type: i1$1.C8yTranslatePipe, name: "translate" }, { kind: "directive", type: i1$1.C8yTranslateDirective, selector: "[translate],[ngx-translate]" }, { kind: "directive", type: i2.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i2.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { kind: "directive", type: i2.NgSwitchCase, selector: "[ngSwitchCase]", inputs: ["ngSwitchCase"] }, { kind: "directive", type: i2.NgSwitchDefault, selector: "[ngSwitchDefault]" }, { kind: "pipe", type: i2.DecimalPipe, name: "number" }, { kind: "directive", type: i1$1.ForOfDirective, selector: "[c8yFor]", inputs: ["c8yForOf", "c8yForLoadMore", "c8yForPipe", "c8yForNotFound", "c8yForMaxIterations", "c8yForLoadingTemplate", "c8yForLoadNextLabel", "c8yForLoadingLabel", "c8yForRealtime", "c8yForRealtimeOptions", "c8yForComparator", "c8yForEnableVirtualScroll", "c8yForVirtualScrollElementSize", "c8yForVirtualScrollStrategy", "c8yForVirtualScrollContainerHeight"], outputs: ["c8yForCount", "c8yForChange", "c8yForLoadMoreComponent"] }, { kind: "pipe", type: i1$1.DatePipe, name: "c8yDate" }, { kind: "component", type: i1$1.LoadingComponent, selector: "c8y-loading", inputs: ["layout", "progress", "message"] }, { kind: "ngmodule", type: DocsModule }, { kind: "directive", type: i1$1.GuideHrefDirective, selector: "[c8y-guide-href]", inputs: ["c8y-guide-href"] }, { kind: "component", type: i1$1.GuideDocsComponent, selector: "[c8y-guide-docs]" }, { kind: "directive", type: DynamicColumnDirective, selector: "[c8yDynamicColumn]", inputs: ["c8yDynamicColumn"] }, { kind: "ngmodule", type: DynamicComponentModule }, { kind: "component", type: i1$1.DynamicComponentAlertsComponent, selector: "c8y-dynamic-component-alerts", inputs: ["alerts"] }, { kind: "ngmodule", type: ListGroupModule }, { kind: "component", type: i1$1.ListGroupComponent, selector: "c8y-list-group" }, { kind: "component", type: i1$1.ListItemComponent, selector: "c8y-list-item, c8y-li", inputs: ["active", "highlighted", "emptyActions", "dense", "collapsed", "selectable"], outputs: ["collapsedChange"] }, { kind: "component", type: i1$1.ListItemBodyComponent, selector: "c8y-list-item-body, c8y-li-body", inputs: ["body"] }, { kind: "component", type: i1$1.ListItemTimelineComponent, selector: "c8y-list-item-timeline, c8y-li-timeline" }, { kind: "directive", type: VirtualScrollListenerDirective, selector: "[c8yVirtualScrollListener]", inputs: ["scrollThreshold"], outputs: ["scrolled", "scrolledToTop"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DatapointsTableComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-datapoints-table', host: { class: 'd-col flex-grow' }, standalone: true, imports: [
                        AdjustAggregatedTimeRangePipe,
                        ApplyRangeClassPipe,
                        ColumnTitlePipe,
                        CommonModule$1,
                        DocsModule,
                        DynamicColumnDirective,
                        DynamicComponentModule,
                        ListGroupModule,
                        VirtualScrollListenerDirective
                    ], changeDetection: ChangeDetectionStrategy.OnPush, template: "<ng-container *ngIf=\"!hasNoPermissionsToReadAnyMeasurement; else missingAllPermissions\">\n  <div class=\"c8y-cq-440\">\n    <div\n      class=\"hidden-xs c8y-list__item c8y-list--timeline hidden-cq\"\n      [ngClass]=\"{ 'separator-top-bottom': devicesColumnHeaders.length > 0 }\"\n    >\n      <div class=\"d-flex container-fluid\">\n        <div class=\"c8y-list--timeline__item__date\"></div>\n        <div class=\"c8y-list__item__block flex-grow min-width-0\">\n          <div class=\"c8y-list__item__body\">\n            <div class=\"d-flex row\">\n              <ng-container *ngIf=\"hasMultipleDatapoints\">\n                <div\n                  class=\"min-width-0\"\n                  [title]=\"'Device' | translate\"\n                  [c8yDynamicColumn]=\"devicesColumnHeaders.length\"\n                >\n                  <span class=\"text-medium text-truncate\">\n                    {{ 'Device' | translate }}\n                  </span>\n                </div>\n              </ng-container>\n              <!-- Data points column headers -->\n              <ng-container *ngFor=\"let header of devicesColumnHeaders\">\n                <div\n                  class=\"min-width-0\"\n                  title=\"{{ header | columnTitle }}\"\n                  [c8yDynamicColumn]=\"devicesColumnHeaders.length\"\n                >\n                  <span class=\"text-medium text-truncate\">\n                    {{ header.label }} {{ header.unit }}\n                  </span>\n                </div>\n              </ng-container>\n            </div>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n  <!-- The record list -->\n  <ng-container *ngIf=\"!isLoading; else loading\">\n    <ng-container *ngIf=\"datapointsTableItems.length; else emptyState\">\n      <c8y-list-group\n        class=\"p-t-8 flex-grow c8y-cq-440\"\n        c8yVirtualScrollListener\n        (scrolled)=\"onListScrolled()\"\n        (scrolledToTop)=\"onListScrolledToTop()\"\n      >\n        <c8y-li-timeline\n          *c8yFor=\"\n            let tableItem of { data: datapointsTableItems, res: null };\n            enableVirtualScroll: true;\n            virtualScrollElementSize: 40;\n            virtualScrollStrategy: 'fixed'\n          \"\n        >\n          {{ tableItem.dateAndTime | c8yDate: 'mediumDate' }}\n          {{\n            tableItem.dateAndTime\n              | c8yDate: 'mediumTime'\n              | adjustAggregatedTimeRange: aggregationType\n          }}\n          <c8y-li>\n            <c8y-li-body>\n              <div class=\"d-flex row\">\n                <div\n                  class=\"min-width-0\"\n                  [c8yDynamicColumn]=\"devicesColumnHeaders.length\"\n                  *ngIf=\"devicesColumnHeaders.length > 1\"\n                  [attr.data-label]=\"'Device' | translate\"\n                >\n                  <div\n                    class=\"text-truncate\"\n                    title=\"{{ tableItem.deviceName }}\"\n                  >\n                    {{ tableItem.deviceName }}\n                  </div>\n                </div>\n                <!-- Data point value row cells -->\n                <ng-container *ngFor=\"let row of tableItem.rowItems\">\n                  <ng-container *ngIf=\"row !== null; else emptyRowContent\">\n                    <ng-container [ngSwitch]=\"row.renderType\">\n                      <div\n                        [c8yDynamicColumn]=\"devicesColumnHeaders.length\"\n                        [ngClass]=\"row.value.min ?? null | applyRangeClass: getRangeValues(row)\"\n                        *ngSwitchCase=\"'min'\"\n                        [attr.data-label]=\"row.label\"\n                      >\n                        <div\n                          class=\"text-truncate\"\n                          title=\"{{ row.value.min ?? '' | number: getFractionSize(row.value.min) }}\"\n                        >\n                          {{ row.value.min ?? '' | number: getFractionSize(row.value.min) }}\n                        </div>\n                      </div>\n                      <div\n                        class=\"col-md-4\"\n                        [ngClass]=\"row.value.min ?? null | applyRangeClass: getRangeValues(row)\"\n                        *ngSwitchCase=\"'max'\"\n                      >\n                        <div\n                          class=\"text-truncate\"\n                          title=\"{{ row.value.min ?? '' | number: getFractionSize(row.value.min) }}\"\n                        >\n                          {{ row.value.min ?? '' | number: getFractionSize(row.value.min) }}\n                        </div>\n                      </div>\n                      <div\n                        [c8yDynamicColumn]=\"devicesColumnHeaders.length\"\n                        *ngSwitchCase=\"'area'\"\n                      >\n                        <span\n                          class=\"text-truncate\"\n                          title=\"{{ row.value.min ?? '' | number: getFractionSize(row.value.min) }}\"\n                          [ngClass]=\"row.value.min ?? null | applyRangeClass: getRangeValues(row)\"\n                        >\n                          {{ row.value.min ?? '' | number: getFractionSize(row.value.min) }}\n                        </span>\n                        ...\n                        <span\n                          class=\"text-truncate\"\n                          title=\"{{ row.value.min ?? '' | number: getFractionSize(row.value.min) }}\"\n                          [ngClass]=\"row.value.max ?? null | applyRangeClass: getRangeValues(row)\"\n                        >\n                          {{ row.value.min ?? '' | number: getFractionSize(row.value.min) }}\n                        </span>\n                      </div>\n                      <div\n                        [c8yDynamicColumn]=\"devicesColumnHeaders.length\"\n                        *ngSwitchDefault\n                      >\n                        <span\n                          class=\"text-truncate\"\n                          title=\"{{ row.value.min ?? '' | number: getFractionSize(row.value.min) }}\"\n                          [ngClass]=\"row.value.min ?? null | applyRangeClass: getRangeValues(row)\"\n                        >\n                          {{ row.value.min ?? '' | number: getFractionSize(row.value.min) }}\n                        </span>\n                      </div>\n                    </ng-container>\n                  </ng-container>\n                  <ng-template #emptyRowContent>\n                    <div [c8yDynamicColumn]=\"devicesColumnHeaders.length\"></div>\n                  </ng-template>\n                </ng-container>\n              </div>\n            </c8y-li-body>\n          </c8y-li>\n        </c8y-li-timeline>\n      </c8y-list-group>\n    </ng-container>\n  </ng-container>\n</ng-container>\n<ng-template #loading>\n  <c8y-loading></c8y-loading>\n</ng-template>\n<ng-template #emptyState>\n  <div class=\"p-relative p-l-24\">\n    <c8y-ui-empty-state\n      [icon]=\"'c8y-alert-idle'\"\n      [title]=\"'No data to display.' | translate\"\n      [horizontal]=\"true\"\n      data-cy=\"datapoints-table-list--empty-state\"\n    >\n      <p c8y-guide-docs>\n        <small translate>\n          Find out more in the\n          <a c8y-guide-href=\"/docs/cockpit/widgets-collection/#data-point-table\">\n            user documentation\n          </a>\n          .\n        </small>\n      </p>\n    </c8y-ui-empty-state>\n  </div>\n</ng-template>\n<ng-template #missingAllPermissions>\n  <div class=\"p-t-24 p-r-16 p-l-16 p-b-16 d-flex\">\n    <div class=\"center-block\">\n      <c8y-dynamic-component-alerts\n        [alerts]=\"missingAllPermissionsAlert\"\n      ></c8y-dynamic-component-alerts>\n    </div>\n  </div>\n</ng-template>\n" }]
        }], propDecorators: { aggregationType: [{
                type: Input
            }], datapointsTableItems: [{
                type: Input
            }], devicesColumnHeaders: [{
                type: Input
            }], decimalPlaces: [{
                type: Input
            }], hasMultipleDatapoints: [{
                type: Input
            }], isLoading: [{
                type: Input
            }], seriesWithoutPermissionToReadCount: [{
                type: Input
            }], isScrolling: [{
                type: Output
            }] } });

class DatapointsTableViewWidgetComponent {
    constructor(alertService, dataFetchingService, datapointsTableConfigService, datapointsTableViewService, formBuilder, translateService, widgetGlobalAutoRefresh) {
        this.alertService = alertService;
        this.dataFetchingService = dataFetchingService;
        this.datapointsTableConfigService = datapointsTableConfigService;
        this.datapointsTableViewService = datapointsTableViewService;
        this.formBuilder = formBuilder;
        this.translateService = translateService;
        this.widgetGlobalAutoRefresh = widgetGlobalAutoRefresh;
        /**
         * Represents the data points where __active property is set to true.
         */
        this.activeDatapoints = [];
        /**
         * An array of `GroupedDatapointTableItem` objects representing the datapoints table items.
         * Used to populate the table with data.
         */
        this.datapointsTableItems = [];
        /**
         * Indicates whether refreshing should be enabled or disabled.
         * It's 'true' when user is not allowed to view a measurements.
         */
        this.isRefreshDisabled = false;
        /**
         * Indicates whether the component is in the initial request state
         * where data for a table structure is being prepared.
         */
        this.isInitialRequest = true;
        /**
         * Current isLoading state. Indicates whether the data is being loaded.
         */
        this.isLoading$ = new BehaviorSubject(true);
        this.isExportModalOpen = false;
        this.isScrolling = signal(false);
        this.TIMEOUT_ERROR_TEXT = gettext('The request is taking longer than usual. We apologize for the inconvenience.');
        this.SERVER_ERROR_TEXT = gettext('Server error occurred.');
        this.destroy$ = new Subject();
        this.scrollingSubject$ = new Subject();
        /**
         * Indicates if the alert has already been displayed and can be dismissed.
         * The message is only displayed when a component is initialized.
         */
        this.isMissingAnyPermissionAlertShown = false;
    }
    async ngOnInit() {
        if (this.config.widgetInstanceGlobalAutoRefreshContext) {
            this.containerClass = 'a-i-center input-group p-t-4 p-b-4 max-width-fit m-l-auto';
        }
        /**
         * Legacy widget used realtime so it must be converted to refresh approach
         * if it was enabled before migration.
         */
        if (this.config.widgetInstanceGlobalTimeContext) {
            this.config.widgetInstanceGlobalAutoRefreshContext = true;
            this.config.widgetInstanceGlobalTimeContext = false;
            this.config.displaySettings.globalAutoRefreshContext = true;
        }
        if (this.config.widgetInstanceGlobalAutoRefreshContext) {
            this.handleGlobalRefreshLoading();
            this.handleGlobalTimeContextSettings();
        }
        this.setScrollingSubscription();
        const isLegacyWidgetRealtimeActive = this.config.realtime &&
            !this.config.hasOwnProperty('decimalPlaces') &&
            !this.config.hasOwnProperty('refreshInterval') &&
            !this.config.hasOwnProperty('isAutoRefreshEnabled');
        if (isLegacyWidgetRealtimeActive) {
            this.setDefaultRefreshRelatedProperties();
        }
        if (this.config.interval !== INTERVAL_VALUES.custom) {
            this.recalculateIntervalToMatchFromNowDate();
        }
        if (this.config.displayDateSelection) {
            this.prepareDateRangeForm();
        }
        await this.prepareTableData();
        this.exportConfig = {
            aggregation: this.config.aggregation,
            dateFrom: this.config.dateFrom,
            dateTo: this.config.dateTo,
            datapointDetails: this.activeDatapoints.map(({ __target, fragment, series }) => ({
                deviceName: __target.name,
                source: __target.id,
                valueFragmentSeries: series,
                valueFragmentType: fragment
            }))
        };
    }
    ngOnDestroy() {
        if (this.subscription) {
            this.subscription.unsubscribe();
        }
        this.destroy$.next();
        this.destroy$.complete();
    }
    onDateChange(data) {
        if (this.formGroup.invalid) {
            return;
        }
        if (data.dateFrom) {
            this.config.dateFrom = data.dateFrom;
        }
        if (data.dateTo) {
            this.config.dateTo = data.dateTo;
        }
        this.prepareTableData();
        this.updateExportConfigDateRange();
    }
    onExportModalOpen(isOpened) {
        this.isExportModalOpen = isOpened;
    }
    onScrolling(value) {
        this.scrollingSubject$.next(value);
    }
    async onCountdownEnded() {
        const dateRange = this.datapointsTableViewService.prepareTimeRange(this.config.interval, this.config.dateFrom, this.config.dateTo);
        this.config.dateFrom = dateRange.dateFrom;
        this.config.dateTo = dateRange.dateTo;
        this.updateExportConfigDateRange();
        await this.prepareTableData(false);
        this.onScrolling(false);
    }
    handleGlobalTimeContextSettings() {
        this.config.dateFrom = this.dataFetchingService.adjustDate(this.config.date[0], 0, false);
        this.config.dateTo = this.dataFetchingService.adjustDate(this.config.date[1], 0, false);
    }
    /**
     * Sets up the scrolling subscription.
     *
     * Ensures similar UX as in the alarms countdown-pause logic.
     */
    setScrollingSubscription() {
        this.subscription = this.scrollingSubject$
            .pipe(debounceTime(300))
            .subscribe(value => this.isScrolling.set(value));
    }
    setDefaultRefreshRelatedProperties() {
        this.config.isAutoRefreshEnabled = true;
        this.config.refreshInterval = DEFAULT_DPT_REFRESH_INTERVAL_VALUE;
    }
    recalculateIntervalToMatchFromNowDate() {
        if (this.config.widgetInstanceGlobalAutoRefreshContext) {
            return;
        }
        const { dateFrom, dateTo } = this.datapointsTableConfigService.calculateDateRange(this.config.interval);
        this.config.dateFrom = dateFrom;
        this.config.dateTo = dateTo;
    }
    prepareDateRangeForm() {
        this.formGroup = this.createForm();
    }
    createForm() {
        return this.formBuilder.group({
            dateFrom: new FormControl(this.config.dateFrom),
            dateTo: new FormControl(this.config.dateTo)
        }, { validators: dateRangeValidator });
    }
    /**
     * Prepares the table data by:
     * - filtering out inactive data points,
     * - checking if there are multiple devices as a source of data points,
     * - getting the column headers for devices,
     * - getting the series data for active data points (API call),
     * - preparing data points with values list,
     * - mapping data points with values to list items,
     * - grouping data points by date and device,
     * - sorting data by date descending.
     *
     * @param roundSeconds - Whether to round the seconds or not.
     *                       If true, the seconds will be rounded to 0.
     *                       If false, the seconds will be displayed as they are.
     */
    async prepareTableData(roundSeconds = true) {
        this.isLoading$.next(true);
        if (this.isInitialRequest) {
            this.activeDatapoints = this.datapointsTableViewService.filterOutInactiveDatapoints(this.config.datapoints);
            this.hasMultipleDatapoints = this.datapointsTableViewService.hasMultipleDatapoints(this.activeDatapoints);
            this.devicesColumnHeaders = this.datapointsTableViewService.getColumnHeaders(this.activeDatapoints);
            this.isInitialRequest = false;
        }
        const activeDatapointsIdsWithSeries = this.datapointsTableViewService.groupSeriesByDeviceId(this.activeDatapoints);
        const activeDatapointsSeriesData = await this.getActiveDatapointsSeriesDataMap(activeDatapointsIdsWithSeries, this.config, roundSeconds);
        if (this.isFailedToFetchSeriesData) {
            return;
        }
        this.seriesWithoutPermissionToRead =
            this.datapointsTableViewService.getSeriesWithoutPermissionToRead(activeDatapointsSeriesData, activeDatapointsIdsWithSeries);
        if (!this.isMissingAnyPermissionAlertShown &&
            this.seriesWithoutPermissionToRead?.length > 0 &&
            activeDatapointsSeriesData?.size) {
            this.handleMissingAnyPermissionErrorMessage();
            this.isMissingAnyPermissionAlertShown = true;
        }
        if (!activeDatapointsSeriesData) {
            return;
        }
        this.datapointsWithValues = this.datapointsTableViewService.getDatapointsWithValues(this.activeDatapoints, activeDatapointsSeriesData);
        const datapointsListItems = this.datapointsTableViewService.mapDatapointsWithValuesToList(this.datapointsWithValues);
        const groupedDatapointsListItems = this.datapointsTableViewService.groupByDateAndDevice(datapointsListItems, this.devicesColumnHeaders);
        this.datapointsTableItems = this.datapointsTableViewService.sortDataByDateDescending(groupedDatapointsListItems);
        this.isLoading$.next(false);
    }
    /**
     * Retrieves the active data points series data and returns it as a map.
     *
     * It's a wrapper method with try-catch block.
     *
     * @param datapointsIdsWithSeries - A map of data point IDs with their associated series.
     * @param config - The configuration of the data points table.
     * @param roundSeconds - Whether to round the seconds or not.
     *                       If true, the seconds will be rounded to 0.
     *                       If false, the seconds will be displayed as they are.
     * @returns A Promise that resolves to a Map object with data point IDs as keys and DataObject as values.
     */
    async getActiveDatapointsSeriesDataMap(datapointsIdsWithSeries, config, roundSeconds) {
        try {
            this.isFailedToFetchSeriesData = false;
            return await this.datapointsTableViewService.getAllActiveSeriesDataMap(datapointsIdsWithSeries, config, roundSeconds);
        }
        catch (error) {
            this.isLoading$.next(false);
            this.handleFetchError(error);
        }
    }
    handleFetchError(error) {
        if (error?.message.includes('403')) {
            this.alerts.setAlertGroupDismissStrategy('warning', DismissAlertStrategy.NONE);
            this.isRefreshDisabled = true;
            return;
        }
        const isTimeoutError = error?.name === 'TimeoutError';
        const errorMessage = isTimeoutError
            ? this.TIMEOUT_ERROR_TEXT
            : (error?.message ?? this.SERVER_ERROR_TEXT);
        this.alerts.setAlertGroupDismissStrategy('warning', DismissAlertStrategy.TEMPORARY_OR_PERMANENT);
        this.alerts.addAlerts(new DynamicComponentAlert({
            type: 'warning',
            text: errorMessage
        }));
        this.isFailedToFetchSeriesData = true;
        this.alertService.addServerFailure(error);
    }
    handleMissingAnyPermissionErrorMessage() {
        this.alerts.setAlertGroupDismissStrategy('system', DismissAlertStrategy.TEMPORARY);
        this.alerts.addAlerts(new DynamicComponentAlert({
            allowHtml: true,
            text: this.getMissingPermissionsMessage(),
            type: 'system'
        }));
    }
    getMissingPermissionsMessage() {
        const baseMessage = this.translateService.instant(gettext(`You don't have permissions to read the following series:`));
        const formattedList = this.seriesWithoutPermissionToRead
            .map(datapoint => `<li>${datapoint.key.valueOf()}_${datapoint.value}</li>`)
            .join('');
        return `
      <div>
        <p>${baseMessage}</p>
        <ul>
          ${formattedList}
        </ul>
        <p><strong>Note:</strong> The name convention for each list item is: <code>[source]_[fragment.series]</code></p>
      </div>
    `;
    }
    updateExportConfigDateRange() {
        this.config.dateTo = this.adjustTargetDateBasedOnConditionTime(this.config.dateFrom, this.config.dateTo);
        this.config.dateFrom = this.adjustTargetDateBasedOnConditionTime(this.config.dateTo, this.config.dateFrom);
        this.syncExportConfigDates();
    }
    adjustTargetDateBasedOnConditionTime(conditionDate, targetDate) {
        if (this.datapointsTableViewService.hasSecondsAndMillisecondsEqualZero(conditionDate)) {
            return this.dataFetchingService.adjustDate(targetDate, 0, true);
        }
        return targetDate;
    }
    syncExportConfigDates() {
        this.exportConfig.dateFrom = this.config.dateFrom;
        this.exportConfig.dateTo = this.config.dateTo;
    }
    handleGlobalRefreshLoading() {
        this.isLoading$
            .pipe(globalAutoRefreshLoading(this.widgetGlobalAutoRefresh), takeUntil(this.destroy$))
            .subscribe();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DatapointsTableViewWidgetComponent, deps: [{ token: i1$1.AlertService }, { token: i1.DataFetchingService }, { token: DatapointsTableService }, { token: DatapointsTableViewService }, { token: i3.FormBuilder }, { token: i1$2.TranslateService }, { token: i1$1.WidgetGlobalAutoRefreshService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: DatapointsTableViewWidgetComponent, isStandalone: true, selector: "c8y-datapoints-table-view", inputs: { config: "config" }, host: { classAttribute: "d-col fit-h" }, ngImport: i0, template: "<div class=\"d-flex gap-16 p-l-16 p-r-16 flex-wrap\">\n  <ng-container *ngIf=\"config.displayDateSelection\">\n    <form [formGroup]=\"formGroup\">\n      <c8y-date-range-picker\n        class=\"d-contents\"\n        [isEmittingDateChange]=\"true\"\n        [showLabel]=\"true\"\n        (updatedDate)=\"onDateChange($event)\"\n      ></c8y-date-range-picker>\n    </form>\n  </ng-container>\n  <ng-container *ngIf=\"config.datapoints.length > 0\">\n    <c8y-datapoints-reload\n      class=\"d-contents\"\n      [isAutoRefreshEnabled]=\"config.isAutoRefreshEnabled\"\n      [refreshInterval]=\"config.refreshInterval\"\n      [isRefreshDisabled]=\"isRefreshDisabled\"\n      [isLoading]=\"isLoading$\"\n      [isScrolling]=\"isScrolling()\"\n      [isExportModalOpen]=\"isExportModalOpen\"\n      [widgetInstanceGlobalAutoRefreshContext]=\"config.widgetInstanceGlobalAutoRefreshContext\"\n      (onCountdownEnded)=\"onCountdownEnded()\"\n    ></c8y-datapoints-reload>\n  </ng-container>\n  <c8y-datapoints-export-selector\n    class=\"d-contents\"\n    [exportConfig]=\"exportConfig\"\n    (isOpen)=\"onExportModalOpen($event)\"\n  ></c8y-datapoints-export-selector>\n</div>\n<ng-container *ngIf=\"devicesColumnHeaders\">\n  <c8y-datapoints-table\n    [aggregationType]=\"config.aggregation\"\n    [datapointsTableItems]=\"datapointsTableItems\"\n    [decimalPlaces]=\"config.decimalPlaces\"\n    [devicesColumnHeaders]=\"devicesColumnHeaders\"\n    [hasMultipleDatapoints]=\"hasMultipleDatapoints\"\n    [isLoading]=\"isLoading$ | async\"\n    [seriesWithoutPermissionToReadCount]=\"seriesWithoutPermissionToRead?.length\"\n    (isScrolling)=\"onScrolling($event)\"\n  ></c8y-datapoints-table>\n</ng-container>\n", dependencies: [{ kind: "ngmodule", type: CommonModule$1 }, { kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "pipe", type: i2.AsyncPipe, name: "async" }, { kind: "component", type: DatapointsExportSelectorComponent, selector: "c8y-datapoints-export-selector", inputs: ["containerClass", "exportConfig"], outputs: ["isOpen"] }, { kind: "component", type: DatapointsReloadComponent, selector: "c8y-datapoints-reload", inputs: ["isAutoRefreshEnabled", "isRefreshDisabled", "isLoading", "isScrolling", "isExportModalOpen", "refreshInterval", "widgetInstanceGlobalAutoRefreshContext"], outputs: ["onCountdownEnded"] }, { kind: "component", type: DatapointsTableComponent, selector: "c8y-datapoints-table", inputs: ["aggregationType", "datapointsTableItems", "devicesColumnHeaders", "decimalPlaces", "hasMultipleDatapoints", "isLoading", "seriesWithoutPermissionToReadCount"], outputs: ["isScrolling"] }, { kind: "component", type: DateRangePickerComponent, selector: "c8y-date-range-picker", inputs: ["isEmittingDateChange", "showLabel"], outputs: ["updatedDate"] }, { kind: "ngmodule", type: ReactiveFormsModule }, { kind: "directive", type: i3.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i3.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i3.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DatapointsTableViewWidgetComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-datapoints-table-view', host: { class: 'd-col fit-h' }, standalone: true, imports: [
                        CommonModule$1,
                        DatapointsExportSelectorComponent,
                        DatapointsReloadComponent,
                        DatapointsTableComponent,
                        DateRangePickerComponent,
                        ReactiveFormsModule
                    ], template: "<div class=\"d-flex gap-16 p-l-16 p-r-16 flex-wrap\">\n  <ng-container *ngIf=\"config.displayDateSelection\">\n    <form [formGroup]=\"formGroup\">\n      <c8y-date-range-picker\n        class=\"d-contents\"\n        [isEmittingDateChange]=\"true\"\n        [showLabel]=\"true\"\n        (updatedDate)=\"onDateChange($event)\"\n      ></c8y-date-range-picker>\n    </form>\n  </ng-container>\n  <ng-container *ngIf=\"config.datapoints.length > 0\">\n    <c8y-datapoints-reload\n      class=\"d-contents\"\n      [isAutoRefreshEnabled]=\"config.isAutoRefreshEnabled\"\n      [refreshInterval]=\"config.refreshInterval\"\n      [isRefreshDisabled]=\"isRefreshDisabled\"\n      [isLoading]=\"isLoading$\"\n      [isScrolling]=\"isScrolling()\"\n      [isExportModalOpen]=\"isExportModalOpen\"\n      [widgetInstanceGlobalAutoRefreshContext]=\"config.widgetInstanceGlobalAutoRefreshContext\"\n      (onCountdownEnded)=\"onCountdownEnded()\"\n    ></c8y-datapoints-reload>\n  </ng-container>\n  <c8y-datapoints-export-selector\n    class=\"d-contents\"\n    [exportConfig]=\"exportConfig\"\n    (isOpen)=\"onExportModalOpen($event)\"\n  ></c8y-datapoints-export-selector>\n</div>\n<ng-container *ngIf=\"devicesColumnHeaders\">\n  <c8y-datapoints-table\n    [aggregationType]=\"config.aggregation\"\n    [datapointsTableItems]=\"datapointsTableItems\"\n    [decimalPlaces]=\"config.decimalPlaces\"\n    [devicesColumnHeaders]=\"devicesColumnHeaders\"\n    [hasMultipleDatapoints]=\"hasMultipleDatapoints\"\n    [isLoading]=\"isLoading$ | async\"\n    [seriesWithoutPermissionToReadCount]=\"seriesWithoutPermissionToRead?.length\"\n    (isScrolling)=\"onScrolling($event)\"\n  ></c8y-datapoints-table>\n</ng-container>\n" }]
        }], ctorParameters: () => [{ type: i1$1.AlertService }, { type: i1.DataFetchingService }, { type: DatapointsTableService }, { type: DatapointsTableViewService }, { type: i3.FormBuilder }, { type: i1$2.TranslateService }, { type: i1$1.WidgetGlobalAutoRefreshService }], propDecorators: { config: [{
                type: Input
            }] } });

/**
 * Generated bundle index. Do not edit.
 */

export { AdjustAggregatedTimeRangePipe, ApplyRangeClassPipe, DATE_SELECTION_LABELS, DATE_SELECTION_VALUES, DATE_SELECTION_VALUES_ARR, DEFAULT_DPT_REFRESH_INTERVAL_VALUE, DURATION_OPTIONS, DatapointsReloadComponent, DatapointsTableComponent, DatapointsTableViewService, DatapointsTableViewWidgetComponent, DatapointsTableWidgetConfigComponent, INTERVAL_VALUES_ARR, REFRESH_INTERVAL_VALUES_ARR, RENDER_TYPES_LABELS, TIME_RANGE_INTERVAL_LABELS, VirtualScrollListenerDirective, minOneDatapointActive };
//# sourceMappingURL=c8y-ngx-components-widgets-implementations-datapoints-table.mjs.map
