export interface MessagingTopic {
    /**
     * Unique topic identifier.
     */
    id?: string;
    /**
     * Tenant ID.
     */
    tenant?: string;
    /**
     * User-friendly topic name.
     */
    name?: string;
    /**
     * Namespace name that the topic belongs to.
     */
    namespace?: string;
    /**
     * If the topic is persistent or not. If false, the topic is not saved and will be deleted if there are no clients.
     */
    persistent?: boolean;
    /**
     * Total rate of messages published on the topic (msg/s).
     */
    msgRateIn?: number;
    /**
     * Total rate of messages dispatched for the topic (msg/s).
     */
    msgRateOut?: number;
    /**
     * Number of all subscribers for the topic.
     */
    subscribers?: number;
    /**
     * Number of currently active subscribers, meaning the ones with at least one client connected.
     */
    activeSubscribers?: number;
    /**
     * Size of the messages backlog in bytes.
     */
    backlogSize?: number;
    /**
     * Percentage of the backlog used. Value range is from o to 100.
     * E.g. if 10% of the backlog is used, this value will be 10 (not 0.1).
     */
    backlogUsagePercentage?: number;
    /**
     * Number of unacknowledged messages in the backlog for topic for all subscribers.
     */
    unackMsgBacklog?: number;
}
//# sourceMappingURL=topic.d.ts.map