import * as i0 from "@angular/core";
/**
 * Usage component displays usage information in a form of e.g. "51% used".
 * It can be used in two ways:
 * 1. By providing `count` and `limit` inputs, it will calculate the usage percentage.
 * 2. By providing `percentage` input, it will use the provided percentage value.
 * Note: `percentage` input takes precedence over `count` and `limit` inputs.
 */
export declare class UsageComponent {
    count: import("@angular/core").InputSignal<number>;
    limit: import("@angular/core").InputSignal<number>;
    /**
     * Percentage of usage. Value range is from 0 to 100 (or more).
     * For example, if 10% is used, this value should be provided as 10 (not 0.1).
     */
    percentage: import("@angular/core").InputSignal<number>;
    /**
     * Usage as a fraction (e.g. if 50% is used, usage value will be 0.5)
     */
    usage: import("@angular/core").Signal<number>;
    status: import("@angular/core").Signal<"warning" | "success" | "danger">;
    usageToDisplay: "{{ percentageOfQuota }} used";
    statusMap: {
        danger: string[];
        warning: string[];
        success: string[];
    };
    /**
     * Get usage as fraction of count and limit.
     * E.g. if count is 5 and limit is 10, returned usage will be 0.5
     * @param count Usage count
     * @param limit Usage limit
     * @returns Count divided by limit or null if count or limit is null or limit is -1 (indicates no limit)
     */
    private getUsage;
    private getStatus;
    static ɵfac: i0.ɵɵFactoryDeclaration<UsageComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UsageComponent, "app-usage", never, { "count": { "alias": "count"; "required": false; "isSignal": true; }; "limit": { "alias": "limit"; "required": false; "isSignal": true; }; "percentage": { "alias": "percentage"; "required": false; "isSignal": true; }; }, {}, never, never, true, never>;
}
//# sourceMappingURL=usage.component.d.ts.map