import * as i0 from '@angular/core';
import { Injectable, Component, inject, InjectionToken, EventEmitter, Input, Output, forwardRef, Optional, Inject, ViewChild, HostBinding, HostListener, TemplateRef, NgModule } from '@angular/core';
import * as i2 from '@c8y/ngx-components';
import { gettext, Permissions, ContextRouteService, ViewContext, Status, NavigatorNode, getActivatedRoute, NEW_DASHBOARD_ROUTER_STATE_PROP, SupportedApps, memoize, DashboardChildChange, CopyDashboardDisabledReason, WidgetsDashboardComponent, hookRoute, CoreModule, hookTab, HookProviderTypes, hookActionBar, hookNavigator, BaseColumn, getBasicInputArrayFormFieldConfig, DataGridService, alertOnError, BuiltInActionType, ModalModule } from '@c8y/ngx-components';
import * as i1 from '@angular/router';
import { of, Subject, from, combineLatest, iif, timer } from 'rxjs';
import * as i4 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i3 from '@angular/forms';
import { Validators, NG_VALUE_ACCESSOR } from '@angular/forms';
import * as i4$1 from 'ngx-bootstrap/popover';
import { PopoverModule } from 'ngx-bootstrap/popover';
import { __decorate, __metadata } from 'tslib';
import * as i2$1 from '@ngx-translate/core';
import { assign, pick, cloneDeep, some, keys, keyBy, has, set, reduce, forEach, get, isEqual, clone, omit, sortBy, escapeRegExp, findIndex, kebabCase, every } from 'lodash-es';
import * as i2$2 from 'ngx-bootstrap/modal';
import * as i1$1 from '@c8y/client';
import { QueriesUtil } from '@c8y/client';
import { tap, map, catchError, throwIfEmpty, filter, mergeMap, toArray, first, switchMap } from 'rxjs/operators';
import * as i9 from 'ngx-bootstrap/collapse';
import { CollapseModule } from 'ngx-bootstrap/collapse';
import * as i5 from '@c8y/ngx-components/icon-selector';
import { IconSelectorModule } from '@c8y/ngx-components/icon-selector';
import * as i8 from '@c8y/ngx-components/assets-navigator';
import { AssetSelectorModule } from '@c8y/ngx-components/assets-navigator';
import * as i1$2 from 'ngx-bootstrap/dropdown';
import { BsDropdownModule } from 'ngx-bootstrap/dropdown';
import { TooltipModule } from 'ngx-bootstrap/tooltip';
import { NameDeviceGridColumn, TypeDeviceGridColumn, GroupDeviceGridColumn, RegistrationDateDeviceGridColumn, DeviceGridModule } from '@c8y/ngx-components/device-grid';

const newDashboardTab = {
    featureId: 'newDashboard',
    icon: 'th',
    label: gettext('New dashboard'),
    path: 'dashboard/new-dashboard',
    // place tab as last one and hide it so it won't be opened until user initiates adding new dashboard
    hide: true,
    priority: -Infinity
};
class NewDashboardGuard {
    canActivate(route) {
        const tabActive = route.routeConfig.path === newDashboardTab.path;
        if (tabActive) {
            const dashboard = {
                c8y_Dashboard: null
            };
            route.data = { dashboard };
        }
        if (!this.tab) {
            this.tab = {
                ...newDashboardTab,
                hide: !tabActive,
                priority: tabActive ? Infinity : -Infinity
            };
        }
        return of([this.tab]);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NewDashboardGuard, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NewDashboardGuard, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NewDashboardGuard, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }] });

class AddDashboardComponent {
    constructor(tabsService, router) {
        this.tabsService = tabsService;
        this.router = router;
    }
    addDashboard() {
        const tempNewDashboardTab = [...this.tabsService.state].find(t => t.featureId === newDashboardTab.featureId);
        // navigate before tab is displayed, because in DashboardDetailComponent tab is hidden on navigation from it.
        this.router.navigate(typeof tempNewDashboardTab.path === 'string'
            ? [tempNewDashboardTab.path]
            : tempNewDashboardTab.path, { replaceUrl: true });
        // show tab and make it appear as first one
        tempNewDashboardTab.hide = false;
        tempNewDashboardTab.priority = Infinity;
        this.tabsService.refresh();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AddDashboardComponent, deps: [{ token: i2.TabsService }, { token: i1.Router }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: AddDashboardComponent, selector: "[c8y-add-dashboard]", host: { classAttribute: "d-flex a-i-stretch sticky-right" }, ngImport: i0, template: "<div class=\"d-flex a-i-stretch m-b-8 m-t-8 p-l-8 hidden-xs\">\n  <button\n    class=\"btn btn-default btn-sm p-l-8 p-r-8 fit-h p-b-0 p-t-0 d-flex a-i-center\"\n    title=\"{{ 'Add dashboard' | translate }}\"\n    type=\"button\"\n    (click)=\"addDashboard()\"\n  >\n    <i\n      class=\"icon-20 m-r-4\"\n      c8yIcon=\"add-circle-outline\"\n    ></i>\n    <span>{{ 'Add dashboard' | translate }}</span>\n  </button>\n  <div class=\"p-r-sm-40\"></div>\n</div>\n", dependencies: [{ kind: "directive", type: i2.IconDirective, selector: "[c8yIcon]", inputs: ["c8yIcon"] }, { kind: "pipe", type: i2.C8yTranslatePipe, name: "translate" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AddDashboardComponent, decorators: [{
            type: Component,
            args: [{ selector: '[c8y-add-dashboard]', host: { class: 'd-flex a-i-stretch sticky-right' }, template: "<div class=\"d-flex a-i-stretch m-b-8 m-t-8 p-l-8 hidden-xs\">\n  <button\n    class=\"btn btn-default btn-sm p-l-8 p-r-8 fit-h p-b-0 p-t-0 d-flex a-i-center\"\n    title=\"{{ 'Add dashboard' | translate }}\"\n    type=\"button\"\n    (click)=\"addDashboard()\"\n  >\n    <i\n      class=\"icon-20 m-r-4\"\n      c8yIcon=\"add-circle-outline\"\n    ></i>\n    <span>{{ 'Add dashboard' | translate }}</span>\n  </button>\n  <div class=\"p-r-sm-40\"></div>\n</div>\n" }]
        }], ctorParameters: () => [{ type: i2.TabsService }, { type: i1.Router }] });

class AddDashboardFactory {
    constructor() {
        this.permissions = inject(Permissions);
        this.contextRoute = inject(ContextRouteService);
    }
    async get(activatedRoute) {
        this.currentContext = this.contextRoute.getContextData(activatedRoute);
        if (this.currentContext?.context === this.targetContext &&
            (await this.hasPermission(this.currentContext.contextData))) {
            return [
                {
                    component: AddDashboardComponent,
                    priority: -Infinity,
                    showAlways: true
                }
            ];
        }
        return [];
    }
    async hasPermission(context) {
        if (context?.id) {
            return await this.permissions.canEdit([
                Permissions.ROLE_INVENTORY_ADMIN,
                Permissions.ROLE_INVENTORY_CREATE,
                Permissions.ROLE_MANAGED_OBJECT_ADMIN,
                Permissions.ROLE_MANAGED_OBJECT_CREATE
            ], context);
        }
        return this.permissions.hasAnyRole([
            Permissions.ROLE_INVENTORY_ADMIN,
            Permissions.ROLE_INVENTORY_CREATE,
            Permissions.ROLE_MANAGED_OBJECT_ADMIN,
            Permissions.ROLE_MANAGED_OBJECT_CREATE
        ]);
    }
}
class AddDeviceDashboardFactory extends AddDashboardFactory {
    constructor() {
        super(...arguments);
        this.targetContext = ViewContext.Device;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AddDeviceDashboardFactory, deps: null, target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AddDeviceDashboardFactory, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AddDeviceDashboardFactory, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });
class AddGroupDashboardFactory extends AddDashboardFactory {
    constructor() {
        super(...arguments);
        this.targetContext = ViewContext.Group;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AddGroupDashboardFactory, deps: null, target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AddGroupDashboardFactory, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AddGroupDashboardFactory, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

const CONTEXT_DASHBOARD_CONFIG = new InjectionToken('ContextDashboardConfig');
const DASHBOARD_SETTINGS_CHANGES = {
    classes: gettext('theme'),
    globalRolesIds: gettext('global roles'),
    widgetClasses: gettext('widget header style'),
    widgetMargin: gettext('widget margin'),
    icon: gettext('icon'),
    name: gettext('name'),
    priority: gettext('priority'),
    c8y_IsNavigatorNode: gettext('navigator item'),
    translateWidgetTitle: gettext('translate widget title')
};
const DASHBOARD_CHILDREN_STATE_NAME = {
    initial: gettext('Initial state'),
    config: gettext('Widget configuration changed'),
    removed: gettext('Widget removed'),
    added: gettext('Widget added'),
    arrangement: gettext('Widgets rearranged')
};
var ContextDashboardType;
(function (ContextDashboardType) {
    ContextDashboardType["Device"] = "device";
    ContextDashboardType["Type"] = "type";
    ContextDashboardType["Group"] = "group";
    ContextDashboardType["Named"] = "name";
    ContextDashboardType["Report"] = "report";
})(ContextDashboardType || (ContextDashboardType = {}));
var DashboardDetailsTabId;
(function (DashboardDetailsTabId) {
    DashboardDetailsTabId["GENERAL"] = "general";
    DashboardDetailsTabId["APPEARANCE"] = "appearance";
    DashboardDetailsTabId["VERSIONHISTORY"] = "versionHistory";
})(DashboardDetailsTabId || (DashboardDetailsTabId = {}));
const WIDGET_HEADER_CLASSES = [
    {
        label: gettext('Regular`style`'),
        class: 'panel-title-regular',
        description: gettext('The widget has no border between header and content.')
    },
    {
        label: gettext('Border`style`'),
        class: 'panel-title-border',
        description: gettext('The widget has a small separation border between header and content.')
    },
    {
        label: gettext('Overlay`style`'),
        class: 'panel-title-overlay',
        description: gettext('The widget content overlays the header.')
    },
    {
        label: gettext('Hidden`style`'),
        class: 'panel-title-hidden',
        description: gettext('The widget header is not shown.')
    }
];
const WIDGET_CONTENT_CLASSES = [
    {
        label: gettext('Branded`style`'),
        class: 'panel-content-branded',
        description: gettext('The widget is styled with the main brand color.')
    },
    {
        label: gettext('Match dashboard`style`'),
        class: 'panel-content-light',
        description: gettext('The widget appearance matches the dashboard appearance.')
    },
    {
        label: gettext('Light`style`'),
        class: 'panel-content-white',
        description: gettext('The widget has light appearance, that is, dark text on light background.')
    },
    {
        label: gettext('Dark`style`'),
        class: 'panel-content-dark',
        description: gettext('The widget has dark appearance, that is, light text on dark background.')
    },
    {
        label: gettext('Transparent`style`'),
        class: 'panel-content-transparent',
        description: gettext('The widget has no background.')
    }
];
const DASHBOARD_THEME_CLASSES = [
    {
        label: gettext('Match UI`theme`'),
        class: 'dashboard-theme-light',
        description: gettext('The dashboard appearance matches the UI appearance.')
    },
    {
        label: gettext('Light`theme`'),
        class: 'dashboard-theme-white',
        description: gettext('The dashboard has light appearance, that is, dark text on light background.')
    },
    {
        label: gettext('Dark`theme`'),
        class: 'dashboard-theme-dark',
        description: gettext('The dashboard has dark appearance, that is, light text on dark background.')
    },
    // {
    //   label: gettext('Transparent`theme`'),
    //   class: 'dashboard-theme-transparent',
    //   description: gettext(
    //     'The dashboard is styled with a transparent background and therefore is border-less.'
    //   )
    // },
    {
        label: gettext('Branded`theme`'),
        class: 'dashboard-theme-branded',
        description: gettext('The dashboard is styled using the brand palette.')
    }
];
const STYLING_CLASS_PREFIXES = [
    'dashboard-theme-',
    'panel-title-',
    'panel-content-'
];
const ALL_GLOBAL_ROLES_SELECTED = 'all';
const PRODUCT_EXPERIENCE = {
    DASHBOARD: {
        EVENTS: {
            DASHBOARDS: 'dashboards',
            REPORTS: 'reports'
        },
        COMPONENTS: {
            DASHBOARD_VIEW: 'context-dashboard',
            DASHBOARD_AVAILABILITY: 'dashboard-availability',
            REPORTS_LIST: 'report-dashboard-list',
            ADD_REPORT: 'report-dashboard-list',
            ADD_DASHBOARD: 'add-dashboard',
            DELETE_DASHBOARD: 'context-dashboard'
        },
        CONTEXT: {
            REPORT: 'report',
            DEVICE: 'device',
            ASSET: 'asset',
            GROUP: 'group'
        },
        ACTIONS: {
            APPLY_GLOBAL_ROLES_CHANGES: 'applyGlobalRolesChanges',
            DELETE: 'delete',
            LOAD: 'load',
            CREATE: 'create',
            ADD_REPORT: 'addReport'
        }
    }
};
const REPORT_DEFAULT_NAVIGATION_NODE_PRIORITY = 30;

class AppearanceSettingsComponent {
    constructor() {
        this.themeClass = 'dashboard-theme-light';
        this.headerClass = 'panel-title-regular';
        this.themeClassChange = new EventEmitter();
        this.headerClassChange = new EventEmitter();
        this.possibleStylingTheme = DASHBOARD_THEME_CLASSES;
        this.possibleStylingHeader = WIDGET_HEADER_CLASSES;
        this.columns = 1;
        this.dashboardDefaultLabel = gettext('Dashboard default');
    }
    themeClassClick(value) {
        value = this.resetToDefault(value, this.themeClass, this.defaultThemeClass);
        this.themeClass = value;
        this.themeClassChange.emit(value);
    }
    headerClassClick(value) {
        value = this.resetToDefault(value, this.headerClass, this.defaultHeaderClass);
        this.headerClass = value;
        this.headerClassChange.emit(value);
    }
    resetToDefault(value, compareTo, defaultValue) {
        if (defaultValue && value === compareTo) {
            value = defaultValue;
        }
        return value;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AppearanceSettingsComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: AppearanceSettingsComponent, selector: "c8y-appearance-settings", inputs: { themeClass: "themeClass", headerClass: "headerClass", defaultThemeClass: "defaultThemeClass", defaultHeaderClass: "defaultHeaderClass", dashboardSettings: "dashboardSettings", possibleStylingTheme: "possibleStylingTheme", possibleStylingHeader: "possibleStylingHeader", columns: "columns" }, outputs: { themeClassChange: "themeClassChange", headerClassChange: "headerClassChange" }, ngImport: i0, template: "<div class=\"row\">\n  <div class=\"col-md-{{ 12 / columns }} col-xs-12\">\n    <fieldset class=\"c8y-fieldset c8y-fieldset--lg\">\n      <legend *ngIf=\"dashboardSettings\">{{ 'Default theme' | translate }}</legend>\n      <legend *ngIf=\"!dashboardSettings\">{{ 'Theme' | translate }}</legend>\n      <ul class=\"list-group\">\n        <li\n          class=\"list-group-item d-flex a-i-center p-l-0 p-r-0 fit-w\"\n          *ngFor=\"let themeClassItem of possibleStylingTheme; let i = index\"\n        >\n          <div\n            class=\"list-item-checkbox\"\n            style=\"max-width: calc(100% - 24px)\"\n          >\n            <label class=\"c8y-radio\">\n              <input\n                name=\"content\"\n                type=\"radio\"\n                [id]=\"'groupradiocontentclass' + i\"\n                [value]=\"themeClassItem.class\"\n                [ngModel]=\"themeClass\"\n                (click)=\"themeClassClick(themeClassItem.class)\"\n              />\n              <span></span>\n              <span\n                class=\"text-truncate\"\n                title=\"{{ themeClassItem.label | translate }}{{\n                  themeClassItem.class === defaultThemeClass\n                    ? ' | ' + (dashboardDefaultLabel | translate)\n                    : ''\n                }}\"\n              >\n                <span>{{ themeClassItem.label | translate }}</span>\n                <br />\n                <small\n                  class=\"text-muted\"\n                  *ngIf=\"themeClassItem.class === defaultThemeClass\"\n                >\n                  {{ dashboardDefaultLabel | translate }}\n                </small>\n              </span>\n            </label>\n          </div>\n\n          <button\n            class=\"btn-help btn-help--sm m-l-auto\"\n            [attr.aria-label]=\"'Help' | translate\"\n            popover=\"{{ themeClassItem.description | translate }}\"\n            placement=\"right\"\n            triggers=\"focus\"\n            container=\"body\"\n            type=\"button\"\n          ></button>\n        </li>\n      </ul>\n    </fieldset>\n  </div>\n  <div class=\"col-md-{{ 12 / columns }} col-xs-12\">\n    <fieldset class=\"c8y-fieldset c8y-fieldset--lg\">\n      <legend *ngIf=\"dashboardSettings\">\n        {{ 'Default widget header style' | translate }}\n      </legend>\n      <legend *ngIf=\"!dashboardSettings\">\n        {{ 'Widget header style' | translate }}\n      </legend>\n      <ul class=\"list-group\">\n        <li\n          class=\"list-group-item d-flex a-i-center p-l-0 p-r-0\"\n          *ngFor=\"let headerClassItem of possibleStylingHeader; let i = index\"\n        >\n          <div\n            class=\"list-item-checkbox\"\n            style=\"max-width: calc(100% - 24px)\"\n          >\n            <label class=\"c8y-radio\">\n              <input\n                name=\"header\"\n                type=\"radio\"\n                [id]=\"'groupradioheaderclass' + i\"\n                [value]=\"headerClassItem.class\"\n                [ngModel]=\"headerClass\"\n                (click)=\"headerClassClick(headerClassItem.class)\"\n              />\n              <span></span>\n              <span\n                class=\"text-truncate\"\n                title=\"{{ headerClassItem.label | translate }}{{\n                  headerClassItem.class === defaultHeaderClass\n                    ? ' | ' + (dashboardDefaultLabel | translate)\n                    : ''\n                }}\"\n              >\n                <span>{{ headerClassItem.label | translate }}</span>\n                <br />\n                <small\n                  class=\"text-muted\"\n                  *ngIf=\"headerClassItem.class === defaultHeaderClass\"\n                >\n                  {{ dashboardDefaultLabel | translate }}\n                </small>\n              </span>\n            </label>\n          </div>\n          <button\n            class=\"btn-help btn-help--sm m-l-auto\"\n            [attr.aria-label]=\"'Help' | translate\"\n            popover=\"{{ headerClassItem.description | translate }}\"\n            placement=\"right\"\n            triggers=\"focus\"\n            container=\"body\"\n            type=\"button\"\n          ></button>\n        </li>\n      </ul>\n    </fieldset>\n  </div>\n  <ng-content></ng-content>\n</div>\n", dependencies: [{ kind: "directive", type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i3.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i3.RadioControlValueAccessor, selector: "input[type=radio][formControlName],input[type=radio][formControl],input[type=radio][ngModel]", inputs: ["name", "formControlName", "value"] }, { kind: "directive", type: i3.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i3.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i4$1.PopoverDirective, selector: "[popover]", inputs: ["adaptivePosition", "boundariesElement", "popover", "popoverContext", "popoverTitle", "placement", "outsideClick", "triggers", "container", "containerClass", "isOpen", "delay"], outputs: ["onShown", "onHidden"], exportAs: ["bs-popover"] }, { kind: "pipe", type: i2.C8yTranslatePipe, name: "translate" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AppearanceSettingsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-appearance-settings', template: "<div class=\"row\">\n  <div class=\"col-md-{{ 12 / columns }} col-xs-12\">\n    <fieldset class=\"c8y-fieldset c8y-fieldset--lg\">\n      <legend *ngIf=\"dashboardSettings\">{{ 'Default theme' | translate }}</legend>\n      <legend *ngIf=\"!dashboardSettings\">{{ 'Theme' | translate }}</legend>\n      <ul class=\"list-group\">\n        <li\n          class=\"list-group-item d-flex a-i-center p-l-0 p-r-0 fit-w\"\n          *ngFor=\"let themeClassItem of possibleStylingTheme; let i = index\"\n        >\n          <div\n            class=\"list-item-checkbox\"\n            style=\"max-width: calc(100% - 24px)\"\n          >\n            <label class=\"c8y-radio\">\n              <input\n                name=\"content\"\n                type=\"radio\"\n                [id]=\"'groupradiocontentclass' + i\"\n                [value]=\"themeClassItem.class\"\n                [ngModel]=\"themeClass\"\n                (click)=\"themeClassClick(themeClassItem.class)\"\n              />\n              <span></span>\n              <span\n                class=\"text-truncate\"\n                title=\"{{ themeClassItem.label | translate }}{{\n                  themeClassItem.class === defaultThemeClass\n                    ? ' | ' + (dashboardDefaultLabel | translate)\n                    : ''\n                }}\"\n              >\n                <span>{{ themeClassItem.label | translate }}</span>\n                <br />\n                <small\n                  class=\"text-muted\"\n                  *ngIf=\"themeClassItem.class === defaultThemeClass\"\n                >\n                  {{ dashboardDefaultLabel | translate }}\n                </small>\n              </span>\n            </label>\n          </div>\n\n          <button\n            class=\"btn-help btn-help--sm m-l-auto\"\n            [attr.aria-label]=\"'Help' | translate\"\n            popover=\"{{ themeClassItem.description | translate }}\"\n            placement=\"right\"\n            triggers=\"focus\"\n            container=\"body\"\n            type=\"button\"\n          ></button>\n        </li>\n      </ul>\n    </fieldset>\n  </div>\n  <div class=\"col-md-{{ 12 / columns }} col-xs-12\">\n    <fieldset class=\"c8y-fieldset c8y-fieldset--lg\">\n      <legend *ngIf=\"dashboardSettings\">\n        {{ 'Default widget header style' | translate }}\n      </legend>\n      <legend *ngIf=\"!dashboardSettings\">\n        {{ 'Widget header style' | translate }}\n      </legend>\n      <ul class=\"list-group\">\n        <li\n          class=\"list-group-item d-flex a-i-center p-l-0 p-r-0\"\n          *ngFor=\"let headerClassItem of possibleStylingHeader; let i = index\"\n        >\n          <div\n            class=\"list-item-checkbox\"\n            style=\"max-width: calc(100% - 24px)\"\n          >\n            <label class=\"c8y-radio\">\n              <input\n                name=\"header\"\n                type=\"radio\"\n                [id]=\"'groupradioheaderclass' + i\"\n                [value]=\"headerClassItem.class\"\n                [ngModel]=\"headerClass\"\n                (click)=\"headerClassClick(headerClassItem.class)\"\n              />\n              <span></span>\n              <span\n                class=\"text-truncate\"\n                title=\"{{ headerClassItem.label | translate }}{{\n                  headerClassItem.class === defaultHeaderClass\n                    ? ' | ' + (dashboardDefaultLabel | translate)\n                    : ''\n                }}\"\n              >\n                <span>{{ headerClassItem.label | translate }}</span>\n                <br />\n                <small\n                  class=\"text-muted\"\n                  *ngIf=\"headerClassItem.class === defaultHeaderClass\"\n                >\n                  {{ dashboardDefaultLabel | translate }}\n                </small>\n              </span>\n            </label>\n          </div>\n          <button\n            class=\"btn-help btn-help--sm m-l-auto\"\n            [attr.aria-label]=\"'Help' | translate\"\n            popover=\"{{ headerClassItem.description | translate }}\"\n            placement=\"right\"\n            triggers=\"focus\"\n            container=\"body\"\n            type=\"button\"\n          ></button>\n        </li>\n      </ul>\n    </fieldset>\n  </div>\n  <ng-content></ng-content>\n</div>\n" }]
        }], propDecorators: { themeClass: [{
                type: Input
            }], headerClass: [{
                type: Input
            }], defaultThemeClass: [{
                type: Input
            }], defaultHeaderClass: [{
                type: Input
            }], dashboardSettings: [{
                type: Input
            }], themeClassChange: [{
                type: Output
            }], headerClassChange: [{
                type: Output
            }], possibleStylingTheme: [{
                type: Input
            }], possibleStylingHeader: [{
                type: Input
            }], columns: [{
                type: Input
            }] } });

/**
 * A hook to define the default widgets of the home dashboard in the cockpit app.
 */
const COCKPIT_HOME_DASHBOARD_CONFIG = new InjectionToken('CockpitHomeDashboardConfig');
/**
 * An array of widgets that is per default placed on the home dashboard of the cockpit app.
 */
const DEFAULT_COCKPIT_HOME_WIDGETS = [
    {
        name: 'cockpit.welcome.widget',
        title: gettext('Welcome to Cockpit'),
        _x: 0,
        _y: 0,
        _height: 5,
        _width: 24,
        classes: { 'panel-title-hidden': true }
    },
    {
        name: 'Asset Alarms',
        title: gettext('Active, critical alarms'),
        _x: 0,
        _y: 5,
        _height: 4,
        _width: 12
    },
    {
        name: 'Recent Alarms',
        title: gettext('Recent alarms'),
        _x: 0,
        _y: 9,
        _height: 4,
        _width: 12
    },
    {
        name: 'Map',
        title: gettext('Map'),
        _x: 12,
        _y: 5,
        _height: 8,
        _width: 12
    }
];

class ContextDashboardService {
    get formDisabled() {
        return this._formDisabled;
    }
    set formDisabled(value) {
        this._formDisabled = value;
        this.formDisabledSubject.next(value);
    }
    constructor(inventory, tabs, modal, translateService, router, navigator, permissions, alert, dynamicComponent, groupService, optionsService) {
        this.inventory = inventory;
        this.tabs = tabs;
        this.modal = modal;
        this.translateService = translateService;
        this.router = router;
        this.navigator = navigator;
        this.permissions = permissions;
        this.alert = alert;
        this.dynamicComponent = dynamicComponent;
        this.groupService = groupService;
        this.optionsService = optionsService;
        this.REPORT_PARTIAL_NAME = 'report_';
        this.VERSION_HISTORY_SIZE_LIMIT = 10;
        this.INVENTORY_ROLES = [
            Permissions.ROLE_INVENTORY_ADMIN,
            Permissions.ROLE_MANAGED_OBJECT_ADMIN
        ];
        this.cache = new Map();
        this.DEFAULT_PAGESIZE = 1000;
        this.FRAGMENT_NAME = 'c8y_Dashboard';
        this.DASHBOARD_ROUTE_PATH = 'dashboard';
        this.INDEX_SPLIT = '!';
        this.CACHE_TIMEOUT = 500;
        this._formDisabled = true;
        this.formDisabledSubject = new Subject();
        this.HIDE_TYPE_DASHBOARD_FOR_ASSETS = 'hideTypeDashboardForAssets';
        this.formDisabled$ = this.formDisabledSubject.asObservable();
        this.queriesUtil = new QueriesUtil();
    }
    async create(dashboardCfg, context, name = '') {
        let dashboard = {};
        assign(dashboard, this.adjustDashboardFor24Columns({ c8y_Dashboard: dashboardCfg }), this.updateDashboardHistory(dashboard, dashboardCfg));
        const [dashboardType, dashboardFragments] = this.getDashboardFragments({ c8y_Dashboard: dashboardCfg }, context, name, false);
        dashboard = { ...dashboard, ...dashboardFragments };
        if (this.shouldSetGlobal(dashboard, context)) {
            assign(dashboard, { c8y_Global: {} });
        }
        dashboard.name = dashboard.c8y_Dashboard.name;
        const { data } = dashboardType === ContextDashboardType.Group ||
            dashboardType === ContextDashboardType.Device ||
            (context && dashboardType === ContextDashboardType.Named)
            ? await this.inventory.childAdditionsCreate(dashboard, context?.contextData.id || '')
            : await this.inventory.create(dashboard);
        return data;
    }
    async detail(dashboardMO) {
        let { data } = await this.inventory.detail(dashboardMO);
        data = this.adjustDashboardFor24Columns(data);
        this.cache.set(dashboardMO.id, data);
        return data;
    }
    async update(dashboard, context) {
        const dashboardCfg = dashboard.c8y_Dashboard;
        dashboard.name = dashboard.c8y_Dashboard.name;
        assign(dashboard, this.adjustDashboardFor24Columns({ c8y_Dashboard: dashboardCfg }), this.updateDashboardHistory(dashboard, dashboardCfg));
        const keepFragments = this.clean(pick(dashboard, [this.FRAGMENT_NAME, 'id', 'name']));
        keepFragments.c8y_DashboardHistory = dashboard.c8y_DashboardHistory;
        await this.serializeWidgetConfigs(keepFragments);
        const [, dashboardTypeFragments] = this.getDashboardFragments(dashboard, context, '', true);
        keepFragments.c8y_Global = this.shouldSetGlobal({ ...dashboard, ...dashboardTypeFragments });
        const { data } = await this.inventory.update({ ...keepFragments, ...dashboardTypeFragments });
        this.cache.set(dashboard.id, data);
        return data;
    }
    async delete(dashboard, withConfirmation = true) {
        try {
            if (withConfirmation) {
                let msg = gettext(`You are about to delete the dashboard "{{ dashboardName }}". Do you want to proceed?`);
                if (this.isDeviceType(dashboard)) {
                    msg = gettext(`You are about to delete the dashboard "{{ dashboardName }}" from all devices of the type "{{ deviceType }}".
           Do you want to proceed?`);
                }
                await this.modal.confirm(gettext('Delete dashboard'), this.translateService.instant(msg, {
                    dashboardName: dashboard.c8y_Dashboard.name,
                    deviceType: dashboard.c8y_Dashboard.deviceTypeValue
                }), Status.DANGER, { ok: gettext('Delete'), cancel: gettext('Cancel') });
            }
            await this.inventory.delete(dashboard);
            const tabToRemove = Array.from(this.tabs.state).find(tab => {
                if (typeof tab.path === 'string') {
                    return tab.path.endsWith(`${this.DASHBOARD_ROUTE_PATH}/${dashboard.id}`);
                }
            });
            this.tabs.remove(tabToRemove);
            queueMicrotask(() => {
                this.tabs.refresh();
            });
        }
        catch (ex) {
            // intended empty
        }
    }
    updateDashboardHistory(dashboard, dashboardCfg) {
        if (!dashboard.c8y_DashboardHistory) {
            dashboard.c8y_DashboardHistory = [];
        }
        if (!dashboardCfg.historyDescription) {
            dashboardCfg.historyDescription = { changeType: 'create' };
        }
        dashboardCfg.created = new Date().toISOString();
        dashboard.c8y_DashboardHistory = cloneDeep([dashboardCfg, ...dashboard.c8y_DashboardHistory]);
        if (dashboard.c8y_DashboardHistory.length > this.VERSION_HISTORY_SIZE_LIMIT) {
            dashboard.c8y_DashboardHistory = [
                ...dashboard.c8y_DashboardHistory.slice(0, this.VERSION_HISTORY_SIZE_LIMIT)
            ];
        }
        return dashboard;
    }
    activateDashboards(route, types) {
        const { dashboardId } = route.params;
        if (dashboardId) {
            return this.getDashboard$(dashboardId, types, route.parent.data.contextData).pipe(tap(dashboard => {
                route.data = { dashboard };
            }), map(() => true), catchError(() => {
                return of(false);
            }));
        }
        this.dashboardTabs$ = this.getTabs$(route.data.contextData, types, route?.parent?.data);
        return this.dashboardTabs$;
    }
    getNamedDashboardOrCreate(name, defaultWidgets, context) {
        const children = this.mapWidgets(defaultWidgets);
        return this.getDashboard$(name, [ContextDashboardType.Named]).pipe(throwIfEmpty(), catchError(() => {
            if (!this.hasPermissionsToCopyDashboard()) {
                this.alert.warning(gettext('You are viewing a read-only dashboard because you don’t have the necessary permissions to modify it.'));
                return of(this.getTemporaryDashboard({
                    name,
                    children,
                    widgetClasses: { 'dashboard-theme-light': true, 'panel-title-regular': true }
                }));
            }
            else
                return from(this.create({
                    children,
                    widgetClasses: { 'dashboard-theme-light': true, 'panel-title-regular': true }
                }, context, name));
        }));
    }
    updateNavigatorItem(mo) {
        this.navigator.state.forEach(node => {
            if (node.path === `reports/${mo.id}`) {
                this.navigator.remove(node);
            }
        });
        if (mo.c8y_IsNavigatorNode) {
            const nodeToAdd = new NavigatorNode({
                label: mo.name,
                path: `reports/${mo.id}`,
                icon: mo.icon,
                priority: mo.priority
            });
            this.navigator.add(nodeToAdd);
        }
    }
    async navigateToDashboard(dashboardMO, isNewDashboard = false) {
        if (/dashboard/.test(this.router.url)) {
            this.router.navigate(['..', dashboardMO.id], {
                relativeTo: getActivatedRoute(this.router),
                ...(isNewDashboard && {
                    state: { [NEW_DASHBOARD_ROUTER_STATE_PROP]: true }
                })
            });
        }
        else if (/^\/(device|group)\/[0-9]+$/.test(this.router.url)) {
            // in case the add dashboard button is the only tab on that route
            this.router.navigate(['.', this.DASHBOARD_ROUTE_PATH, dashboardMO.id], {
                relativeTo: getActivatedRoute(this.router),
                ...(isNewDashboard && {
                    state: { [NEW_DASHBOARD_ROUTER_STATE_PROP]: true }
                })
            });
        }
        else {
            this.router.navigate(['..', this.DASHBOARD_ROUTE_PATH, dashboardMO.id], {
                relativeTo: getActivatedRoute(this.router),
                ...(isNewDashboard && {
                    state: { [NEW_DASHBOARD_ROUTER_STATE_PROP]: true }
                })
            });
        }
    }
    /**
     * Checks if user is able to edit dashboard according to his roles and dashboard ownership.
     *
     * @param mo - Dashboard managed object.
     * @returns True if user is able to edit dashboard, false if he cannot.
     */
    async canEditDashboard(mo) {
        return await this.permissions.canEdit(this.INVENTORY_ROLES, mo);
    }
    /**
     * Checks if user has permissions to copy dashboard according to his roles.
     *
     * @returns True if user has permissions to copy dashboard, false if he cannot.
     */
    hasPermissionsToCopyDashboard() {
        return this.permissions.hasAnyRole([
            Permissions.ROLE_INVENTORY_ADMIN,
            Permissions.ROLE_INVENTORY_CREATE,
            Permissions.ROLE_MANAGED_OBJECT_ADMIN,
            Permissions.ROLE_MANAGED_OBJECT_CREATE
        ]);
    }
    isNamed(dashboard) {
        return some(keys(dashboard), prop => new RegExp(`^${this.FRAGMENT_NAME}${this.INDEX_SPLIT}${ContextDashboardType.Named}${this.INDEX_SPLIT}`).test(prop));
    }
    isReport(dashboard) {
        return some(keys(dashboard), prop => new RegExp(`^${this.FRAGMENT_NAME}${this.INDEX_SPLIT}${ContextDashboardType.Named}${this.INDEX_SPLIT}${this.REPORT_PARTIAL_NAME}`).test(prop));
    }
    isDeviceType(dashboard) {
        return some(keys(dashboard), prop => {
            const matchingProp = new RegExp(`^${this.FRAGMENT_NAME}${this.INDEX_SPLIT}${ContextDashboardType.Type}${this.INDEX_SPLIT}`).test(prop);
            if (!matchingProp) {
                return false;
            }
            else {
                // there might be matching key, but its value can be {} or null
                return !!dashboard[prop];
            }
        });
    }
    isDeviceDashboard(dashboard) {
        return some(keys(dashboard), prop => new RegExp(`^${this.FRAGMENT_NAME}${this.INDEX_SPLIT}${ContextDashboardType.Device}${this.INDEX_SPLIT}`).test(prop));
    }
    isGroupDashboard(dashboard) {
        return some(keys(dashboard), prop => new RegExp(`^${this.FRAGMENT_NAME}${this.INDEX_SPLIT}${ContextDashboardType.Group}${this.INDEX_SPLIT}`).test(prop));
    }
    getFilteredDashboardStyles(styleList) {
        return styleList.filter(c => STYLING_CLASS_PREFIXES.some(classPrefix => c.startsWith(classPrefix)));
    }
    getStyling(styleList, styleName, defaultValue) {
        const styling = styleList.find(style => style && new RegExp(`-${styleName}$`, 'i').test(style.class));
        return styling ? styling.class : defaultValue;
    }
    mapWidgets(widgets) {
        return keyBy(widgets.map(widget => {
            widget.id = String(Math.random()).substr(2);
            return widget;
        }), 'id');
    }
    getDashboard$(dashboardIdOrName, dashboardType, mo) {
        const cache = this.cache.get(dashboardIdOrName);
        const dashboards = mo
            ? this.getContextDashboards(mo, dashboardType)
            : this.getNamedDashboard(dashboardIdOrName);
        const cacheRefresh = this.getContextDashboards$(dashboards).pipe(tap(dashboard => this.cacheDashboard(dashboard)), filter(dashboard => dashboard.id === dashboardIdOrName ||
            has(dashboard, `${this.FRAGMENT_NAME}${this.INDEX_SPLIT}${ContextDashboardType.Named}${this.INDEX_SPLIT}${dashboardIdOrName}`)));
        return cache ? of(cache) : cacheRefresh;
    }
    async pasteDashboard(newContext) {
        if (this.copyClipboard) {
            try {
                const dashboardToPaste = this.createContextDashboardCopy(this.copyClipboard.dashboard, newContext.contextData, this.copyClipboard.context.contextData);
                const dashboard = await this.create(this.clean(dashboardToPaste), newContext);
                // linking childAdditions for e.g. to grant access to the images uploaded by the image widget for users with only inventory roles.
                const { data: childAdditions } = await this.inventory.childAdditionsList(this.copyClipboard.dashboardId, { pageSize: 2000 });
                if (childAdditions.length) {
                    await this.inventory.childAdditionsBulkAdd(childAdditions, dashboard.id);
                }
                this.copyClipboard = undefined;
                this.navigateToDashboard(dashboard);
            }
            catch {
                this.alert.warning(gettext('Insufficient permissions for this action.'));
            }
        }
    }
    /**
     * Creates fragment that associates dashboards with device/asset. It consists of three elements:
     * - FRAGMENT_NAME - static string
     * - dashboard type (e.g. 'group', 'device')
     * - fragment value ( id of device/asset if it is not typed dashboard; deviceTypeValue property of dashboard if it is type dashboard)
     * Example fragment for device dashboard: 'c8y_Dashboard!device!773200'
     * Example fragment for group dashboard: 'c8y_Dashboard!group!84129208'
     * Example fragment for typed device dashboard: 'c8y_Dashboard!type!c8y_lwm2m_connector_device'
     *
     * @param contextDashboardType Type of dashboard
     * @param value Fragment value
     * @returns Fragment for dashboard
     */
    createFragmentKey(contextDashboardType, value) {
        return `${this.FRAGMENT_NAME}${this.INDEX_SPLIT}${contextDashboardType}${this.INDEX_SPLIT}${value}`;
    }
    /**
     * Indicates if dashboard can be set to type dashboard.
     * First, it checks if deviceTypeValue exists and if user has permission to set dashboard type.
     * Then, case from sensor app is checked- dashboard created with sensor app has deviceType set to true but
     * type fragment is missing- we do not support this combination.
     * @param mo Dashboard managed object
     * @param context {ContextData} Current context
     * @returns True if dashboard can be set to type dashboard, false if it is forbidden.
     */
    shouldAllowToSetDashboardType(mo, context) {
        // disallow if dashboard managed object or context is missing or context is not device/asset/group
        if (!mo ||
            !context?.contextData ||
            (context.context !== ViewContext.Device && context.context !== ViewContext.Group)) {
            return 'disallow';
        }
        // if context is asset/group and type dashboard feature is hidden for assets/groups or asset/group has no typ, return disallow
        const typeDashboardHiddenForAssets = this.optionsService.get(this.HIDE_TYPE_DASHBOARD_FOR_ASSETS, true);
        if (context.context === ViewContext.Group &&
            (typeDashboardHiddenForAssets || !context.contextData.type)) {
            return 'disallow';
        }
        // if user has no permission to change dashboard, return disallow
        if (!this.permissions.hasAnyRole(this.INVENTORY_ROLES)) {
            return 'disallow';
        }
        // case from sensor app is checked- dashboard created with sensor app has deviceType set to true but
        // type fragment is missing- we do not support this combination.
        const typeFragment = this.createFragmentKey(ContextDashboardType.Type, context?.contextData?.type);
        if (mo?.c8y_Dashboard &&
            mo?.c8y_Dashboard.deviceType &&
            context?.contextData?.type &&
            !mo[typeFragment]) {
            return 'disallow';
        }
        // if view context is Device and contextData of this device has no type yet but type dashboard can be set when type is filled,
        // return allow_if_type_filled
        if (!context?.contextData?.type &&
            context.context === ViewContext.Device &&
            this.permissions.hasAnyRole(this.INVENTORY_ROLES)) {
            return 'allow_if_type_filled';
        }
        return 'allow';
    }
    createReport(reportCfg) {
        const report = {};
        Object.assign(report, reportCfg);
        Object.assign(report, { c8y_Report: {} });
        return this.inventory.create(report);
    }
    addReportNavigatorNode(report) {
        const node = new NavigatorNode({
            label: report.name,
            path: `reports/${report.id}`,
            icon: report.icon,
            priority: report.priority
        });
        this.navigator.add(node);
    }
    getContextForGS(mo) {
        if (this.groupService.isDevice(mo)) {
            return PRODUCT_EXPERIENCE.DASHBOARD.CONTEXT.DEVICE;
        }
        else if (this.groupService.isAsset(mo)) {
            return PRODUCT_EXPERIENCE.DASHBOARD.CONTEXT.ASSET;
        }
        else if (this.groupService.isGroup(mo)) {
            return PRODUCT_EXPERIENCE.DASHBOARD.CONTEXT.GROUP;
        }
        else {
            return null;
        }
    }
    async getContextDashboards(mo, dashboardType) {
        const filterCriteria = dashboardType.map(t => ({
            // it's necessary to wrap fragment in quotes because dashboard type can contain spaces
            __has: `'${this.createDashboardFragment(mo, t)}'`
        }));
        // the has query above does not work for device type dashboards where the type contains a dot
        const typeFilterCriteria = dashboardType.includes(ContextDashboardType.Type) && mo.type
            ? {
                __and: [
                    { 'c8y_Dashboard.deviceType': { __eq: true } },
                    { 'c8y_Dashboard.deviceTypeValue': { __eq: mo.type } }
                ]
            }
            : undefined;
        const finalFilterCriteria = typeFilterCriteria
            ? [...filterCriteria, typeFilterCriteria]
            : filterCriteria;
        const query = this.queriesUtil.buildQuery({ __filter: { __or: finalFilterCriteria } });
        const now = Date.now();
        const cacheHasValidResponse = this.contextDashboardsCache &&
            this.contextDashboardsCache.query === query &&
            now - this.contextDashboardsCache.timestamp < this.CACHE_TIMEOUT;
        if (cacheHasValidResponse) {
            return this.contextDashboardsCache.result;
        }
        else {
            this.contextDashboardsCache = null;
        }
        this.contextDashboardsCache = {
            query,
            result: this.inventory.list({ query, pageSize: this.DEFAULT_PAGESIZE }),
            timestamp: now
        };
        return this.contextDashboardsCache.result;
    }
    /**
     * Creates a tuple describing the dashboard type and its fragments. For assets like devices and groups, it's possible
     * to have two fragments: one indicating this particular device/asset with its ID, and the second indicating
     * the device/asset type (if the dashboard is meant to be applied to all assets of this type).
     *
     * @param dashboardMO - Dashboard managed object.
     * @param context - Context data of asset.
     * @param name - Name of the dashboard.
     * @param isEdit - True if existing dashboard is updated, false when it's creation of new dashboard.
     * @returns Tuple of dashboard type and object containing dashboard fragments.
     */
    getDashboardFragments(dashboardMO, context, name, isEdit) {
        let dashboardType;
        const id = context?.contextData?.id || '';
        const fragments = {};
        if (name) {
            // a named dashboard should not receive any other fragments
            dashboardType = ContextDashboardType.Named;
            const namedFragmentKey = this.createFragmentKey(ContextDashboardType.Named, name);
            fragments[namedFragmentKey] = {};
        }
        else if (context?.context === ViewContext.Device || context?.context === ViewContext.Group) {
            // get base type for device or group
            const defaultType = context.context === ViewContext.Device
                ? ContextDashboardType.Device
                : ContextDashboardType.Group;
            dashboardType = dashboardMO.c8y_Dashboard.deviceType
                ? ContextDashboardType.Type
                : defaultType;
            // clear fragments from other asset if current asset is not origin of this dashboard
            this.clearRedundantFragment(dashboardMO, defaultType, fragments);
            // add base fragment for particular asset
            const deviceOrGroupFragmentKey = this.createFragmentKey(defaultType, id);
            fragments[deviceOrGroupFragmentKey] = {};
            // add or clear type fragment
            if (dashboardMO.c8y_Dashboard.deviceType || isEdit) {
                const typeFragmentKey = this.createFragmentKey(ContextDashboardType.Type, dashboardMO.c8y_Dashboard.deviceTypeValue);
                fragments[typeFragmentKey] = dashboardMO.c8y_Dashboard.deviceType ? {} : null;
            }
        }
        return [dashboardType, fragments];
    }
    /**
     * Clears fragments that originates from other managed object.
     * E.g. typed dashboard is created for device A of type c8y_MQTTDevice and id 1, so it gets fragments object
     * ```ts
     * {
     * c8y_Dashboard!device!1: {},
     * c8y_Dashboard!type!c8y_MQTTDevice: {}
     * }
     *```
     * then, on device B of type c8y_MQTTDevice and id 2, which also has access to this dashboard, deviceType is set to
     * false, so dashboard is not typed dashboard anymore and now belongs to device B, therefore fragments should look like
     * ```ts
     * {
     * c8y_Dashboard!device!1: null, // this value is cleared because dashboard is doesn't belong to device A anymore
     * c8y_Dashboard!device!2: {}, // assign dashboard to device B
     * c8y_Dashboard!type!c8y_MQTTDevice: null // this value is cleared in getDashboardFragments method as it's not typed dashboard anymore
     * }
     * ```
     *
     * @param dashboardMO - Dashboard managed object.
     * @param type - Context dashboard type.
     * @param fragments - Fragments object.
     */
    clearRedundantFragment(dashboardMO, type, fragments) {
        Object.keys(dashboardMO)
            .filter(key => key.startsWith(this.createFragmentKey(type, '')))
            .forEach(key => (fragments[key] = null));
    }
    adjustDashboardFor24Columns(dashboards) {
        if (Array.isArray(dashboards)) {
            return dashboards.map(dashboard => this.adjustDashboardFor24Columns(dashboard));
        }
        // if `columns` attribute exists, dashboard was already adjusted.
        if (dashboards.c8y_Dashboard.columns) {
            return dashboards;
        }
        dashboards.c8y_Dashboard.columns = 24;
        if (!dashboards.c8y_Dashboard.children) {
            return dashboards;
        }
        // Newly created NamedContextDashboards are still created with 12 columns for backwards compatibility.
        // Default widgets might be already configured for 24 columns.
        // If a widget is already configured for more than 12 columns, we should not adjust it.
        const alreadyHasWidgetsConfiguredForMoreThan12Columns = Object.values(dashboards.c8y_Dashboard.children).some(widget => widget._x + widget._width > 12);
        if (alreadyHasWidgetsConfiguredForMoreThan12Columns) {
            return dashboards;
        }
        // we need to multiply both _width and _x attributes with 2 to migrate from 12 to 24 columns.
        Object.values(dashboards.c8y_Dashboard.children).forEach(widget => {
            if (widget._width) {
                widget._width = widget._width * 2;
            }
            if (widget._x) {
                widget._x = widget._x * 2;
            }
        });
        return dashboards;
    }
    async serializeWidgetConfigs(dashboard) {
        const children = cloneDeep(dashboard.c8y_Dashboard.children);
        if (!children) {
            return;
        }
        const configs = Object.values(children);
        const details = configs.map(({ componentId, config }) => ({ componentId, config }));
        const results = await this.dynamicComponent.serializeConfigs(details);
        results.forEach((result, index) => {
            Object.entries(result).forEach(([key, value]) => {
                set(details[index].config, key, value);
            });
        });
        dashboard.c8y_Dashboard.children = children;
    }
    createContextDashboardCopy(dash, newContext, oldContext) {
        const children = reduce(dash.children, (_children, child) => {
            const { id } = child;
            const cfg = child.config;
            const propertiesToCopy = {
                device: device => this.replaceContextInObj(device, newContext, oldContext),
                datapoints: dataPoints => this.replaceContextInDataPoints(dataPoints, newContext, oldContext),
                dataPoints: dataPoints => this.replaceContextInDataPoints(dataPoints, newContext, oldContext),
                datapointsGauge: dataPoints => this.replaceContextInDataPoints(dataPoints, newContext, oldContext),
                datapointsLabels: dataPoints => this.replaceContextInDataPoints(dataPoints, newContext, oldContext)
            };
            if (cfg) {
                this.copyProperties(cfg, propertiesToCopy);
                if (cfg.options) {
                    this.copyProperties(cfg.options, propertiesToCopy);
                }
            }
            _children[id] = cloneDeep(child);
            return _children;
        }, {});
        dash.children = children;
        const isTypeDashboard = dash.deviceType && !!dash.deviceTypeValue;
        if (isTypeDashboard) {
            dash.deviceTypeValue = newContext.type;
        }
        return dash;
    }
    copyProperties(obj, propertiesToCopy) {
        forEach(propertiesToCopy, (copyFn, property) => {
            if (obj[property]) {
                obj[property] = copyFn(obj[property]);
            }
        });
    }
    replaceContextInDataPoints(dataPoints, newContext, oldContext) {
        dataPoints.forEach(dp => {
            dp.__target = this.replaceContextInObj(dp.__target, newContext, oldContext);
        });
        return dataPoints;
    }
    replaceContextInObj(obj, newContext, oldContext) {
        if (obj && obj.id === oldContext.id) {
            Object.assign(obj, pick(newContext, ['id', 'name']));
        }
        return obj;
    }
    getTabs$(mo, dashboardType, context) {
        const dashboards = this.getContextDashboards(mo, dashboardType);
        return this.getContextDashboards$(dashboards).pipe(mergeMap(dashboard => this.verifyDashboardAvailability$(dashboard)), 
        // Due to MTM-62321 named context dashboards included fragments for device and groups.
        // therefore some device-info dashboards (from DM app) might occur in cockpit on device level.
        // We need to filter those out..
        filter(([dashboard]) => {
            // list all identifiers of the dashboard (name, device, group, type)
            const dashboardIdentifiers = Object.keys(dashboard)
                .filter(key => key.startsWith(`${this.FRAGMENT_NAME}${this.INDEX_SPLIT}`))
                .map(key => key.split(this.INDEX_SPLIT)[1]);
            // if dashboard is not named, it's safe to include it
            if (!dashboardIdentifiers.includes(ContextDashboardType.Named)) {
                return true;
            }
            // if dashboard is named, but also has a context identifier, we skip it
            if (dashboardIdentifiers.includes(ContextDashboardType.Device) ||
                dashboardIdentifiers.includes(ContextDashboardType.Group)) {
                return false;
            }
            // all others are good..
            return true;
        }), mergeMap(([dashboard]) => this.removeDashboardMoProperty(dashboard)), tap(dashboard => this.cacheDashboard(dashboard)), map(dashboard => this.createDashboardTab(dashboard, context)), toArray());
    }
    verifyDashboardAvailability$(dashboard) {
        const globalRolesIds = dashboard?.c8y_Dashboard?.globalRolesIds;
        const canEdit = from(this.permissions.canEdit(this.INVENTORY_ROLES, dashboard, { skipRequestCheck: true }));
        const hasAnyGlobalRole = !globalRolesIds || globalRolesIds === ALL_GLOBAL_ROLES_SELECTED
            ? of(true)
            : of(this.permissions.hasAnyGlobalRole(globalRolesIds));
        return combineLatest([of(dashboard), canEdit, hasAnyGlobalRole]).pipe(filter(([, canEdit, hasAnyGlobalRole]) => canEdit || hasAnyGlobalRole));
    }
    getContextDashboards$(request) {
        return from(request).pipe(mergeMap(response => this.adjustDashboardFor24Columns(response.data)));
    }
    /**
     * Cleans already corrupted dashboards from dashboardMo property.
     * Added to fix dashboards on the cloud instance (eu-latest).
     * @deprecated This is going to be removed after 1007.7.0.
     */
    async removeDashboardMoProperty(dashboard) {
        const dashboardCopy = cloneDeep(dashboard);
        const children = get(dashboardCopy, 'c8y_Dashboard.children');
        let updateDashboard = false;
        forEach(children, child => {
            if (get(child, 'componentTransformConfigWithContext')) {
                delete child.componentTransformConfigWithContext;
                updateDashboard = true;
            }
            if (get(child, 'config.dashboardMo')) {
                delete child.config.dashboardMo;
                updateDashboard = true;
            }
        });
        if (updateDashboard) {
            await this.update(dashboardCopy);
        }
        return dashboardCopy;
    }
    cacheDashboard(dashboard) {
        this.cache.set(dashboard.id, dashboard);
    }
    createDashboardTab(dashboard, context) {
        const { c8y_Dashboard: _dashboard, id } = dashboard;
        return {
            icon: _dashboard.icon,
            path: `${this.DASHBOARD_ROUTE_PATH}/${id}`,
            label: _dashboard.name,
            priority: _dashboard.priority,
            hide: this.isReport(dashboard),
            badge: _dashboard.deviceType && this.shouldAllowToSetDashboardType(dashboard, context)
                ? gettext('Dashboard template')
                : null,
            tooltipText: _dashboard.description || gettext('Dashboard template')
        };
    }
    clean(dashboard) {
        const jsonString = JSON.stringify(dashboard, (key, value) => {
            if (key === '$$hashKey' || key === 'klasses') {
                return undefined;
            }
            return value;
        });
        return JSON.parse(jsonString);
    }
    getNamedDashboard(name) {
        return this.inventory.list({
            fragmentType: `${this.FRAGMENT_NAME}${this.INDEX_SPLIT}${ContextDashboardType.Named}${this.INDEX_SPLIT}${name}`,
            pageSize: 1
        });
    }
    createDashboardFragment(mo, type) {
        let value;
        if (mo.c8y_Report) {
            value = `${this.REPORT_PARTIAL_NAME}${mo.id}`;
        }
        else {
            value = type === ContextDashboardType.Type ? mo.type : mo.id;
        }
        return `${this.FRAGMENT_NAME}${this.INDEX_SPLIT}${type}${this.INDEX_SPLIT}${value}`;
    }
    shouldSetGlobal(dashboard, context) {
        if ((!context && this.isNamed(dashboard) && !this.isReport(dashboard)) ||
            this.isDeviceType(dashboard)) {
            return {};
        }
        return null;
    }
    getTemporaryDashboard(dashboardCfg) {
        return {
            c8y_Dashboard: {
                ...dashboardCfg,
                name: dashboardCfg.name || 'Temporary Dashboard',
                isTransient: true,
                description: gettext('This is a temporary, non-editable dashboard displayed due to insufficient permissions.')
            },
            [`c8y_Dashboard!name!${dashboardCfg.name}`]: {}
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ContextDashboardService, deps: [{ token: i1$1.InventoryService }, { token: i2.TabsService }, { token: i2.ModalService }, { token: i2$1.TranslateService }, { token: i1.Router }, { token: i2.NavigatorService }, { token: i2.Permissions }, { token: i2.AlertService }, { token: i2.DynamicComponentService }, { token: i2.GroupService }, { token: i2.OptionsService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ContextDashboardService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ContextDashboardService, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }], ctorParameters: () => [{ type: i1$1.InventoryService }, { type: i2.TabsService }, { type: i2.ModalService }, { type: i2$1.TranslateService }, { type: i1.Router }, { type: i2.NavigatorService }, { type: i2.Permissions }, { type: i2.AlertService }, { type: i2.DynamicComponentService }, { type: i2.GroupService }, { type: i2.OptionsService }] });

class DashboardDetailService {
    constructor(fb, translateService) {
        this.fb = fb;
        this.translateService = translateService;
        this.styling = {
            themeClass: 'dashboard-theme-light',
            headerClass: 'panel-title-regular'
        };
        this.DEFAULT_DASHBOARD_MARGIN = 12;
        this.DEFAULT_DASHBOARD_ICON = 'th';
        this.DEFAULT_DASHBOARD_PRIORITY = 5000;
    }
    /**
     * Creates dashboard details form divided into two groups- general settings and appearance settings.
     * @param dashboard Context dashboard object
     * @param isReport True if its report dashboard
     * @param allowTypeDashboard Allow to make dashboard type dashboard
     * @returns Dashboard details form
     */
    initForm(dashboard, isReport, allowTypeDashboard) {
        return this.fb.group({
            generalSettingsForm: this.initGeneralSettingsForm(dashboard, isReport, allowTypeDashboard),
            appearanceSettingsForm: this.initAppearanceSettingsForm(dashboard)
        });
    }
    /**
     * Creates form group for general settings of dashboard.
     * @param dashboard Context dashboard object
     * @param isReport True if its report dashboard
     * @param deviceTypeValue Value used for typed dashboard
     * @returns Dashboard general settings form
     */
    initGeneralSettingsForm(dashboard, isReport, allowTypeDashboard) {
        const globalRolesIdsValue = !dashboard?.globalRolesIds
            ? null
            : Array.isArray(dashboard.globalRolesIds)
                ? [...dashboard.globalRolesIds]
                : dashboard.globalRolesIds;
        return this.fb.group({
            icon: [dashboard?.icon || this.DEFAULT_DASHBOARD_ICON, [Validators.minLength(1)]],
            priority: [
                dashboard?.priority || this.DEFAULT_DASHBOARD_PRIORITY,
                [Validators.min(-10000), Validators.max(10000), Validators.required]
            ],
            name: [
                dashboard?.name ||
                    (isReport
                        ? this.translateService.instant(gettext('Report'))
                        : this.translateService.instant(gettext('Dashboard'))),
                [Validators.required, Validators.maxLength(512)]
            ],
            description: [dashboard?.description || null, [Validators.maxLength(1_000)]],
            globalRolesIds: [globalRolesIdsValue],
            c8y_IsNavigatorNode: [!!dashboard?.c8y_IsNavigatorNode],
            ...(allowTypeDashboard !== 'disallow' && {
                deviceType: [
                    {
                        value: dashboard?.deviceType ?? false,
                        disabled: allowTypeDashboard === 'allow_if_type_filled'
                    }
                ]
            })
        });
    }
    /**
     * Creates form group for appearance settings of dashboard.
     * @param dashboard Context dashboard object
     * @returns Dashboard appearance settings form
     */
    initAppearanceSettingsForm(dashboard) {
        return this.fb.group({
            widgetMargin: [
                dashboard?.widgetMargin || this.DEFAULT_DASHBOARD_MARGIN,
                [Validators.min(0), Validators.max(50)]
            ],
            translateWidgetTitle: [!!dashboard?.translateWidgetTitle],
            classes: [dashboard?.classes || { [this.styling.themeClass]: true }],
            widgetClasses: [dashboard?.widgetClasses || { [this.styling.headerClass]: true }]
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardDetailService, deps: [{ token: i3.FormBuilder }, { token: i2$1.TranslateService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardDetailService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardDetailService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: i3.FormBuilder }, { type: i2$1.TranslateService }] });

class DashboardAvailabilityComponent {
    /**
     * Ids of global roles assigned to the dashboard or a string "all" indicating the selection of all global roles.
     * The value undefined is treated as equivalent to 'all'.
     */
    get globalRolesIds() {
        return this._globalRolesIds;
    }
    set globalRolesIds(ids) {
        if (!ids || ids === ALL_GLOBAL_ROLES_SELECTED) {
            this._globalRolesIds = ALL_GLOBAL_ROLES_SELECTED;
            return;
        }
        this._globalRolesIds = [...ids];
    }
    constructor(userGroupService, gainsightService, permissions) {
        this.userGroupService = userGroupService;
        this.gainsightService = gainsightService;
        this.permissions = permissions;
        this.globalRolesIdsChange = new EventEmitter();
        this.globalRolesItems = [];
        this.globalRolesItemsSelected = [];
        this.selectHidden = false;
        this.globalRoles = [];
        this.PAGE_SIZE = 100;
    }
    async ngOnInit() {
        if (this.permissions.hasRole(Permissions.ROLE_USER_MANAGEMENT_READ)) {
            this.globalRoles = await this.getGlobalRoles();
            this.globalRolesItems = this.mapGlobalRolesToItems();
            this.globalRolesItemsSelected = this.getSelectedGlobalRolesItems();
        }
        else {
            this.selectHidden = true;
        }
    }
    onSelected(items) {
        if (!items || !Array.isArray(items)) {
            return;
        }
        const allItemsSelected = items.length === this.globalRolesItems.length;
        this.globalRolesItemsSelected = items;
        if (allItemsSelected) {
            this.globalRolesIdsChange.emit(ALL_GLOBAL_ROLES_SELECTED);
            this.gainsightService.triggerEvent(PRODUCT_EXPERIENCE.DASHBOARD.EVENTS.DASHBOARDS, {
                component: PRODUCT_EXPERIENCE.DASHBOARD.COMPONENTS.DASHBOARD_AVAILABILITY,
                action: PRODUCT_EXPERIENCE.DASHBOARD.ACTIONS.APPLY_GLOBAL_ROLES_CHANGES,
                globalRoles: ALL_GLOBAL_ROLES_SELECTED
            });
        }
        else {
            const selectedGlobalRolesIds = items.map(i => i.id);
            this.globalRolesIdsChange.emit([...selectedGlobalRolesIds]);
            this.gainsightService.triggerEvent(PRODUCT_EXPERIENCE.DASHBOARD.EVENTS.DASHBOARDS, {
                component: PRODUCT_EXPERIENCE.DASHBOARD.COMPONENTS.DASHBOARD_AVAILABILITY,
                action: PRODUCT_EXPERIENCE.DASHBOARD.ACTIONS.APPLY_GLOBAL_ROLES_CHANGES,
                globalRoles: selectedGlobalRolesIds?.sort()?.join()
            });
        }
    }
    async getGlobalRoles() {
        return (await this.userGroupService.list({ pageSize: this.PAGE_SIZE })).data;
    }
    mapGlobalRolesToItems() {
        return this.globalRoles.map(({ name, id }) => ({
            name,
            id
        }));
    }
    getSelectedGlobalRolesItems() {
        if (!this.globalRolesIds || this.globalRolesIds === ALL_GLOBAL_ROLES_SELECTED) {
            return this.globalRolesItems;
        }
        return this.globalRolesIds
            .map(globalRoleId => this.globalRolesItems.find(gR => gR.id === globalRoleId))
            .filter(Boolean);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardAvailabilityComponent, deps: [{ token: i1$1.UserGroupService }, { token: i2.GainsightService }, { token: i2.Permissions }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: DashboardAvailabilityComponent, selector: "c8y-dashboard-availability", inputs: { globalRolesIds: "globalRolesIds" }, outputs: { globalRolesIdsChange: "globalRolesIdsChange" }, ngImport: i0, template: "<fieldset class=\"c8y-fieldset c8y-fieldset--lg\">\n  <legend>{{ 'Availability`of dashboard based on permissions`' | translate }}</legend>\n  <c8y-form-group>\n    <label for=\"availability\">\n      <span\n        class=\"m-r-4\"\n        id=\"availability\"\n      >\n        {{ 'Global roles' | translate }}\n      </span>\n      <button\n        class=\"btn-help btn-help--sm\"\n        [attr.aria-label]=\"'Help' | translate\"\n        popover=\"{{\n          'Select the global roles for which the dashboard will be available' | translate\n        }}\"\n        placement=\"right\"\n        triggers=\"focus\"\n        container=\"body\"\n        type=\"button\"\n      ></button>\n    </label>\n    <c8y-select-legacy\n      *ngIf=\"!selectHidden\"\n      [items]=\"globalRolesItems\"\n      [selected]=\"globalRolesItemsSelected\"\n      (onChange)=\"onSelected($event)\"\n    ></c8y-select-legacy>\n    <p\n      class=\"form-control-static\"\n      *ngIf=\"selectHidden\"\n    >\n      {{ \"You don't have permission to change global roles.\" | translate }}\n    </p>\n  </c8y-form-group>\n</fieldset>\n", dependencies: [{ kind: "directive", type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i2.SelectLegacyComponent, selector: "c8y-select-legacy", inputs: ["placeholder", "selectedLabel", "applyLabel", "items", "selected", "updateItems", "disableApplyOnNoSelection", "addDropdownContainerToBody"], outputs: ["onChange"] }, { kind: "component", type: i2.FormGroupComponent, selector: "c8y-form-group", inputs: ["hasError", "hasWarning", "hasSuccess", "novalidation", "status"] }, { kind: "directive", type: i4$1.PopoverDirective, selector: "[popover]", inputs: ["adaptivePosition", "boundariesElement", "popover", "popoverContext", "popoverTitle", "placement", "outsideClick", "triggers", "container", "containerClass", "isOpen", "delay"], outputs: ["onShown", "onHidden"], exportAs: ["bs-popover"] }, { kind: "pipe", type: i2.C8yTranslatePipe, name: "translate" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardAvailabilityComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-dashboard-availability', template: "<fieldset class=\"c8y-fieldset c8y-fieldset--lg\">\n  <legend>{{ 'Availability`of dashboard based on permissions`' | translate }}</legend>\n  <c8y-form-group>\n    <label for=\"availability\">\n      <span\n        class=\"m-r-4\"\n        id=\"availability\"\n      >\n        {{ 'Global roles' | translate }}\n      </span>\n      <button\n        class=\"btn-help btn-help--sm\"\n        [attr.aria-label]=\"'Help' | translate\"\n        popover=\"{{\n          'Select the global roles for which the dashboard will be available' | translate\n        }}\"\n        placement=\"right\"\n        triggers=\"focus\"\n        container=\"body\"\n        type=\"button\"\n      ></button>\n    </label>\n    <c8y-select-legacy\n      *ngIf=\"!selectHidden\"\n      [items]=\"globalRolesItems\"\n      [selected]=\"globalRolesItemsSelected\"\n      (onChange)=\"onSelected($event)\"\n    ></c8y-select-legacy>\n    <p\n      class=\"form-control-static\"\n      *ngIf=\"selectHidden\"\n    >\n      {{ \"You don't have permission to change global roles.\" | translate }}\n    </p>\n  </c8y-form-group>\n</fieldset>\n" }]
        }], ctorParameters: () => [{ type: i1$1.UserGroupService }, { type: i2.GainsightService }, { type: i2.Permissions }], propDecorators: { globalRolesIds: [{
                type: Input
            }], globalRolesIdsChange: [{
                type: Output
            }] } });

class TypeDashboardInfoComponent {
    constructor(inventory, alert) {
        this.inventory = inventory;
        this.alert = alert;
    }
    async ngOnInit() {
        await this.updateDeviceTypeCount();
    }
    async updateDeviceTypeCount() {
        try {
            const count = await this.inventory.count({
                type: this.deviceTypeValue || this.context.c8y_Dashboard.deviceTypeValue
            });
            this.deviceTypeInstancesCount = count.data;
            this.asyncRenderSuccess?.();
        }
        catch (error) {
            this.alert.addServerFailure(error);
            this.asyncRenderFail?.();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TypeDashboardInfoComponent, deps: [{ token: i1$1.InventoryService }, { token: i2.AlertService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: TypeDashboardInfoComponent, selector: "c8y-type-dashboard-info", inputs: { deviceTypeValue: "deviceTypeValue", displayDeviceTypeValue: "displayDeviceTypeValue", context: "context", asyncRenderSuccess: "asyncRenderSuccess", asyncRenderFail: "asyncRenderFail" }, ngImport: i0, template: "<ul class=\"list-unstyled small animated fadeIn\">\n  <li class=\"p-t-4 p-b-4 d-flex separator-top-bottom text-nowrap\">\n    <label class=\"small m-b-0 m-r-8\">{{ 'Target asset model' | translate }}</label>\n    <span class=\"m-l-auto\">\n      <span class=\"label label-info\">\n        {{ displayDeviceTypeValue || context.c8y_Dashboard.deviceTypeValue }}\n      </span>\n    </span>\n  </li>\n  <li class=\"p-t-4 p-b-4 d-flex separator-bottom text-nowrap\">\n    <label class=\"small m-b-0 m-r-8\">{{ 'Dashboard instances' | translate }}</label>\n    <span class=\"m-l-auto\">{{ deviceTypeInstancesCount }}</span>\n  </li>\n  <ng-container *ngIf=\"context?.c8y_Dashboard\">\n    <li class=\"p-t-4 p-b-4 d-flex separator-bottom text-nowrap\">\n      <label class=\"small m-b-0 m-r-8\">{{ 'Created' | translate }}</label>\n      <span class=\"m-l-auto\">\n        {{ context.creationTime | c8yDate }} {{ 'by`user`' | translate }} {{ context.owner }}\n      </span>\n    </li>\n    <li\n      class=\"p-t-4 p-b-4 d-flex separator-bottom text-nowrap\"\n      *ngIf=\"context?.c8y_DashboardHistory?.length\"\n    >\n      <label class=\"small m-b-0 m-r-8\">{{ 'Last modified' | translate }}</label>\n      <span class=\"m-l-auto\">\n        {{ context.c8y_DashboardHistory[0].created | c8yDate }} {{ 'by`user`' | translate }}\n        {{ context.c8y_DashboardHistory[0].author }}\n      </span>\n    </li>\n  </ng-container>\n</ul>\n", dependencies: [{ kind: "directive", type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "pipe", type: i2.C8yTranslatePipe, name: "translate" }, { kind: "pipe", type: i2.DatePipe, name: "c8yDate" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TypeDashboardInfoComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-type-dashboard-info', template: "<ul class=\"list-unstyled small animated fadeIn\">\n  <li class=\"p-t-4 p-b-4 d-flex separator-top-bottom text-nowrap\">\n    <label class=\"small m-b-0 m-r-8\">{{ 'Target asset model' | translate }}</label>\n    <span class=\"m-l-auto\">\n      <span class=\"label label-info\">\n        {{ displayDeviceTypeValue || context.c8y_Dashboard.deviceTypeValue }}\n      </span>\n    </span>\n  </li>\n  <li class=\"p-t-4 p-b-4 d-flex separator-bottom text-nowrap\">\n    <label class=\"small m-b-0 m-r-8\">{{ 'Dashboard instances' | translate }}</label>\n    <span class=\"m-l-auto\">{{ deviceTypeInstancesCount }}</span>\n  </li>\n  <ng-container *ngIf=\"context?.c8y_Dashboard\">\n    <li class=\"p-t-4 p-b-4 d-flex separator-bottom text-nowrap\">\n      <label class=\"small m-b-0 m-r-8\">{{ 'Created' | translate }}</label>\n      <span class=\"m-l-auto\">\n        {{ context.creationTime | c8yDate }} {{ 'by`user`' | translate }} {{ context.owner }}\n      </span>\n    </li>\n    <li\n      class=\"p-t-4 p-b-4 d-flex separator-bottom text-nowrap\"\n      *ngIf=\"context?.c8y_DashboardHistory?.length\"\n    >\n      <label class=\"small m-b-0 m-r-8\">{{ 'Last modified' | translate }}</label>\n      <span class=\"m-l-auto\">\n        {{ context.c8y_DashboardHistory[0].created | c8yDate }} {{ 'by`user`' | translate }}\n        {{ context.c8y_DashboardHistory[0].author }}\n      </span>\n    </li>\n  </ng-container>\n</ul>\n" }]
        }], ctorParameters: () => [{ type: i1$1.InventoryService }, { type: i2.AlertService }], propDecorators: { deviceTypeValue: [{
                type: Input
            }], displayDeviceTypeValue: [{
                type: Input
            }], context: [{
                type: Input
            }], asyncRenderSuccess: [{
                type: Input
            }], asyncRenderFail: [{
                type: Input
            }] } });

class TypedDashboardSettingsComponent {
    constructor(inventory, interAppService, route) {
        this.inventory = inventory;
        this.interAppService = interAppService;
        this.route = route;
        this.touched = false;
        this.disabled = false;
        this.onDuplicateWithoutType = new EventEmitter();
        this.deviceManagementAppKey = SupportedApps.devicemanagement;
        this.deviceManagementLinkTitle = gettext('Device Info page in {{ deviceManagementAppName }}');
        // eslint-disable-next-line @typescript-eslint/no-empty-function
        this.onChange = _ => { };
        // eslint-disable-next-line @typescript-eslint/no-empty-function
        this.onTouched = () => { };
    }
    async ngOnInit() {
        this.userDeviceManagementApp$ = this.interAppService.getApp$(this.deviceManagementAppKey);
        this.context = this.route.parent.snapshot.data.contextData;
        this.showSourceNavigationLink$ = this.interAppService.shouldShowAppLink$(this.deviceManagementAppKey);
    }
    async goToDeviceView() {
        await this.interAppService.navigateToApp(this.deviceManagementAppKey, `#/device/${this.context.id}/device-info`);
    }
    writeValue(value) {
        this.value = value;
        this.updateTexts();
        if (value) {
            this.updateDeviceTypeCount();
        }
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(onTouched) {
        this.onTouched = onTouched;
    }
    markAsTouched() {
        if (!this.touched) {
            this.onTouched();
            this.touched = true;
        }
    }
    setDisabledState(disabled) {
        this.disabled = disabled;
    }
    async toggle() {
        this.value = !this.value;
        this.onChange(this.value);
        if (this.value && this.deviceTypeInstancesCount == null) {
            this.setDisabledState(true);
            await this.updateDeviceTypeCount();
        }
        this.updateTexts();
        this.setDisabledState(false);
    }
    updateTexts() {
        this.typedDashboardStatus = this.value
            ? gettext('Enabled`typed dashboard`')
            : gettext('Disabled`typed dashboard`');
        if (this.allowTypeDashboard === 'allow_if_type_filled') {
            this.infoText = gettext(`<p class="p-b-8">Enabling this option uses the layout and configuration of this dashboard to create dashboard instances for all devices based on the device type.</p>
             <p class="p-b-16">The current device doesn't have a device type assigned to it. Assign a device type to the device via the "Asset properties" widget in the <strong>Info</strong> tab of the device.</p>`);
            return;
        }
        if (this.value) {
            if (this.isDevice) {
                this.infoText = gettext(`<p class="p-b-8">
            The layout and configuration of this dashboard is used by all devices based on device type <span class="tag tag--info text-12">{{ displayDeviceTypeValue }}</span>.
          </p>
          <p class="p-b-16">
            Disabling this option removes it from all devices based on the same type and makes it available only for the current instance.
          </p>`);
            }
            else {
                this.infoText = gettext(`<p class="p-b-8">
              The layout and configuration of this dashboard is used by all assets based on asset model <span class="tag tag--info text-12">{{ displayDeviceTypeValue }}</span>.
            </p>
            <p class="p-b-16">
              Disabling this option removes it from all assets based on the same model and makes it available only for the current instance.
            </p>`);
            }
        }
        else {
            if (this.isDevice) {
                this.infoText = gettext(`<p>Enabling this option uses the layout and configuration of this dashboard to create dashboard instances for all devices based on the type <span class="tag tag--info text-12">{{ displayDeviceTypeValue }}</span>.</p>`);
            }
            else {
                this.infoText = gettext(`<p>Enabling this option uses the layout and configuration of this dashboard to create dashboard instances for all assets based on the model <span class="tag tag--info text-12">{{ displayDeviceTypeValue }}</span>.</p>`);
            }
        }
    }
    async updateDeviceTypeCount() {
        const count = await this.inventory.count({
            type: this.deviceTypeValue
        });
        this.deviceTypeInstancesCount = count.data;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TypedDashboardSettingsComponent, deps: [{ token: i1$1.InventoryService }, { token: i2.InterAppService }, { token: i1.ActivatedRoute }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: TypedDashboardSettingsComponent, selector: "c8y-typed-dashboard-settings", inputs: { deviceTypeValue: "deviceTypeValue", displayDeviceTypeValue: "displayDeviceTypeValue", formInvalid: "formInvalid", mo: "mo", isDevice: "isDevice", allowTypeDashboard: "allowTypeDashboard" }, outputs: { onDuplicateWithoutType: "onDuplicateWithoutType" }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => TypedDashboardSettingsComponent),
                multi: true
            }
        ], ngImport: i0, template: "<fieldset class=\"c8y-fieldset c8y-fieldset--lg\">\n  <legend>{{ 'Dashboard template' | translate }}</legend>\n  <div class=\"d-flex p-b-16 gap-16\">\n    <label class=\"c8y-switch flex-no-shrink\">\n      <input\n        type=\"checkbox\"\n        [checked]=\"value\"\n        [disabled]=\"disabled\"\n        (click)=\"toggle()\"\n      />\n      <span></span>\n      <span>{{ typedDashboardStatus | translate }}</span>\n    </label>\n    <div class=\"flex-grow d-flex d-col\">\n      <div\n        class=\"flex-grow\"\n        [innerHtml]=\"infoText | translate: { displayDeviceTypeValue: displayDeviceTypeValue }\"\n      ></div>\n      <button\n        class=\"btn-link p-0 m-r-auto\"\n        type=\"button\"\n        *ngIf=\"allowTypeDashboard === 'allow_if_type_filled' && showSourceNavigationLink$ | async\"\n        (click)=\"goToDeviceView()\"\n      >\n        {{\n          deviceManagementLinkTitle\n            | translate\n              : {\n                  deviceManagementAppName:\n                    userDeviceManagementApp$ | async | humanizeAppName | async\n                }\n        }}\n        <i c8yIcon=\"external-link\"></i>\n      </button>\n    </div>\n  </div>\n\n  <c8y-type-dashboard-info\n    *ngIf=\"allowTypeDashboard === 'allow'\"\n    [context]=\"mo\"\n    [deviceTypeValue]=\"deviceTypeValue\"\n    [displayDeviceTypeValue]=\"displayDeviceTypeValue\"\n  ></c8y-type-dashboard-info>\n\n  <div\n    class=\"p-t-8 p-b-16\"\n    *ngIf=\"mo?.c8y_Dashboard && value\"\n  >\n    <button\n      class=\"btn btn-default btn-sm\"\n      type=\"button\"\n      (click)=\"onDuplicateWithoutType.emit()\"\n      [disabled]=\"formInvalid\"\n    >\n      {{ 'Duplicate as regular dashboard' | translate }}\n    </button>\n  </div>\n</fieldset>\n", dependencies: [{ kind: "directive", type: i2.IconDirective, selector: "[c8yIcon]", inputs: ["c8yIcon"] }, { kind: "directive", type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: TypeDashboardInfoComponent, selector: "c8y-type-dashboard-info", inputs: ["deviceTypeValue", "displayDeviceTypeValue", "context", "asyncRenderSuccess", "asyncRenderFail"] }, { kind: "pipe", type: i2.C8yTranslatePipe, name: "translate" }, { kind: "pipe", type: i4.AsyncPipe, name: "async" }, { kind: "pipe", type: i2.HumanizeAppNamePipe, name: "humanizeAppName" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TypedDashboardSettingsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-typed-dashboard-settings', providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => TypedDashboardSettingsComponent),
                            multi: true
                        }
                    ], template: "<fieldset class=\"c8y-fieldset c8y-fieldset--lg\">\n  <legend>{{ 'Dashboard template' | translate }}</legend>\n  <div class=\"d-flex p-b-16 gap-16\">\n    <label class=\"c8y-switch flex-no-shrink\">\n      <input\n        type=\"checkbox\"\n        [checked]=\"value\"\n        [disabled]=\"disabled\"\n        (click)=\"toggle()\"\n      />\n      <span></span>\n      <span>{{ typedDashboardStatus | translate }}</span>\n    </label>\n    <div class=\"flex-grow d-flex d-col\">\n      <div\n        class=\"flex-grow\"\n        [innerHtml]=\"infoText | translate: { displayDeviceTypeValue: displayDeviceTypeValue }\"\n      ></div>\n      <button\n        class=\"btn-link p-0 m-r-auto\"\n        type=\"button\"\n        *ngIf=\"allowTypeDashboard === 'allow_if_type_filled' && showSourceNavigationLink$ | async\"\n        (click)=\"goToDeviceView()\"\n      >\n        {{\n          deviceManagementLinkTitle\n            | translate\n              : {\n                  deviceManagementAppName:\n                    userDeviceManagementApp$ | async | humanizeAppName | async\n                }\n        }}\n        <i c8yIcon=\"external-link\"></i>\n      </button>\n    </div>\n  </div>\n\n  <c8y-type-dashboard-info\n    *ngIf=\"allowTypeDashboard === 'allow'\"\n    [context]=\"mo\"\n    [deviceTypeValue]=\"deviceTypeValue\"\n    [displayDeviceTypeValue]=\"displayDeviceTypeValue\"\n  ></c8y-type-dashboard-info>\n\n  <div\n    class=\"p-t-8 p-b-16\"\n    *ngIf=\"mo?.c8y_Dashboard && value\"\n  >\n    <button\n      class=\"btn btn-default btn-sm\"\n      type=\"button\"\n      (click)=\"onDuplicateWithoutType.emit()\"\n      [disabled]=\"formInvalid\"\n    >\n      {{ 'Duplicate as regular dashboard' | translate }}\n    </button>\n  </div>\n</fieldset>\n" }]
        }], ctorParameters: () => [{ type: i1$1.InventoryService }, { type: i2.InterAppService }, { type: i1.ActivatedRoute }], propDecorators: { deviceTypeValue: [{
                type: Input
            }], displayDeviceTypeValue: [{
                type: Input
            }], formInvalid: [{
                type: Input
            }], mo: [{
                type: Input
            }], isDevice: [{
                type: Input
            }], allowTypeDashboard: [{
                type: Input
            }], onDuplicateWithoutType: [{
                type: Output
            }] } });

class DashboardGeneralSettingsComponent {
    constructor(navigatorService) {
        this.navigatorService = navigatorService;
        this.onDuplicateWithoutType = new EventEmitter();
        this.priorityExampleLabel = gettext('e.g. {{ example }}');
        this.positionInTabsExampleLabel = gettext('Position in tabs (10000 first, -10000 last)');
    }
    ngOnInit() {
        this.navigatorNodes$ = this.navigatorService.items$;
        this.globalRolesIds = this.dashboard.globalRolesIds;
    }
    changeGlobalRoleIds() {
        this.generalSettingsForm.patchValue({ globalRolesIds: this.globalRolesIds });
        this.generalSettingsForm.markAsDirty();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardGeneralSettingsComponent, deps: [{ token: i2.NavigatorService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: DashboardGeneralSettingsComponent, selector: "c8y-dashboard-general-settings", inputs: { isReport: "isReport", isNamedDashboard: "isNamedDashboard", hideAvailability: "hideAvailability", dashboard: "dashboard", generalSettingsForm: "generalSettingsForm", deviceTypeValue: "deviceTypeValue", displayDeviceTypeValue: "displayDeviceTypeValue", allowTypeDashboard: "allowTypeDashboard", isDevice: "isDevice", mo: "mo" }, outputs: { onDuplicateWithoutType: "onDuplicateWithoutType" }, ngImport: i0, template: "<div\n  class=\"row\"\n  [formGroup]=\"generalSettingsForm\"\n>\n  <div\n    class=\"col-xs-12 p-b-24\"\n    [ngClass]=\"{ 'col-md-6': !isReport, 'col-md-8': isReport }\"\n    *ngIf=\"!isNamedDashboard || isReport\"\n  >\n    <fieldset class=\"c8y-fieldset c8y-fieldset--lg m-b-24\">\n      <legend>{{ 'Navigation' | translate }}</legend>\n      <div class=\"d-flex gap-16\">\n        <c8y-form-group>\n          <label>{{ 'Icon' | translate }}</label>\n          <c8y-icon-selector-wrapper\n            [iconSize]=\"24\"\n            name=\"icon\"\n            formControlName=\"icon\"\n          ></c8y-icon-selector-wrapper>\n        </c8y-form-group>\n        <c8y-form-group class=\"flex-grow\">\n          <label for=\"menuLabel\">\n            {{ 'Menu label' | translate }}\n            <button\n              class=\"btn-help btn-help--sm\"\n              [attr.aria-label]=\"'Help' | translate\"\n              popover=\"{{\n                'Menu label to display in submenu when dashboard is attached' | translate\n              }}\"\n              placement=\"right\"\n              triggers=\"focus\"\n              container=\"body\"\n              type=\"button\"\n            ></button>\n          </label>\n          <input\n            class=\"form-control\"\n            id=\"menuLabel\"\n            placeholder=\"{{ namePlaceholder | translate }}\"\n            name=\"name\"\n            type=\"text\"\n            formControlName=\"name\"\n          />\n        </c8y-form-group>\n      </div>\n\n      <c8y-form-group>\n        <label for=\"description\">{{ 'Description ' | translate }}</label>\n        <textarea\n          class=\"form-control\"\n          id=\"description\"\n          name=\"description\"\n          c8y-textarea-autoresize\n          formControlName=\"description\"\n        ></textarea>\n      </c8y-form-group>\n\n      <div class=\"row\">\n        <div\n          class=\"col-lg-7 col-xs-12\"\n          *ngIf=\"!isReport\"\n        >\n          <c8y-form-group>\n            <label for=\"position\">\n              {{ 'Position in tabs' | translate }}\n              <button\n                class=\"btn-help btn-help--sm\"\n                [attr.aria-label]=\"'Help' | translate\"\n                popover=\"{{ positionInTabsExampleLabel | translate }}\"\n                placement=\"right\"\n                triggers=\"focus\"\n                container=\"body\"\n                type=\"button\"\n              ></button>\n            </label>\n            <input\n              class=\"form-control\"\n              id=\"positionNav\"\n              placeholder=\"{{ priorityExampleLabel | translate: { example: '500' } }}\"\n              name=\"priority\"\n              for=\"position\"\n              type=\"number\"\n              formControlName=\"priority\"\n            />\n          </c8y-form-group>\n        </div>\n\n        <div\n          class=\"col-xs-6\"\n          *ngIf=\"isReport\"\n        >\n          <label translate>Navigator menu item</label>\n          <c8y-form-group>\n            <label\n              class=\"c8y-switch\"\n              title=\"{{ 'Show in navigator' | translate }}\"\n            >\n              <input\n                type=\"checkbox\"\n                formControlName=\"c8y_IsNavigatorNode\"\n              />\n              <span></span>\n              <span>{{ 'Show in navigator' | translate }}</span>\n            </label>\n          </c8y-form-group>\n        </div>\n\n        <div\n          class=\"col-xs-6\"\n          *ngIf=\"isReport && generalSettingsForm.value.c8y_IsNavigatorNode\"\n        >\n          <c8y-form-group>\n            <label\n              class=\"d-block\"\n              for=\"position\"\n            >\n              {{ 'Position in navigator' | translate }}\n              <ng-template #positionInNavPop>\n                <span>\n                  {{ positionInNavigationExampleLabel | translate }}&nbsp;\n                  {{ 'Existing nodes:' | translate }}\n                </span>\n                <ul class=\"list-unstyled m-t-16 m-b-0\">\n                  <li\n                    class=\"p-t-4 p-b-4\"\n                    title=\"{{ node.label | translate }}\"\n                    *ngFor=\"let node of navigatorNodes$ | async\"\n                  >\n                    <div class=\"icon-flex fit-w\">\n                      <i [c8yIcon]=\"node.icon\"></i>\n                      <span class=\"text-truncate m-l-4 m-r-16 flex-grow\">\n                        {{ node.label | translate }}\n                      </span>\n                      <span class=\"text-medium flex-no-shrink\">{{ node.priority }}</span>\n                    </div>\n                  </li>\n                </ul>\n              </ng-template>\n              <button\n                class=\"btn-help btn-help--sm\"\n                [attr.aria-label]=\"'Help' | translate\"\n                [popover]=\"positionInNavPop\"\n                placement=\"right\"\n                triggers=\"focus\"\n                container=\"body\"\n                type=\"button\"\n              ></button>\n            </label>\n            <input\n              class=\"form-control\"\n              placeholder=\"{{ priorityExampleLabel | translate: { example: '500' } }}\"\n              name=\"priority\"\n              for=\"position\"\n              type=\"number\"\n              formControlName=\"priority\"\n            />\n          </c8y-form-group>\n        </div>\n      </div>\n    </fieldset>\n    <c8y-dashboard-availability\n      *ngIf=\"\n        !!isReport === false &&\n        allowTypeDashboard &&\n        deviceTypeValue &&\n        generalSettingsForm.controls['deviceType'] &&\n        !hideAvailability\n      \"\n      [(globalRolesIds)]=\"globalRolesIds\"\n      (globalRolesIdsChange)=\"changeGlobalRoleIds()\"\n    ></c8y-dashboard-availability>\n  </div>\n\n  <div class=\"col-xs-12 col-md-6 p-b-24\">\n    <c8y-typed-dashboard-settings\n      *ngIf=\"allowTypeDashboard !== 'disallow'\"\n      formControlName=\"deviceType\"\n      [deviceTypeValue]=\"deviceTypeValue\"\n      [displayDeviceTypeValue]=\"displayDeviceTypeValue\"\n      [formInvalid]=\"generalSettingsForm.invalid\"\n      [mo]=\"mo\"\n      [isDevice]=\"isDevice\"\n      [allowTypeDashboard]=\"allowTypeDashboard\"\n      (onDuplicateWithoutType)=\"onDuplicateWithoutType.emit()\"\n    ></c8y-typed-dashboard-settings>\n    <c8y-dashboard-availability\n      *ngIf=\"\n        !!isReport === false &&\n        (!allowTypeDashboard || !deviceTypeValue || !generalSettingsForm.controls['deviceType']) &&\n        !hideAvailability\n      \"\n      [(globalRolesIds)]=\"globalRolesIds\"\n      (globalRolesIdsChange)=\"changeGlobalRoleIds()\"\n    ></c8y-dashboard-availability>\n  </div>\n</div>\n", dependencies: [{ kind: "directive", type: i2.IconDirective, selector: "[c8yIcon]", inputs: ["c8yIcon"] }, { kind: "directive", type: i2.C8yTranslateDirective, selector: "[translate],[ngx-translate]" }, { kind: "directive", type: i4.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.TextareaAutoresizeDirective, selector: "[c8y-textarea-autoresize]" }, { kind: "directive", type: i3.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i3.NumberValueAccessor, selector: "input[type=number][formControlName],input[type=number][formControl],input[type=number][ngModel]" }, { kind: "directive", type: i3.CheckboxControlValueAccessor, selector: "input[type=checkbox][formControlName],input[type=checkbox][formControl],input[type=checkbox][ngModel]" }, { kind: "directive", type: i3.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i3.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "component", type: i2.FormGroupComponent, selector: "c8y-form-group", inputs: ["hasError", "hasWarning", "hasSuccess", "novalidation", "status"] }, { kind: "directive", type: i2.RequiredInputPlaceholderDirective, selector: "input[required], input[formControlName]" }, { kind: "directive", type: i3.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i3.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "directive", type: i4$1.PopoverDirective, selector: "[popover]", inputs: ["adaptivePosition", "boundariesElement", "popover", "popoverContext", "popoverTitle", "placement", "outsideClick", "triggers", "container", "containerClass", "isOpen", "delay"], outputs: ["onShown", "onHidden"], exportAs: ["bs-popover"] }, { kind: "component", type: i5.IconSelectorWrapperComponent, selector: "c8y-icon-selector-wrapper", inputs: ["canRemoveIcon", "selectedIcon", "iconSize"], outputs: ["onSelect"] }, { kind: "component", type: DashboardAvailabilityComponent, selector: "c8y-dashboard-availability", inputs: ["globalRolesIds"], outputs: ["globalRolesIdsChange"] }, { kind: "component", type: TypedDashboardSettingsComponent, selector: "c8y-typed-dashboard-settings", inputs: ["deviceTypeValue", "displayDeviceTypeValue", "formInvalid", "mo", "isDevice", "allowTypeDashboard"], outputs: ["onDuplicateWithoutType"] }, { kind: "pipe", type: i2.C8yTranslatePipe, name: "translate" }, { kind: "pipe", type: i4.AsyncPipe, name: "async" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardGeneralSettingsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-dashboard-general-settings', template: "<div\n  class=\"row\"\n  [formGroup]=\"generalSettingsForm\"\n>\n  <div\n    class=\"col-xs-12 p-b-24\"\n    [ngClass]=\"{ 'col-md-6': !isReport, 'col-md-8': isReport }\"\n    *ngIf=\"!isNamedDashboard || isReport\"\n  >\n    <fieldset class=\"c8y-fieldset c8y-fieldset--lg m-b-24\">\n      <legend>{{ 'Navigation' | translate }}</legend>\n      <div class=\"d-flex gap-16\">\n        <c8y-form-group>\n          <label>{{ 'Icon' | translate }}</label>\n          <c8y-icon-selector-wrapper\n            [iconSize]=\"24\"\n            name=\"icon\"\n            formControlName=\"icon\"\n          ></c8y-icon-selector-wrapper>\n        </c8y-form-group>\n        <c8y-form-group class=\"flex-grow\">\n          <label for=\"menuLabel\">\n            {{ 'Menu label' | translate }}\n            <button\n              class=\"btn-help btn-help--sm\"\n              [attr.aria-label]=\"'Help' | translate\"\n              popover=\"{{\n                'Menu label to display in submenu when dashboard is attached' | translate\n              }}\"\n              placement=\"right\"\n              triggers=\"focus\"\n              container=\"body\"\n              type=\"button\"\n            ></button>\n          </label>\n          <input\n            class=\"form-control\"\n            id=\"menuLabel\"\n            placeholder=\"{{ namePlaceholder | translate }}\"\n            name=\"name\"\n            type=\"text\"\n            formControlName=\"name\"\n          />\n        </c8y-form-group>\n      </div>\n\n      <c8y-form-group>\n        <label for=\"description\">{{ 'Description ' | translate }}</label>\n        <textarea\n          class=\"form-control\"\n          id=\"description\"\n          name=\"description\"\n          c8y-textarea-autoresize\n          formControlName=\"description\"\n        ></textarea>\n      </c8y-form-group>\n\n      <div class=\"row\">\n        <div\n          class=\"col-lg-7 col-xs-12\"\n          *ngIf=\"!isReport\"\n        >\n          <c8y-form-group>\n            <label for=\"position\">\n              {{ 'Position in tabs' | translate }}\n              <button\n                class=\"btn-help btn-help--sm\"\n                [attr.aria-label]=\"'Help' | translate\"\n                popover=\"{{ positionInTabsExampleLabel | translate }}\"\n                placement=\"right\"\n                triggers=\"focus\"\n                container=\"body\"\n                type=\"button\"\n              ></button>\n            </label>\n            <input\n              class=\"form-control\"\n              id=\"positionNav\"\n              placeholder=\"{{ priorityExampleLabel | translate: { example: '500' } }}\"\n              name=\"priority\"\n              for=\"position\"\n              type=\"number\"\n              formControlName=\"priority\"\n            />\n          </c8y-form-group>\n        </div>\n\n        <div\n          class=\"col-xs-6\"\n          *ngIf=\"isReport\"\n        >\n          <label translate>Navigator menu item</label>\n          <c8y-form-group>\n            <label\n              class=\"c8y-switch\"\n              title=\"{{ 'Show in navigator' | translate }}\"\n            >\n              <input\n                type=\"checkbox\"\n                formControlName=\"c8y_IsNavigatorNode\"\n              />\n              <span></span>\n              <span>{{ 'Show in navigator' | translate }}</span>\n            </label>\n          </c8y-form-group>\n        </div>\n\n        <div\n          class=\"col-xs-6\"\n          *ngIf=\"isReport && generalSettingsForm.value.c8y_IsNavigatorNode\"\n        >\n          <c8y-form-group>\n            <label\n              class=\"d-block\"\n              for=\"position\"\n            >\n              {{ 'Position in navigator' | translate }}\n              <ng-template #positionInNavPop>\n                <span>\n                  {{ positionInNavigationExampleLabel | translate }}&nbsp;\n                  {{ 'Existing nodes:' | translate }}\n                </span>\n                <ul class=\"list-unstyled m-t-16 m-b-0\">\n                  <li\n                    class=\"p-t-4 p-b-4\"\n                    title=\"{{ node.label | translate }}\"\n                    *ngFor=\"let node of navigatorNodes$ | async\"\n                  >\n                    <div class=\"icon-flex fit-w\">\n                      <i [c8yIcon]=\"node.icon\"></i>\n                      <span class=\"text-truncate m-l-4 m-r-16 flex-grow\">\n                        {{ node.label | translate }}\n                      </span>\n                      <span class=\"text-medium flex-no-shrink\">{{ node.priority }}</span>\n                    </div>\n                  </li>\n                </ul>\n              </ng-template>\n              <button\n                class=\"btn-help btn-help--sm\"\n                [attr.aria-label]=\"'Help' | translate\"\n                [popover]=\"positionInNavPop\"\n                placement=\"right\"\n                triggers=\"focus\"\n                container=\"body\"\n                type=\"button\"\n              ></button>\n            </label>\n            <input\n              class=\"form-control\"\n              placeholder=\"{{ priorityExampleLabel | translate: { example: '500' } }}\"\n              name=\"priority\"\n              for=\"position\"\n              type=\"number\"\n              formControlName=\"priority\"\n            />\n          </c8y-form-group>\n        </div>\n      </div>\n    </fieldset>\n    <c8y-dashboard-availability\n      *ngIf=\"\n        !!isReport === false &&\n        allowTypeDashboard &&\n        deviceTypeValue &&\n        generalSettingsForm.controls['deviceType'] &&\n        !hideAvailability\n      \"\n      [(globalRolesIds)]=\"globalRolesIds\"\n      (globalRolesIdsChange)=\"changeGlobalRoleIds()\"\n    ></c8y-dashboard-availability>\n  </div>\n\n  <div class=\"col-xs-12 col-md-6 p-b-24\">\n    <c8y-typed-dashboard-settings\n      *ngIf=\"allowTypeDashboard !== 'disallow'\"\n      formControlName=\"deviceType\"\n      [deviceTypeValue]=\"deviceTypeValue\"\n      [displayDeviceTypeValue]=\"displayDeviceTypeValue\"\n      [formInvalid]=\"generalSettingsForm.invalid\"\n      [mo]=\"mo\"\n      [isDevice]=\"isDevice\"\n      [allowTypeDashboard]=\"allowTypeDashboard\"\n      (onDuplicateWithoutType)=\"onDuplicateWithoutType.emit()\"\n    ></c8y-typed-dashboard-settings>\n    <c8y-dashboard-availability\n      *ngIf=\"\n        !!isReport === false &&\n        (!allowTypeDashboard || !deviceTypeValue || !generalSettingsForm.controls['deviceType']) &&\n        !hideAvailability\n      \"\n      [(globalRolesIds)]=\"globalRolesIds\"\n      (globalRolesIdsChange)=\"changeGlobalRoleIds()\"\n    ></c8y-dashboard-availability>\n  </div>\n</div>\n" }]
        }], ctorParameters: () => [{ type: i2.NavigatorService }], propDecorators: { isReport: [{
                type: Input
            }], isNamedDashboard: [{
                type: Input
            }], hideAvailability: [{
                type: Input
            }], dashboard: [{
                type: Input
            }], generalSettingsForm: [{
                type: Input
            }], deviceTypeValue: [{
                type: Input
            }], displayDeviceTypeValue: [{
                type: Input
            }], allowTypeDashboard: [{
                type: Input
            }], isDevice: [{
                type: Input
            }], mo: [{
                type: Input
            }], onDuplicateWithoutType: [{
                type: Output
            }] } });

class DashboardAppearanceSettingsComponent {
    constructor(contextDashboardService) {
        this.contextDashboardService = contextDashboardService;
        this.styling = {
            themeClass: 'dashboard-theme-light',
            headerClass: 'panel-title-regular'
        };
        this.previewChanged = new EventEmitter();
        this.DEFAULT_DASHBOARD_MARGIN = 12;
    }
    ngOnInit() {
        if (this.dashboard) {
            this.setDashboardStyle();
        }
    }
    ngOnChanges(changes) {
        if (changes.dashboard) {
            this.dashboard = changes.dashboard.currentValue;
            this.ngOnInit();
        }
    }
    changeThemeClass(themeClass) {
        this.styling.themeClass = themeClass;
        this.appearanceSettingsForm.patchValue({ classes: { [this.styling.themeClass]: true } });
        this.previewChanged.emit({ classes: { [this.styling.themeClass]: true } });
        this.appearanceSettingsForm.markAsDirty();
    }
    changeHeaderClass(headerClass) {
        this.styling.headerClass = headerClass;
        this.appearanceSettingsForm.patchValue({ widgetClasses: { [this.styling.headerClass]: true } });
        this.previewChanged.emit({ widgetClasses: { [this.styling.headerClass]: true } });
        this.appearanceSettingsForm.markAsDirty();
    }
    setDashboardStyle() {
        const allClasses = {
            ...this.dashboard.classes,
            ...this.dashboard.widgetClasses
        };
        const styles = Object.keys(allClasses).map(c => c.split('-').pop());
        styles.forEach(styleName => {
            this.styling.themeClass = this.contextDashboardService.getStyling(DASHBOARD_THEME_CLASSES, styleName, this.styling.themeClass);
            this.styling.headerClass = this.contextDashboardService.getStyling(WIDGET_HEADER_CLASSES, styleName, this.styling.headerClass);
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardAppearanceSettingsComponent, deps: [{ token: ContextDashboardService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: DashboardAppearanceSettingsComponent, selector: "c8y-dashboard-appearance-settings", inputs: { dashboard: "dashboard", appearanceSettingsForm: "appearanceSettingsForm" }, outputs: { previewChanged: "previewChanged" }, usesOnChanges: true, ngImport: i0, template: "<div [formGroup]=\"appearanceSettingsForm\">\n  <c8y-appearance-settings\n    [themeClass]=\"styling.themeClass\"\n    [headerClass]=\"styling.headerClass\"\n    (themeClassChange)=\"changeThemeClass($event)\"\n    (headerClassChange)=\"changeHeaderClass($event)\"\n    [dashboardSettings]=\"true\"\n    [columns]=\"3\"\n  >\n    <div class=\"col-md-4\">\n      <fieldset class=\"c8y-fieldset c8y-fieldset--lg\">\n        <legend translate>Misc</legend>\n        <c8y-form-group>\n          <label for=\"margin\">{{ 'Widget margin' | translate }}</label>\n          <div class=\"input-group\">\n            <input\n              class=\"form-control\"\n              id=\"margin\"\n              placeholder=\"{{ DEFAULT_DASHBOARD_MARGIN }}\"\n              name=\"margin\"\n              type=\"number\"\n              formControlName=\"widgetMargin\"\n            />\n            <span class=\"input-group-addon\">px</span>\n          </div>\n        </c8y-form-group>\n\n        <c8y-form-group>\n          <label translate>Widget titles</label>\n          <label\n            class=\"c8y-checkbox\"\n            title=\"{{ 'Translate if possible' | translate }}\"\n          >\n            <input\n              name=\"translateWidgetTitle\"\n              type=\"checkbox\"\n              formControlName=\"translateWidgetTitle\"\n            />\n            <span></span>\n            <span>{{ 'Translate if possible' | translate }}</span>\n          </label>\n        </c8y-form-group>\n      </fieldset>\n    </div>\n  </c8y-appearance-settings>\n</div>\n", dependencies: [{ kind: "directive", type: i2.C8yTranslateDirective, selector: "[translate],[ngx-translate]" }, { kind: "directive", type: i3.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i3.NumberValueAccessor, selector: "input[type=number][formControlName],input[type=number][formControl],input[type=number][ngModel]" }, { kind: "directive", type: i3.CheckboxControlValueAccessor, selector: "input[type=checkbox][formControlName],input[type=checkbox][formControl],input[type=checkbox][ngModel]" }, { kind: "directive", type: i3.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i3.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "component", type: i2.FormGroupComponent, selector: "c8y-form-group", inputs: ["hasError", "hasWarning", "hasSuccess", "novalidation", "status"] }, { kind: "directive", type: i2.RequiredInputPlaceholderDirective, selector: "input[required], input[formControlName]" }, { kind: "directive", type: i3.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i3.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "component", type: AppearanceSettingsComponent, selector: "c8y-appearance-settings", inputs: ["themeClass", "headerClass", "defaultThemeClass", "defaultHeaderClass", "dashboardSettings", "possibleStylingTheme", "possibleStylingHeader", "columns"], outputs: ["themeClassChange", "headerClassChange"] }, { kind: "pipe", type: i2.C8yTranslatePipe, name: "translate" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardAppearanceSettingsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-dashboard-appearance-settings', template: "<div [formGroup]=\"appearanceSettingsForm\">\n  <c8y-appearance-settings\n    [themeClass]=\"styling.themeClass\"\n    [headerClass]=\"styling.headerClass\"\n    (themeClassChange)=\"changeThemeClass($event)\"\n    (headerClassChange)=\"changeHeaderClass($event)\"\n    [dashboardSettings]=\"true\"\n    [columns]=\"3\"\n  >\n    <div class=\"col-md-4\">\n      <fieldset class=\"c8y-fieldset c8y-fieldset--lg\">\n        <legend translate>Misc</legend>\n        <c8y-form-group>\n          <label for=\"margin\">{{ 'Widget margin' | translate }}</label>\n          <div class=\"input-group\">\n            <input\n              class=\"form-control\"\n              id=\"margin\"\n              placeholder=\"{{ DEFAULT_DASHBOARD_MARGIN }}\"\n              name=\"margin\"\n              type=\"number\"\n              formControlName=\"widgetMargin\"\n            />\n            <span class=\"input-group-addon\">px</span>\n          </div>\n        </c8y-form-group>\n\n        <c8y-form-group>\n          <label translate>Widget titles</label>\n          <label\n            class=\"c8y-checkbox\"\n            title=\"{{ 'Translate if possible' | translate }}\"\n          >\n            <input\n              name=\"translateWidgetTitle\"\n              type=\"checkbox\"\n              formControlName=\"translateWidgetTitle\"\n            />\n            <span></span>\n            <span>{{ 'Translate if possible' | translate }}</span>\n          </label>\n        </c8y-form-group>\n      </fieldset>\n    </div>\n  </c8y-appearance-settings>\n</div>\n" }]
        }], ctorParameters: () => [{ type: ContextDashboardService }], propDecorators: { dashboard: [{
                type: Input
            }], appearanceSettingsForm: [{
                type: Input
            }], previewChanged: [{
                type: Output
            }] } });

class DashboardVersionHistoryComponent {
    constructor(translateService, contextDashboardService) {
        this.translateService = translateService;
        this.contextDashboardService = contextDashboardService;
        this.dashboardHistory = [];
        this.onRevert = new EventEmitter();
        this.dashboardHistoryExtended = [];
        this.restoredDashboardMessage = gettext('Restored dashboard state from {{ restoredStateCreationDate }}');
        this.versionHistoryLimitMessage = gettext('Store up to {{ versionHistoryLimit }} dashboard versions. Any additional versions will replace/delete older ones');
    }
    ngOnInit() {
        this.generateDashboardHistoryDescription();
    }
    generateDashboardHistoryDescription() {
        for (const dashboard of this.dashboardHistory) {
            const copiedDashboard = { ...dashboard };
            let settingChangesMessage = '';
            let assetModelMessage = '';
            let widgetChanges = '';
            if (dashboard.historyDescription.changeType === 'create') {
                copiedDashboard.descriptionText = this.translateService.instant(this.isReport ? gettext('Report created.') : gettext('Dashboard created.'));
                this.dashboardHistoryExtended.push(copiedDashboard);
                continue;
            }
            if (dashboard.historyDescription.changeType === 'reset') {
                copiedDashboard.descriptionText = this.translateService.instant(gettext('Reset widgets'));
                this.dashboardHistoryExtended.push(copiedDashboard);
                continue;
            }
            const isDashboardUpdated = dashboard.historyDescription.dashboardSettingChanges?.length > 0;
            if (isDashboardUpdated) {
                const translatedValuesChanged = dashboard.historyDescription.dashboardSettingChanges
                    .map(val => this.translateService.instant(val))
                    .join(', ');
                settingChangesMessage = this.translateService.instant(this.isReport
                    ? gettext('Report updated: {{ values }}.')
                    : gettext('Dashboard updated: {{ values }}.'), { values: translatedValuesChanged });
            }
            const isDeviceDashboard = dashboard.historyDescription.deviceType != null && !this.isReport;
            if (isDeviceDashboard) {
                assetModelMessage = this.translateService.instant(dashboard.historyDescription.deviceType
                    ? gettext('Dashboard asset model has been enabled.')
                    : gettext('Dashboard asset model has been disabled.'));
            }
            if (dashboard.historyDescription.widgetChanges) {
                for (const change in dashboard.historyDescription.widgetChanges) {
                    const widgetList = dashboard.historyDescription.widgetChanges[change];
                    if (!widgetList) {
                        continue;
                    }
                    const translatedWidgetList = dashboard.translateWidgetTitle
                        ? widgetList.map(widget => this.translateService.instant(widget))
                        : widgetList;
                    switch (change) {
                        case 'added':
                            widgetChanges =
                                widgetChanges +
                                    this.translateService.instant(gettext('Added widgets: {{ widgetList }}. '), {
                                        widgetList: `"${translatedWidgetList.join('", "')}"`
                                    });
                            break;
                        case 'removed':
                            widgetChanges =
                                widgetChanges +
                                    this.translateService.instant(gettext('Removed widgets: {{ widgetList }}. '), {
                                        widgetList: `"${translatedWidgetList.join('", "')}"`
                                    });
                            break;
                        case 'config':
                            widgetChanges =
                                widgetChanges +
                                    this.translateService.instant(gettext('Updated widgets: {{ widgetList }}. '), {
                                        widgetList: `"${translatedWidgetList.join('", "')}"`
                                    });
                            break;
                        case 'arrangement':
                            widgetChanges =
                                widgetChanges +
                                    this.translateService.instant(gettext('Rearranged widgets: {{ widgetList }}. '), {
                                        widgetList: `"${translatedWidgetList.join('", "')}"`
                                    });
                            break;
                        default:
                            break;
                    }
                }
            }
            copiedDashboard.descriptionText = `${settingChangesMessage} ${assetModelMessage} ${widgetChanges}`;
            this.dashboardHistoryExtended.push(copiedDashboard);
        }
    }
    revertDashboard(dashboard) {
        const newDashboard = cloneDeep(dashboard);
        newDashboard.historyDescription.restored = dashboard.created;
        this.onRevert.emit(newDashboard);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardVersionHistoryComponent, deps: [{ token: i2$1.TranslateService }, { token: ContextDashboardService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: DashboardVersionHistoryComponent, selector: "c8y-dashboard-version-history", inputs: { dashboardHistory: "dashboardHistory", isReport: "isReport" }, outputs: { onRevert: "onRevert" }, ngImport: i0, template: "<div class=\"bg-component p-t-8 p-b-8 separator-bottom text-center\">\n  <i\n    class=\"text-info m-r-4\"\n    c8yIcon=\"info\"\n  ></i>\n  {{\n    versionHistoryLimitMessage\n      | translate: { versionHistoryLimit: contextDashboardService.VERSION_HISTORY_SIZE_LIMIT }\n  }}\n</div>\n<c8y-list-group class=\"p-t-24 p-b-24\">\n  <c8y-li-timeline\n    *ngFor=\"let dashboard of dashboardHistoryExtended; index as i\"\n    [ngClass]=\"{ active: i === 0 }\"\n  >\n    {{ dashboard.created | date: 'mediumDate' }}\n    {{ dashboard.created | date: 'shortTime' }}\n    <c8y-li data-cy=\"c8y-dashboard-version-history--history-row\">\n      <c8y-li-body>\n        <div class=\"d-flex a-i-start\">\n          <div class=\"flex-grow\">\n            <span\n              class=\"text-truncate-wrap\"\n              title=\"{{ dashboard.descriptionText }}\"\n              data-cy=\"c8y-dashboard-version-history--history-title\"\n            >\n              {{ dashboard.descriptionText }}\n              {{\n                dashboard.historyDescription.restored\n                  ? (restoredDashboardMessage\n                    | translate\n                      : {\n                          restoredStateCreationDate: dashboard.historyDescription.restored | c8yDate\n                        })\n                  : ''\n              }}\n            </span>\n            <small\n              class=\"text-muted\"\n              title=\"{{ 'by`user`' | translate }} {{ dashboard.author }}\"\n              *ngIf=\"dashboard.author\"\n            >\n              <div class=\"icon-flex\">\n                <i c8yIcon=\"c8y-user\"></i>\n                {{ dashboard.author }}\n              </div>\n            </small>\n          </div>\n\n          <span\n            class=\"label label-primary m-l-auto\"\n            title=\"{{ 'The last saved status of the dashboard' | translate }}\"\n            *ngIf=\"i === 0\"\n          >\n            {{ 'Current`dashboard status`' | translate }}\n          </span>\n          <span\n            class=\"m-l-auto showOnHover\"\n            *ngIf=\"dashboardHistoryExtended.length > 1 && i > 0\"\n          >\n            <button\n              class=\"btn btn-default btn-sm\"\n              title=\"{{ 'Restore the dashboard to this status' | translate }}\"\n              type=\"button\"\n              (click)=\"revertDashboard(dashboard)\"\n            >\n              {{ 'Restore' | translate }}\n            </button>\n          </span>\n        </div>\n      </c8y-li-body>\n    </c8y-li>\n  </c8y-li-timeline>\n</c8y-list-group>\n", dependencies: [{ kind: "directive", type: i2.IconDirective, selector: "[c8yIcon]", inputs: ["c8yIcon"] }, { kind: "directive", type: i4.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i2.ListGroupComponent, selector: "c8y-list-group" }, { kind: "component", type: i2.ListItemComponent, selector: "c8y-list-item, c8y-li", inputs: ["active", "highlighted", "emptyActions", "dense", "collapsed", "selectable"], outputs: ["collapsedChange"] }, { kind: "component", type: i2.ListItemBodyComponent, selector: "c8y-list-item-body, c8y-li-body", inputs: ["body"] }, { kind: "component", type: i2.ListItemTimelineComponent, selector: "c8y-list-item-timeline, c8y-li-timeline" }, { kind: "pipe", type: i2.C8yTranslatePipe, name: "translate" }, { kind: "pipe", type: i4.DatePipe, name: "date" }, { kind: "pipe", type: i2.DatePipe, name: "c8yDate" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardVersionHistoryComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-dashboard-version-history', template: "<div class=\"bg-component p-t-8 p-b-8 separator-bottom text-center\">\n  <i\n    class=\"text-info m-r-4\"\n    c8yIcon=\"info\"\n  ></i>\n  {{\n    versionHistoryLimitMessage\n      | translate: { versionHistoryLimit: contextDashboardService.VERSION_HISTORY_SIZE_LIMIT }\n  }}\n</div>\n<c8y-list-group class=\"p-t-24 p-b-24\">\n  <c8y-li-timeline\n    *ngFor=\"let dashboard of dashboardHistoryExtended; index as i\"\n    [ngClass]=\"{ active: i === 0 }\"\n  >\n    {{ dashboard.created | date: 'mediumDate' }}\n    {{ dashboard.created | date: 'shortTime' }}\n    <c8y-li data-cy=\"c8y-dashboard-version-history--history-row\">\n      <c8y-li-body>\n        <div class=\"d-flex a-i-start\">\n          <div class=\"flex-grow\">\n            <span\n              class=\"text-truncate-wrap\"\n              title=\"{{ dashboard.descriptionText }}\"\n              data-cy=\"c8y-dashboard-version-history--history-title\"\n            >\n              {{ dashboard.descriptionText }}\n              {{\n                dashboard.historyDescription.restored\n                  ? (restoredDashboardMessage\n                    | translate\n                      : {\n                          restoredStateCreationDate: dashboard.historyDescription.restored | c8yDate\n                        })\n                  : ''\n              }}\n            </span>\n            <small\n              class=\"text-muted\"\n              title=\"{{ 'by`user`' | translate }} {{ dashboard.author }}\"\n              *ngIf=\"dashboard.author\"\n            >\n              <div class=\"icon-flex\">\n                <i c8yIcon=\"c8y-user\"></i>\n                {{ dashboard.author }}\n              </div>\n            </small>\n          </div>\n\n          <span\n            class=\"label label-primary m-l-auto\"\n            title=\"{{ 'The last saved status of the dashboard' | translate }}\"\n            *ngIf=\"i === 0\"\n          >\n            {{ 'Current`dashboard status`' | translate }}\n          </span>\n          <span\n            class=\"m-l-auto showOnHover\"\n            *ngIf=\"dashboardHistoryExtended.length > 1 && i > 0\"\n          >\n            <button\n              class=\"btn btn-default btn-sm\"\n              title=\"{{ 'Restore the dashboard to this status' | translate }}\"\n              type=\"button\"\n              (click)=\"revertDashboard(dashboard)\"\n            >\n              {{ 'Restore' | translate }}\n            </button>\n          </span>\n        </div>\n      </c8y-li-body>\n    </c8y-li>\n  </c8y-li-timeline>\n</c8y-list-group>\n" }]
        }], ctorParameters: () => [{ type: i2$1.TranslateService }, { type: ContextDashboardService }], propDecorators: { dashboardHistory: [{
                type: Input
            }], isReport: [{
                type: Input
            }], onRevert: [{
                type: Output
            }] } });

class DashboardDetailComponent {
    constructor(contextDashboardService, translateService, contextRoute, activatedRoute, tabsService, router, inventory, route, dashboardDetailService, appState, groupService, modal, gainsightService) {
        this.contextDashboardService = contextDashboardService;
        this.translateService = translateService;
        this.contextRoute = contextRoute;
        this.activatedRoute = activatedRoute;
        this.tabsService = tabsService;
        this.router = router;
        this.inventory = inventory;
        this.route = route;
        this.dashboardDetailService = dashboardDetailService;
        this.appState = appState;
        this.groupService = groupService;
        this.modal = modal;
        this.gainsightService = gainsightService;
        this.isCollapsed = true;
        this.hideAvailability = false;
        this.selectedTab = DashboardDetailsTabId.GENERAL;
        this.dashboardSaved = new EventEmitter();
        this.previewChanged = new EventEmitter();
        this.destroy$ = new Subject();
        this.TABS_OUTLET_NAME = 'dashboardTabs';
        this.TABS = {
            general: {
                featureId: DashboardDetailsTabId.GENERAL,
                priority: 30,
                label: gettext('General')
            },
            appearance: {
                featureId: DashboardDetailsTabId.APPEARANCE,
                priority: 20,
                label: gettext('Appearance')
            },
            versionHistory: {
                featureId: DashboardDetailsTabId.VERSIONHISTORY,
                priority: 10,
                label: gettext('Version history')
            }
        };
    }
    ngOnInit() {
        this.tabs$ = this.tabsService.items$;
        this.currentContext = this.contextRoute.getContextData(this.activatedRoute);
        this.deviceTypeValue = this.context?.type;
        this.displayDeviceTypeValue =
            this.context &&
                this.groupService.isGroup(this.context) &&
                !this.groupService.isAsset(this.context)
                ? this.translateService.instant(gettext('Group'))
                : this.deviceTypeValue;
        this.updateAllowTypeDashboard();
        this.initForm();
    }
    ngOnChanges() {
        this.updateAllowTypeDashboard();
    }
    ngAfterContentInit() {
        if (!this.isEdit) {
            this.initializeConfiguration();
        }
    }
    ngOnDestroy() {
        this.destroy$.next();
        this.destroy$.complete();
    }
    async save() {
        const oldDashboard = cloneDeep(this.dashboard);
        this.dashboard = {
            ...this.dashboard,
            ...this.generalSettingsForm.value,
            ...this.appearanceSettingsForm.value
        };
        const dashboardSettingChanges = Object.keys(this.dashboard).filter(key => {
            if (key === 'c8y_IsNavigatorNode') {
                return !!oldDashboard[key] !== !!this.dashboard[key];
            }
            return !isEqual(oldDashboard[key], this.dashboard[key]);
        });
        this.dashboard.author = this.appState.currentUser.value.userName;
        this.dashboard.c8y_IsNavigatorNode = this.dashboard.c8y_IsNavigatorNode
            ? {}
            : this.currentDashboard
                ? null
                : undefined;
        this.dashboard.deviceTypeValue ??= this.deviceTypeValue;
        this.dashboard.historyDescription =
            this.updateDashboardHistoryDescription(dashboardSettingChanges);
        if (!this.isEdit && !this.isReport) {
            await this.createNewDashboard();
        }
        else if (!this.isEdit && this.isReport) {
            await this.createNewReport();
        }
        else {
            await this.updateDashboard();
            this.mo.c8y_DashboardHistory = [
                this.dashboard,
                ...(this.mo?.c8y_DashboardHistory ? this.mo.c8y_DashboardHistory : [])
            ];
        }
    }
    updateDashboardHistoryDescription(dashboardChanges) {
        return {
            changeType: this.isEdit ? 'update' : 'create',
            dashboardSettingChanges: dashboardChanges
                .filter(value => value !== 'deviceType')
                .map(value => DASHBOARD_SETTINGS_CHANGES[value] || value),
            deviceType: dashboardChanges.find(value => value === 'deviceType')
                ? this.dashboard.deviceType
                : undefined
        };
    }
    selectTab(selectedTab) {
        this.selectedTab = selectedTab;
        this.tabsService.refresh();
    }
    async cancel() {
        if (!this.isEdit && !this.isReport) {
            // dashboard creation in it's own tab- confirm and cleanup triggered in canDeactivate during routing
            this.tabsService.items$.pipe(first()).subscribe((tabs) => {
                const tab = tabs.find(t => t.featureId !== newDashboardTab.featureId);
                this.router.navigate(typeof tab.path === 'string' ? [tab.path] : tab.path, {
                    replaceUrl: true
                });
            });
            return;
        }
        else if (!this.isEdit && this.isReport) {
            this.router.navigate(['reports']);
            return;
        }
        else if (this.dashboardDetailsForm.dirty && !(await this.confirmClosing())) {
            return;
        }
        this.cleanupAfterDetailsClose();
    }
    async canDeactivate(omitConfirm = false) {
        let canDeactivate;
        if (this.isCollapsed || !this.dashboardDetailsForm.dirty) {
            canDeactivate = true;
        }
        else {
            if (omitConfirm) {
                canDeactivate = false;
            }
            else {
                canDeactivate = await this.confirmClosing();
            }
        }
        if (canDeactivate) {
            this.cleanupAfterDetailsClose();
        }
        return canDeactivate;
    }
    show(isEdit) {
        this.isEdit = isEdit;
        if (this.isEdit) {
            this.edit();
        }
        this.initForm();
        this.isCollapsed = false;
    }
    async revertDashboard(dashboard) {
        this.dashboard = dashboard;
        this.dashboard.c8y_IsNavigatorNode = this.dashboard.c8y_IsNavigatorNode
            ? {}
            : this.currentDashboard
                ? null
                : undefined;
        await this.updateDashboard();
    }
    async duplicateWithoutType() {
        const newDashboardName = this.translateService.instant(gettext('{{ dashboardName }} (copy)'), {
            dashboardName: this.generalSettingsForm.value.name
        });
        this.generalSettingsForm.patchValue({
            deviceType: false,
            name: newDashboardName
        });
        // setting edition to false so new dashboard can be created as copy of current one
        this.isEdit = false;
        await this.save();
    }
    updateAllowTypeDashboard() {
        this.allowTypeDashboard = this.contextDashboardService.shouldAllowToSetDashboardType(this.mo, this.currentContext);
    }
    initForm() {
        this.dashboardDetailsForm = this.dashboardDetailService.initForm(this.dashboard, this.isReport, this.allowTypeDashboard);
        this.generalSettingsForm = this.dashboardDetailsForm.get('generalSettingsForm');
        this.appearanceSettingsForm = this.dashboardDetailsForm.get('appearanceSettingsForm');
    }
    async confirmClosing() {
        try {
            await this.modal.confirm(gettext('Close dashboard details'), gettext('Are you sure you want to close dashboard details? All unsaved changes will be lost.'), Status.WARNING, {
                ok: gettext('Close'),
                cancel: gettext('Cancel')
            });
            return true;
        }
        catch (e) {
            return false;
        }
    }
    async createNewDashboard() {
        const mo = await this.contextDashboardService.create(this.dashboard, this.currentContext);
        await this.onCreateGSEvent(mo);
        this.cleanupAfterDetailsClose();
        await this.contextDashboardService.navigateToDashboard(mo, true);
    }
    async onCreateGSEvent(mo) {
        const parentName = await this.convertStringToHash(this.context?.name);
        const dashboardName = await this.convertStringToHash(this.dashboard?.name);
        this.gainsightService.triggerEvent(PRODUCT_EXPERIENCE.DASHBOARD.EVENTS.DASHBOARDS, {
            component: PRODUCT_EXPERIENCE.DASHBOARD.COMPONENTS.ADD_DASHBOARD,
            action: PRODUCT_EXPERIENCE.DASHBOARD.ACTIONS.CREATE,
            name: dashboardName,
            id: mo.id,
            nameId: `${dashboardName}_${this.mo.id}`,
            parentAssetId: this.context?.id ? this.context.id : 'noContext',
            parentAssetName: this.context?.id ? parentName : 'noContext',
            parentAssetType: this.context?.id ? this.context.type : 'noContext',
            parentAssetNameId: this.context?.id ? `${parentName}_${this.context.id}` : 'noContext',
            parentAssetNameDashboardName: this.context?.id
                ? `${parentName}_${dashboardName}`
                : 'noContext',
            parentAssetIdDashboardId: this.context?.id ? `${this.context.id}_${this.mo.id}` : 'noContext',
            parentAssetNameDashboardId: this.context?.id ? `${parentName}_${this.mo.id}` : 'noContext',
            parentAssetNameIdDashboardNameId: this.context?.id
                ? `${parentName}_${this.context.id}_${dashboardName}_${this.mo.id}`
                : 'noContext',
            dashboardType: mo.c8y_Dashboard.deviceType ? mo.c8y_Dashboard.deviceTypeValue : null,
            context: this.contextDashboardService.getContextForGS(this.currentContext.contextData)
        });
    }
    async convertStringToHash(str) {
        if (!str) {
            return null;
        }
        return (await this.gainsightService.shouldSendPiiData())
            ? str
            : await this.gainsightService.hashGroupName(str);
    }
    async createNewReport() {
        try {
            const { name, icon, c8y_IsNavigatorNode, priority, description } = this.dashboard;
            const report = (await this.contextDashboardService.createReport({
                name,
                icon,
                c8y_IsNavigatorNode,
                priority,
                description
            })).data;
            await this.contextDashboardService.create(this.dashboard, undefined, `${this.contextDashboardService.REPORT_PARTIAL_NAME}${report.id}`);
            this.gainsightService.triggerEvent(PRODUCT_EXPERIENCE.DASHBOARD.EVENTS.REPORTS, {
                component: PRODUCT_EXPERIENCE.DASHBOARD.COMPONENTS.ADD_REPORT,
                action: PRODUCT_EXPERIENCE.DASHBOARD.ACTIONS.CREATE,
                name: report.name,
                id: report.id,
                context: PRODUCT_EXPERIENCE.DASHBOARD.CONTEXT.REPORT
            });
            if (report.c8y_IsNavigatorNode) {
                this.contextDashboardService.addReportNavigatorNode(report);
            }
            this.cleanupAfterDetailsClose();
            await this.router.navigate(['reports', report.id]);
        }
        catch (ex) {
            // intended empty
        }
    }
    async updateDashboard() {
        try {
            const dashboardMO = cloneDeep(this.mo);
            const cfg = this.dashboard;
            if (this.isReport) {
                const { name, icon, c8y_IsNavigatorNode, priority, description } = cfg;
                dashboardMO.c8y_Dashboard = cfg;
                await this.updateReport({
                    id: this.context.id,
                    name,
                    icon,
                    c8y_IsNavigatorNode,
                    priority,
                    description
                });
            }
            else {
                dashboardMO.c8y_Dashboard = cfg;
            }
            const updatedDashboardMo = await this.contextDashboardService.update(dashboardMO, this.currentContext);
            this.cleanupAfterDetailsClose();
            this.dashboardSaved.emit(updatedDashboardMo);
        }
        catch (ex) {
            // intended empty
        }
    }
    edit() {
        if (this.isReport) {
            const { name, icon, priority, c8y_IsNavigatorNode, description } = this.context;
            Object.assign(this.dashboard, { name, icon, priority, c8y_IsNavigatorNode, description });
        }
        this.isNamedDashboard = this.contextDashboardService.isNamed(this.mo);
        this.selectedTab =
            this.hideAvailability && this.isNamedDashboard
                ? DashboardDetailsTabId.APPEARANCE
                : DashboardDetailsTabId.GENERAL;
        this.initializeConfiguration();
    }
    initializeConfiguration() {
        const defaultDashboardCfg = {
            name: this.translateService.instant(this.isReport ? gettext('Report') : gettext('Dashboard')),
            priority: this.isReport
                ? REPORT_DEFAULT_NAVIGATION_NODE_PRIORITY
                : this.dashboardDetailService.DEFAULT_DASHBOARD_PRIORITY,
            icon: this.dashboardDetailService.DEFAULT_DASHBOARD_ICON,
            deviceTypeValue: this.deviceType,
            columns: 24
        };
        if (this.dashboard) {
            this.currentDashboard = clone(this.dashboard);
        }
        else {
            this.dashboard = defaultDashboardCfg;
            this.dashboardDetailsForm.markAsDirty();
        }
        this.namePlaceholder = this.isReport ? gettext('e.g. My report') : gettext('e.g. My dashboard');
    }
    async updateReport(mo) {
        mo.c8y_IsNavigatorNode = mo.c8y_IsNavigatorNode ? {} : null;
        const res = await this.inventory.update(mo);
        this.context = res.data;
        if (this.route.parent) {
            this.route.parent.snapshot.data.contextData = this.context;
        }
        this.contextDashboardService.updateNavigatorItem(res.data);
    }
    cleanupAfterDetailsClose() {
        this.isCollapsed = true;
        if (!this.isEdit) {
            const dashboardContext = this.route.snapshot.data.dashboard;
            // hide New dashboard tab
            const tmpNewDashboardTab = [...this.tabsService.state].find(t => t.featureId === newDashboardTab.featureId);
            // don't hide the new dashboard tab when clicking on the add dashboard button from another dashboard.
            if (!tmpNewDashboardTab || dashboardContext?.c8y_Dashboard) {
                return;
            }
            // hide tab and make it appear as last one to prevent navigating to it
            tmpNewDashboardTab.hide = true;
            tmpNewDashboardTab.priority = -Infinity;
            this.tabsService.refresh();
        }
        this.previewChanged.emit(this.dashboard);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardDetailComponent, deps: [{ token: ContextDashboardService }, { token: i2$1.TranslateService }, { token: i2.ContextRouteService }, { token: i1.ActivatedRoute }, { token: i2.TabsService }, { token: i1.Router }, { token: i1$1.InventoryService }, { token: i1.ActivatedRoute }, { token: DashboardDetailService }, { token: i2.AppStateService }, { token: i2.GroupService }, { token: i2.ModalService }, { token: i2.GainsightService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: DashboardDetailComponent, selector: "c8y-dashboard-detail", inputs: { isReport: "isReport", deviceType: "deviceType", context: "context", mo: "mo", dashboard: "dashboard", isNamedDashboard: "isNamedDashboard", hideAvailability: "hideAvailability" }, outputs: { dashboardSaved: "dashboardSaved", previewChanged: "previewChanged" }, usesOnChanges: true, ngImport: i0, template: "<div\n  class=\"collapse c8y-top-drawer\"\n  [collapse]=\"isCollapsed\"\n  [isAnimated]=\"true\"\n>\n  <div class=\"p-t-16 p-b-16 p-l-24 p-r-24 separator-bottom\">\n    <span class=\"h4\">{{ 'Dashboard settings' | translate }}</span>\n  </div>\n\n  <div\n    class=\"d-flex\"\n    [formGroup]=\"dashboardDetailsForm\"\n    *ngIf=\"!isCollapsed\"\n  >\n    <c8y-tabs-outlet\n      [tabs]=\"tabs$ | async\"\n      [outletName]=\"TABS_OUTLET_NAME\"\n      [orientation]=\"'vertical'\"\n      class=\"c8y-top-drawer--tabs\"\n    ></c8y-tabs-outlet>\n    <div class=\"inner-scroll c8y-top-drawer__tabs-container flex-grow p-l-24 p-r-lg-32 p-r-xs-24 p-r-sm-24\">\n      <c8y-tab\n        *ngIf=\"(!isNamedDashboard && !hideAvailability) || isReport\"\n        [label]=\"TABS.general.label\"\n        [icon]=\"'imac-settings'\"\n        [priority]=\"100\"\n        [tabsOutlet]=\"TABS_OUTLET_NAME\"\n        (onSelect)=\"selectTab(TABS.general.featureId)\"\n        [isActive]=\"selectedTab === TABS.general.featureId\"\n      ></c8y-tab>\n      <c8y-tab\n        [label]=\"TABS.appearance.label\"\n        [priority]=\"50\"\n        [icon]=\"'web-design'\"\n        [tabsOutlet]=\"TABS_OUTLET_NAME\"\n        (onSelect)=\"selectTab(TABS.appearance.featureId)\"\n        [isActive]=\"selectedTab === TABS.appearance.featureId\"\n      ></c8y-tab>\n      <c8y-tab\n        *ngIf=\"mo?.c8y_DashboardHistory\"\n        [label]=\"TABS.versionHistory.label\"\n        [icon]=\"'versions'\"\n        [priority]=\"10\"\n        [tabsOutlet]=\"TABS_OUTLET_NAME\"\n        (onSelect)=\"selectTab(TABS.versionHistory.featureId)\"\n        [isActive]=\"selectedTab === TABS.versionHistory.featureId\"\n      ></c8y-tab>\n      <ng-container [ngSwitch]=\"selectedTab\">\n        <c8y-dashboard-general-settings\n          *ngSwitchCase=\"TABS.general.featureId\"\n          [isReport]=\"isReport\"\n          [isNamedDashboard]=\"isNamedDashboard\"\n          [hideAvailability]=\"hideAvailability\"\n          [dashboard]=\"dashboard\"\n          [generalSettingsForm]=\"generalSettingsForm\"\n          [deviceTypeValue]=\"deviceTypeValue\"\n          [displayDeviceTypeValue]=\"displayDeviceTypeValue\"\n          [mo]=\"mo\"\n          [allowTypeDashboard]=\"allowTypeDashboard\"\n          [isDevice]=\"!!context?.c8y_IsDevice\"\n          class=\"animated fadeIn\"\n          (onDuplicateWithoutType)=\"duplicateWithoutType()\"\n        ></c8y-dashboard-general-settings>\n        <c8y-dashboard-appearance-settings\n          *ngSwitchCase=\"TABS.appearance.featureId\"\n          [dashboard]=\"dashboard\"\n          [appearanceSettingsForm]=\"appearanceSettingsForm\"\n          (previewChanged)=\"previewChanged.emit($event)\"\n          class=\"animated fadeIn\"\n        ></c8y-dashboard-appearance-settings>\n        <c8y-dashboard-version-history\n          *ngSwitchCase=\"TABS.versionHistory.featureId\"\n          [dashboardHistory]=\"mo.c8y_DashboardHistory\"\n          [isReport]=\"isReport\"\n          (onRevert)=\"revertDashboard($event)\"\n          class=\"animated fadeIn\"\n        ></c8y-dashboard-version-history>\n      </ng-container>\n    </div>\n  </div>\n\n  <div class=\"c8y-top-drawer--footer\">\n    <button\n      class=\"btn btn-default\"\n      title=\"{{ 'Cancel' | translate }}\"\n      type=\"button\"\n      data-cy=\"dashboard-detail--cancel-dashboard\"\n      (click)=\"cancel()\"\n    >\n      {{ 'Cancel' | translate }}\n    </button>\n    <button\n      class=\"btn btn-primary\"\n      title=\"{{ 'Save' | translate }}\"\n      type=\"button\"\n      data-cy=\"dashboard-detail--save-dashboard\"\n      (click)=\"save()\"\n      [disabled]=\"\n        (dashboardDetailsForm?.invalid || dashboardDetailsForm?.pristine) && this.isEdit\n      \"\n    >\n      {{ 'Save' | translate }}\n    </button>\n  </div>\n</div>\n", dependencies: [{ kind: "directive", type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i4.NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { kind: "directive", type: i4.NgSwitchCase, selector: "[ngSwitchCase]", inputs: ["ngSwitchCase"] }, { kind: "component", type: i2.TabsOutletComponent, selector: "c8y-tabs-outlet,c8y-ui-tabs", inputs: ["tabs", "orientation", "navigatorOpen", "outletName", "context", "openFirstTab", "hasHeader"] }, { kind: "component", type: i2.TabComponent, selector: "c8y-tab", inputs: ["path", "label", "icon", "priority", "orientation", "injector", "tabsOutlet", "isActive"], outputs: ["onSelect"] }, { kind: "directive", type: i3.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i3.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i9.CollapseDirective, selector: "[collapse]", inputs: ["display", "isAnimated", "collapse"], outputs: ["collapsed", "collapses", "expanded", "expands"], exportAs: ["bs-collapse"] }, { kind: "component", type: DashboardGeneralSettingsComponent, selector: "c8y-dashboard-general-settings", inputs: ["isReport", "isNamedDashboard", "hideAvailability", "dashboard", "generalSettingsForm", "deviceTypeValue", "displayDeviceTypeValue", "allowTypeDashboard", "isDevice", "mo"], outputs: ["onDuplicateWithoutType"] }, { kind: "component", type: DashboardAppearanceSettingsComponent, selector: "c8y-dashboard-appearance-settings", inputs: ["dashboard", "appearanceSettingsForm"], outputs: ["previewChanged"] }, { kind: "component", type: DashboardVersionHistoryComponent, selector: "c8y-dashboard-version-history", inputs: ["dashboardHistory", "isReport"], outputs: ["onRevert"] }, { kind: "pipe", type: i2.C8yTranslatePipe, name: "translate" }, { kind: "pipe", type: i4.AsyncPipe, name: "async" }] }); }
}
__decorate([
    memoize(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", Promise)
], DashboardDetailComponent.prototype, "convertStringToHash", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardDetailComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-dashboard-detail', template: "<div\n  class=\"collapse c8y-top-drawer\"\n  [collapse]=\"isCollapsed\"\n  [isAnimated]=\"true\"\n>\n  <div class=\"p-t-16 p-b-16 p-l-24 p-r-24 separator-bottom\">\n    <span class=\"h4\">{{ 'Dashboard settings' | translate }}</span>\n  </div>\n\n  <div\n    class=\"d-flex\"\n    [formGroup]=\"dashboardDetailsForm\"\n    *ngIf=\"!isCollapsed\"\n  >\n    <c8y-tabs-outlet\n      [tabs]=\"tabs$ | async\"\n      [outletName]=\"TABS_OUTLET_NAME\"\n      [orientation]=\"'vertical'\"\n      class=\"c8y-top-drawer--tabs\"\n    ></c8y-tabs-outlet>\n    <div class=\"inner-scroll c8y-top-drawer__tabs-container flex-grow p-l-24 p-r-lg-32 p-r-xs-24 p-r-sm-24\">\n      <c8y-tab\n        *ngIf=\"(!isNamedDashboard && !hideAvailability) || isReport\"\n        [label]=\"TABS.general.label\"\n        [icon]=\"'imac-settings'\"\n        [priority]=\"100\"\n        [tabsOutlet]=\"TABS_OUTLET_NAME\"\n        (onSelect)=\"selectTab(TABS.general.featureId)\"\n        [isActive]=\"selectedTab === TABS.general.featureId\"\n      ></c8y-tab>\n      <c8y-tab\n        [label]=\"TABS.appearance.label\"\n        [priority]=\"50\"\n        [icon]=\"'web-design'\"\n        [tabsOutlet]=\"TABS_OUTLET_NAME\"\n        (onSelect)=\"selectTab(TABS.appearance.featureId)\"\n        [isActive]=\"selectedTab === TABS.appearance.featureId\"\n      ></c8y-tab>\n      <c8y-tab\n        *ngIf=\"mo?.c8y_DashboardHistory\"\n        [label]=\"TABS.versionHistory.label\"\n        [icon]=\"'versions'\"\n        [priority]=\"10\"\n        [tabsOutlet]=\"TABS_OUTLET_NAME\"\n        (onSelect)=\"selectTab(TABS.versionHistory.featureId)\"\n        [isActive]=\"selectedTab === TABS.versionHistory.featureId\"\n      ></c8y-tab>\n      <ng-container [ngSwitch]=\"selectedTab\">\n        <c8y-dashboard-general-settings\n          *ngSwitchCase=\"TABS.general.featureId\"\n          [isReport]=\"isReport\"\n          [isNamedDashboard]=\"isNamedDashboard\"\n          [hideAvailability]=\"hideAvailability\"\n          [dashboard]=\"dashboard\"\n          [generalSettingsForm]=\"generalSettingsForm\"\n          [deviceTypeValue]=\"deviceTypeValue\"\n          [displayDeviceTypeValue]=\"displayDeviceTypeValue\"\n          [mo]=\"mo\"\n          [allowTypeDashboard]=\"allowTypeDashboard\"\n          [isDevice]=\"!!context?.c8y_IsDevice\"\n          class=\"animated fadeIn\"\n          (onDuplicateWithoutType)=\"duplicateWithoutType()\"\n        ></c8y-dashboard-general-settings>\n        <c8y-dashboard-appearance-settings\n          *ngSwitchCase=\"TABS.appearance.featureId\"\n          [dashboard]=\"dashboard\"\n          [appearanceSettingsForm]=\"appearanceSettingsForm\"\n          (previewChanged)=\"previewChanged.emit($event)\"\n          class=\"animated fadeIn\"\n        ></c8y-dashboard-appearance-settings>\n        <c8y-dashboard-version-history\n          *ngSwitchCase=\"TABS.versionHistory.featureId\"\n          [dashboardHistory]=\"mo.c8y_DashboardHistory\"\n          [isReport]=\"isReport\"\n          (onRevert)=\"revertDashboard($event)\"\n          class=\"animated fadeIn\"\n        ></c8y-dashboard-version-history>\n      </ng-container>\n    </div>\n  </div>\n\n  <div class=\"c8y-top-drawer--footer\">\n    <button\n      class=\"btn btn-default\"\n      title=\"{{ 'Cancel' | translate }}\"\n      type=\"button\"\n      data-cy=\"dashboard-detail--cancel-dashboard\"\n      (click)=\"cancel()\"\n    >\n      {{ 'Cancel' | translate }}\n    </button>\n    <button\n      class=\"btn btn-primary\"\n      title=\"{{ 'Save' | translate }}\"\n      type=\"button\"\n      data-cy=\"dashboard-detail--save-dashboard\"\n      (click)=\"save()\"\n      [disabled]=\"\n        (dashboardDetailsForm?.invalid || dashboardDetailsForm?.pristine) && this.isEdit\n      \"\n    >\n      {{ 'Save' | translate }}\n    </button>\n  </div>\n</div>\n" }]
        }], ctorParameters: () => [{ type: ContextDashboardService }, { type: i2$1.TranslateService }, { type: i2.ContextRouteService }, { type: i1.ActivatedRoute }, { type: i2.TabsService }, { type: i1.Router }, { type: i1$1.InventoryService }, { type: i1.ActivatedRoute }, { type: DashboardDetailService }, { type: i2.AppStateService }, { type: i2.GroupService }, { type: i2.ModalService }, { type: i2.GainsightService }], propDecorators: { isReport: [{
                type: Input
            }], deviceType: [{
                type: Input
            }], context: [{
                type: Input
            }], mo: [{
                type: Input
            }], dashboard: [{
                type: Input
            }], isNamedDashboard: [{
                type: Input
            }], hideAvailability: [{
                type: Input
            }], dashboardSaved: [{
                type: Output
            }], previewChanged: [{
                type: Output
            }], convertStringToHash: [] } });

class WidgetService {
    constructor(dynamicComponentService, translateService, moduleConfig) {
        this.dynamicComponentService = dynamicComponentService;
        this.translateService = translateService;
        this.moduleConfig = moduleConfig;
        this.dynamicComponentService.items$.subscribe(widgets => {
            this.widgets = widgets;
        });
    }
    async getWidgetDefinition(componentId) {
        return this.dynamicComponentService.getById(componentId);
    }
    getWidgetDefinitions() {
        const translatedComponents = this.widgets.map(cmp => ({
            ...cmp,
            label: this.translateService.instant(cmp.label)
        }));
        // cloneDeep and injector lead to a performance issue. We removing the injectors here,
        // as they are not needed, to avoid use of a lot of CPU for cloning.
        const translatedComponentsWithoutInjector = translatedComponents.map(cmp => omit(cmp, 'injector'));
        const filterFn = this.moduleConfig?.widgetFilter ||
            (({ data }) => !(data && data.settings && data.settings.noNewWidgets));
        return cloneDeep(sortBy(translatedComponentsWithoutInjector, 'label').filter(filterFn));
    }
    async mapLegacy(widget) {
        const cmp = await this.getWidgetDefinition(widget.componentId || widget.name);
        widget = this.mapDisplaySettings(widget, cmp);
        if (get(cmp, 'data.settings.upgrade')) {
            widget.widgetComponent = cmp.data.settings.widgetComponent;
            widget.configComponent = cmp.data.settings.configComponent;
            widget.templateUrl = cmp.data.settings.templateUrl;
            widget.configTemplateUrl = cmp.data.settings.configTemplateUrl;
            widget.transformConfigWithContext =
                cmp.data.settings.componentTransformConfigWithContext ||
                    cmp.data.settings.transformConfigWithContext ||
                    widget.transformConfigWithContext;
        }
        else {
            delete widget.templateUrl;
            delete widget.configTemplateUrl;
        }
        return widget;
    }
    mapDisplaySettings(widget, cmp) {
        if (cmp?.data?.displaySettings) {
            widget.config = { displaySettings: cmp.data.displaySettings, ...(widget.config || {}) };
        }
        return widget;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WidgetService, deps: [{ token: i2.DynamicComponentService }, { token: i2$1.TranslateService }, { token: CONTEXT_DASHBOARD_CONFIG, optional: true }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WidgetService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WidgetService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: i2.DynamicComponentService }, { type: i2$1.TranslateService }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [CONTEXT_DASHBOARD_CONFIG]
                }] }] });

class WidgetPreviewComponent {
    constructor() {
        this.previewClasses = {
            'dashboard-theme-light': true,
            'panel-title-regular': true
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WidgetPreviewComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: WidgetPreviewComponent, selector: "c8y-widget-preview", inputs: { previewClasses: "previewClasses", tab: "tab" }, ngImport: i0, template: "<div class=\"legend form-block\" translate>Preview</div>\n<label *ngIf=\"tab\" translate>Tab and layout</label>\n<label *ngIf=\"!tab\" translate>Layout</label>\n<div class=\"dashboard-preview-slot\" [ngClass]=\"previewClasses\">\n  <div\n    class=\"page-tabs page-tabs-horizontal navigator-open p-absolute overflow-hidden\"\n    style=\"left: 0; margin: 0 15px\"\n    *ngIf=\"tab\"\n  >\n    <div class=\"tabContainer hidden-xs\">\n      <ul role=\"menu\" class=\"nav nav-tabs nav-tabsc8y\">\n        <li role=\"menuitem\" class=\"active\" style=\"left: 16px\">\n          <a routerlinkactive=\"\" title=\"{{ tab.name }}\">\n            <i class=\"text-primary\" [c8yIcon]=\"tab.icon\"></i>\n            <span class=\"txt\">{{ tab.name }}</span>\n          </a>\n        </li>\n      </ul>\n    </div>\n    <div class=\"visible-xs mobile-tabs\"></div>\n  </div>\n  <div [ngClass]=\"{ 'm-t-64': !!tab }\">\n    <div class=\"card card-dashboard\" style=\"height: 300px\">\n      <div class=\"card-header-actions\" style=\"z-index: 8\">\n        <div class=\"card-title\">\n          <span translate>Widget title</span>\n        </div>\n        <div class=\"header-actions\">\n          <div class=\"optionsBtn dropdown\">\n            <button\n              type=\"button\"\n              title=\"{{ 'Settings' | translate }}\"\n              (click)=\"(false)\"\n              class=\"btn btn-dot dropdown-toggle c8y-dropdown\"\n              aria-haspopup=\"true\"\n            >\n              <i c8yIcon=\"cog\"></i>\n            </button>\n          </div>\n        </div>\n      </div>\n      <div class=\"card-inner-scroll p-t-16\">\n        <p translate>Widget example content.</p>\n      </div>\n    </div>\n  </div>\n</div>\n", dependencies: [{ kind: "directive", type: i2.IconDirective, selector: "[c8yIcon]", inputs: ["c8yIcon"] }, { kind: "directive", type: i2.C8yTranslateDirective, selector: "[translate],[ngx-translate]" }, { kind: "directive", type: i4.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "pipe", type: i2.C8yTranslatePipe, name: "translate" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WidgetPreviewComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-widget-preview', template: "<div class=\"legend form-block\" translate>Preview</div>\n<label *ngIf=\"tab\" translate>Tab and layout</label>\n<label *ngIf=\"!tab\" translate>Layout</label>\n<div class=\"dashboard-preview-slot\" [ngClass]=\"previewClasses\">\n  <div\n    class=\"page-tabs page-tabs-horizontal navigator-open p-absolute overflow-hidden\"\n    style=\"left: 0; margin: 0 15px\"\n    *ngIf=\"tab\"\n  >\n    <div class=\"tabContainer hidden-xs\">\n      <ul role=\"menu\" class=\"nav nav-tabs nav-tabsc8y\">\n        <li role=\"menuitem\" class=\"active\" style=\"left: 16px\">\n          <a routerlinkactive=\"\" title=\"{{ tab.name }}\">\n            <i class=\"text-primary\" [c8yIcon]=\"tab.icon\"></i>\n            <span class=\"txt\">{{ tab.name }}</span>\n          </a>\n        </li>\n      </ul>\n    </div>\n    <div class=\"visible-xs mobile-tabs\"></div>\n  </div>\n  <div [ngClass]=\"{ 'm-t-64': !!tab }\">\n    <div class=\"card card-dashboard\" style=\"height: 300px\">\n      <div class=\"card-header-actions\" style=\"z-index: 8\">\n        <div class=\"card-title\">\n          <span translate>Widget title</span>\n        </div>\n        <div class=\"header-actions\">\n          <div class=\"optionsBtn dropdown\">\n            <button\n              type=\"button\"\n              title=\"{{ 'Settings' | translate }}\"\n              (click)=\"(false)\"\n              class=\"btn btn-dot dropdown-toggle c8y-dropdown\"\n              aria-haspopup=\"true\"\n            >\n              <i c8yIcon=\"cog\"></i>\n            </button>\n          </div>\n        </div>\n      </div>\n      <div class=\"card-inner-scroll p-t-16\">\n        <p translate>Widget example content.</p>\n      </div>\n    </div>\n  </div>\n</div>\n" }]
        }], propDecorators: { previewClasses: [{
                type: Input
            }], tab: [{
                type: Input
            }] } });

class WidgetConfigComponent {
    get isEdit() {
        return !!this.current;
    }
    get isDeviceTypeDashboard() {
        return !!this.mo.c8y_Dashboard?.deviceType && !!this.mo.c8y_Dashboard?.deviceTypeValue;
    }
    constructor(widgetService, modal, inventory, contextDashboardService) {
        this.widgetService = widgetService;
        this.modal = modal;
        this.inventory = inventory;
        this.contextDashboardService = contextDashboardService;
        this.mode = 'select';
        this.searchChange$ = new Subject();
        this.searchTerm = '';
        this.styling = {
            headerClass: 'panel-title-regular',
            contentClass: 'panel-content-light'
        };
        this.defaultStyling = {
            headerClass: 'panel-title-regular',
            contentClass: 'panel-content-light'
        };
        this.possibleStyling = { WIDGET_HEADER_CLASSES, WIDGET_CONTENT_CLASSES };
        this.isUpgrade = false;
        this.result = new Promise((resolve, reject) => {
            this._save = resolve;
            this._cancel = reject;
        });
    }
    async ngAfterContentInit() {
        this.components = this.widgetService.getWidgetDefinitions();
        if (this.selected) {
            this.current = clone(this.selected);
            this.select(this.selected, this.isEdit ? 'config' : 'select');
        }
        this.searchSub = this.searchChange$
            .pipe(switchMap((event) => iif(() => event.which !== 13, timer(200), timer(10))))
            .subscribe(() => {
            this.search();
        });
        this.setStylings();
        if (this.widgetConfig?.device) {
            const { data } = await this.inventory.detail(this.widgetConfig.device.id);
            this.selectedDevice = data;
        }
    }
    isSaveDisabled() {
        return this.configForm?.invalid || this.checkIfDeviceRequired();
    }
    checkIfDeviceRequired() {
        return (!this.widgetConfig ||
            (!this.widgetConfig.settings.deviceTargetNotRequired &&
                !this.widgetConfig.device &&
                !this.widgetConfig.settings.noDeviceTarget));
    }
    selectionChanged(selection) {
        this.widgetConfig.device = selection?.change?.item;
        this.dynamicComponent.emitConfigChange({
            device: this.widgetConfig.device
        });
    }
    async save() {
        const hookSuccess = await this.dynamicComponent?.callLifeCycleHooks().toPromise();
        if (!hookSuccess) {
            return;
        }
        const { _x, _y, _width, _height } = this.selected.data;
        if (this.widgetConfig &&
            this.widgetConfig.device &&
            // serializing will be handled by resolver
            !this.selected?.resolve?.device) {
            const { id, name } = this.widgetConfig.device;
            this.widgetConfig.device = { id, name };
        }
        const widget = {
            _x,
            _y,
            _width,
            _height,
            config: omit(this.widgetConfig, ['settings', 'displaySettings']),
            title: this.selected.data.title,
            componentId: this.selected.id,
            id: this.isEdit ? this.current.data.id : String(Math.random()).substr(2),
            classes: this.getStyle(),
            ...(!this.isEdit ? this.widgetConfig.settings.widgetDefaults : {})
        };
        this._save(widget);
    }
    select(cmp, mode = 'config') {
        if (mode === 'config' && this.configForm) {
            const formGroup = this.configForm.control;
            for (const control of Object.keys(formGroup.controls)) {
                formGroup.removeControl(control);
            }
        }
        cmp.data = cmp.data || {};
        this.selected = cmp;
        this.isUpgrade = !!get(cmp, 'data.settings.upgrade');
        this.contextDashboardService.formDisabled = this.isUpgrade;
        if (this.isEdit) {
            const { _x, _y, _width, _height, classes, title } = this.current.data;
            this.selected.data = { ...this.selected.data, _x, _y, _width, _height, classes, title };
        }
        /* this.selected.component cannot be checked since it is faulty for widgets like Help and Service,
            but exists for Applications widget and this would cause chaotic behaviour.
         */
        this.widgetHasConfigComponent =
            !!this.selected.loadConfigComponent || mode === 'select' || mode === 'config';
        this.widgetConfig = cloneDeep(this.composeWidgetConfig(this.selected, this.context));
        this.selected.data.title = this.selected.data.title || cmp.label;
        this.componentLabel = cmp.label;
        this.mode = mode;
    }
    search() {
        if (this.searchTerm.length > 0) {
            this.searchResult = this.components.filter(cmp => new RegExp(escapeRegExp(this.searchTerm.trim()), 'i').test(cmp.label));
        }
        else {
            this.resetSearch();
        }
    }
    resetSearch() {
        this.searchTerm = '';
        this.searchResult = undefined;
    }
    changeMode(mode) {
        this.mode = mode;
    }
    close() {
        this._cancel();
        this.modal.hide();
    }
    getStyle(isPreview = false) {
        const cssClasses = {};
        if (isPreview || !this.isDashboardDefaultStyle(this.styling.headerClass)) {
            cssClasses[this.styling.headerClass] = true;
        }
        if (isPreview || !this.isDashboardDefaultStyle(this.styling.contentClass)) {
            cssClasses[this.styling.contentClass] = true;
        }
        if (isPreview) {
            cssClasses[`dashboard-theme-${this.defaultStyling.contentClass.split('-').pop()}`] = true;
        }
        return cssClasses;
    }
    ngOnDestroy() {
        this.contextDashboardService.formDisabled = true;
        if (this.searchSub) {
            this.searchSub.unsubscribe();
        }
    }
    hasConfig() {
        if (this.widgetConfig.settings?.upgrade) {
            return (this.widgetConfig.settings?.configComponent || this.widgetConfig.settings?.configTemplateUrl);
        }
        return !this.dynamicComponent?.error;
    }
    isAnyOfAlarmsWidget() {
        return (this.widgetConfig?.settings?.alarmListWidget ||
            this.widgetConfig?.settings?.criticalAlarmsWidget ||
            this.widgetConfig?.settings?.recentAlarmsWidget);
    }
    setStylings() {
        const dashboardClasses = (this.mo.c8y_Dashboard?.classes && Object.keys(this.mo.c8y_Dashboard.classes)) || [];
        const dashboardWidgetClasses = (this.mo.c8y_Dashboard?.widgetClasses && Object.keys(this.mo.c8y_Dashboard.widgetClasses)) ||
            [];
        const widgetClasses = this.isEdit ? Object.keys(this.current.data.classes) : [];
        this.styling = this.setDefaultStyle([
            ...dashboardClasses,
            ...dashboardWidgetClasses,
            ...widgetClasses
        ]);
        this.defaultStyling = this.setDefaultStyle([...dashboardClasses, ...dashboardWidgetClasses]);
    }
    isDashboardDefaultStyle(className) {
        const allClasses = {
            ...this.mo.c8y_Dashboard.classes,
            ...this.mo.c8y_Dashboard.widgetClasses
        };
        const styles = Object.keys(allClasses).map(cssClass => ({ class: cssClass }));
        const style = this.contextDashboardService.getStyling(styles, className.split('-').pop(), undefined);
        return !!style;
    }
    setDefaultStyle(setClasses) {
        let contentClass = this.styling.contentClass;
        let headerClass = this.styling.headerClass;
        const styles = this.contextDashboardService
            .getFilteredDashboardStyles(setClasses)
            .map(c => c.split('-').pop());
        styles.forEach(styleName => {
            contentClass = this.contextDashboardService.getStyling(WIDGET_CONTENT_CLASSES, styleName, contentClass);
            headerClass = this.contextDashboardService.getStyling(WIDGET_HEADER_CLASSES, styleName, headerClass);
        });
        return { headerClass, contentClass };
    }
    composeWidgetConfig(selectedComponent, context = {}) {
        const setting = {
            settings: {
                ...selectedComponent.data.settings,
                ...get(selectedComponent.data.settings, 'ng1.options'),
                ...get(selectedComponent.data, 'ng1.options'),
                context,
                dashboardMo: this.mo.c8y_Dashboard
            },
            ...selectedComponent.data.config
        };
        return this.applyTargetIfDeviceDashboard(setting);
    }
    applyTargetIfDeviceDashboard(widgetConfig) {
        const isDeviceType = this.contextDashboardService.isDeviceType(this.mo);
        if (isDeviceType) {
            widgetConfig.settings.hideTarget = isDeviceType;
            const noDeviceTarget = widgetConfig.settings.ng1
                ? widgetConfig.settings.ng1.options.noDeviceTarget
                : widgetConfig.settings.noDeviceTarget;
            if (!noDeviceTarget) {
                widgetConfig.device = {
                    id: this.context.id,
                    name: this.context.name
                };
            }
        }
        return widgetConfig;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WidgetConfigComponent, deps: [{ token: WidgetService }, { token: i2$2.BsModalRef }, { token: i1$1.InventoryService }, { token: ContextDashboardService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: WidgetConfigComponent, selector: "c8y-widget-config", viewQueries: [{ propertyName: "dynamicComponent", first: true, predicate: ["config"], descendants: true }, { propertyName: "configForm", first: true, predicate: ["configForm"], descendants: true }], ngImport: i0, template: "<div class=\"modal-header\">\n  <div\n    class=\"h3\"\n    title=\"{{ 'Add widget' | translate }}\"\n    id=\"modal-title\"\n    *ngIf=\"!current\"\n    translate\n  >\n    Add widget\n  </div>\n  <div\n    class=\"h3\"\n    title=\"{{ 'Edit widget' | translate }}\"\n    id=\"modal-title\"\n    *ngIf=\"current\"\n    translate\n  >\n    Edit widget\n  </div>\n</div>\n<form\n  name=\"form\"\n  #configForm=\"ngForm\"\n>\n  <div\n    class=\"c8y-modal-tabs\"\n    id=\"modal-body\"\n  >\n    <div class=\"tabContainer\">\n      <ul class=\"nav nav-tabs nav-tabsc8y p-l-24\">\n        <li [class.active]=\"mode === 'select'\">\n          <button\n            class=\"btn\"\n            title=\"{{ 'Select widget' | translate }}\"\n            type=\"button\"\n            (click)=\"changeMode('select'); (false)\"\n          >\n            <i c8yIcon=\"th-large\"></i>\n            <span translate>Select widget</span>\n          </button>\n        </li>\n        <li [class.active]=\"mode === 'config'\">\n          <button\n            class=\"btn\"\n            title=\"{{ 'Configuration' | translate }}\"\n            type=\"button\"\n            [disabled]=\"!selected\"\n            (click)=\"changeMode('config'); (false)\"\n          >\n            <i c8yIcon=\"cog\"></i>\n            <span translate>Configuration</span>\n          </button>\n        </li>\n        <li [class.active]=\"mode === 'style'\">\n          <button\n            class=\"btn\"\n            title=\"{{ 'Appearance' | translate }}\"\n            type=\"button\"\n            [disabled]=\"!selected\"\n            (click)=\"changeMode('style'); (false)\"\n          >\n            <i c8yIcon=\"paint-brush\"></i>\n            <span translate>Appearance</span>\n          </button>\n        </li>\n      </ul>\n    </div>\n  </div>\n\n  <div class=\"modal-inner-scroll modal-inner-scroll--fixed\">\n    <div\n      class=\"bg-level-0 p-l-24 p-r-24 p-t-8 p-b-8 sticky-header-top-0 elevation-md\"\n      style=\"z-index: 2\"\n      *ngIf=\"mode === 'select'\"\n    >\n      <div class=\"row\">\n        <div class=\"col-sm-6\">\n          <div class=\"input-group input-group-search\">\n            <input\n              class=\"form-control\"\n              [attr.aria-label]=\"'Search' | translate\"\n              placeholder=\"{{ 'Search\u2026' | translate }}\"\n              type=\"text\"\n              data-cy=\"widget-config--Search\"\n              [(ngModel)]=\"searchTerm\"\n              [ngModelOptions]=\"{ standalone: true }\"\n              (keydown)=\"searchChange$.next($event)\"\n            />\n            <span class=\"input-group-btn\">\n              <button\n                class=\"btn btn-dot\"\n                title=\"{{ 'Search' | translate }}\"\n                type=\"button\"\n                (click)=\"resetSearch()\"\n              >\n                <i [c8yIcon]=\"searchTerm.length === 0 ? 'search' : 'close'\"></i>\n              </button>\n            </span>\n          </div>\n        </div>\n      </div>\n    </div>\n    <div\n      class=\"modal-body bg-level-2\"\n      *ngIf=\"mode === 'select'\"\n    >\n      <div class=\"card-group card-select m-b-0\">\n        <div\n          class=\"col-md-3 col-sm-4 col-xs-6\"\n          title=\"{{ cmp.description | translate }}\"\n          data-cy=\"widget-config--widget-list\"\n          *ngFor=\"let cmp of searchResult || components\"\n        >\n          <button\n            class=\"btn-clean d-col card p-8\"\n            [class.active]=\"selected === cmp\"\n            type=\"button\"\n            (click)=\"select(cmp)\"\n          >\n            <div\n              class=\"text-center p-8 m-b-8 d-col flex-center flex-grow bg-level-2\"\n              role=\"presentation\"\n            >\n              <ng-container *ngIf=\"!cmp.previewImage; else previewImage\">\n                <div class=\"h1\"><i c8yIcon=\"file-image-o\"></i></div>\n                <small translate>Preview not available</small>\n              </ng-container>\n              <ng-template #previewImage>\n                <img\n                  class=\"widget-thumbnail\"\n                  alt\n                  [src]=\"cmp.previewImage\"\n                />\n              </ng-template>\n            </div>\n            <p class=\"card-title text-truncate\">\n              <c8y-highlight\n                text=\"{{ cmp.label | translate }}\"\n                [pattern]=\"searchTerm\"\n              ></c8y-highlight>\n            </p>\n          </button>\n        </div>\n\n        <div\n          class=\"c8y-empty-state text-center\"\n          *ngIf=\"searchResult && searchResult.length === 0\"\n        >\n          <div\n            class=\"h1\"\n            c8yIcon=\"search\"\n          ></div>\n          <h3 translate>No widgets found.</h3>\n          <div class=\"d-flex\">\n            <p\n              class=\"m-r-8\"\n              translate\n            >\n              Rephrase your search term.\n            </p>\n            <button\n              class=\"btn btn-primary\"\n              title=\"{{ 'Reset search' | translate }}\"\n              type=\"button\"\n              (click)=\"resetSearch()\"\n            >\n              {{ 'Reset search' | translate }}\n            </button>\n          </div>\n        </div>\n      </div>\n    </div>\n\n    <!-- The following is intentional set to hidden to allow the ViewChild ref in the controller -->\n    <div\n      class=\"d-flex d-col fit-h\"\n      *ngIf=\"selected\"\n      [ngClass]=\"{ hidden: mode !== 'config' }\"\n    >\n      <div class=\"p-t-16 flex-no-shrink separator-bottom p-b-16\">\n        <div class=\"row\">\n          <div class=\"col-sm-4\">\n            <div class=\"p-l-24\">\n              <div class=\"text-left text-medium h4\">\n                {{ selected.label | translate }}\n              </div>\n              <p>\n                {{ selected.description | translate }}\n              </p>\n            </div>\n          </div>\n          <div class=\"col-sm-8\">\n            <div class=\"p-r-24\">\n              <c8y-form-group>\n                <label\n                  for=\"widgetTitle\"\n                  translate\n                >\n                  Title\n                </label>\n                <input\n                  class=\"form-control\"\n                  id=\"widgetTitle\"\n                  placeholder=\"{{ 'e.g.' | translate }} {{ componentLabel | translate }}\"\n                  name=\"title\"\n                  type=\"text\"\n                  required\n                  [(ngModel)]=\"selected.data.title\"\n                />\n              </c8y-form-group>\n            </div>\n          </div>\n        </div>\n      </div>\n      <div\n        class=\"row flex-grow\"\n        [ngClass]=\"{ 'd-flex': widgetConfig.options || hasConfig() }\"\n      >\n        <div\n          class=\"a-s-stretch\"\n          [ngStyle]=\"isLegacyAlarmWidget ? { 'pointer-events': 'none', opacity: '0.5' } : {}\"\n          *ngIf=\"!widgetConfig.settings?.noDeviceTarget && mode === 'config'\"\n          [ngClass]=\"{\n            'bg-level-1 col-sm-4 p-r-0': hasConfig(),\n            'bg-level-0 col-sm-12': !hasConfig()\n          }\"\n        >\n          <div\n            class=\"fit-h bg-inherit p-l-16\"\n            [ngClass]=\"{ 'p-r-24': !hasConfig() }\"\n          >\n            <div class=\"p-relative bg-inherit\">\n              <c8y-asset-selector-miller\n                class=\"d-block bg-inherit p-relative\"\n                style=\"height: calc(100vh - 422px)\"\n                (onSelected)=\"selectionChanged($event)\"\n                [config]=\"{\n                  view: 'miller',\n                  groupsSelectable: this.widgetConfig.settings?.groupsSelectable,\n                  showChildDevices: true,\n                  columnHeaders: true,\n                  showUnassignedDevices: true,\n                  search: !this.widgetConfig.settings.context?.additionParents,\n                  showFilter: true,\n                  singleColumn: !!this.hasConfig(),\n                  showSelected: true\n                }\"\n                [asset]=\"widgetConfig.settings?.context\"\n                [selectedDevice]=\"selectedDevice\"\n              ></c8y-asset-selector-miller>\n            </div>\n          </div>\n        </div>\n        <div\n          [ngClass]=\"{\n            'col-sm-8': !widgetConfig.settings?.noDeviceTarget,\n            'col-sm-12': widgetConfig.settings?.noDeviceTarget,\n            'sr-only': !hasConfig()\n          }\"\n        >\n          <c8y-dynamic-component\n            class=\"d-block\"\n            style=\"height: {{ hasConfig() ? 'calc(100vh - 422px)' : '0' }}\"\n            [ngClass]=\"{ 'inner-scroll p-r-24 p-t-16': !widgetConfig.settings?.noDeviceTarget }\"\n            [componentId]=\"selected.id\"\n            mode=\"config\"\n            [config]=\"widgetConfig\"\n            [notFoundError]=\"false\"\n            #config\n          ></c8y-dynamic-component>\n        </div>\n      </div>\n    </div>\n\n    <div\n      class=\"modal-body p-t-0\"\n      style=\"height: calc(100vh - 310px)\"\n      *ngIf=\"mode === 'style'\"\n    >\n      <div class=\"row\">\n        <div class=\"col-xs-6\">\n          <c8y-appearance-settings\n            [(themeClass)]=\"styling.contentClass\"\n            [(headerClass)]=\"styling.headerClass\"\n            [possibleStylingTheme]=\"possibleStyling.WIDGET_CONTENT_CLASSES\"\n            [possibleStylingHeader]=\"possibleStyling.WIDGET_HEADER_CLASSES\"\n            [defaultThemeClass]=\"defaultStyling.contentClass\"\n            [defaultHeaderClass]=\"defaultStyling.headerClass\"\n          ></c8y-appearance-settings>\n        </div>\n        <div class=\"col-xs-6 sticky-header-top-0\">\n          <c8y-widget-preview\n            style=\"height: calc(100vh - 382px)\"\n            [previewClasses]=\"getStyle(true)\"\n          ></c8y-widget-preview>\n        </div>\n      </div>\n    </div>\n  </div>\n\n  <div class=\"modal-footer\">\n    <button\n      class=\"btn btn-default\"\n      title=\"{{ 'Cancel' | translate }}\"\n      type=\"button\"\n      data-cy=\"widget-config--cancel-widget\"\n      (click)=\"close()\"\n    >\n      {{ 'Cancel' | translate }}\n    </button>\n    <button\n      class=\"btn btn-primary\"\n      title=\"{{ 'Save' | translate }}\"\n      type=\"submit\"\n      data-cy=\"widget-config--save-widget\"\n      (click)=\"save()\"\n      [disabled]=\"\n        !dynamicComponent ||\n        (((this.contextDashboardService.formDisabled$ | async) || isSaveDisabled()) &&\n          !!widgetHasConfigComponent)\n      \"\n      c8yProductExperience\n      [actionName]=\"current ? 'editWidget' : 'createWidget'\"\n      [actionData]=\"{ widgetName: selected && selected.id }\"\n    >\n      {{ 'Save' | translate }}\n    </button>\n  </div>\n</form>\n", dependencies: [{ kind: "directive", type: i2.IconDirective, selector: "[c8yIcon]", inputs: ["c8yIcon"] }, { kind: "directive", type: i2.C8yTranslateDirective, selector: "[translate],[ngx-translate]" }, { kind: "directive", type: i4.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i4.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "component", type: i2.HighlightComponent, selector: "c8y-highlight", inputs: ["pattern", "text", "elementClass", "shouldTrimPattern"] }, { kind: "directive", type: i3.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i3.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i3.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i3.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i3.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { kind: "directive", type: i3.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i3.NgForm, selector: "form:not([ngNoForm]):not([formGroup]),ng-form,[ngForm]", inputs: ["ngFormOptions"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "component", type: i2.FormGroupComponent, selector: "c8y-form-group", inputs: ["hasError", "hasWarning", "hasSuccess", "novalidation", "status"] }, { kind: "directive", type: i2.RequiredInputPlaceholderDirective, selector: "input[required], input[formControlName]" }, { kind: "component", type: i2.DynamicComponentComponent, selector: "c8y-dynamic-component", inputs: ["componentId", "config", "mode", "notFoundError", "executeResolvers"], outputs: ["updateWidgetClasses"] }, { kind: "directive", type: i2.ProductExperienceDirective, selector: "[c8yProductExperience]", inputs: ["actionName", "actionData", "inherit", "suppressDataOverriding"] }, { kind: "component", type: i8.MillerViewComponent, selector: "c8y-asset-selector-miller", inputs: ["config", "asset", "selectedDevice", "rootNode", "container"], outputs: ["onSelected", "onClearSelected"] }, { kind: "component", type: AppearanceSettingsComponent, selector: "c8y-appearance-settings", inputs: ["themeClass", "headerClass", "defaultThemeClass", "defaultHeaderClass", "dashboardSettings", "possibleStylingTheme", "possibleStylingHeader", "columns"], outputs: ["themeClassChange", "headerClassChange"] }, { kind: "component", type: WidgetPreviewComponent, selector: "c8y-widget-preview", inputs: ["previewClasses", "tab"] }, { kind: "pipe", type: i2.C8yTranslatePipe, name: "translate" }, { kind: "pipe", type: i4.AsyncPipe, name: "async" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WidgetConfigComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-widget-config', template: "<div class=\"modal-header\">\n  <div\n    class=\"h3\"\n    title=\"{{ 'Add widget' | translate }}\"\n    id=\"modal-title\"\n    *ngIf=\"!current\"\n    translate\n  >\n    Add widget\n  </div>\n  <div\n    class=\"h3\"\n    title=\"{{ 'Edit widget' | translate }}\"\n    id=\"modal-title\"\n    *ngIf=\"current\"\n    translate\n  >\n    Edit widget\n  </div>\n</div>\n<form\n  name=\"form\"\n  #configForm=\"ngForm\"\n>\n  <div\n    class=\"c8y-modal-tabs\"\n    id=\"modal-body\"\n  >\n    <div class=\"tabContainer\">\n      <ul class=\"nav nav-tabs nav-tabsc8y p-l-24\">\n        <li [class.active]=\"mode === 'select'\">\n          <button\n            class=\"btn\"\n            title=\"{{ 'Select widget' | translate }}\"\n            type=\"button\"\n            (click)=\"changeMode('select'); (false)\"\n          >\n            <i c8yIcon=\"th-large\"></i>\n            <span translate>Select widget</span>\n          </button>\n        </li>\n        <li [class.active]=\"mode === 'config'\">\n          <button\n            class=\"btn\"\n            title=\"{{ 'Configuration' | translate }}\"\n            type=\"button\"\n            [disabled]=\"!selected\"\n            (click)=\"changeMode('config'); (false)\"\n          >\n            <i c8yIcon=\"cog\"></i>\n            <span translate>Configuration</span>\n          </button>\n        </li>\n        <li [class.active]=\"mode === 'style'\">\n          <button\n            class=\"btn\"\n            title=\"{{ 'Appearance' | translate }}\"\n            type=\"button\"\n            [disabled]=\"!selected\"\n            (click)=\"changeMode('style'); (false)\"\n          >\n            <i c8yIcon=\"paint-brush\"></i>\n            <span translate>Appearance</span>\n          </button>\n        </li>\n      </ul>\n    </div>\n  </div>\n\n  <div class=\"modal-inner-scroll modal-inner-scroll--fixed\">\n    <div\n      class=\"bg-level-0 p-l-24 p-r-24 p-t-8 p-b-8 sticky-header-top-0 elevation-md\"\n      style=\"z-index: 2\"\n      *ngIf=\"mode === 'select'\"\n    >\n      <div class=\"row\">\n        <div class=\"col-sm-6\">\n          <div class=\"input-group input-group-search\">\n            <input\n              class=\"form-control\"\n              [attr.aria-label]=\"'Search' | translate\"\n              placeholder=\"{{ 'Search\u2026' | translate }}\"\n              type=\"text\"\n              data-cy=\"widget-config--Search\"\n              [(ngModel)]=\"searchTerm\"\n              [ngModelOptions]=\"{ standalone: true }\"\n              (keydown)=\"searchChange$.next($event)\"\n            />\n            <span class=\"input-group-btn\">\n              <button\n                class=\"btn btn-dot\"\n                title=\"{{ 'Search' | translate }}\"\n                type=\"button\"\n                (click)=\"resetSearch()\"\n              >\n                <i [c8yIcon]=\"searchTerm.length === 0 ? 'search' : 'close'\"></i>\n              </button>\n            </span>\n          </div>\n        </div>\n      </div>\n    </div>\n    <div\n      class=\"modal-body bg-level-2\"\n      *ngIf=\"mode === 'select'\"\n    >\n      <div class=\"card-group card-select m-b-0\">\n        <div\n          class=\"col-md-3 col-sm-4 col-xs-6\"\n          title=\"{{ cmp.description | translate }}\"\n          data-cy=\"widget-config--widget-list\"\n          *ngFor=\"let cmp of searchResult || components\"\n        >\n          <button\n            class=\"btn-clean d-col card p-8\"\n            [class.active]=\"selected === cmp\"\n            type=\"button\"\n            (click)=\"select(cmp)\"\n          >\n            <div\n              class=\"text-center p-8 m-b-8 d-col flex-center flex-grow bg-level-2\"\n              role=\"presentation\"\n            >\n              <ng-container *ngIf=\"!cmp.previewImage; else previewImage\">\n                <div class=\"h1\"><i c8yIcon=\"file-image-o\"></i></div>\n                <small translate>Preview not available</small>\n              </ng-container>\n              <ng-template #previewImage>\n                <img\n                  class=\"widget-thumbnail\"\n                  alt\n                  [src]=\"cmp.previewImage\"\n                />\n              </ng-template>\n            </div>\n            <p class=\"card-title text-truncate\">\n              <c8y-highlight\n                text=\"{{ cmp.label | translate }}\"\n                [pattern]=\"searchTerm\"\n              ></c8y-highlight>\n            </p>\n          </button>\n        </div>\n\n        <div\n          class=\"c8y-empty-state text-center\"\n          *ngIf=\"searchResult && searchResult.length === 0\"\n        >\n          <div\n            class=\"h1\"\n            c8yIcon=\"search\"\n          ></div>\n          <h3 translate>No widgets found.</h3>\n          <div class=\"d-flex\">\n            <p\n              class=\"m-r-8\"\n              translate\n            >\n              Rephrase your search term.\n            </p>\n            <button\n              class=\"btn btn-primary\"\n              title=\"{{ 'Reset search' | translate }}\"\n              type=\"button\"\n              (click)=\"resetSearch()\"\n            >\n              {{ 'Reset search' | translate }}\n            </button>\n          </div>\n        </div>\n      </div>\n    </div>\n\n    <!-- The following is intentional set to hidden to allow the ViewChild ref in the controller -->\n    <div\n      class=\"d-flex d-col fit-h\"\n      *ngIf=\"selected\"\n      [ngClass]=\"{ hidden: mode !== 'config' }\"\n    >\n      <div class=\"p-t-16 flex-no-shrink separator-bottom p-b-16\">\n        <div class=\"row\">\n          <div class=\"col-sm-4\">\n            <div class=\"p-l-24\">\n              <div class=\"text-left text-medium h4\">\n                {{ selected.label | translate }}\n              </div>\n              <p>\n                {{ selected.description | translate }}\n              </p>\n            </div>\n          </div>\n          <div class=\"col-sm-8\">\n            <div class=\"p-r-24\">\n              <c8y-form-group>\n                <label\n                  for=\"widgetTitle\"\n                  translate\n                >\n                  Title\n                </label>\n                <input\n                  class=\"form-control\"\n                  id=\"widgetTitle\"\n                  placeholder=\"{{ 'e.g.' | translate }} {{ componentLabel | translate }}\"\n                  name=\"title\"\n                  type=\"text\"\n                  required\n                  [(ngModel)]=\"selected.data.title\"\n                />\n              </c8y-form-group>\n            </div>\n          </div>\n        </div>\n      </div>\n      <div\n        class=\"row flex-grow\"\n        [ngClass]=\"{ 'd-flex': widgetConfig.options || hasConfig() }\"\n      >\n        <div\n          class=\"a-s-stretch\"\n          [ngStyle]=\"isLegacyAlarmWidget ? { 'pointer-events': 'none', opacity: '0.5' } : {}\"\n          *ngIf=\"!widgetConfig.settings?.noDeviceTarget && mode === 'config'\"\n          [ngClass]=\"{\n            'bg-level-1 col-sm-4 p-r-0': hasConfig(),\n            'bg-level-0 col-sm-12': !hasConfig()\n          }\"\n        >\n          <div\n            class=\"fit-h bg-inherit p-l-16\"\n            [ngClass]=\"{ 'p-r-24': !hasConfig() }\"\n          >\n            <div class=\"p-relative bg-inherit\">\n              <c8y-asset-selector-miller\n                class=\"d-block bg-inherit p-relative\"\n                style=\"height: calc(100vh - 422px)\"\n                (onSelected)=\"selectionChanged($event)\"\n                [config]=\"{\n                  view: 'miller',\n                  groupsSelectable: this.widgetConfig.settings?.groupsSelectable,\n                  showChildDevices: true,\n                  columnHeaders: true,\n                  showUnassignedDevices: true,\n                  search: !this.widgetConfig.settings.context?.additionParents,\n                  showFilter: true,\n                  singleColumn: !!this.hasConfig(),\n                  showSelected: true\n                }\"\n                [asset]=\"widgetConfig.settings?.context\"\n                [selectedDevice]=\"selectedDevice\"\n              ></c8y-asset-selector-miller>\n            </div>\n          </div>\n        </div>\n        <div\n          [ngClass]=\"{\n            'col-sm-8': !widgetConfig.settings?.noDeviceTarget,\n            'col-sm-12': widgetConfig.settings?.noDeviceTarget,\n            'sr-only': !hasConfig()\n          }\"\n        >\n          <c8y-dynamic-component\n            class=\"d-block\"\n            style=\"height: {{ hasConfig() ? 'calc(100vh - 422px)' : '0' }}\"\n            [ngClass]=\"{ 'inner-scroll p-r-24 p-t-16': !widgetConfig.settings?.noDeviceTarget }\"\n            [componentId]=\"selected.id\"\n            mode=\"config\"\n            [config]=\"widgetConfig\"\n            [notFoundError]=\"false\"\n            #config\n          ></c8y-dynamic-component>\n        </div>\n      </div>\n    </div>\n\n    <div\n      class=\"modal-body p-t-0\"\n      style=\"height: calc(100vh - 310px)\"\n      *ngIf=\"mode === 'style'\"\n    >\n      <div class=\"row\">\n        <div class=\"col-xs-6\">\n          <c8y-appearance-settings\n            [(themeClass)]=\"styling.contentClass\"\n            [(headerClass)]=\"styling.headerClass\"\n            [possibleStylingTheme]=\"possibleStyling.WIDGET_CONTENT_CLASSES\"\n            [possibleStylingHeader]=\"possibleStyling.WIDGET_HEADER_CLASSES\"\n            [defaultThemeClass]=\"defaultStyling.contentClass\"\n            [defaultHeaderClass]=\"defaultStyling.headerClass\"\n          ></c8y-appearance-settings>\n        </div>\n        <div class=\"col-xs-6 sticky-header-top-0\">\n          <c8y-widget-preview\n            style=\"height: calc(100vh - 382px)\"\n            [previewClasses]=\"getStyle(true)\"\n          ></c8y-widget-preview>\n        </div>\n      </div>\n    </div>\n  </div>\n\n  <div class=\"modal-footer\">\n    <button\n      class=\"btn btn-default\"\n      title=\"{{ 'Cancel' | translate }}\"\n      type=\"button\"\n      data-cy=\"widget-config--cancel-widget\"\n      (click)=\"close()\"\n    >\n      {{ 'Cancel' | translate }}\n    </button>\n    <button\n      class=\"btn btn-primary\"\n      title=\"{{ 'Save' | translate }}\"\n      type=\"submit\"\n      data-cy=\"widget-config--save-widget\"\n      (click)=\"save()\"\n      [disabled]=\"\n        !dynamicComponent ||\n        (((this.contextDashboardService.formDisabled$ | async) || isSaveDisabled()) &&\n          !!widgetHasConfigComponent)\n      \"\n      c8yProductExperience\n      [actionName]=\"current ? 'editWidget' : 'createWidget'\"\n      [actionData]=\"{ widgetName: selected && selected.id }\"\n    >\n      {{ 'Save' | translate }}\n    </button>\n  </div>\n</form>\n" }]
        }], ctorParameters: () => [{ type: WidgetService }, { type: i2$2.BsModalRef }, { type: i1$1.InventoryService }, { type: ContextDashboardService }], propDecorators: { dynamicComponent: [{
                type: ViewChild,
                args: ['config', { static: false }]
            }], configForm: [{
                type: ViewChild,
                args: ['configForm', { static: false }]
            }] } });

/**
 * Holds current state of dashboard children during edit mode.
 */
class DashboardOriginatorService {
    /**
     * Current dashboard children state name for indicating what change will be undone.
     */
    get currentStateName() {
        return this.state?.name;
    }
    /**
     * Initializes dashboard children state on edit mode start.
     * @param state Dashboard children initial state.
     */
    initState(state) {
        this.state = state;
    }
    /**
     * Updates dashboard children state when it is changed or restored with undo/redo.
     * @param state Dashboard children updated state.
     */
    setState(state) {
        this.state = state;
    }
    /**
     * Returns copy of current state.
     */
    getState() {
        return cloneDeep(this.state);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardOriginatorService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardOriginatorService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardOriginatorService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

/**
 * Caretaker is responsible for undo and redo functionalities.
 */
class DashboardCaretakerService {
    /**
     * Current undo stack length for defining undo button disable state.
     */
    get undoStackLength() {
        return this.undoStack.length;
    }
    /**
     * Redo stack latest item for defining redo button disable state and its' title.
     */
    get redoStackLastItem() {
        return this.redoStack[this.redoStack.length - 1];
    }
    constructor(originator) {
        this.originator = originator;
        /**
         * List of dashboard children changes.
         * @private
         */
        this.undoStack = [];
        /**
         * List of dashboard children changes that were undone and can be redone back.
         * @private
         */
        this.redoStack = [];
    }
    /**
     * Adds current dashboard children state to undo stack and clears redo stack.
     */
    backup() {
        this.undoStack.push(this.originator.getState());
        this.redoStack = [];
    }
    /**
     * Reverts last dashboard children change and puts it in redo stack.
     * @returns Current state of dashboard children after reverting last change.
     */
    undo() {
        if (!this.undoStack.length) {
            return;
        }
        const memento = this.undoStack.pop();
        this.redoStack.push(this.originator.getState());
        this.originator.setState(memento);
        return memento;
    }
    /**
     * Applies previously undone change.
     * @returns Current state of dashboard children after applying previously undone change.
     */
    redo() {
        if (!this.redoStack.length) {
            return;
        }
        this.undoStack.push(this.originator.getState());
        const memento = this.redoStack.pop();
        this.originator.setState(memento);
        return memento;
    }
    /**
     * Clears both undo and redo stack, sets current state as initial state and returns initial state.
     * @returns Initial state of dashboard children.
     */
    reset() {
        const initialItem = this.undoStack[0] || this.originator.getState();
        this.undoStack = [];
        this.redoStack = [];
        this.originator.initState(initialItem);
        return initialItem;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardCaretakerService, deps: [{ token: DashboardOriginatorService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardCaretakerService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardCaretakerService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: DashboardOriginatorService }] });

/**
 * Facade for implementation of Memento design pattern (caretaker, originator). Responsible for undo/redo feature
 * during edit mode of dashboard.
 */
class DashboardEditModeService {
    get undoButtonDisabled() {
        return this.caretaker.undoStackLength === 0;
    }
    /**
     * Current dashboard change name for undo button title.
     */
    get changeToUndoName() {
        return this.originator.currentStateName;
    }
    /**
     * Redo stack latest item for defining redo button disable state and its title.
     */
    get redoStackLastItem() {
        return this.caretaker.redoStackLastItem;
    }
    constructor(originator, caretaker) {
        this.originator = originator;
        this.caretaker = caretaker;
    }
    /**
     * Initializes dashboard children state on edit mode start.
     * @param state Dashboard children initial state.
     */
    init(state) {
        this.originator.initState(state);
    }
    /**
     * Saves current state for further undo actions and sets new dashboard children state.
     * @param state Dashboard children updated state.
     */
    newState(state) {
        this.caretaker.backup();
        this.originator.setState(state);
    }
    /**
     * Returns copy of current state.
     */
    getCurrentState() {
        return this.originator.getState();
    }
    /**
     * Reverts last dashboard children change.
     * @returns Current state of dashboard children after reverting last change.
     */
    undo() {
        return this.caretaker.undo();
    }
    /**
     * Applies previously undone change.
     * @returns Current state of dashboard children after applying previously undone change.
     */
    redo() {
        return this.caretaker.redo();
    }
    /**
     * Resets dashboard children state to initial one and returns initial state.
     * @returns Initial state of dashboard children.
     */
    reset() {
        return this.caretaker.reset();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardEditModeService, deps: [{ token: DashboardOriginatorService }, { token: DashboardCaretakerService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardEditModeService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardEditModeService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: DashboardOriginatorService }, { type: DashboardCaretakerService }] });

/**
 * The context dashboard is a dashboard which resolves it data from the current context (device or group)
 * it is displayed on. It usually uses the route.data for it, but you can pass
 * a different managedObject to the [mo] input parameter to change that behavior.
 */
class ContextDashboardComponent {
    get disabled() {
        return !this.hasPermissionToEditDashboard || !this.dashboardDetails?.isCollapsed;
    }
    constructor(route, router, contextDashboardService, alert, renderer, moduleConfig, widgetService, bsModal, gainsightService, actionBarService, translateService, modal, editModeService) {
        this.route = route;
        this.router = router;
        this.contextDashboardService = contextDashboardService;
        this.alert = alert;
        this.renderer = renderer;
        this.moduleConfig = moduleConfig;
        this.widgetService = widgetService;
        this.bsModal = bsModal;
        this.gainsightService = gainsightService;
        this.actionBarService = actionBarService;
        this.translateService = translateService;
        this.modal = modal;
        this.editModeService = editModeService;
        this.childrenClasses = '';
        this.setTitle = false;
        this.defaultWidgets = [];
        this._canCopy = true;
        this.canDelete = true;
        this.isLoading = true;
        this.showContextHelpButton = true;
        /**
         * Hides dashboard availability selection.
         */
        this.hideAvailability = false;
        this.class = '';
        this.widgets = [];
        this.canCopy = true;
        this.dashboardTypeLabel = gettext('Dashboard for "{{ dashboardType }}"');
        this.dashboardTypePopover = gettext(`
  The layout and configuration of this dashboard is used by all other assets of model type
  <strong>{{ dashboardType }}</strong>. Any changes made to this dashboard instance will be applied to all
  other instances.`);
        this.hasPermissionToEditDashboard = false;
    }
    ngOnInit() {
        if (!this.name) {
            this.loadContextDashboard();
            return;
        }
        this.loadNamedDashboard();
    }
    async beforeUnloadHandler($event) {
        const canDeactivate = await this.canDeactivate(true);
        if (!canDeactivate) {
            $event.returnValue = true;
        }
    }
    /**
     * Applies the current context to the widget
     * @param widget The widget to apply the context to.
     */
    applyDeviceTarget(widget) {
        if (widget.config.device) {
            widget.config.device = { id: this.context.id, name: this.context.name };
        }
    }
    /**
     * Removes the route listener.
     */
    ngOnDestroy() {
        if (this.dataSub) {
            this.dataSub.unsubscribe();
        }
    }
    /**
     * Guards component from unintended navigation away or closing tab without saving changes.
     * Navigation continues if true is returned, and navigation is cancelled if returned value is false.
     * @param omitConfirm Omits confirm calls inside method body (without this param, when method is used in
     * on 'beforeunload' event handler, error is thrown in console because confirm is blocked by browser anyway and returns false)
     */
    async canDeactivate(omitConfirm = false) {
        const canDeactivate = (await this.dashboardDetails.canDeactivate(omitConfirm)) &&
            (await this.widgetsDashboard.canDeactivate(omitConfirm));
        // Needed in order to reset edit mode, otherwise when switching between dashboards, the edit mode is still enabled.
        if (canDeactivate) {
            await this.cancelEditMode(true);
        }
        return canDeactivate;
    }
    /**
     * Restores the dashboard widgets to the default widgets.
     */
    async restore() {
        const mesg = gettext('You are about to reset the widgets of this dashboard. All changes to the dashboard widgets will get lost and cannot be recovered. Do you want to proceed?');
        try {
            await this.modal.confirm(gettext('Reset widgets'), mesg, Status.WARNING, {
                ok: gettext('Reset`dashboard`'),
                cancel: gettext('Cancel')
            });
            this.isLoading = true;
            this.mo.c8y_Dashboard.children = this.contextDashboardService.mapWidgets(this.defaultWidgets);
            this.mo.c8y_Dashboard.historyDescription = { changeType: 'reset' };
            await this.contextDashboardService.update(this.mo);
            await this.onLoad();
        }
        catch (error) {
            if (error) {
                this.alert.addServerFailure(error);
            }
        }
        finally {
            this.isLoading = false;
        }
    }
    /**
     * Method called on every widgets dimensions or position change but also for adding new widget (because adding
     * widget causes layout changes). It recognizes what type of change has been done and updates current widgets state
     * accordingly.
     * @param child Change object.
     */
    positionOrWidgetDimensionChange(child) {
        const currentState = this.editModeService.getCurrentState()?.children || {};
        const descriptionProp = child.children.length === Object.values(currentState).length ? 'arrangement' : 'added';
        let changeName;
        let widgetsChanged;
        if (descriptionProp === 'added') {
            changeName = DASHBOARD_CHILDREN_STATE_NAME.added;
            const addedWidget = child.children.find(c => !currentState[c.data.id]);
            widgetsChanged = [addedWidget.data];
        }
        else {
            changeName = DASHBOARD_CHILDREN_STATE_NAME.arrangement;
            widgetsChanged = child.children
                .map(c => {
                const lastStateChild = currentState[c.data.id];
                if (c.x != lastStateChild._x ||
                    c.y != lastStateChild._y ||
                    c.width != lastStateChild._width ||
                    c.height != lastStateChild._height) {
                    return c.data;
                }
            })
                .filter(Boolean);
        }
        this.updateDashboardChildren(child, changeName, descriptionProp, widgetsChanged);
    }
    async revertChange(revertType) {
        let dashboardChildren;
        if (revertType === 'undo') {
            dashboardChildren = this.editModeService.undo().children;
        }
        else {
            dashboardChildren = this.editModeService.redo().children;
        }
        await this.setWidgets(dashboardChildren);
    }
    /**
     * Updates all dashboards children's. Useful for position changes on the dashboard.
     * @param child The child to change.
     * @param changeName Name of the change to indicate it on undo/redo button.
     * @param descriptionProp Property to add to dashboard change history.
     * @param widgetsChanged List of changed widgets.
     */
    updateDashboardChildren(child, changeName, descriptionProp, widgetsChanged) {
        const { children } = child;
        const mappedChildren = keyBy(children.map(c => this.componentToWidget(c)), 'id');
        this.setNewState({ name: changeName, children: mappedChildren }, descriptionProp, widgetsChanged);
    }
    /**
     * Copies the dashboard and current context to a clipboard.
     */
    async copyDashboard() {
        const viewContext = this.route.parent.snapshot.data?.context;
        this.contextDashboardService.copyClipboard = {
            dashboardId: this.mo.id,
            dashboard: cloneDeep(this.mo.c8y_Dashboard),
            context: cloneDeep({ context: viewContext, contextData: this.context })
        };
        if (viewContext) {
            const ctx = viewContext.split('/').shift();
            const msg = this.translateService.instant('Dashboard copied. Navigate to the desired {{ ctx }} and select "Paste dashboard"', { ctx });
            this.alert.success(msg);
        }
        this.actionBarService.refresh();
    }
    /**
     * Remove the complete dashboard and navigate away.
     */
    async deleteDashboard() {
        await this.contextDashboardService.delete(this.mo);
        if (this.route.parent) {
            const route = this.route.parent.snapshot.url.map(segment => segment.path).join('/');
            this.router.navigateByUrl(route);
        }
        await this.onDeleteGSEvent();
    }
    get isDeviceTypeDashboard() {
        return !!this.dashboard?.deviceType;
    }
    /**
     * Edits a widget on the dashboard.
     * @param change The widget change event.
     */
    async editWidget(change) {
        const { x, y, width, height } = change.source;
        const component = await this.widgetService.getWidgetDefinition(change.widget.name || change.widget.componentId);
        if (!component) {
            this.addWidget();
            return;
        }
        await this.addWidget({
            ...component,
            data: { ...component.data, ...change.widget, _x: x, _y: y, _width: width, _height: height }
        });
    }
    /**
     * Adds a widget to the dashboard.
     * @param selected Define a selected component to switch to edit mode directly.
     */
    async addWidget(selected) {
        const partialCloneSelected = selected
            ? { ...selected, data: cloneDeep(selected.data) }
            : selected;
        const activeContext = this.context.contextData ? this.context.contextData : this.context;
        const initialState = {
            mo: this.mo,
            context: this.context.c8y_Report ? {} : activeContext,
            selected: partialCloneSelected
        };
        const modal = this.bsModal.show(WidgetConfigComponent, {
            class: 'modal-lg',
            ariaDescribedby: 'modal-body',
            ariaLabelledBy: 'modal-title',
            initialState,
            ignoreBackdropClick: true,
            keyboard: false
        }).content;
        try {
            const newWidget = await modal.result;
            if (!this.mo.c8y_Dashboard.children) {
                this.mo.c8y_Dashboard.children = {};
            }
            newWidget.classes = this.mergeWidgetClasses(newWidget);
            await this.updateWidget(newWidget);
            // New state in edit mode is added only for widget update. When adding widget, layout change is always triggered,
            // so it's easier to set new state on layout change only
            if (selected) {
                const children = {
                    ...this.editModeService.getCurrentState().children,
                    [newWidget.id]: newWidget
                };
                this.setNewState({ name: DASHBOARD_CHILDREN_STATE_NAME.config, children }, 'config', [
                    newWidget
                ]);
            }
            modal.close();
        }
        catch (ex) {
            // intended empty
        }
    }
    async saveWidgetsToDashboard() {
        const currentState = this.editModeService.getCurrentState();
        this.mo.c8y_Dashboard.children = currentState.children;
        this.mo.c8y_Dashboard.historyDescription = {
            changeType: 'update',
            widgetChanges: this.mapStateToHistoryDescription(currentState.changeHistory)
        };
        await this.contextDashboardService.update(this.mo);
        this.editModeService.reset();
        this.editModeService.init({
            name: DASHBOARD_CHILDREN_STATE_NAME.initial,
            children: this.mo.c8y_Dashboard.children,
            changeHistory: {}
        });
        this.isCopyDisabled = this.getDashboardCopyPermissionState();
    }
    async cancelEditMode(onDeactivate = false) {
        const dashboardChildren = this.editModeService.reset();
        if (this.dashboard) {
            this.dashboard.historyDescription = {};
        }
        this.widgetsDashboard.editMode$.next(false);
        if (!onDeactivate) {
            // when setWidgets is called during navigation from device to device, navigation fails
            await this.setWidgets(dashboardChildren.children);
        }
    }
    /**
     * Updates a widget or adds a new one if it doesn't exist on
     * the dashboard.
     * @param widget The new widget
     */
    async updateWidget(widget) {
        const index = findIndex(this.widgets, { id: widget.id });
        const isNew = index === -1;
        const mappedWidget = await this.widgetService.mapLegacy(widget);
        if (isNew) {
            this.widgets.push(mappedWidget);
        }
        else {
            this.widgets.splice(index, 1, mappedWidget);
        }
    }
    /**
     * Removes a widget and rearranges the remaining ones
     * if necessary.
     * @param change The change event.
     */
    async deleteWidget(change) {
        try {
            const { widget, source } = change;
            const removed = this.widgets.find(({ id }) => id === widget.id);
            this.widgets.splice(this.widgets.indexOf(removed), 1);
            const { dashboard } = source;
            dashboard.children = dashboard.children.filter(c => c.data.id !== widget.id);
            // using setTimeout to give the component the chance to remove it.
            const sleep = timeout => new Promise(resolve => setTimeout(resolve, timeout));
            await sleep(0);
            const child = new DashboardChildChange(source);
            child.collapseUpAll();
            this.updateDashboardChildren(child, DASHBOARD_CHILDREN_STATE_NAME.removed, 'removed', [
                widget
            ]);
        }
        catch (e) {
            this.alert.addServerFailure(e);
        }
    }
    /**
     * This is a workaround to ensure that the dragged-element
     * (which is attached to the body) has the right styling.
     */
    addDashboardClassToBody() {
        this.class.split(' ').forEach(cssClass => {
            this.renderer.addClass(document.body, cssClass);
        });
    }
    /**
     * This is a workaround to ensure that the dragged-element
     * (which is attached to the body) has the right styling.
     */
    removeDashboardClassFromBody() {
        this.class.split(' ').forEach(cssClass => {
            this.renderer.removeClass(document.body, cssClass);
        });
    }
    async onLoad(trackExperience) {
        this.hasPermissionToEditDashboard =
            this.dashboard && !this.dashboard.isTransient
                ? await this.contextDashboardService.canEditDashboard(this.mo)
                : false;
        this.canCopy =
            this._canCopy &&
                !this.dashboard?.isTransient &&
                (this.contextDashboardService.isDeviceDashboard(this.mo) ||
                    this.contextDashboardService.isDeviceType(this.mo) ||
                    this.contextDashboardService.isGroupDashboard(this.mo));
        const dashboardChildren = cloneDeep(this.mo.c8y_Dashboard?.children);
        const dashboardClasses = {
            'c8y-grid-dashboard': true,
            dashboard: true,
            ...this.dashboard?.classes
        };
        this.isCopyDisabled = this.dashboard
            ? this.getDashboardCopyPermissionState()
            : { state: false, reason: null };
        this.editModeService.init({
            name: gettext('Initial state'),
            children: dashboardChildren,
            changeHistory: {}
        });
        await this.setWidgets(dashboardChildren, trackExperience);
        this.class = Object.keys(dashboardClasses).join(' ');
        if (this.isReport) {
            this.addReportDashboardSettings();
        }
        this.isLoading = false;
        if (!this.dashboard) {
            this.dashboardDetails.show(false);
        }
        else {
            await this.onLoadGSEvent();
        }
    }
    async dashboardPreview(layoutChanges) {
        if (layoutChanges?.classes) {
            const dashboardClasses = {
                'c8y-grid-dashboard': true,
                dashboard: true,
                ...layoutChanges.classes
            };
            this.class = Object.keys(dashboardClasses).join(' ');
        }
        else if (this.dashboard) {
            this.dashboard.widgetClasses = {
                ...this.dashboard.widgetClasses,
                ...layoutChanges.widgetClasses
            };
        }
    }
    async reloadDashboard(dashboardMo) {
        this.dashboard = dashboardMo.c8y_Dashboard;
        this.mo = dashboardMo;
        await this.onLoad();
    }
    async setWidgets(dashboardChildren, trackExperience = false) {
        const isDeviceType = this.contextDashboardService.isDeviceType(this.mo);
        this.widgets = await Promise.all(Object.values(dashboardChildren || {}).map(widget => {
            widget.classes = this.mergeWidgetClasses(widget);
            if (isDeviceType) {
                this.applyDeviceTarget(widget);
            }
            if (trackExperience) {
                this.gainsightService.triggerEvent('loadWidget', {
                    widgetName: widget.componentId || widget.name
                });
            }
            return this.widgetService.mapLegacy(widget);
        }));
    }
    loadContextDashboard() {
        this.dataSub = this.route.data.subscribe(({ dashboard, isReport }) => {
            this.context = this.route.parent.snapshot.data.contextData || {};
            this.title = this.context?.name;
            this.mo = dashboard;
            this.dashboard = this.mo.c8y_Dashboard;
            this.isReport = isReport || this.contextDashboardService.isReport(this.mo);
            if (this.isReport && this.dashboard && !this.dashboard?.name) {
                this.dashboard.name = this.title;
            }
            if (this.isReport && this.dashboard) {
                this.dashboard.c8y_IsNavigatorNode = this.context.c8y_IsNavigatorNode;
            }
            this.patchSensorPhoneDashboard(this.dashboard, this.mo.owner, this.context?.type);
            this.onLoad(true);
        });
    }
    /**
     * To enable translation for widgets within the dashboard, the "translateWidgetTitle" flag must be enabled.
     * The property needs to be patched, as the "Sensor App" does not provide this setting.
     */
    patchSensorPhoneDashboard(dashboard, owner, type) {
        if (type === 'c8y_SensorPhone' && owner?.includes('device_phone')) {
            dashboard.translateWidgetTitle = true;
        }
    }
    loadNamedDashboard() {
        this.dataSub = this.contextDashboardService
            .getNamedDashboardOrCreate(this.name, this.defaultWidgets, this.context)
            .subscribe(mo => {
            this.context = this.context || {};
            this.mo = mo;
            this.dashboard = this.mo.c8y_Dashboard;
            this.onLoad(true);
        });
    }
    mergeWidgetClasses(widget) {
        const hasHeaderClass = WIDGET_HEADER_CLASSES.find(el => widget.classes && widget.classes[el.class]);
        const widgetClasses = hasHeaderClass
            ? { ...widget.classes }
            : { ...this.dashboard.widgetClasses, ...widget.classes };
        return {
            card: true,
            'card-dashboard': true,
            [kebabCase(widget.componentId || widget.name)]: true,
            ...widgetClasses
        };
    }
    componentToWidget(child) {
        return {
            ...omit(child.data, ['componentTransformConfigWithContext', 'transformConfigWithContext']), // remove legacy
            ...{ _x: child.x, _y: child.y, _width: child.width, _height: child.height }
        };
    }
    addReportDashboardSettings() {
        this.setTitle = true;
        this.title = this.context?.name || gettext('New report');
        this.breadcrumbSettings = { icon: 'th', label: 'Reports', path: 'reports' };
        this.canDelete = false;
    }
    getDashboardCopyPermissionState() {
        if (!this.contextDashboardService.hasPermissionsToCopyDashboard()) {
            return { state: false, reason: CopyDashboardDisabledReason.PERMISSIONS };
        }
        const allDashboardChildrenAreValid = every(this.mo.c8y_Dashboard.children, child => {
            const config = child.config || {};
            const dataPoints = config.datapoints || [];
            return !((config.device && config.device.id !== this.context.id) ||
                some(dataPoints, dataPoint => dataPoint.__target?.id !== this.context.id));
        });
        if (!allDashboardChildrenAreValid) {
            return { state: false, reason: CopyDashboardDisabledReason.WRONG_REFERENCE };
        }
        return { state: true };
    }
    setNewState(state, descriptionProp, widgetsChanged) {
        const description = this.getDescriptionForNewState(descriptionProp, widgetsChanged);
        this.editModeService.newState({ ...state, changeHistory: description });
    }
    getDescriptionForNewState(descriptionProp, widgetsChanged) {
        const changeHistory = this.editModeService.getCurrentState().changeHistory;
        if (!changeHistory[descriptionProp]) {
            changeHistory[descriptionProp] = {};
        }
        widgetsChanged.forEach(w => {
            if (descriptionProp === 'removed' && changeHistory.added?.[w.id]) {
                // if widget was added during current edit session and then removed, it should not be at description at all
                delete changeHistory.added[w.id];
                if (changeHistory.config?.[w.id]) {
                    delete changeHistory.config[w.id];
                }
                if (changeHistory.arrangement?.[w.id]) {
                    delete changeHistory?.arrangement[w.id];
                }
            }
            else if ((descriptionProp === 'config' || descriptionProp === 'arrangement') &&
                changeHistory.added?.[w.id]) {
                // if widget was added and then modified in current edit session, it should only be indicated as added
            }
            else {
                changeHistory[descriptionProp][w.id] = w;
            }
        });
        return changeHistory;
    }
    mapStateToHistoryDescription(description) {
        const historyDescription = {};
        for (const [key, value] of Object.entries(description)) {
            const widgets = Object.values(value);
            if (!widgets.length) {
                continue;
            }
            historyDescription[key] = Object.values(value).map(widget => widget.title);
        }
        return historyDescription;
    }
    async onDeleteGSEvent() {
        const parentName = await this.convertStringToHash(this.context?.name);
        const dashboardName = await this.convertStringToHash(this.dashboard?.name);
        this.gainsightService.triggerEvent(PRODUCT_EXPERIENCE.DASHBOARD.EVENTS.DASHBOARDS, {
            component: PRODUCT_EXPERIENCE.DASHBOARD.COMPONENTS.DELETE_DASHBOARD,
            action: PRODUCT_EXPERIENCE.DASHBOARD.ACTIONS.DELETE,
            name: dashboardName,
            id: this.mo.id,
            nameId: `${dashboardName}_${this.mo.id}`,
            parentAssetId: this.context?.id ? this.context.id : 'noContext',
            parentAssetName: this.context?.id ? parentName : 'noContext',
            parentAssetType: this.context?.id ? this.context.type : 'noContext',
            parentAssetNameId: this.context?.id ? `${parentName}_${this.context.id}` : 'noContext',
            parentAssetNameDashboardName: this.context?.id
                ? `${parentName}_${dashboardName}`
                : 'noContext',
            parentAssetIdDashboardId: this.context?.id ? `${this.context.id}_${this.mo.id}` : 'noContext',
            parentAssetNameDashboardId: this.context?.id ? `${parentName}_${this.mo.id}` : 'noContext',
            parentAssetNameIdDashboardNameId: this.context?.id
                ? `${parentName}_${this.context.id}_${dashboardName}_${this.mo.id}`
                : 'noContext',
            dashboardType: this.dashboard.deviceType ? this.dashboard.deviceTypeValue : null,
            context: this.contextDashboardService.getContextForGS(this.context)
        });
    }
    async onLoadGSEvent() {
        const parentName = await this.convertStringToHash(this.context?.name);
        const dashboardName = (await this.convertStringToHash(this.dashboard?.name)) ??
            this.extractDefaultDashboardName(this.mo) ??
            'none';
        this.gainsightService.triggerEvent(this.isReport
            ? PRODUCT_EXPERIENCE.DASHBOARD.EVENTS.REPORTS
            : PRODUCT_EXPERIENCE.DASHBOARD.EVENTS.DASHBOARDS, {
            component: PRODUCT_EXPERIENCE.DASHBOARD.COMPONENTS.DASHBOARD_VIEW,
            action: PRODUCT_EXPERIENCE.DASHBOARD.ACTIONS.LOAD,
            name: dashboardName,
            id: this.mo.id,
            nameId: `${dashboardName}_${this.mo.id}`,
            parentAssetId: this.context?.id ? this.context.id : 'noContext',
            parentAssetName: this.context?.id ? parentName : 'noContext',
            parentAssetType: this.context?.id ? this.context.type : 'noContext',
            parentAssetNameId: this.context?.id ? `${parentName}_${this.context.id}` : 'noContext',
            parentAssetNameDashboardName: this.context?.id
                ? `${parentName}_${dashboardName}`
                : 'noContext',
            parentAssetIdDashboardId: this.context?.id
                ? `${this.context.id}_${this.mo.id}`
                : 'noContext',
            parentAssetNameDashboardId: this.context?.id ? `${parentName}_${this.mo.id}` : 'noContext',
            parentAssetNameIdDashboardNameId: this.context?.id
                ? `${parentName}_${this.context.id}_${dashboardName}_${this.mo.id}`
                : 'noContext',
            dashboardType: this.dashboard.deviceType ? this.dashboard.deviceTypeValue : null,
            context: this.isReport
                ? PRODUCT_EXPERIENCE.DASHBOARD.CONTEXT.REPORT
                : this.contextDashboardService.getContextForGS(this.context)
        });
    }
    extractDefaultDashboardName(obj) {
        const nameKey = Object.keys(obj).find(key => key.startsWith('c8y_Dashboard!name!'));
        if (nameKey) {
            return nameKey.split('!').pop();
        }
        return null;
    }
    async convertStringToHash(str) {
        if (!str) {
            return null;
        }
        return (await this.gainsightService.shouldSendPiiData())
            ? str
            : this.gainsightService.hashGroupName(str);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ContextDashboardComponent, deps: [{ token: i1.ActivatedRoute }, { token: i1.Router }, { token: ContextDashboardService }, { token: i2.AlertService }, { token: i0.Renderer2 }, { token: CONTEXT_DASHBOARD_CONFIG }, { token: WidgetService }, { token: i2$2.BsModalService }, { token: i2.GainsightService }, { token: i2.ActionBarService }, { token: i2$1.TranslateService }, { token: i2.ModalService }, { token: DashboardEditModeService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: ContextDashboardComponent, selector: "c8y-context-dashboard", inputs: { name: "name", childrenClasses: "childrenClasses", context: "context", setTitle: "setTitle", defaultWidgets: "defaultWidgets", _canCopy: ["canCopy", "_canCopy"], canDelete: "canDelete", isLoading: "isLoading", breadcrumbSettings: "breadcrumbSettings", showContextHelpButton: "showContextHelpButton", translateWidgetTitle: "translateWidgetTitle", hideAvailability: "hideAvailability" }, host: { listeners: { "window:beforeunload": "beforeUnloadHandler($event)" }, properties: { "class": "this.class" }, styleAttribute: "\n      display: block;\n    ", classAttribute: "dashboard c8y-grid-dashboard" }, viewQueries: [{ propertyName: "dashboardDetails", first: true, predicate: DashboardDetailComponent, descendants: true, static: true }, { propertyName: "widgetsDashboard", first: true, predicate: WidgetsDashboardComponent, descendants: true, static: true }], ngImport: i0, template: "<c8y-title *ngIf=\"title\">\n  {{ title }}\n</c8y-title>\n\n<c8y-action-bar-item\n  [placement]=\"'right'\"\n  [priority]=\"10000\"\n  *ngIf=\"dashboard?.deviceType && dashboard.deviceTypeValue\"\n>\n  <button\n    class=\"btn-clean btn-link\"\n    popoverTitle=\"{{ 'Dashboard template' | translate }}\"\n    [attr.aria-label]=\"'Help' | translate\"\n    [popover]=\"dashboardTypePopoverRef\"\n    placement=\"bottom\"\n    triggers=\"focus\"\n    container=\"body\"\n    type=\"button\"\n  >\n    <span class=\"tag tag--info text-12\">\n      <span class=\"dashboard-template-marker\"></span>\n      {{ dashboardTypeLabel | translate: { dashboardType: dashboard.deviceTypeValue } }}\n    </span>\n  </button>\n  <ng-template #dashboardTypePopoverRef>\n    <div\n      [innerHTML]=\"dashboardTypePopover | translate: { dashboardType: dashboard.deviceTypeValue }\"\n    ></div>\n  </ng-template>\n</c8y-action-bar-item>\n\n<c8y-action-bar-item\n  [placement]=\"'right'\"\n  [priority]=\"-1\"\n  *ngIf=\"defaultWidgets.length > 0\"\n>\n  <button\n    class=\"btn btn-link\"\n    title=\"{{ 'Reset widgets' | translate }}\"\n    type=\"button\"\n    px-event=\"Reset dashboard\"\n    (click)=\"restore()\"\n    [disabled]=\"disabled || (widgetsDashboard?.editMode$ | async)\"\n    data-cy=\"context-dashboard--button-reset-dashboard\"\n  >\n    <i\n      class=\"m-r-4\"\n      c8yIcon=\"reset\"\n    ></i>\n    <span class=\"visible-xs-inline hidden-sm visible-md-inline visible-lg-inline\">\n      {{ 'Reset widgets' | translate }}\n    </span>\n  </button>\n</c8y-action-bar-item>\n\n<c8y-help\n  src=\"/docs/cockpit/working-with-dashboards/#working-with-dashboards\"\n  *ngIf=\"showContextHelpButton\"\n></c8y-help>\n\n<c8y-dashboard-detail\n  class=\"d-contents\"\n  [isReport]=\"isReport\"\n  [dashboard]=\"dashboard\"\n  [mo]=\"mo\"\n  [context]=\"context\"\n  [deviceType]=\"context?.type\"\n  [hideAvailability]=\"hideAvailability\"\n  (dashboardSaved)=\"reloadDashboard($event)\"\n  (previewChanged)=\"dashboardPreview($event)\"\n></c8y-dashboard-detail>\n\n<c8y-widgets-dashboard\n  [context]=\"context\"\n  [contextDashboard]=\"dashboard\"\n  [widgets]=\"widgets\"\n  [isCopyDisabled]=\"isCopyDisabled\"\n  [settings]=\"{\n    isLoading: isLoading,\n    isDisabled: disabled,\n    canDelete: canDelete && !!dashboard,\n    translateWidgetTitle: dashboard?.translateWidgetTitle ?? translateWidgetTitle,\n    allowFullscreen: moduleConfig.allowFullscreen,\n    title: setTitle ? dashboard?.name || title : undefined,\n    widgetMargin: dashboard?.widgetMargin,\n    canCopy: canCopy && !!dashboard,\n    defaultWidth: dashboard?.columns >= 24 ? 8 : 4,\n    columns: dashboard?.columns || 12\n  }\"\n  [breadcrumb]=\"breadcrumbSettings\"\n  [editModeButtons]=\"{\n    undoButtonDisabled: editModeService.undoButtonDisabled,\n    changeToUndoName: editModeService.changeToUndoName,\n    redoButtonDisabled: !editModeService.redoStackLastItem,\n    changeToRedoName: editModeService.redoStackLastItem?.name\n  }\"\n  (onChangeDashboard)=\"positionOrWidgetDimensionChange($event)\"\n  (onAddWidget)=\"addWidget()\"\n  (onEditWidget)=\"editWidget($event)\"\n  (onDeleteWidget)=\"deleteWidget($event)\"\n  (onSaveDashboard)=\"saveWidgetsToDashboard()\"\n  (onCancelDashboard)=\"cancelEditMode()\"\n  (revertChange)=\"revertChange($event)\"\n  (onChangeStart)=\"addDashboardClassToBody()\"\n  (onChangeEnd)=\"removeDashboardClassFromBody()\"\n  (onEditDashboard)=\"dashboardDetails.show(true)\"\n  (onCopyDashboard)=\"copyDashboard()\"\n  (onDeleteDashboard)=\"deleteDashboard()\"\n></c8y-widgets-dashboard>\n", dependencies: [{ kind: "component", type: i2.ActionBarItemComponent, selector: "c8y-action-bar-item", inputs: ["placement", "priority", "itemClass", "injector", "groupId", "inGroupPriority"] }, { kind: "directive", type: i2.IconDirective, selector: "[c8yIcon]", inputs: ["c8yIcon"] }, { kind: "directive", type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i2.TitleComponent, selector: "c8y-title", inputs: ["pageTitleUpdate"] }, { kind: "component", type: i2.WidgetsDashboardComponent, selector: "c8y-widgets-dashboard", inputs: ["widgets", "context", "contextDashboard", "settings", "isCopyDisabled", "breadcrumb", "editModeButtons"], outputs: ["onAddWidget", "onEditWidget", "onDeleteWidget", "onChangeDashboard", "onResize", "onEditDashboard", "onCopyDashboard", "onDeleteDashboard", "onChangeStart", "onChangeEnd", "onSaveDashboard", "onCancelDashboard", "revertChange"] }, { kind: "component", type: i2.HelpComponent, selector: "c8y-help", inputs: ["src", "isCollapsed", "priority", "icon"] }, { kind: "directive", type: i4$1.PopoverDirective, selector: "[popover]", inputs: ["adaptivePosition", "boundariesElement", "popover", "popoverContext", "popoverTitle", "placement", "outsideClick", "triggers", "container", "containerClass", "isOpen", "delay"], outputs: ["onShown", "onHidden"], exportAs: ["bs-popover"] }, { kind: "component", type: DashboardDetailComponent, selector: "c8y-dashboard-detail", inputs: ["isReport", "deviceType", "context", "mo", "dashboard", "isNamedDashboard", "hideAvailability"], outputs: ["dashboardSaved", "previewChanged"] }, { kind: "pipe", type: i2.C8yTranslatePipe, name: "translate" }, { kind: "pipe", type: i4.AsyncPipe, name: "async" }] }); }
}
__decorate([
    memoize(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", Promise)
], ContextDashboardComponent.prototype, "convertStringToHash", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ContextDashboardComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-context-dashboard', host: {
                        style: `
      display: block;
    `,
                        class: 'dashboard c8y-grid-dashboard'
                    }, template: "<c8y-title *ngIf=\"title\">\n  {{ title }}\n</c8y-title>\n\n<c8y-action-bar-item\n  [placement]=\"'right'\"\n  [priority]=\"10000\"\n  *ngIf=\"dashboard?.deviceType && dashboard.deviceTypeValue\"\n>\n  <button\n    class=\"btn-clean btn-link\"\n    popoverTitle=\"{{ 'Dashboard template' | translate }}\"\n    [attr.aria-label]=\"'Help' | translate\"\n    [popover]=\"dashboardTypePopoverRef\"\n    placement=\"bottom\"\n    triggers=\"focus\"\n    container=\"body\"\n    type=\"button\"\n  >\n    <span class=\"tag tag--info text-12\">\n      <span class=\"dashboard-template-marker\"></span>\n      {{ dashboardTypeLabel | translate: { dashboardType: dashboard.deviceTypeValue } }}\n    </span>\n  </button>\n  <ng-template #dashboardTypePopoverRef>\n    <div\n      [innerHTML]=\"dashboardTypePopover | translate: { dashboardType: dashboard.deviceTypeValue }\"\n    ></div>\n  </ng-template>\n</c8y-action-bar-item>\n\n<c8y-action-bar-item\n  [placement]=\"'right'\"\n  [priority]=\"-1\"\n  *ngIf=\"defaultWidgets.length > 0\"\n>\n  <button\n    class=\"btn btn-link\"\n    title=\"{{ 'Reset widgets' | translate }}\"\n    type=\"button\"\n    px-event=\"Reset dashboard\"\n    (click)=\"restore()\"\n    [disabled]=\"disabled || (widgetsDashboard?.editMode$ | async)\"\n    data-cy=\"context-dashboard--button-reset-dashboard\"\n  >\n    <i\n      class=\"m-r-4\"\n      c8yIcon=\"reset\"\n    ></i>\n    <span class=\"visible-xs-inline hidden-sm visible-md-inline visible-lg-inline\">\n      {{ 'Reset widgets' | translate }}\n    </span>\n  </button>\n</c8y-action-bar-item>\n\n<c8y-help\n  src=\"/docs/cockpit/working-with-dashboards/#working-with-dashboards\"\n  *ngIf=\"showContextHelpButton\"\n></c8y-help>\n\n<c8y-dashboard-detail\n  class=\"d-contents\"\n  [isReport]=\"isReport\"\n  [dashboard]=\"dashboard\"\n  [mo]=\"mo\"\n  [context]=\"context\"\n  [deviceType]=\"context?.type\"\n  [hideAvailability]=\"hideAvailability\"\n  (dashboardSaved)=\"reloadDashboard($event)\"\n  (previewChanged)=\"dashboardPreview($event)\"\n></c8y-dashboard-detail>\n\n<c8y-widgets-dashboard\n  [context]=\"context\"\n  [contextDashboard]=\"dashboard\"\n  [widgets]=\"widgets\"\n  [isCopyDisabled]=\"isCopyDisabled\"\n  [settings]=\"{\n    isLoading: isLoading,\n    isDisabled: disabled,\n    canDelete: canDelete && !!dashboard,\n    translateWidgetTitle: dashboard?.translateWidgetTitle ?? translateWidgetTitle,\n    allowFullscreen: moduleConfig.allowFullscreen,\n    title: setTitle ? dashboard?.name || title : undefined,\n    widgetMargin: dashboard?.widgetMargin,\n    canCopy: canCopy && !!dashboard,\n    defaultWidth: dashboard?.columns >= 24 ? 8 : 4,\n    columns: dashboard?.columns || 12\n  }\"\n  [breadcrumb]=\"breadcrumbSettings\"\n  [editModeButtons]=\"{\n    undoButtonDisabled: editModeService.undoButtonDisabled,\n    changeToUndoName: editModeService.changeToUndoName,\n    redoButtonDisabled: !editModeService.redoStackLastItem,\n    changeToRedoName: editModeService.redoStackLastItem?.name\n  }\"\n  (onChangeDashboard)=\"positionOrWidgetDimensionChange($event)\"\n  (onAddWidget)=\"addWidget()\"\n  (onEditWidget)=\"editWidget($event)\"\n  (onDeleteWidget)=\"deleteWidget($event)\"\n  (onSaveDashboard)=\"saveWidgetsToDashboard()\"\n  (onCancelDashboard)=\"cancelEditMode()\"\n  (revertChange)=\"revertChange($event)\"\n  (onChangeStart)=\"addDashboardClassToBody()\"\n  (onChangeEnd)=\"removeDashboardClassFromBody()\"\n  (onEditDashboard)=\"dashboardDetails.show(true)\"\n  (onCopyDashboard)=\"copyDashboard()\"\n  (onDeleteDashboard)=\"deleteDashboard()\"\n></c8y-widgets-dashboard>\n" }]
        }], ctorParameters: () => [{ type: i1.ActivatedRoute }, { type: i1.Router }, { type: ContextDashboardService }, { type: i2.AlertService }, { type: i0.Renderer2 }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [CONTEXT_DASHBOARD_CONFIG]
                }] }, { type: WidgetService }, { type: i2$2.BsModalService }, { type: i2.GainsightService }, { type: i2.ActionBarService }, { type: i2$1.TranslateService }, { type: i2.ModalService }, { type: DashboardEditModeService }], propDecorators: { name: [{
                type: Input
            }], childrenClasses: [{
                type: Input
            }], context: [{
                type: Input
            }], setTitle: [{
                type: Input
            }], defaultWidgets: [{
                type: Input
            }], _canCopy: [{
                type: Input,
                args: ['canCopy']
            }], canDelete: [{
                type: Input
            }], isLoading: [{
                type: Input
            }], breadcrumbSettings: [{
                type: Input
            }], showContextHelpButton: [{
                type: Input
            }], translateWidgetTitle: [{
                type: Input
            }], hideAvailability: [{
                type: Input
            }], class: [{
                type: HostBinding,
                args: ['class']
            }], dashboardDetails: [{
                type: ViewChild,
                args: [DashboardDetailComponent, { static: true }]
            }], widgetsDashboard: [{
                type: ViewChild,
                args: [WidgetsDashboardComponent, { static: true }]
            }], beforeUnloadHandler: [{
                type: HostListener,
                args: ['window:beforeunload', ['$event']]
            }], convertStringToHash: [] } });

class CockpitDashboardComponent {
    constructor(appState, homeDashboardConfig) {
        this.appState = appState;
        this.homeDashboardConfig = homeDashboardConfig;
        this.defaultWidgets = DEFAULT_COCKPIT_HOME_WIDGETS;
        this.dashboardName = 'home-cockpit1';
        this.pageTitle = gettext('Home');
        const config = {
            ...this.homeDashboardConfig,
            dashboardName: appState.currentApplication.value?.config?.homeDashboardName,
            userSpecific: appState.currentApplication.value?.config?.userSpecificHomeDashboard
        };
        this.applyDashboardConfig(config);
    }
    canDeactivate() {
        return this.contextDashboard.canDeactivate();
    }
    applyDashboardConfig(config) {
        if (!config) {
            return;
        }
        if (config.dashboardName) {
            this.dashboardName = config.dashboardName;
        }
        if (config.defaultWidgets) {
            this.defaultWidgets = config.defaultWidgets;
        }
        if (config.userSpecific && this.appState.currentUser.value) {
            this.dashboardName = `${this.appState.currentUser.value.userName.replace(/\./g, '__')}_${this.dashboardName}`;
        }
        if (config.pageTitle) {
            this.pageTitle = config.pageTitle;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CockpitDashboardComponent, deps: [{ token: i2.AppStateService }, { token: COCKPIT_HOME_DASHBOARD_CONFIG, optional: true }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: CockpitDashboardComponent, selector: "c8y-cockpit-dashboard", viewQueries: [{ propertyName: "contextDashboard", first: true, predicate: ContextDashboardComponent, descendants: true, static: true }], ngImport: i0, template: "<c8y-title>\n  {{ pageTitle | translate }}\n</c8y-title>\n\n<c8y-context-dashboard\n  [name]=\"dashboardName\"\n  [defaultWidgets]=\"defaultWidgets\"\n  [canDelete]=\"false\"\n  [hideAvailability]=\"true\"\n></c8y-context-dashboard>\n", dependencies: [{ kind: "component", type: i2.TitleComponent, selector: "c8y-title", inputs: ["pageTitleUpdate"] }, { kind: "component", type: ContextDashboardComponent, selector: "c8y-context-dashboard", inputs: ["name", "childrenClasses", "context", "setTitle", "defaultWidgets", "canCopy", "canDelete", "isLoading", "breadcrumbSettings", "showContextHelpButton", "translateWidgetTitle", "hideAvailability"] }, { kind: "pipe", type: i2.C8yTranslatePipe, name: "translate" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CockpitDashboardComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-cockpit-dashboard', template: "<c8y-title>\n  {{ pageTitle | translate }}\n</c8y-title>\n\n<c8y-context-dashboard\n  [name]=\"dashboardName\"\n  [defaultWidgets]=\"defaultWidgets\"\n  [canDelete]=\"false\"\n  [hideAvailability]=\"true\"\n></c8y-context-dashboard>\n" }]
        }], ctorParameters: () => [{ type: i2.AppStateService }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [COCKPIT_HOME_DASHBOARD_CONFIG]
                }] }], propDecorators: { contextDashboard: [{
                type: ViewChild,
                args: [ContextDashboardComponent, { static: true }]
            }] } });

class PasteDashboardActionComponent {
    constructor(vcRef, router, contextDashboardService, inventoryService) {
        this.vcRef = vcRef;
        this.router = router;
        this.contextDashboardService = contextDashboardService;
        this.inventoryService = inventoryService;
        this.pasteDisabled = false;
        this.dashboardName = '';
    }
    async ngOnInit() {
        this.currentUrl = this.router.url;
        this.contextId = this.currentUrl.match(/\d+/)[0];
        const isDevice = new RegExp(/device\/\d+/).test(this.currentUrl);
        const isGroup = new RegExp(/group\/\d+/).test(this.currentUrl);
        this.currentViewContext = isDevice ? ViewContext.Device : isGroup ? ViewContext.Group : null;
        await this.checkIfPasteIsAllowed();
        this.vcRef.createEmbeddedView(this.templatePaste);
        const clipboard = this.contextDashboardService.copyClipboard;
        if (clipboard) {
            this.dashboardName = clipboard.dashboard.name;
        }
    }
    async pasteDashboard() {
        if (!this.contextMO) {
            this.contextMO = await this.getContextMo(this.contextId);
        }
        const context = {
            context: this.currentViewContext,
            contextData: this.contextMO
        };
        await this.contextDashboardService.pasteDashboard(context);
    }
    async getContextMo(id) {
        return (await this.inventoryService.detail(id)).data;
    }
    async checkIfPasteIsAllowed() {
        const clipboardViewContext = this.contextDashboardService.copyClipboard.context.context;
        const isTypeDashboard = this.contextDashboardService.copyClipboard?.dashboard?.deviceType;
        if (this.currentViewContext !== clipboardViewContext) {
            if (clipboardViewContext === ViewContext.Device) {
                this.buttonTitle = gettext('Device dashboards can only be copied into a device.');
            }
            else if (clipboardViewContext === ViewContext.Group) {
                this.buttonTitle = gettext('Group dashboards can only be copied into a group.');
            }
            this.pasteDisabled = true;
            return;
        }
        else if (isTypeDashboard) {
            this.contextMO = await this.getContextMo(this.contextId);
            const dashboardDeviceType = this.contextDashboardService.copyClipboard.dashboard.deviceTypeValue;
            if (dashboardDeviceType === this.contextMO.type) {
                this.buttonTitle = gettext('Dashboard template can only be copied into assets of a different type.');
                this.pasteDisabled = true;
                return;
            }
        }
        this.buttonTitle = gettext('Paste dashboard');
        this.pasteDisabled = false;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PasteDashboardActionComponent, deps: [{ token: i0.ViewContainerRef }, { token: i1.Router }, { token: ContextDashboardService }, { token: i1$1.InventoryService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: PasteDashboardActionComponent, selector: "c8y-paste-dashboard-action", viewQueries: [{ propertyName: "templatePaste", first: true, predicate: ["templatePaste"], descendants: true, read: TemplateRef, static: true }], ngImport: i0, template: `
    <ng-template #templatePaste>
      <li>
        <button
          class="btn btn-link"
          title="{{ buttonTitle | translate }}"
          type="button"
          (click)="pasteDashboard()"
          [disabled]="pasteDisabled"
        >
          <i class="m-r-4" c8yIcon="clipboard"></i>
          <span ngNonBindable translate [translateParams]="{ dashboardName: dashboardName }">
            Paste dashboard "{{ dashboardName }}"
          </span>
        </button>
      </li>
    </ng-template>
  `, isInline: true, dependencies: [{ kind: "directive", type: i2.IconDirective, selector: "[c8yIcon]", inputs: ["c8yIcon"] }, { kind: "directive", type: i2.C8yTranslateDirective, selector: "[translate],[ngx-translate]" }, { kind: "pipe", type: i2.C8yTranslatePipe, name: "translate" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PasteDashboardActionComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'c8y-paste-dashboard-action',
                    template: `
    <ng-template #templatePaste>
      <li>
        <button
          class="btn btn-link"
          title="{{ buttonTitle | translate }}"
          type="button"
          (click)="pasteDashboard()"
          [disabled]="pasteDisabled"
        >
          <i class="m-r-4" c8yIcon="clipboard"></i>
          <span ngNonBindable translate [translateParams]="{ dashboardName: dashboardName }">
            Paste dashboard "{{ dashboardName }}"
          </span>
        </button>
      </li>
    </ng-template>
  `
                }]
        }], ctorParameters: () => [{ type: i0.ViewContainerRef }, { type: i1.Router }, { type: ContextDashboardService }, { type: i1$1.InventoryService }], propDecorators: { templatePaste: [{
                type: ViewChild,
                args: ['templatePaste', { read: TemplateRef, static: true }]
            }] } });

class DashboardActionBarFactory {
    constructor() {
        this.contextDashboardService = inject(ContextDashboardService);
    }
    get(activeRoute) {
        const actions = [];
        const data = !activeRoute.parent || activeRoute.snapshot.data.context
            ? activeRoute.snapshot.data
            : activeRoute.parent.snapshot.data;
        const { contextData } = data;
        const canPaste = contextData &&
            data.context === this.targetContext &&
            this.contextDashboardService.copyClipboard;
        if (canPaste) {
            actions.push({
                priority: -10,
                placement: 'more',
                template: PasteDashboardActionComponent
            });
        }
        return actions;
    }
}
class DeviceDashboardActionBarFactory extends DashboardActionBarFactory {
    constructor() {
        super(...arguments);
        this.targetContext = ViewContext.Device;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DeviceDashboardActionBarFactory, deps: null, target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DeviceDashboardActionBarFactory, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DeviceDashboardActionBarFactory, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });
class GroupDashboardActionBarFactory extends DashboardActionBarFactory {
    constructor() {
        super(...arguments);
        this.targetContext = ViewContext.Group;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: GroupDashboardActionBarFactory, deps: null, target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: GroupDashboardActionBarFactory, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: GroupDashboardActionBarFactory, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

class DeviceDashboardGuard {
    constructor(contextDashboardService) {
        this.contextDashboardService = contextDashboardService;
    }
    canActivate(route) {
        return this.contextDashboardService.activateDashboards(route, [
            ContextDashboardType.Device,
            ContextDashboardType.Type
        ]);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DeviceDashboardGuard, deps: [{ token: ContextDashboardService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DeviceDashboardGuard, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DeviceDashboardGuard, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }], ctorParameters: () => [{ type: ContextDashboardService }] });

class GroupDashboardGuard {
    constructor(contextDashboardService) {
        this.contextDashboardService = contextDashboardService;
    }
    canActivate(route) {
        return this.contextDashboardService.activateDashboards(route, [
            ContextDashboardType.Group,
            ContextDashboardType.Type
        ]);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: GroupDashboardGuard, deps: [{ token: ContextDashboardService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: GroupDashboardGuard, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: GroupDashboardGuard, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }], ctorParameters: () => [{ type: ContextDashboardService }] });

const defaultConfig = {
    allowFullscreen: true
};
class ContextDashboardModule {
    static config(config = {}) {
        return {
            ngModule: ContextDashboardModule,
            providers: [
                {
                    provide: CONTEXT_DASHBOARD_CONFIG,
                    useValue: { ...defaultConfig, ...config }
                },
                hookRoute(config.routes || [])
            ]
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ContextDashboardModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: ContextDashboardModule, declarations: [AppearanceSettingsComponent,
            ContextDashboardComponent,
            WidgetConfigComponent,
            WidgetPreviewComponent,
            DashboardDetailComponent,
            AddDashboardComponent,
            PasteDashboardActionComponent,
            DashboardAvailabilityComponent,
            DashboardGeneralSettingsComponent,
            DashboardAppearanceSettingsComponent,
            DashboardVersionHistoryComponent,
            TypedDashboardSettingsComponent,
            TypeDashboardInfoComponent], imports: [CoreModule,
            TooltipModule,
            PopoverModule,
            AssetSelectorModule,
            IconSelectorModule, i1$2.BsDropdownModule, i9.CollapseModule], exports: [ContextDashboardComponent,
            WidgetConfigComponent,
            DashboardDetailComponent,
            TypeDashboardInfoComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ContextDashboardModule, providers: [
            {
                provide: CONTEXT_DASHBOARD_CONFIG,
                useValue: defaultConfig
            }
        ], imports: [CoreModule,
            TooltipModule,
            PopoverModule,
            AssetSelectorModule,
            IconSelectorModule,
            BsDropdownModule.forRoot(),
            CollapseModule.forRoot()] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ContextDashboardModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        AppearanceSettingsComponent,
                        ContextDashboardComponent,
                        WidgetConfigComponent,
                        WidgetPreviewComponent,
                        DashboardDetailComponent,
                        AddDashboardComponent,
                        PasteDashboardActionComponent,
                        DashboardAvailabilityComponent,
                        DashboardGeneralSettingsComponent,
                        DashboardAppearanceSettingsComponent,
                        DashboardVersionHistoryComponent,
                        TypedDashboardSettingsComponent,
                        TypeDashboardInfoComponent
                    ],
                    imports: [
                        CoreModule,
                        TooltipModule,
                        PopoverModule,
                        AssetSelectorModule,
                        IconSelectorModule,
                        BsDropdownModule.forRoot(),
                        CollapseModule.forRoot()
                    ],
                    exports: [
                        ContextDashboardComponent,
                        WidgetConfigComponent,
                        DashboardDetailComponent,
                        TypeDashboardInfoComponent
                    ],
                    providers: [
                        {
                            provide: CONTEXT_DASHBOARD_CONFIG,
                            useValue: defaultConfig
                        }
                    ]
                }]
        }] });
class DeviceContextDashboardModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DeviceContextDashboardModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: DeviceContextDashboardModule, imports: [ContextDashboardModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DeviceContextDashboardModule, providers: [
            hookRoute([
                {
                    path: 'dashboard/:dashboardId',
                    component: ContextDashboardComponent,
                    canActivate: [DeviceDashboardGuard],
                    canDeactivate: [(component) => component.canDeactivate()],
                    context: ViewContext.Device
                },
                // new dashboard route should be defined last
                {
                    path: newDashboardTab.path,
                    component: ContextDashboardComponent,
                    canActivate: [NewDashboardGuard],
                    canDeactivate: [(component) => component.canDeactivate()],
                    context: ViewContext.Device
                }
            ]),
            hookTab(AddDeviceDashboardFactory, { providerType: HookProviderTypes.ExistingProvider }),
            hookActionBar(DeviceDashboardActionBarFactory)
        ], imports: [ContextDashboardModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DeviceContextDashboardModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [ContextDashboardModule],
                    declarations: [],
                    providers: [
                        hookRoute([
                            {
                                path: 'dashboard/:dashboardId',
                                component: ContextDashboardComponent,
                                canActivate: [DeviceDashboardGuard],
                                canDeactivate: [(component) => component.canDeactivate()],
                                context: ViewContext.Device
                            },
                            // new dashboard route should be defined last
                            {
                                path: newDashboardTab.path,
                                component: ContextDashboardComponent,
                                canActivate: [NewDashboardGuard],
                                canDeactivate: [(component) => component.canDeactivate()],
                                context: ViewContext.Device
                            }
                        ]),
                        hookTab(AddDeviceDashboardFactory, { providerType: HookProviderTypes.ExistingProvider }),
                        hookActionBar(DeviceDashboardActionBarFactory)
                    ]
                }]
        }] });
class GroupContextDashboardModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: GroupContextDashboardModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: GroupContextDashboardModule, imports: [ContextDashboardModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: GroupContextDashboardModule, providers: [
            hookRoute([
                {
                    path: 'dashboard/:dashboardId',
                    component: ContextDashboardComponent,
                    canActivate: [GroupDashboardGuard],
                    canDeactivate: [(component) => component.canDeactivate()],
                    context: ViewContext.Group
                },
                // new dashboard route should be defined last
                {
                    path: newDashboardTab.path,
                    component: ContextDashboardComponent,
                    canActivate: [NewDashboardGuard],
                    canDeactivate: [(component) => component.canDeactivate()],
                    context: ViewContext.Group
                }
            ]),
            hookTab(AddGroupDashboardFactory, { providerType: HookProviderTypes.ExistingProvider }),
            hookActionBar(GroupDashboardActionBarFactory)
        ], imports: [ContextDashboardModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: GroupContextDashboardModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [ContextDashboardModule],
                    declarations: [],
                    providers: [
                        hookRoute([
                            {
                                path: 'dashboard/:dashboardId',
                                component: ContextDashboardComponent,
                                canActivate: [GroupDashboardGuard],
                                canDeactivate: [(component) => component.canDeactivate()],
                                context: ViewContext.Group
                            },
                            // new dashboard route should be defined last
                            {
                                path: newDashboardTab.path,
                                component: ContextDashboardComponent,
                                canActivate: [NewDashboardGuard],
                                canDeactivate: [(component) => component.canDeactivate()],
                                context: ViewContext.Group
                            }
                        ]),
                        hookTab(AddGroupDashboardFactory, { providerType: HookProviderTypes.ExistingProvider }),
                        hookActionBar(GroupDashboardActionBarFactory)
                    ]
                }]
        }] });

class CockpitHomeDashboardModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CockpitHomeDashboardModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: CockpitHomeDashboardModule, declarations: [CockpitDashboardComponent], imports: [CoreModule, ContextDashboardModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CockpitHomeDashboardModule, providers: [
            hookNavigator({ label: gettext('Home'), icon: 'home', priority: 10000, path: '/' }),
            hookRoute({
                path: '',
                component: CockpitDashboardComponent,
                canDeactivate: [(component) => component.canDeactivate()]
            })
        ], imports: [CoreModule, ContextDashboardModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CockpitHomeDashboardModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CoreModule, ContextDashboardModule],
                    declarations: [CockpitDashboardComponent],
                    providers: [
                        hookNavigator({ label: gettext('Home'), icon: 'home', priority: 10000, path: '/' }),
                        hookRoute({
                            path: '',
                            component: CockpitDashboardComponent,
                            canDeactivate: [(component) => component.canDeactivate()]
                        })
                    ]
                }]
        }] });
class CockpitDashboardModule {
    static config(config = {}) {
        return {
            ngModule: CockpitDashboardModule,
            providers: [
                {
                    provide: COCKPIT_HOME_DASHBOARD_CONFIG,
                    useValue: config
                }
            ]
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CockpitDashboardModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: CockpitDashboardModule, imports: [CockpitHomeDashboardModule, DeviceContextDashboardModule, GroupContextDashboardModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CockpitDashboardModule, imports: [CockpitHomeDashboardModule, DeviceContextDashboardModule, GroupContextDashboardModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CockpitDashboardModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CockpitHomeDashboardModule, DeviceContextDashboardModule, GroupContextDashboardModule]
                }]
        }] });

class DeviceInfoDashboardComponent {
    constructor(router, widgetService, translateService, inventoryService) {
        this.router = router;
        this.widgetService = widgetService;
        this.translateService = translateService;
        this.inventoryService = inventoryService;
        this.isLoading = true;
        this.dashboardName = '';
        this.DEVICE_INFO_WIDGETS = [
            {
                name: 'deviceStatusWidget',
                title: gettext('Device status'),
                _x: 0,
                _y: 0,
                _height: 5,
                _width: 8
            },
            {
                name: 'Data points graph',
                title: gettext('Device and communication'),
                _x: 8,
                _y: 0,
                _height: 5,
                _width: 16,
                config: {
                    interval: 'hours',
                    aggregation: 'NONE',
                    realtime: true,
                    datapointsInitialDisplayLimit: 3,
                    datapoints: [
                        {
                            fragment: 'c8y_Battery',
                            series: 'level',
                            label: this.translateService.instant('Battery: level'),
                            unit: '%',
                            renderType: 'min',
                            lineType: 'line',
                            color: '#5e07b3',
                            __active: true
                        },
                        {
                            fragment: 'c8y_SignalStrength',
                            series: 'rssi',
                            label: this.translateService.instant('Signal: RSSI'),
                            unit: 'dBm',
                            renderType: 'min',
                            lineType: 'line',
                            color: '#a7d0f1',
                            __active: true
                        },
                        {
                            fragment: 'c8y_MemoryMeasurement',
                            series: 'Used',
                            label: this.translateService.instant('Memory: used'),
                            unit: 'MB',
                            renderType: 'min',
                            lineType: 'line',
                            color: '#f75229',
                            __active: true
                        },
                        {
                            fragment: 'c8y_CPUMeasurement',
                            series: 'Workload',
                            label: this.translateService.instant('CPU: workload'),
                            unit: '%',
                            renderType: 'min',
                            lineType: 'line',
                            color: '#b24f3e',
                            __active: true
                        },
                        {
                            fragment: 'c8y_NetworkStatistics',
                            series: 'Upload',
                            label: this.translateService.instant('Network: upload'),
                            unit: 'KB/s',
                            renderType: 'min',
                            lineType: 'line',
                            color: '#88c039',
                            __active: true
                        },
                        {
                            fragment: 'c8y_SignalStrength',
                            series: 'RCSP',
                            label: this.translateService.instant('Signal: RCSP'),
                            renderType: 'min',
                            lineType: 'line',
                            color: '#5e2f19',
                            __active: true
                        },
                        {
                            fragment: 'c8y_SignalStrength',
                            series: 'RSCP',
                            label: this.translateService.instant('Signal: RSCP'),
                            renderType: 'min',
                            lineType: 'line',
                            color: '#5e2f19',
                            __active: true
                        },
                        {
                            fragment: 'c8y_SignalStrength',
                            series: 'RSRP',
                            label: this.translateService.instant('Signal: RSRP'),
                            renderType: 'min',
                            lineType: 'line',
                            color: '#43ba3b',
                            __active: true
                        },
                        {
                            fragment: 'c8y_SignalStrength',
                            series: 'RSRQ',
                            label: this.translateService.instant('Signal: RSRQ'),
                            renderType: 'min',
                            lineType: 'line',
                            color: '#14b0b3',
                            __active: true
                        },
                        {
                            fragment: 'c8y_SignalStrength',
                            series: 'ber',
                            label: this.translateService.instant('Signal: BER'),
                            unit: '%',
                            renderType: 'min',
                            lineType: 'line',
                            color: '#44ff33',
                            __active: true
                        },
                        {
                            fragment: 'c8y_SignalStrength',
                            series: 'ECN0',
                            label: this.translateService.instant('Signal: ECN0'),
                            renderType: 'min',
                            lineType: 'line',
                            color: '#873efa',
                            __active: true
                        },
                        {
                            fragment: 'c8y_NetworkStatistics',
                            series: 'Download',
                            label: this.translateService.instant('Network: download'),
                            unit: 'KB/s',
                            renderType: 'min',
                            lineType: 'line',
                            color: '#f27a45',
                            __active: true
                        },
                        {
                            fragment: 'c8y_MemoryMeasurement',
                            series: 'Total',
                            label: this.translateService.instant('Memory: total'),
                            unit: 'MB',
                            renderType: 'min',
                            lineType: 'line',
                            color: '#dadd8c',
                            __active: true
                        }
                    ],
                    alarmsEventsConfigs: [
                        {
                            label: 'c8y_LocationUpdate',
                            timelineType: 'EVENT',
                            color: '#6f6cd0',
                            filters: {
                                type: 'c8y_LocationUpdate'
                            },
                            __active: true
                        },
                        {
                            label: 'c8y_UnavailabilityAlarm',
                            timelineType: 'ALARM',
                            color: '#375bf2',
                            filters: {
                                type: 'c8y_UnavailabilityAlarm'
                            },
                            __active: true
                        }
                    ]
                }
            },
            {
                name: 'Asset Properties',
                title: gettext('Device data'),
                config: {
                    options: {
                        properties: [
                            {
                                id: 'c8ySchema!!id',
                                __active: true,
                                keyPath: ['id'],
                                type: 'string',
                                label: 'ID'
                            },
                            {
                                id: 'c8ySchema!!name',
                                __active: true,
                                keyPath: ['name'],
                                type: 'string',
                                label: 'Name'
                            },
                            {
                                id: 'c8ySchema!!type',
                                __active: true,
                                keyPath: ['type'],
                                type: 'string',
                                label: 'Type'
                            },
                            {
                                id: 'c8ySchema!!lastUpdated',
                                __active: true,
                                keyPath: ['lastUpdated'],
                                type: 'string',
                                label: 'Last Updated'
                            },
                            {
                                id: 'c8ySchema!!creationTime',
                                __active: true,
                                keyPath: ['creationTime'],
                                type: 'string',
                                label: 'Creation Time'
                            }
                        ],
                        allowDisplayAndEditKnownProperties: false,
                        hiddenPropertiesKeyPaths: ['owner']
                    }
                },
                _x: 0,
                _y: 5,
                _height: 8,
                _width: 8
            },
            {
                name: 'Alarm list',
                title: gettext('Active, critical alarms'),
                _x: 8,
                _y: 5,
                _height: 4,
                _width: 8,
                config: {
                    options: {
                        orderMode: 'ACTIVE_FIRST',
                        severity: { CRITICAL: true },
                        status: {
                            ACTIVE: true,
                            ACKNOWLEDGED: false,
                            CLEARED: false
                        },
                        types: []
                    }
                }
            },
            {
                name: 'deviceGroupAssignmentWidget',
                title: gettext('Group assignment'),
                _x: 16,
                _y: 5,
                _height: 4,
                _width: 8
            },
            {
                componentId: 'Map',
                title: gettext('Location'),
                _x: 8,
                _y: 9,
                _height: 4,
                _width: 16
            }
        ];
    }
    ngOnInit() {
        this.contextSubscription = this.router.parent.data
            .pipe(tap(({ contextData }) => {
            const contextNameValid = contextData.name && contextData.name.trim();
            this.title = contextNameValid ? contextData.name : contextData.id;
            this.dashboardName = `${contextData.id}-device-info`;
        }))
            .subscribe(async (data) => {
            this.currentContext = data;
            this.addDeviceTargetForDP(data.contextData.id, data.contextData.name);
        });
        this.widgetsSubscription = from(this.DEVICE_INFO_WIDGETS)
            .pipe(mergeMap(widget => this.widgetService.mapLegacy(widget)), map(widget => {
            let device = this.router.parent.snapshot.data.contextData;
            if (device) {
                device = {
                    name: device.name,
                    id: device.id
                };
            }
            return {
                ...widget,
                config: {
                    ...widget.config,
                    device
                }
            };
        }), toArray())
            .subscribe(async (data) => {
            await this.filterSupportedSeriesForDP(this.currentContext.contextData.id, data);
            this.widgetsList = data;
            this.isLoading = false;
        });
    }
    addDeviceTargetForDP(id, name) {
        const dpWidget = this.DEVICE_INFO_WIDGETS.filter(item => item.name == 'Data points graph')[0];
        // Add target to dataPoint config
        dpWidget.config.datapoints.map(item => (item['__target'] = { id, name }));
        // Add target to alarmEvents Config
        dpWidget.config.alarmsEventsConfigs.map(item => (item['__target'] = { id, name }));
    }
    async filterSupportedSeriesForDP(id, widgets) {
        const supportedMeasurements = await this.inventoryService.getMeasurementsAndSeries(id);
        const isDataPointSupported = dp => supportedMeasurements.some(({ fragment, series }) => dp.fragment === fragment && dp.series === series);
        const dpWidget = widgets.find(({ name }) => name === 'Data points graph');
        dpWidget.config.datapoints = dpWidget.config.datapoints.filter(isDataPointSupported);
    }
    ngOnDestroy() {
        this.widgetsSubscription.unsubscribe();
        this.contextSubscription.unsubscribe();
    }
    canDeactivate() {
        return this.contextDashboard?.canDeactivate();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DeviceInfoDashboardComponent, deps: [{ token: i1.ActivatedRoute }, { token: WidgetService }, { token: i2$1.TranslateService }, { token: i1$1.InventoryService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: DeviceInfoDashboardComponent, selector: "c8y-device-info-dashboard-dashboard", viewQueries: [{ propertyName: "contextDashboard", first: true, predicate: ContextDashboardComponent, descendants: true }], ngImport: i0, template: "<div *ngIf=\"!isLoading\">\n  <c8y-title>\n    {{ title }}\n  </c8y-title>\n  <c8y-context-dashboard\n    [translateWidgetTitle]=\"true\"\n    [name]=\"dashboardName\"\n    [context]=\"currentContext\"\n    [defaultWidgets]=\"widgetsList\"\n    [canDelete]=\"false\"\n    [hideAvailability]=\"true\"\n    [canCopy]=\"false\"\n  ></c8y-context-dashboard>\n</div>\n", dependencies: [{ kind: "directive", type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i2.TitleComponent, selector: "c8y-title", inputs: ["pageTitleUpdate"] }, { kind: "component", type: ContextDashboardComponent, selector: "c8y-context-dashboard", inputs: ["name", "childrenClasses", "context", "setTitle", "defaultWidgets", "canCopy", "canDelete", "isLoading", "breadcrumbSettings", "showContextHelpButton", "translateWidgetTitle", "hideAvailability"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DeviceInfoDashboardComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-device-info-dashboard-dashboard', template: "<div *ngIf=\"!isLoading\">\n  <c8y-title>\n    {{ title }}\n  </c8y-title>\n  <c8y-context-dashboard\n    [translateWidgetTitle]=\"true\"\n    [name]=\"dashboardName\"\n    [context]=\"currentContext\"\n    [defaultWidgets]=\"widgetsList\"\n    [canDelete]=\"false\"\n    [hideAvailability]=\"true\"\n    [canCopy]=\"false\"\n  ></c8y-context-dashboard>\n</div>\n" }]
        }], ctorParameters: () => [{ type: i1.ActivatedRoute }, { type: WidgetService }, { type: i2$1.TranslateService }, { type: i1$1.InventoryService }], propDecorators: { contextDashboard: [{
                type: ViewChild,
                args: [ContextDashboardComponent, { static: false }]
            }] } });

class DeviceInfoDashboardModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DeviceInfoDashboardModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: DeviceInfoDashboardModule, declarations: [DeviceInfoDashboardComponent], imports: [CommonModule, CoreModule, ContextDashboardModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DeviceInfoDashboardModule, providers: [
            hookRoute({
                context: ViewContext.Device,
                path: 'device-info',
                component: DeviceInfoDashboardComponent,
                label: gettext('Info'),
                priority: 10000,
                icon: 'asterisk',
                canDeactivate: [(component) => component.canDeactivate()]
            })
        ], imports: [CommonModule, CoreModule, ContextDashboardModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DeviceInfoDashboardModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [DeviceInfoDashboardComponent],
                    imports: [CommonModule, CoreModule, ContextDashboardModule],
                    exports: [],
                    providers: [
                        hookRoute({
                            context: ViewContext.Device,
                            path: 'device-info',
                            component: DeviceInfoDashboardComponent,
                            label: gettext('Info'),
                            priority: 10000,
                            icon: 'asterisk',
                            canDeactivate: [(component) => component.canDeactivate()]
                        })
                    ]
                }]
        }] });

class DeviceManagementHomeDashboardComponent {
    constructor(widgetService) {
        this.widgetService = widgetService;
        this.widgets = [];
        this.dashboardName = 'home-dm1';
        this.defaultWidgets = [
            {
                name: 'devicemanagement.welcome.widget',
                title: gettext('Quick links'),
                _x: 0,
                _y: 0,
                _height: 4,
                _width: 12
            },
            {
                name: 'Recent Alarms',
                title: gettext('Recent alarms'),
                _x: 12,
                _y: 0,
                _height: 4,
                _width: 12
            }
        ];
    }
    ngOnInit() {
        this.defaultWidgets.map(async (widget) => {
            await this.widgetService
                .mapLegacy(widget)
                .then(transformedWidget => this.widgets.push(transformedWidget));
        });
    }
    canDeactivate() {
        return this.contextDashboard?.canDeactivate();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DeviceManagementHomeDashboardComponent, deps: [{ token: WidgetService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: DeviceManagementHomeDashboardComponent, selector: "c8y-device-management-home-dashboard", viewQueries: [{ propertyName: "contextDashboard", first: true, predicate: ContextDashboardComponent, descendants: true, static: true }], ngImport: i0, template: "<c8y-title>\n  {{ 'Home' | translate }}\n</c8y-title>\n\n<c8y-context-dashboard\n  [name]=\"dashboardName\"\n  [defaultWidgets]=\"defaultWidgets\"\n  [canDelete]=\"false\"\n  [hideAvailability]=\"true\"\n></c8y-context-dashboard>\n", dependencies: [{ kind: "component", type: i2.TitleComponent, selector: "c8y-title", inputs: ["pageTitleUpdate"] }, { kind: "component", type: ContextDashboardComponent, selector: "c8y-context-dashboard", inputs: ["name", "childrenClasses", "context", "setTitle", "defaultWidgets", "canCopy", "canDelete", "isLoading", "breadcrumbSettings", "showContextHelpButton", "translateWidgetTitle", "hideAvailability"] }, { kind: "pipe", type: i2.C8yTranslatePipe, name: "translate" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DeviceManagementHomeDashboardComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-device-management-home-dashboard', template: "<c8y-title>\n  {{ 'Home' | translate }}\n</c8y-title>\n\n<c8y-context-dashboard\n  [name]=\"dashboardName\"\n  [defaultWidgets]=\"defaultWidgets\"\n  [canDelete]=\"false\"\n  [hideAvailability]=\"true\"\n></c8y-context-dashboard>\n" }]
        }], ctorParameters: () => [{ type: WidgetService }], propDecorators: { contextDashboard: [{
                type: ViewChild,
                args: [ContextDashboardComponent, { static: true }]
            }] } });

class DeviceManagementHomeDashboardModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DeviceManagementHomeDashboardModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: DeviceManagementHomeDashboardModule, declarations: [DeviceManagementHomeDashboardComponent], imports: [CommonModule, CoreModule, ContextDashboardModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DeviceManagementHomeDashboardModule, providers: [
            hookRoute({
                path: '',
                component: DeviceManagementHomeDashboardComponent,
                canDeactivate: [(component) => component.canDeactivate()]
            }),
            hookNavigator({ label: gettext('Home'), icon: 'home', priority: 10000, path: '/' })
        ], imports: [CommonModule, CoreModule, ContextDashboardModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DeviceManagementHomeDashboardModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [DeviceManagementHomeDashboardComponent],
                    imports: [CommonModule, CoreModule, ContextDashboardModule],
                    exports: [],
                    providers: [
                        hookRoute({
                            path: '',
                            component: DeviceManagementHomeDashboardComponent,
                            canDeactivate: [(component) => component.canDeactivate()]
                        }),
                        hookNavigator({ label: gettext('Home'), icon: 'home', priority: 10000, path: '/' })
                    ]
                }]
        }] });

class DashboardManagerTabsFactory {
    constructor(router) {
        this.router = router;
    }
    get() {
        const tabs = [];
        if (this.router.url.match(/\/dashboard-manager/g)) {
            tabs.push({
                path: 'dashboard-manager/type-dashboards',
                priority: 1000,
                label: gettext('Type dashboards')
            });
        }
        return tabs;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardManagerTabsFactory, deps: [{ token: i1.Router }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardManagerTabsFactory }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardManagerTabsFactory, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.Router }] });

class DeviceTypeValueGridColumn extends BaseColumn {
    constructor(initialColumnConfig) {
        super(initialColumnConfig);
        this.name = 'deviceTypeValue';
        this.path = 'c8y_Dashboard.deviceTypeValue';
        this.header = gettext('Target asset model');
        this.filterable = true;
        this.sortable = false;
        this.filteringConfig = {
            fields: getBasicInputArrayFormFieldConfig({
                key: 'deviceTypeValues',
                label: gettext('Filter dashboards by target asset model'),
                addText: gettext('Add next`target asset model`'),
                tooltip: gettext('Use * as a wildcard character'),
                placeholder: 'c8y_MQTTDevice'
            }),
            getFilter: (model) => {
                const filter = {};
                if (model.deviceTypeValues.length) {
                    filter[this.path] = { __in: model.deviceTypeValues };
                }
                return filter;
            }
        };
    }
}

class DashboardManagerService extends DataGridService {
    constructor(inventory, userPreferencesService, modal, translateService) {
        super(userPreferencesService);
        this.inventory = inventory;
        this.userPreferencesService = userPreferencesService;
        this.modal = modal;
        this.translateService = translateService;
        this.baseQuery = {
            __filter: {
                __and: [
                    { 'c8y_Dashboard.deviceType': { __eq: true } },
                    { __has: 'c8y_Dashboard.deviceTypeValue' }
                ]
            }
        };
        this.TYPE_DASHBOARDS_QUERY = '$filter=((c8y_Dashboard.deviceType eq true) and (has(c8y_Dashboard.deviceTypeValue)))';
    }
    getColumns() {
        return [
            {
                name: 'icon',
                header: gettext('Icon'),
                path: 'c8y_Dashboard.icon',
                sortable: false,
                gridTrackSize: '45px'
            },
            {
                name: 'name',
                header: gettext('Name'),
                path: 'name',
                sortable: false,
                gridTrackSize: '200px'
            },
            {
                name: 'description',
                header: gettext('Description'),
                path: 'c8y_Dashboard.description',
                sortable: false
            },
            new DeviceTypeValueGridColumn(),
            {
                name: 'lastUpdated',
                header: gettext('Last update'),
                path: 'lastUpdated',
                sortable: false,
                gridTrackSize: '200px'
            }
        ];
    }
    getDefaultPagination() {
        return {
            pageSize: 25,
            currentPage: 1
        };
    }
    async getData(columns, pagination, text) {
        const filters = this.getFilters(columns, pagination, text);
        return await this.inventory.list(filters);
    }
    async getTotal() {
        return (await this.inventory.list({
            query: this.TYPE_DASHBOARDS_QUERY,
            withTotalElements: true
        })).paging.totalElements;
    }
    async delete(dashboard, onSuccess) {
        try {
            const msg = gettext(`You are about to delete the dashboard "{{ dashboardName }}" from all devices of type "{{ deviceType }}".
           Do you want to proceed?`);
            await this.modal.confirm(gettext('Delete dashboard'), this.translateService.instant(msg, {
                dashboardName: dashboard.c8y_Dashboard.name,
                deviceType: dashboard.c8y_Dashboard.deviceTypeValue
            }), Status.DANGER, {
                ok: gettext('Delete'),
                cancel: gettext('Cancel')
            });
            await this.inventory.delete(dashboard);
            onSuccess();
        }
        catch (ex) {
            // intended empty
        }
    }
    getFilters(columns, pagination, text) {
        return {
            query: this.getQueryString(columns),
            ...(text && { text }),
            pageSize: pagination.pageSize,
            currentPage: pagination.currentPage,
            withTotalPages: true,
            withTotalElements: true
        };
    }
    getQueryString(columns) {
        const queryFromColumns = this.getQueryObj(columns);
        const fullQuery = this.queriesUtil.addAndFilter(queryFromColumns, this.baseQuery);
        return this.queriesUtil.buildQuery(fullQuery);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardManagerService, deps: [{ token: i1$1.InventoryService }, { token: i2.UserPreferencesService }, { token: i2.ModalService }, { token: i2$1.TranslateService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardManagerService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardManagerService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: i1$1.InventoryService }, { type: i2.UserPreferencesService }, { type: i2.ModalService }, { type: i2$1.TranslateService }] });

class BasicNameDeviceGridColumn extends NameDeviceGridColumn {
    constructor(initialColumnConfig) {
        super(initialColumnConfig);
        this.name = 'basic-name';
        this.cellRendererComponent = null;
    }
}

class TypeDashboardAssetsGridService extends DataGridService {
    constructor(inventoryService, userPreferencesService) {
        super(userPreferencesService);
        this.inventoryService = inventoryService;
        this.userPreferencesService = userPreferencesService;
    }
    getDefaultColumns(columnsForDevice = true) {
        return columnsForDevice
            ? [
                new BasicNameDeviceGridColumn(),
                new TypeDeviceGridColumn(),
                new GroupDeviceGridColumn(),
                new RegistrationDateDeviceGridColumn()
            ]
            : [
                new BasicNameDeviceGridColumn(),
                new TypeDeviceGridColumn(),
                new RegistrationDateDeviceGridColumn()
            ];
    }
    async getData(columns, pagination, query = {}, text = null) {
        const filters = {
            ...this.getFilters(columns, pagination, query, text),
            withGroups: true
        };
        return this.inventoryService.list(filters);
    }
    async getCount(columns, pagination, query = {}, text = null) {
        const filters = {
            ...this.getFilters(columns, pagination, query, text),
            pageSize: 1,
            currentPage: 1
        };
        return (await this.inventoryService.list(filters)).paging.totalPages;
    }
    async getTotal(query = {}) {
        const filters = {
            query: this.queriesUtil.buildQuery(query),
            pageSize: 1,
            withTotalPages: true
        };
        return (await this.inventoryService.list(filters)).paging.totalPages;
    }
    getFilters(columns, pagination, query, text) {
        return {
            ...{ query: this.getDeviceQueryString(columns, query) },
            ...(text && { text }),
            pageSize: pagination.pageSize,
            currentPage: pagination.currentPage,
            withChildren: false,
            withTotalPages: true
        };
    }
    getDeviceQueryString(columns, query) {
        let fullQuery = this.getQueryObj(columns);
        fullQuery = this.queriesUtil.addAndFilter(fullQuery, query);
        return this.queriesUtil.buildQuery(fullQuery);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TypeDashboardAssetsGridService, deps: [{ token: i1$1.InventoryService }, { token: i2.UserPreferencesService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TypeDashboardAssetsGridService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TypeDashboardAssetsGridService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: i1$1.InventoryService }, { type: i2.UserPreferencesService }] });

class TypeDashboardTargetAssetsGridComponent {
    constructor(router, assetsGridService, contextDashboardService) {
        this.router = router;
        this.assetsGridService = assetsGridService;
        this.contextDashboardService = contextDashboardService;
        this.labels = { cancel: gettext('Cancel') };
        this.actionControls = [
            {
                type: 'navigateToInstance',
                text: gettext('Open instance`dashboard`'),
                callback: item => this.navigateToDevice(item),
                icon: 'file-create'
            }
        ];
        this.loadMoreItemsLabel = gettext('Load more assets');
        this.loadingItemsLabel = gettext('Loading assets…');
        this.pagination = {
            pageSize: 25,
            currentPage: 1
        };
        this.onNavigateToAsset = new EventEmitter();
        this.serverSideDataCallback = this.onDataSourceModifier.bind(this);
    }
    ngOnInit() {
        this.isDeviceDashboard = this.contextDashboardService.isDeviceDashboard(this.dashboard);
        this.columns = this.assetsGridService.getDefaultColumns(this.isDeviceDashboard);
    }
    async onDataSourceModifier(dataSourceModifier) {
        const baseQuery = { type: this.dashboard.c8y_Dashboard.deviceTypeValue };
        const { res, data, paging } = await alertOnError(this.assetsGridService.getData(dataSourceModifier.columns, dataSourceModifier.pagination, baseQuery, dataSourceModifier.searchText));
        const filteredSize = await alertOnError(this.assetsGridService.getCount(dataSourceModifier.columns, dataSourceModifier.pagination, baseQuery, dataSourceModifier.searchText));
        const size = await alertOnError(this.assetsGridService.getTotal(baseQuery));
        const serverSideDataResult = {
            res,
            data,
            paging,
            filteredSize,
            size
        };
        return serverSideDataResult;
    }
    trackByName(_index, column) {
        return column.name;
    }
    navigateToDevice(val) {
        const parentSubPath = this.isDeviceDashboard ? 'device' : 'group';
        this.onNavigateToAsset.emit();
        this.router.navigate([`/${parentSubPath}/${val.id}/dashboard/${this.dashboard.id}`]);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TypeDashboardTargetAssetsGridComponent, deps: [{ token: i1.Router }, { token: TypeDashboardAssetsGridService }, { token: ContextDashboardService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: TypeDashboardTargetAssetsGridComponent, selector: "c8y-type-dashboard-target-assets-grid", inputs: { dashboard: "dashboard" }, outputs: { onNavigateToAsset: "onNavigateToAsset" }, ngImport: i0, template: "<c8y-data-grid\n  [title]=\"''\"\n  [loadMoreItemsLabel]=\"loadMoreItemsLabel\"\n  [loadingItemsLabel]=\"loadingItemsLabel\"\n  [columns]=\"columns\"\n  [pagination]=\"pagination\"\n  [infiniteScroll]=\"'auto'\"\n  [actionControls]=\"actionControls\"\n  [serverSideDataCallback]=\"serverSideDataCallback\"\n  [showSearch]=\"true\"\n>\n  <c8y-ui-empty-state\n    [icon]=\"'search'\"\n    [title]=\"'No results to display.' | translate\"\n    [subtitle]=\"'Refine your search terms.' | translate\"\n    [horizontal]=\"true\"\n  ></c8y-ui-empty-state>\n\n  <ng-container *ngFor=\"let column of columns; trackBy: trackByName\">\n    <c8y-column [name]=\"column.name\"></c8y-column>\n  </ng-container>\n</c8y-data-grid>\n", dependencies: [{ kind: "component", type: i2.EmptyStateComponent, selector: "c8y-ui-empty-state", inputs: ["icon", "title", "subtitle", "horizontal"] }, { kind: "directive", type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i2.ColumnDirective, selector: "c8y-column", inputs: ["name"] }, { kind: "component", type: i2.DataGridComponent, selector: "c8y-data-grid", inputs: ["title", "loadMoreItemsLabel", "loadingItemsLabel", "showSearch", "refresh", "columns", "rows", "pagination", "infiniteScroll", "serverSideDataCallback", "selectable", "singleSelection", "selectionPrimaryKey", "displayOptions", "actionControls", "bulkActionControls", "headerActionControls", "searchText", "configureColumnsEnabled", "showCounterWarning", "activeClassName", "expandableRows", "hideReload"], outputs: ["rowMouseOver", "rowMouseLeave", "rowClick", "onConfigChange", "onBeforeFilter", "onBeforeSearch", "onFilter", "itemsSelect", "onReload", "onAddCustomColumn", "onRemoveCustomColumn", "onColumnFilterReset", "onSort", "onPageSizeChange", "onColumnReordered", "onColumnVisibilityChange"] }, { kind: "pipe", type: i2.C8yTranslatePipe, name: "translate" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TypeDashboardTargetAssetsGridComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-type-dashboard-target-assets-grid', template: "<c8y-data-grid\n  [title]=\"''\"\n  [loadMoreItemsLabel]=\"loadMoreItemsLabel\"\n  [loadingItemsLabel]=\"loadingItemsLabel\"\n  [columns]=\"columns\"\n  [pagination]=\"pagination\"\n  [infiniteScroll]=\"'auto'\"\n  [actionControls]=\"actionControls\"\n  [serverSideDataCallback]=\"serverSideDataCallback\"\n  [showSearch]=\"true\"\n>\n  <c8y-ui-empty-state\n    [icon]=\"'search'\"\n    [title]=\"'No results to display.' | translate\"\n    [subtitle]=\"'Refine your search terms.' | translate\"\n    [horizontal]=\"true\"\n  ></c8y-ui-empty-state>\n\n  <ng-container *ngFor=\"let column of columns; trackBy: trackByName\">\n    <c8y-column [name]=\"column.name\"></c8y-column>\n  </ng-container>\n</c8y-data-grid>\n" }]
        }], ctorParameters: () => [{ type: i1.Router }, { type: TypeDashboardAssetsGridService }, { type: ContextDashboardService }], propDecorators: { dashboard: [{
                type: Input
            }], onNavigateToAsset: [{
                type: Output
            }] } });

class TypeDashboardTargetAssetsModalComponent {
    constructor(bsModalRef) {
        this.bsModalRef = bsModalRef;
        this.labels = { cancel: gettext('Cancel') };
    }
    handleKeyboardEvent(event) {
        if (event.key === 'Escape') {
            this.close();
        }
    }
    close() {
        this.bsModalRef.hide();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TypeDashboardTargetAssetsModalComponent, deps: [{ token: i2$2.BsModalRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: TypeDashboardTargetAssetsModalComponent, selector: "c8y-type-dashboard-target-assets-modal", inputs: { dashboard: "dashboard" }, host: { listeners: { "document:keydown": "handleKeyboardEvent($event)" } }, ngImport: i0, template: "<c8y-modal\n  title=\"{{ 'Select dashboard instance to edit' | translate }}\"\n  (onClose)=\"close()\"\n  (onDismiss)=\"close()\"\n  [labels]=\"labels\"\n  [disabled]=\"true\"\n  [headerClasses]=\"'has-data-grid'\"\n>\n  <c8y-type-dashboard-target-assets-grid\n    [dashboard]=\"dashboard\"\n    (onNavigateToAsset)=\"close()\"\n  ></c8y-type-dashboard-target-assets-grid>\n</c8y-modal>\n", dependencies: [{ kind: "component", type: i2.ModalComponent, selector: "c8y-modal", inputs: ["disabled", "close", "dismiss", "title", "body", "customFooter", "headerClasses", "labels"], outputs: ["onDismiss", "onClose"] }, { kind: "component", type: TypeDashboardTargetAssetsGridComponent, selector: "c8y-type-dashboard-target-assets-grid", inputs: ["dashboard"], outputs: ["onNavigateToAsset"] }, { kind: "pipe", type: i2.C8yTranslatePipe, name: "translate" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TypeDashboardTargetAssetsModalComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-type-dashboard-target-assets-modal', template: "<c8y-modal\n  title=\"{{ 'Select dashboard instance to edit' | translate }}\"\n  (onClose)=\"close()\"\n  (onDismiss)=\"close()\"\n  [labels]=\"labels\"\n  [disabled]=\"true\"\n  [headerClasses]=\"'has-data-grid'\"\n>\n  <c8y-type-dashboard-target-assets-grid\n    [dashboard]=\"dashboard\"\n    (onNavigateToAsset)=\"close()\"\n  ></c8y-type-dashboard-target-assets-grid>\n</c8y-modal>\n" }]
        }], ctorParameters: () => [{ type: i2$2.BsModalRef }], propDecorators: { dashboard: [{
                type: Input
            }], handleKeyboardEvent: [{
                type: HostListener,
                args: ['document:keydown', ['$event']]
            }] } });

class TypeDashboardsListComponent {
    constructor(dashboardManagerService, bsModalService) {
        this.dashboardManagerService = dashboardManagerService;
        this.bsModalService = bsModalService;
        this.title = gettext('Type dashboards');
        this.loadMoreItemsLabel = gettext('Load more dashboards');
        this.loadingItemsLabel = gettext('Loading dashboards…');
        this.columns = this.dashboardManagerService.getColumns();
        this.pagination = this.dashboardManagerService.getDefaultPagination();
        this.actionControls = [
            {
                type: BuiltInActionType.Edit,
                text: gettext('Edit dashboard'),
                callback: item => this.openTargetAssetsModal(item)
            },
            {
                type: BuiltInActionType.Delete,
                text: gettext('Delete dashboard'),
                callback: item => this.delete(item)
            }
        ];
        this.displayOptions = {
            striped: true,
            bordered: false,
            gridHeader: true,
            filter: true,
            hover: false
        };
        this.refresh = new EventEmitter();
        this.serverSideDataCallback = this.onDataSourceModifier.bind(this);
    }
    async delete(dashboard) {
        await this.dashboardManagerService.delete(dashboard, () => this.refresh.emit());
    }
    openTargetAssetsModal(dashboard) {
        const initialState = { dashboard };
        this.bsModalService.show(TypeDashboardTargetAssetsModalComponent, {
            class: 'modal-lg',
            ariaDescribedby: 'modal-body',
            ariaLabelledBy: 'modal-title',
            ignoreBackdropClick: true,
            initialState
        });
    }
    trackByName(_index, column) {
        return column.name;
    }
    async onDataSourceModifier(dataSourceModifier) {
        const { res, data, paging } = await alertOnError(this.dashboardManagerService.getData(dataSourceModifier.columns, dataSourceModifier.pagination, dataSourceModifier.searchText));
        const filteredSize = paging.totalElements;
        const size = await alertOnError(this.dashboardManagerService.getTotal());
        return {
            res,
            data,
            paging,
            filteredSize,
            size
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TypeDashboardsListComponent, deps: [{ token: DashboardManagerService }, { token: i2$2.BsModalService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: TypeDashboardsListComponent, selector: "c8y-dashboard-manager", ngImport: i0, template: "<c8y-title>\n  {{ 'Dashboard manager' | translate }}\n</c8y-title>\n\n<div class=\"content-fullpage d-flex d-col border-top border-bottom\">\n  <c8y-data-grid\n    [title]=\"title\"\n    [loadMoreItemsLabel]=\"loadMoreItemsLabel\"\n    [loadingItemsLabel]=\"loadingItemsLabel\"\n    [columns]=\"columns\"\n    [pagination]=\"pagination\"\n    [serverSideDataCallback]=\"serverSideDataCallback\"\n    [infiniteScroll]=\"'auto'\"\n    [actionControls]=\"actionControls\"\n    [showSearch]=\"true\"\n    [displayOptions]=\"displayOptions\"\n    [refresh]=\"refresh\"\n    [expandableRows]=\"'ASYNC'\"\n  >\n    <div\n      *c8yExpandableRow=\"\n        let context;\n        let asyncRenderSuccess = asyncRenderSuccess;\n        let asyncRenderFail = asyncRenderFail\n      \"\n    >\n      <c8y-type-dashboard-info\n        [context]=\"context\"\n        [asyncRenderSuccess]=\"asyncRenderSuccess\"\n        [asyncRenderFail]=\"asyncRenderFail\"\n      ></c8y-type-dashboard-info>\n    </div>\n\n    <c8y-ui-empty-state\n      [icon]=\"'search'\"\n      [title]=\"'No matching dashboards.' | translate\"\n      [subtitle]=\"'Refine your search terms' | translate\"\n      [horizontal]=\"true\"\n    ></c8y-ui-empty-state>\n\n    <ng-container *ngFor=\"let column of columns; trackBy: trackByName\">\n      <c8y-column name=\"icon\">\n        <ng-container *c8yCellRendererDef=\"let context\">\n          <i [c8yIcon]=\"context.value\"></i>\n        </ng-container>\n      </c8y-column>\n\n      <c8y-column name=\"deviceTypeValue\">\n        <ng-container *c8yCellRendererDef=\"let context\">\n          <span class=\"label label-info\">\n            {{ context.value }}\n          </span>\n        </ng-container>\n      </c8y-column>\n\n      <c8y-column [name]=\"column.name\"></c8y-column>\n    </ng-container>\n  </c8y-data-grid>\n</div>\n", dependencies: [{ kind: "component", type: i2.EmptyStateComponent, selector: "c8y-ui-empty-state", inputs: ["icon", "title", "subtitle", "horizontal"] }, { kind: "directive", type: i2.IconDirective, selector: "[c8yIcon]", inputs: ["c8yIcon"] }, { kind: "directive", type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i2.CellRendererDefDirective, selector: "[c8yCellRendererDef]" }, { kind: "directive", type: i2.ColumnDirective, selector: "c8y-column", inputs: ["name"] }, { kind: "component", type: i2.DataGridComponent, selector: "c8y-data-grid", inputs: ["title", "loadMoreItemsLabel", "loadingItemsLabel", "showSearch", "refresh", "columns", "rows", "pagination", "infiniteScroll", "serverSideDataCallback", "selectable", "singleSelection", "selectionPrimaryKey", "displayOptions", "actionControls", "bulkActionControls", "headerActionControls", "searchText", "configureColumnsEnabled", "showCounterWarning", "activeClassName", "expandableRows", "hideReload"], outputs: ["rowMouseOver", "rowMouseLeave", "rowClick", "onConfigChange", "onBeforeFilter", "onBeforeSearch", "onFilter", "itemsSelect", "onReload", "onAddCustomColumn", "onRemoveCustomColumn", "onColumnFilterReset", "onSort", "onPageSizeChange", "onColumnReordered", "onColumnVisibilityChange"] }, { kind: "directive", type: i2.ExpandableRowDirective, selector: "[c8yExpandableRow]" }, { kind: "component", type: i2.TitleComponent, selector: "c8y-title", inputs: ["pageTitleUpdate"] }, { kind: "component", type: TypeDashboardInfoComponent, selector: "c8y-type-dashboard-info", inputs: ["deviceTypeValue", "displayDeviceTypeValue", "context", "asyncRenderSuccess", "asyncRenderFail"] }, { kind: "pipe", type: i2.C8yTranslatePipe, name: "translate" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TypeDashboardsListComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-dashboard-manager', template: "<c8y-title>\n  {{ 'Dashboard manager' | translate }}\n</c8y-title>\n\n<div class=\"content-fullpage d-flex d-col border-top border-bottom\">\n  <c8y-data-grid\n    [title]=\"title\"\n    [loadMoreItemsLabel]=\"loadMoreItemsLabel\"\n    [loadingItemsLabel]=\"loadingItemsLabel\"\n    [columns]=\"columns\"\n    [pagination]=\"pagination\"\n    [serverSideDataCallback]=\"serverSideDataCallback\"\n    [infiniteScroll]=\"'auto'\"\n    [actionControls]=\"actionControls\"\n    [showSearch]=\"true\"\n    [displayOptions]=\"displayOptions\"\n    [refresh]=\"refresh\"\n    [expandableRows]=\"'ASYNC'\"\n  >\n    <div\n      *c8yExpandableRow=\"\n        let context;\n        let asyncRenderSuccess = asyncRenderSuccess;\n        let asyncRenderFail = asyncRenderFail\n      \"\n    >\n      <c8y-type-dashboard-info\n        [context]=\"context\"\n        [asyncRenderSuccess]=\"asyncRenderSuccess\"\n        [asyncRenderFail]=\"asyncRenderFail\"\n      ></c8y-type-dashboard-info>\n    </div>\n\n    <c8y-ui-empty-state\n      [icon]=\"'search'\"\n      [title]=\"'No matching dashboards.' | translate\"\n      [subtitle]=\"'Refine your search terms' | translate\"\n      [horizontal]=\"true\"\n    ></c8y-ui-empty-state>\n\n    <ng-container *ngFor=\"let column of columns; trackBy: trackByName\">\n      <c8y-column name=\"icon\">\n        <ng-container *c8yCellRendererDef=\"let context\">\n          <i [c8yIcon]=\"context.value\"></i>\n        </ng-container>\n      </c8y-column>\n\n      <c8y-column name=\"deviceTypeValue\">\n        <ng-container *c8yCellRendererDef=\"let context\">\n          <span class=\"label label-info\">\n            {{ context.value }}\n          </span>\n        </ng-container>\n      </c8y-column>\n\n      <c8y-column [name]=\"column.name\"></c8y-column>\n    </ng-container>\n  </c8y-data-grid>\n</div>\n" }]
        }], ctorParameters: () => [{ type: DashboardManagerService }, { type: i2$2.BsModalService }] });

const DASHBOARD_MANAGER_PATH = 'dashboard-manager';
class DashboardManagerModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardManagerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: DashboardManagerModule, declarations: [TypeDashboardsListComponent,
            TypeDashboardTargetAssetsModalComponent,
            TypeDashboardTargetAssetsGridComponent], imports: [CoreModule, TooltipModule, DeviceGridModule, ContextDashboardModule, ModalModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardManagerModule, providers: [
            hookTab(DashboardManagerTabsFactory),
            hookRoute([
                {
                    path: DASHBOARD_MANAGER_PATH,
                    redirectTo: `${DASHBOARD_MANAGER_PATH}/type-dashboards`,
                    pathMatch: 'full'
                },
                {
                    path: `${DASHBOARD_MANAGER_PATH}/type-dashboards`,
                    component: TypeDashboardsListComponent
                }
            ]),
            hookNavigator(new NavigatorNode({
                parent: gettext('Configuration'),
                path: DASHBOARD_MANAGER_PATH,
                label: gettext('Dashboard manager'),
                icon: 'management1',
                routerLinkExact: false,
                featureId: 'dashboardManager'
            }))
        ], imports: [CoreModule, TooltipModule, DeviceGridModule, ContextDashboardModule, ModalModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DashboardManagerModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        TypeDashboardsListComponent,
                        TypeDashboardTargetAssetsModalComponent,
                        TypeDashboardTargetAssetsGridComponent
                    ],
                    imports: [CoreModule, TooltipModule, DeviceGridModule, ContextDashboardModule, ModalModule],
                    providers: [
                        hookTab(DashboardManagerTabsFactory),
                        hookRoute([
                            {
                                path: DASHBOARD_MANAGER_PATH,
                                redirectTo: `${DASHBOARD_MANAGER_PATH}/type-dashboards`,
                                pathMatch: 'full'
                            },
                            {
                                path: `${DASHBOARD_MANAGER_PATH}/type-dashboards`,
                                component: TypeDashboardsListComponent
                            }
                        ]),
                        hookNavigator(new NavigatorNode({
                            parent: gettext('Configuration'),
                            path: DASHBOARD_MANAGER_PATH,
                            label: gettext('Dashboard manager'),
                            icon: 'management1',
                            routerLinkExact: false,
                            featureId: 'dashboardManager'
                        }))
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ALL_GLOBAL_ROLES_SELECTED, AddDashboardComponent, AddDashboardFactory, AddDeviceDashboardFactory, AddGroupDashboardFactory, AppearanceSettingsComponent, COCKPIT_HOME_DASHBOARD_CONFIG, CONTEXT_DASHBOARD_CONFIG, CockpitDashboardComponent, CockpitDashboardModule, CockpitHomeDashboardModule, ContextDashboardComponent, ContextDashboardModule, ContextDashboardService, ContextDashboardType, DASHBOARD_CHILDREN_STATE_NAME, DASHBOARD_SETTINGS_CHANGES, DASHBOARD_THEME_CLASSES, DEFAULT_COCKPIT_HOME_WIDGETS, DashboardActionBarFactory, DashboardDetailComponent, DashboardDetailsTabId, DashboardManagerModule, DeviceContextDashboardModule, DeviceDashboardActionBarFactory, DeviceDashboardGuard, DeviceInfoDashboardComponent, DeviceInfoDashboardModule, DeviceManagementHomeDashboardComponent, DeviceManagementHomeDashboardModule, GroupContextDashboardModule, GroupDashboardActionBarFactory, GroupDashboardGuard, PRODUCT_EXPERIENCE, PasteDashboardActionComponent, REPORT_DEFAULT_NAVIGATION_NODE_PRIORITY, STYLING_CLASS_PREFIXES, TypeDashboardInfoComponent, WIDGET_CONTENT_CLASSES, WIDGET_HEADER_CLASSES, WidgetConfigComponent, WidgetPreviewComponent, WidgetService };
//# sourceMappingURL=c8y-ngx-components-context-dashboard.mjs.map
