import * as i0 from '@angular/core';
import { Component, Input, NgModule } from '@angular/core';
import * as i3 from '@angular/router';
import { RouterModule } from '@angular/router';
import * as i1 from '@c8y/client';
import * as i2 from '@c8y/ngx-components';
import { gettext, CoreModule, QuickLinkModule } from '@c8y/ngx-components';
import * as i4 from '@angular/common';

class WelcomeToCockpitComponent {
    constructor(tenantService, docs, router, navigator, applicationService) {
        this.tenantService = tenantService;
        this.docs = docs;
        this.router = router;
        this.navigator = navigator;
        this.applicationService = applicationService;
        this.quickLinks = [];
        this.CONFIGURATION_NODE = 'Configuration';
        this.TRIAL = 'TRIAL';
    }
    async ngOnInit() {
        this.tenantType = await this.tenantService.currentTenantType();
        this.setMessage();
        this.navSubscription = this.navigator.items$.subscribe(nodes => {
            this.navNodes = nodes;
            this.configurationNode = nodes.find((node) => node.label === this.CONFIGURATION_NODE);
        });
        this.docsSubscription = this.docs.items$.subscribe(links => {
            this.links = links;
        });
        // <---TRIAL & REGULAR TENANT --->
        this.createConnectSmartphoneQuickLink();
        await this.createQuicklinkRegisterDevice();
        // <--- TRIAL TENANT --->
        if (this.tenantType === this.TRIAL) {
            this.createQuicklinkUserGuide();
            return;
        }
        // <--- REGULAR TENANT --->
        this.createQuicklinkAddGroup();
        this.createQuickLinkReports();
        this.createQuickLinkExports();
        this.createQuicklinkSmartRules();
    }
    ngOnDestroy() {
        if (this.docsSubscription && !this.docsSubscription.closed) {
            this.docsSubscription.unsubscribe();
        }
        if (this.navSubscription && !this.navSubscription.closed) {
            this.navSubscription.unsubscribe();
        }
    }
    setMessage() {
        if (this.tenantType === this.TRIAL) {
            this.welcomeMessage = gettext(`
        The Cockpit application allows you to build IoT applications in minutes.
        To get started, connect any device to the platform.
        If you do not have an IoT device to hand, you can start by connecting your smartphone.
        Click below to be guided through the process.
      `);
        }
        else {
            this.welcomeMessage = gettext(`
        The Cockpit application provides you with options to manage
        and monitor Internet of Things assets and data from business perspective.
      `);
        }
    }
    createQuicklinkAddGroup() {
        const groupsNodeLabel = gettext('Groups');
        const groupsNode = this.findNavigatorNode(groupsNodeLabel, this.navNodes);
        if (groupsNode) {
            const quickLink = {
                icon: 'c8y-icon c8y-icon-group-add',
                label: gettext('Add group'),
                url: '/group',
                click: () => this.router.navigate([quickLink.url], { queryParams: { showAddGroup: true } })
            };
            this.quickLinks.push(quickLink);
        }
    }
    createConnectSmartphoneQuickLink() {
        // Provider in SensorPhoneModule defines the
        // 'Connect smartphone' quicklink.
        const connectSmartphone = this.links.find(link => link.label === 'Connect smartphone');
        if (connectSmartphone) {
            this.quickLinks.push(connectSmartphone);
        }
    }
    createQuickLinkReports() {
        const label = gettext('Reports');
        const reports = {
            icon: 'th',
            label,
            url: '/reports'
        };
        const reportsNode = this.findNavigatorNode(label, this.navNodes);
        if (reportsNode) {
            reports.click = () => {
                reportsNode.open = true;
                this.router.navigateByUrl(reports.url);
            };
            this.quickLinks.push(reports);
        }
    }
    createQuickLinkExports() {
        const label = gettext('Exports');
        const exports = {
            icon: 'c8y-reports',
            label,
            url: '/export'
        };
        if (this.isConfigChildNodeShown(label)) {
            exports.click = () => {
                this.configurationNode.open = true;
                this.router.navigateByUrl(exports.url);
            };
            this.quickLinks.push(exports);
        }
    }
    createQuicklinkSmartRules() {
        const label = gettext('Smart rules');
        const smartRules = {
            icon: 'c8y-smart-rules',
            label,
            url: '/rules'
        };
        if (this.isConfigChildNodeShown('Global smart rules')) {
            smartRules.click = () => {
                this.configurationNode.open = true;
                this.router.navigateByUrl(smartRules.url);
            };
            this.quickLinks.push(smartRules);
        }
    }
    async createQuicklinkRegisterDevice() {
        const { data } = await this.applicationService.listByUser(undefined, { pageSize: 2000 });
        if (data) {
            const deviceManagement = data.find(app => app.contextPath === 'devicemanagement');
            if (deviceManagement) {
                const deviceMgmtUrl = this.applicationService.getHref(deviceManagement);
                const registerDevice = {
                    icon: 'c8y-device-connect',
                    label: gettext('Register device'),
                    click: () => window.open(`${deviceMgmtUrl}/#/deviceregistration`, '_self')
                };
                this.quickLinks.push(registerDevice);
            }
        }
    }
    createQuicklinkUserGuide() {
        const userGuide = {
            icon: 'c8y-user',
            label: gettext('User documentation'),
            url: '/docs/sector/getting_started',
            click: () => {
                const userGuideURL = this.docs.getUserGuideLink(userGuide.url);
                window.open(userGuideURL);
            }
        };
        this.quickLinks.push(userGuide);
    }
    isConfigChildNodeShown(nodeName) {
        if (this.configurationNode && this.configurationNode.show) {
            const navNode = this.findNavigatorNode(nodeName, this.configurationNode.children);
            return !!navNode && navNode.show;
        }
        return false;
    }
    findNavigatorNode(nodeName, navNodes) {
        if (navNodes && navNodes.length > 0) {
            return navNodes.find((node) => node.label === nodeName);
        }
        return undefined;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WelcomeToCockpitComponent, deps: [{ token: i1.TenantService }, { token: i2.DocsService }, { token: i3.Router }, { token: i2.NavigatorService }, { token: i1.ApplicationService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: WelcomeToCockpitComponent, isStandalone: true, selector: "c8y-welcome-to-cockpit", inputs: { config: "config" }, ngImport: i0, template: "<div class=\"welcome-widget welcome-cockpit\" tabindex=\"0\">\n  <div class=\"d-flex fit-h\">\n    <div class=\"col-xs-12 col-md-6 a-s-stretch p-24\">\n      <h2 class=\"text-light\">{{ 'Welcome to Cockpit' | translate }}</h2>\n      <p class=\"text-16 text-light p-t-16 p-b-24\">{{ welcomeMessage | translate }}</p>\n      <div class=\"card-group interact-grid tight-grid\">\n        <div *ngFor=\"let link of quickLinks\" class=\"col-sm-4 col-xs-6\">\n          <button\n            type=\"button\"\n            title=\"{{ link.label }}\" \n            class=\"btn-clean card text-pre-normal\"\n            (click)=\"link.click ? link.click() : false\"\n            c8yProductExperience\n            [actionName]=\"'welcomeWidgetClicked'\"\n            [actionData]=\"{ link: link.label }\"\n          >\n            <c8y-quick-link [icon]=\"link.icon\" [label]=\"link.label\"></c8y-quick-link>\n          </button>\n        </div>\n      </div>\n    </div>\n    <div class=\"welcome-illustration a-s-stretch\">\n      <svg class=\"p-0\" viewBox=\"0 0 519 376\" fill=\"none\" xmlns=\"http://www.w3.org/2000/svg\">\n        <g opacity=\"0.05\" filter=\"url(#filter0_f_641_19870)\">\n        <path d=\"M102.632 141.085L175.921 184.041L150.295 199.06L77.006 156.105L102.632 141.085Z\" fill=\"#212121\"/>\n        <path d=\"M50.2364 171.795L123.526 214.75L96.756 230.439L23.4668 187.484L50.2364 171.795Z\" fill=\"#212121\"/>\n        <path d=\"M150.295 199.06L77.006 156.105L50.2364 171.795L123.526 214.75L150.295 199.06Z\" fill=\"#212121\"/>\n        </g>\n        <g opacity=\"0.05\" filter=\"url(#filter1_f_641_19870)\">\n        <path d=\"M417.934 142.261L491.223 185.216L465.598 200.236L392.309 157.28L417.934 142.261Z\" fill=\"#212121\"/>\n        <path d=\"M365.539 172.97L438.828 215.925L412.059 231.615L338.77 188.66L365.539 172.97Z\" fill=\"#212121\"/>\n        <path d=\"M465.598 200.236L392.309 157.28L365.539 172.97L438.828 215.925L465.598 200.236Z\" fill=\"#212121\"/>\n        </g>\n        <g opacity=\"0.05\">\n        <g filter=\"url(#filter2_f_641_19870)\">\n        <path d=\"M190.071 233.673L236.233 260.804L222.735 268.737L176.573 241.606L190.071 233.673Z\" fill=\"#212121\"/>\n        <path d=\"M190.071 233.673L142.64 205.75L129.143 213.683L176.573 241.606L190.071 233.673Z\" fill=\"#212121\"/>\n        </g>\n        </g>\n        <g opacity=\"0.05\" filter=\"url(#filter3_f_641_19870)\">\n        <path d=\"M322.599 234.056L275.169 261.98L288.667 269.913L336.097 241.989L322.599 234.056Z\" fill=\"#212121\"/>\n        <path d=\"M322.599 234.056L370.03 206.133L383.527 214.066L336.097 241.989L322.599 234.056Z\" fill=\"#212121\"/>\n        </g>\n        <g opacity=\"0.05\" filter=\"url(#filter4_f_641_19870)\">\n        <path d=\"M291.054 295.989L328.012 317.442L314.515 325.375L277.557 303.922L291.054 295.989Z\" fill=\"#212121\"/>\n        <path d=\"M375.443 345.366L328.012 317.442L314.515 325.375L361.945 353.298L375.443 345.366Z\" fill=\"#212121\"/>\n        </g>\n        <g opacity=\"0.05\" filter=\"url(#filter5_f_641_19870)\">\n        <path d=\"M411.003 323.321L484.292 366.276L458.666 381.295L385.377 338.34L411.003 323.321Z\" fill=\"#212121\"/>\n        <path d=\"M358.607 354.03L431.897 396.985L405.127 412.675L331.838 369.72L358.607 354.03Z\" fill=\"#212121\"/>\n        <path d=\"M458.666 381.295L385.377 338.34L358.607 354.03L431.897 396.985L458.666 381.295Z\" fill=\"#212121\"/>\n        </g>\n        <g opacity=\"0.05\" filter=\"url(#filter6_f_641_19870)\">\n        <path d=\"M148.483 412.836C148.616 410.421 147.115 407.98 143.98 406.137C137.963 402.601 128.198 402.602 122.178 406.14C118.408 408.356 116.998 411.435 117.95 414.296C117.788 413.81 117.694 413.317 117.669 412.823V414.669C117.784 416.894 119.285 419.099 122.173 420.797C128.19 424.333 137.955 424.332 143.975 420.794C147.105 418.955 148.608 416.52 148.483 414.109V412.836Z\" fill=\"#212121\"/>\n        <path d=\"M175.984 396.671V398.503C175.868 400.728 174.365 402.934 171.475 404.632C165.456 408.169 155.691 408.17 149.674 404.634C146.545 402.795 145.044 400.361 145.17 397.95V396.663C145.182 396.906 145.212 397.149 145.257 397.391C145.211 397.146 145.182 396.901 145.17 396.656V396.663C145.16 396.477 145.16 396.29 145.17 396.104V396.116C145.282 393.887 146.785 391.678 149.679 389.977C155.698 386.439 165.463 386.438 171.48 389.974C174.615 391.816 176.116 394.256 175.984 396.671Z\" fill=\"#212121\"/>\n        <path d=\"M204.347 379.268C204.163 377.044 202.594 374.856 199.652 373.189C193.525 369.716 183.765 369.821 177.854 373.424C174.78 375.297 173.352 377.747 173.551 380.156V382C173.735 384.223 175.304 386.411 178.246 388.078C184.373 391.551 194.133 391.446 200.044 387.843C203.118 385.97 204.546 383.52 204.347 381.111V380.151C204.352 380.094 204.355 380.037 204.358 379.98C204.366 379.827 204.367 379.673 204.362 379.519C204.359 379.434 204.354 379.35 204.347 379.265V379.268Z\" fill=\"#212121\"/>\n        <path d=\"M202.702 359.246L195.444 363.512L216.504 375.89L223.762 371.624L202.702 359.246Z\" fill=\"#212121\"/>\n        <path d=\"M120.554 429.278V431.079C120.438 433.304 118.935 435.51 116.045 437.208C110.026 440.745 100.261 440.747 94.2434 437.21C91.1145 435.371 89.6132 432.937 89.7392 430.526V429.24C89.7704 429.838 89.9019 430.435 90.1336 431.021C89.8973 430.422 89.7658 429.811 89.7392 429.199V429.24C89.7294 429.053 89.7294 428.867 89.7392 428.68V428.732C89.8368 426.491 91.3404 424.267 94.2499 422.557C100.269 419.019 110.034 419.018 116.052 422.554C119.197 424.403 120.698 426.854 120.554 429.278Z\" fill=\"#212121\"/>\n        <path d=\"M237.512 363.546V365.387L230.254 369.653V369.654L230.253 369.653L209.194 357.276V355.43L209.197 355.432L216.454 351.167L237.511 363.542L237.512 363.541V363.543L237.514 363.544L237.512 363.546Z\" fill=\"#212121\"/>\n        <path d=\"M70.9987 436.862L78.2554 432.597L99.3126 444.973L99.3145 444.971V444.974L99.3155 444.974L99.3145 444.975V446.818L92.0568 451.083V451.084L92.0561 451.084L70.9966 438.707L70.9966 436.863L70.9966 436.861L70.9987 436.862Z\" fill=\"#212121\"/>\n        <path d=\"M79.9086 452.78C79.7951 450.553 78.2935 448.347 75.4039 446.648C69.3867 443.112 59.6364 443.122 53.617 446.66C50.4854 448.5 48.9785 450.934 49.1006 453.344V455.183C49.2119 457.406 50.71 459.609 53.5982 461.306C59.6154 464.843 69.3804 464.842 75.3999 461.304C78.5301 459.464 80.033 457.029 79.9086 454.619V453.326C79.9095 453.308 79.9104 453.29 79.9111 453.272C79.918 453.105 79.9172 452.939 79.9086 452.772V452.78Z\" fill=\"#212121\"/>\n        <path d=\"M195.444 363.513L216.504 375.891V377.737L195.444 365.36V363.513Z\" fill=\"#212121\"/>\n        <path d=\"M223.763 371.624L216.504 375.89V377.737L223.763 373.471V371.624Z\" fill=\"#212121\"/>\n        </g>\n        <g opacity=\"0.05\" filter=\"url(#filter7_f_641_19870)\">\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M304.654 340.435L252.415 310.388L200.176 340.435L252.415 370.483L304.654 340.435Z\" fill=\"#212121\"/>\n        </g>\n        <rect width=\"82.5838\" height=\"28.8755\" transform=\"matrix(0.862126 0.506694 -0.862126 0.506694 96.9082 59.9609)\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"11.1196\" transform=\"matrix(0.862126 0.506694 0 1 72.0137 74.5918)\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"28.8755\" height=\"11.1196\" transform=\"matrix(0.862126 -0.506694 0 1 143.213 116.437)\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"28.8755\" transform=\"matrix(0.862126 0.506694 -0.862126 0.506694 70.9043 75.2446)\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"11.1196\" transform=\"matrix(0.862126 0.506694 0 1 46.0098 89.8755)\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"28.8755\" height=\"11.1196\" transform=\"matrix(0.862126 -0.506694 0 1 117.209 131.72)\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"28.8755\" transform=\"matrix(0.862126 0.506694 -0.862126 0.506694 44.8984 90.5293)\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"11.1196\" transform=\"matrix(0.862126 0.506694 0 1 20.0039 105.16)\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"28.8755\" height=\"11.1196\" transform=\"matrix(0.862126 -0.506694 0 1 91.2031 147.005)\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M147.397 94.0562L82.3828 132.267V134.618L147.397 96.4076V94.0562Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M82.382 132.267L41.373 108.165V110.516L82.382 134.618V132.267Z\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"75.4116\" height=\"47.5673\" transform=\"matrix(0.862126 -0.506694 0.862126 0.506694 41.373 108.165)\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"69.6107\" height=\"41.7664\" transform=\"matrix(0.862126 -0.506694 0.862126 0.506694 46.7637 107.871)\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M119.184 93.219C118.94 93.3624 118.933 93.5906 119.166 93.7275L119.36 93.8414C119.594 93.9791 119.982 93.9751 120.226 93.8317L121.157 93.2845C121.401 93.1411 121.408 92.9129 121.174 92.7751L120.98 92.6612C120.747 92.5244 120.359 92.5284 120.115 92.6718L119.184 93.219Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M119.167 94.5219L117.464 93.5207C117.231 93.3838 116.843 93.3878 116.599 93.5312L115.403 94.2341C115.159 94.3775 115.152 94.6058 115.385 94.7426L115.969 95.0861C116.202 95.223 116.505 95.2691 116.699 95.1547L116.749 95.1257C116.96 95.0017 117.103 95.1419 117.336 95.2788L117.608 95.4386C117.843 95.5772 118.227 95.5723 118.473 95.4281L119.148 95.0313C119.392 94.8879 119.402 94.6614 119.166 94.5228L119.167 94.5219Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M117.31 89.3159L118.155 90.1029C118.309 90.2423 118.264 90.4309 118.058 90.5523L115.289 92.1798C115.045 92.3232 115.036 92.5524 115.269 92.6892L115.591 92.8782C115.824 93.015 116.212 93.0093 116.456 92.8659L116.546 92.8131C116.791 92.6688 117.18 92.6648 117.414 92.8026L117.624 92.9262C117.857 93.063 118.245 93.059 118.489 92.9156L121.917 90.901C122.125 90.7787 122.167 90.5919 122.015 90.4516L119.595 88.1867C119.5 88.0958 119.335 88.0392 119.154 88.0293C118.968 88.0203 118.784 88.0598 118.649 88.1389L117.409 88.8674C117.201 88.9897 117.161 89.1773 117.312 89.3168L117.31 89.3159Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M117.163 85.7022L115.241 86.8318C115.028 86.9568 114.992 87.148 115.148 87.2892L116.264 88.2721C116.364 88.3595 116.526 88.4143 116.708 88.4224C116.888 88.4297 117.069 88.3902 117.201 88.3128L119.123 87.1832C119.337 87.0574 119.375 86.8671 119.218 86.7268L118.1 85.7429C118 85.6555 117.837 85.6007 117.659 85.5926C117.475 85.5845 117.295 85.6248 117.163 85.7022Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M126.741 93.6807C126.613 93.6762 126.485 93.7042 126.39 93.7597L126.254 93.8397C126.077 93.9435 126.079 94.1119 126.257 94.2161C126.434 94.3202 126.433 94.4886 126.258 94.5915L124.944 95.3639C124.768 95.4669 124.481 95.4666 124.305 95.3633L124.426 95.4348C124.305 95.3633 124.129 95.3393 123.966 95.3699C123.804 95.3997 123.684 95.4807 123.658 95.5811L123.085 97.7592C123.062 97.8438 123.111 97.9276 123.215 97.9885L125.484 99.3217C125.659 99.425 125.946 99.4262 126.122 99.3224L129.564 97.2998C129.676 97.2339 129.841 97.2058 129.995 97.2298L130.815 97.354C130.966 97.378 131.131 97.3517 131.243 97.2857L132.547 96.5195C132.631 96.4702 132.677 96.4042 132.681 96.3363L132.708 95.1624C132.712 95.091 132.661 95.0222 132.574 94.971L130.759 93.9044C130.681 93.8585 130.576 93.8302 130.469 93.8257L126.742 93.6798L126.741 93.6807Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M113.816 103.173L113.599 103.301C113.263 103.498 113.183 103.799 113.404 104.047L114.181 104.919C114.342 105.098 114.639 105.225 114.98 105.256C115.322 105.286 115.668 105.221 115.912 105.077L116.13 104.949C116.466 104.752 116.543 104.45 116.325 104.204L115.545 103.331C115.386 103.151 115.09 103.026 114.746 102.993C114.406 102.962 114.061 103.029 113.816 103.173Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M86.4069 106.588L82.4312 108.925C82.0974 109.121 81.6328 109.223 81.1589 109.199L79.3337 109.119C78.6978 109.092 78.1482 108.848 77.9237 108.496C77.7021 108.144 77.8464 107.751 78.2955 107.487L78.8807 107.143C79.213 106.947 79.3847 106.677 79.3508 106.4L78.7693 101.621C78.7309 101.303 78.4226 101.014 77.9512 100.855L70.2655 98.2681C69.626 98.0542 68.8239 98.1159 68.306 98.4203L53.3762 107.195C52.74 107.569 52.7418 108.173 53.3803 108.549L58.2868 111.432C58.9237 111.807 59.9539 111.809 60.5901 111.435L62.8519 110.105C63.4177 109.773 64.3098 109.732 64.96 110.011L69.9346 112.139C70.2694 112.281 70.682 112.346 71.0898 112.315L79.8979 111.691C80.4466 111.652 80.9898 111.778 81.3445 112.027L91.6581 119.229C91.9542 119.433 92.3804 119.556 92.8379 119.57C93.2908 119.581 93.7373 119.481 94.0592 119.292L95.6997 118.328C96.0829 118.103 96.2484 117.781 96.144 117.468L93.5498 109.667C93.4862 109.48 93.3297 109.308 93.0999 109.172L88.7072 106.591C88.0703 106.216 87.0401 106.214 86.4039 106.588L86.4069 106.588Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M84.9527 96.8779L86.8583 95.7579C86.978 95.6875 86.9792 95.5739 86.8575 95.5023L83.2986 93.4107C83.1784 93.34 82.9835 93.3416 82.8652 93.4111L80.9597 94.531C80.8399 94.6014 80.8403 94.7142 80.9605 94.7849L84.5194 96.8765C84.6411 96.948 84.833 96.9482 84.9527 96.8779Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M83.1499 97.9375L83.7876 97.5627C83.9073 97.4923 83.9085 97.3786 83.7868 97.3071L82.624 96.6237C82.5039 96.5531 82.3089 96.5546 82.1907 96.6241L81.553 96.9989C81.4317 97.0702 81.4321 97.183 81.5523 97.2536L82.715 97.937C82.8367 98.0085 83.0287 98.0087 83.1499 97.9375Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M105.885 76.3363L92.3633 84.2831C92.0655 84.4582 91.9703 84.719 92.1135 84.9509L93.6717 87.4573C93.8164 87.6901 93.7182 87.9509 93.4203 88.126L92.5821 88.6186C92.3111 88.7779 91.9169 88.84 91.5449 88.785L88.4453 88.3093C88.0732 88.2525 87.6775 88.3156 87.4066 88.4748L85.8708 89.3774C85.5819 89.5472 85.4807 89.7974 85.6074 90.0267L87.8646 94.0489C88.0425 94.3646 88.6069 94.5502 89.16 94.4706L90.548 94.2694C91.1056 94.1889 91.457 93.8658 91.351 93.5343L91.1087 92.7744C91.0497 92.5919 91.1331 92.4086 91.3156 92.2678C91.7369 92.2303 92.1766 92.341 92.4097 92.5677L93.0504 93.1871C93.3076 93.4368 93.2441 93.7602 92.8909 93.9678L87.5231 97.1226C87.3854 97.2035 87.2867 97.3039 87.2406 97.4158L86.0999 100.034C86.0076 100.252 86.1148 100.484 86.3867 100.644L88.254 101.742C88.6777 101.991 89.3645 101.991 89.7881 101.742L90.7506 101.177C91.1727 100.929 91.6222 100.79 91.9001 100.953C92.4003 101.247 92.9775 101.205 93.3982 100.975C93.7888 100.73 93.8748 100.4 93.358 100.096C93.0426 99.9108 93.3162 99.6687 93.7399 99.4198L94.4314 99.0133C94.855 98.7644 95.5418 98.7651 95.9655 99.0141L96.1683 99.1333C96.5919 99.3823 96.5932 99.7859 96.1695 100.035L91.5232 102.766C91.0996 103.015 91.1009 103.418 91.526 103.668L96.9733 106.87C97.3999 107.12 98.0882 107.122 98.5118 106.873L100.887 105.477C101.31 105.229 101.996 105.229 102.42 105.478L108.207 108.88C108.633 109.13 109.319 109.13 109.742 108.881L113.426 106.716C113.757 106.522 113.835 106.223 113.623 105.977L107.486 98.9179C107.339 98.7467 107.07 98.6257 106.755 98.5831L102.535 98.026C101.998 97.9567 101.636 97.6611 101.692 97.3403C101.733 97.217 101.835 97.1025 101.986 97.0136L103.908 95.884C104.196 95.7151 104.618 95.6556 105.008 95.7283L109.66 96.6093C110.018 96.6758 110.413 96.6295 110.697 96.4852C110.984 96.341 111.12 96.1164 111.058 95.8987L110.097 92.5168C110.039 92.3141 110.151 92.1071 110.397 91.9628L112.239 90.8798C112.5 90.7267 112.613 90.5065 112.53 90.294L111.562 87.7072C111.458 87.4312 111.31 86.9745 111.271 86.6916C111.227 86.3469 111.58 86.0582 111.807 86.1915C112.23 86.4405 112.917 86.4412 113.341 86.1923L113.369 86.1755C113.728 85.9644 113.789 85.6322 113.514 85.3807L111.721 83.7448C111.542 83.5798 111.498 83.378 111.606 83.193L113.287 80.3049C113.422 80.075 113.32 79.8193 113.027 79.6471L107.408 76.345C106.983 76.0951 106.296 76.0944 105.874 76.3425L105.885 76.3363Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M93.4406 100.953C93.4284 100.96 93.4133 100.966 93.4012 100.973C93.3875 100.981 93.3784 100.99 93.3663 100.997L93.4406 100.953Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M65.6489 82.1346C66.3191 82.5148 67.1222 82.4298 68.0612 81.878C69.0003 81.3261 69.8033 80.4671 70.4736 79.299C71.1438 78.1039 71.4806 76.9461 71.4806 75.8237C71.4806 74.7013 71.1471 73.9375 70.4736 73.5322L68.4731 72.3564C69.1466 72.7617 69.4802 73.5256 69.4802 74.648C69.4802 75.7704 69.1434 76.9282 68.4731 78.1233C67.8028 79.2913 66.9998 80.1503 66.0608 80.7023C65.1218 81.2541 64.3187 81.3391 63.6484 80.9589L65.6489 82.1346Z\" fill=\"url(#paint0_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M68.0679 66.7282C69.3834 65.956 70.6117 65.5282 71.7497 65.4467C72.8192 65.3844 73.7544 65.5811 74.5603 66.0339L72.5598 64.8582C71.7539 64.4053 70.8187 64.2087 69.7493 64.271C68.6095 64.3526 67.379 64.7817 66.0611 65.5562C64.7424 66.3322 63.5174 67.3465 62.3794 68.6027C61.217 69.9013 60.1776 71.3675 59.3292 72.8802C58.4808 74.3928 57.8105 75.975 57.3184 77.6266C56.8262 79.3053 56.5801 80.9595 56.5801 82.5076C56.5801 84.0558 56.8132 85.5598 57.2827 87.0216C57.7749 88.4431 58.4452 89.903 59.2936 91.4093C60.1646 92.8752 61.1814 94.4295 62.3438 96.0685C63.5872 97.8458 64.8274 99.6287 66.0644 101.414L68.0648 102.589C66.8279 100.804 65.5877 99.0215 64.3443 97.2442C63.1818 95.6052 62.165 94.0509 61.294 92.585C60.4456 91.0787 59.7754 89.6188 59.2832 88.1973C58.8137 86.7355 58.5805 85.2315 58.5805 83.6833C58.5805 82.1352 58.8266 80.4811 59.3188 78.8023C59.811 77.1507 60.4813 75.5685 61.3296 74.0559C62.178 72.5432 63.2174 71.077 64.3799 69.7784C65.5197 68.5202 66.7467 67.5047 68.0679 66.7282Z\" fill=\"url(#paint1_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M68.0631 81.8778C69.0021 81.3259 69.8051 80.4669 70.4754 79.2988C71.1457 78.1037 71.4825 76.946 71.4825 75.8235C71.4825 74.7011 71.1489 73.9373 70.4754 73.532C69.8019 73.1266 69.0021 73.1942 68.0631 73.7461C67.124 74.298 66.321 75.1686 65.6507 76.3676C64.9804 77.5665 64.6437 78.7205 64.6437 79.8429C64.6437 80.9653 64.9804 81.7272 65.6507 82.1344C66.321 82.5146 67.124 82.4297 68.0631 81.8778ZM68.0631 66.7329C69.381 65.9584 70.6114 65.5293 71.7512 65.4478C72.9137 65.3799 73.9175 65.6182 74.7691 66.1589C75.6401 66.661 76.3234 67.4476 76.8123 68.5226C77.3272 69.6095 77.583 70.9415 77.583 72.5168C77.583 74.092 77.3369 75.8545 76.8447 77.8777C76.3525 79.8777 75.6725 82.1312 74.8015 84.648C73.9531 87.1244 72.959 89.8567 71.8192 92.8527C70.5564 96.0952 69.3032 99.3436 68.0663 102.59C66.8294 100.805 65.5892 99.0223 64.3458 97.2451C63.1833 95.606 62.1666 94.0517 61.2955 92.5858C60.4472 91.0796 59.7769 89.6196 59.2847 88.1982C58.8152 86.7363 58.582 85.2323 58.582 83.6841C58.582 82.136 58.8281 80.4819 59.3203 78.8031C59.8125 77.1515 60.4828 75.5693 61.3311 74.0567C62.1795 72.544 63.2189 71.0778 64.3814 69.7792C65.5212 68.521 66.7484 67.5056 68.0695 66.7291L68.0631 66.7329Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M105.495 63.9105C106.165 64.2907 106.968 64.2057 107.907 63.6538C108.846 63.1019 109.649 62.2429 110.319 61.0749C110.99 59.8798 111.326 58.722 111.326 57.5996C111.326 56.4772 110.993 55.7133 110.319 55.308L108.319 54.1323C108.992 54.5376 109.326 55.3015 109.326 56.4239C109.326 57.5463 108.989 58.7041 108.319 59.8992C107.649 61.0672 106.846 61.9262 105.906 62.4781C104.967 63.03 104.164 63.115 103.494 62.7348L105.495 63.9105Z\" fill=\"url(#paint2_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M107.914 48.5041C109.229 47.7319 110.457 47.3041 111.595 47.2226C112.665 47.1602 113.6 47.3569 114.406 47.8098L112.406 46.6341C111.6 46.1812 110.664 45.9845 109.595 46.0469C108.455 46.1285 107.225 46.5575 105.907 47.3321C104.588 48.1081 103.363 49.1224 102.225 50.3785C101.063 51.6771 100.023 53.1434 99.1749 54.656C98.3265 56.1687 97.6562 57.7508 97.1641 59.4025C96.6719 61.0812 96.4258 62.7354 96.4258 64.2835C96.4258 65.8316 96.6589 67.3357 97.1284 68.7975C97.6206 70.2189 98.2909 71.6789 99.1393 73.1852C100.01 74.651 101.027 76.2054 102.19 77.8444C103.433 79.6217 104.673 81.4046 105.91 83.1895L107.91 84.3652C106.674 82.5803 105.433 80.7974 104.19 79.0201C103.028 77.3811 102.011 75.8267 101.14 74.3609C100.291 72.8546 99.6211 71.3946 99.1289 69.9732C98.6594 68.5114 98.4262 67.0074 98.4262 65.4592C98.4262 63.9111 98.6723 62.2569 99.1645 60.5782C99.6567 58.9266 100.327 57.3444 101.175 55.8318C102.024 54.3191 103.063 52.8529 104.226 51.5543C105.365 50.2961 106.592 49.2806 107.914 48.5041Z\" fill=\"url(#paint3_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M107.909 63.6536C108.848 63.1017 109.651 62.2427 110.321 61.0747C110.991 59.8796 111.328 58.7218 111.328 57.5994C111.328 56.477 110.995 55.7132 110.321 55.3078C109.648 54.9025 108.848 54.9701 107.909 55.5219C106.97 56.0738 106.167 56.9445 105.496 58.1434C104.826 59.3424 104.489 60.4963 104.489 61.6187C104.489 62.7412 104.826 63.5031 105.496 63.9103C106.167 64.2905 106.97 64.2055 107.909 63.6536ZM107.909 48.5088C109.227 47.7342 110.457 47.3052 111.597 47.2236C112.759 47.1558 113.763 47.3941 114.615 47.9347C115.486 48.4368 116.169 49.2235 116.658 50.2985C117.173 51.3854 117.429 52.7174 117.429 54.2927C117.429 55.8679 117.183 57.6304 116.69 59.6536C116.198 61.6536 115.518 63.9071 114.647 66.4239C113.799 68.9003 112.805 71.6326 111.665 74.6286C110.402 77.8711 109.149 81.1195 107.912 84.3661C106.675 82.5812 105.435 80.7982 104.191 79.0209C103.029 77.3819 102.012 75.8275 101.141 74.3617C100.293 72.8555 99.6226 71.3955 99.1304 69.974C98.6609 68.5122 98.4277 67.0082 98.4277 65.46C98.4277 63.9118 98.6738 62.2578 99.166 60.579C99.6582 58.9274 100.328 57.3452 101.177 55.8326C102.025 54.3199 103.065 52.8537 104.227 51.5551C105.367 50.2969 106.594 49.2815 107.915 48.505L107.909 48.5088Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M94.7094 83.3094C95.3797 83.6896 96.1827 83.6046 97.1218 83.0528C98.0608 82.5009 98.8638 81.6419 99.5341 80.4738C100.204 79.2787 100.541 78.1209 100.541 76.9985C100.541 75.8761 100.208 75.1123 99.5341 74.707L97.5337 73.5312C98.2072 73.9365 98.5407 74.7004 98.5407 75.8228C98.5407 76.9452 98.2039 78.103 97.5337 79.2981C96.8634 80.4661 96.0604 81.3251 95.1213 81.8771C94.1823 82.4289 93.3792 82.5139 92.709 82.1337L94.7094 83.3094Z\" fill=\"url(#paint4_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M97.1265 67.9035C98.442 67.1313 99.6703 66.7035 100.808 66.622C101.878 66.5597 102.813 66.7564 103.619 67.2092L101.618 66.0335C100.813 65.5806 99.8773 65.3839 98.8079 65.4463C97.6681 65.5279 96.4376 65.957 95.1197 66.7315C93.801 67.5075 92.576 68.5218 91.438 69.778C90.2756 71.0766 89.2362 72.5428 88.3878 74.0555C87.5394 75.5681 86.8691 77.1503 86.3769 78.8019C85.8848 80.4806 85.6387 82.1348 85.6387 83.6829C85.6387 85.2311 85.8718 86.7351 86.3413 88.1969C86.8335 89.6183 87.5038 91.0783 88.3522 92.5846C89.2232 94.0504 90.24 95.6048 91.4024 97.2438C92.6458 99.0211 93.886 100.804 95.123 102.589L97.1234 103.765C95.8865 101.98 94.6462 100.197 93.4029 98.4195C92.2404 96.7805 91.2236 95.2262 90.3526 93.7603C89.5042 92.254 88.834 90.7941 88.3418 89.3726C87.8723 87.9108 87.6391 86.4068 87.6391 84.8586C87.6391 83.3105 87.8852 81.6563 88.3774 79.9776C88.8696 78.326 89.5399 76.7438 90.3882 75.2312C91.2366 73.7185 92.276 72.2523 93.4385 70.9537C94.5783 69.6955 95.8053 68.68 97.1265 67.9035Z\" fill=\"url(#paint5_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M97.1217 83.0531C98.0607 82.5012 98.8637 81.6421 99.534 80.4741C100.204 79.279 100.541 78.1212 100.541 76.9988C100.541 75.8764 100.208 75.1126 99.534 74.7073C98.8605 74.3019 98.0607 74.3695 97.1217 74.9214C96.1826 75.4733 95.3796 76.3439 94.7093 77.5429C94.039 78.7418 93.7023 79.8957 93.7023 81.0182C93.7023 82.1406 94.039 82.9025 94.7093 83.3097C95.3796 83.6899 96.1826 83.6049 97.1217 83.0531ZM97.1217 67.9082C98.4396 67.1337 99.67 66.7046 100.81 66.623C101.972 66.5552 102.976 66.7935 103.828 67.3342C104.699 67.8363 105.382 68.6229 105.871 69.6979C106.386 70.7848 106.642 72.1168 106.642 73.6921C106.642 75.2673 106.395 77.0298 105.903 79.053C105.411 81.053 104.731 83.3065 103.86 85.8233C103.012 88.2997 102.018 91.032 100.878 94.028C99.615 97.2705 98.3618 100.519 97.1249 103.765C95.888 101.981 94.6478 100.198 93.4044 98.4204C92.2419 96.7813 91.2252 95.227 90.3541 93.7611C89.5057 92.2549 88.8355 90.7949 88.3433 89.3735C87.8738 87.9116 87.6406 86.4076 87.6406 84.8594C87.6406 83.3113 87.8867 81.6572 88.3789 79.9784C88.8711 78.3268 89.5414 76.7446 90.3897 75.232C91.2381 73.7193 92.2775 72.2531 93.44 70.9545C94.5798 69.6963 95.807 68.6809 97.1281 67.9044L97.1217 67.9082Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M183.029 150.581L169.532 158.514L123.369 131.383V140.201L169.532 167.332L183.029 159.399V150.581Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"15.6044\" height=\"8.74496\" transform=\"matrix(0.862126 -0.506694 0 1 169.566 158.535)\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M136.867 123.45L183.029 150.581L169.532 158.514L123.369 131.383L136.867 123.45Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M230.461 178.504L216.963 186.437L170.801 159.306V168.124L216.963 195.255L230.461 187.322V178.504Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"15.6044\" height=\"8.74496\" transform=\"matrix(0.862126 -0.506694 0 1 216.998 186.458)\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M184.297 151.373L230.459 178.504L216.961 186.437L170.799 159.306L184.297 151.373Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"28.8755\" transform=\"matrix(0.862126 0.506694 -0.862126 0.506694 412.211 61.1362)\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"11.1196\" transform=\"matrix(0.862126 0.506694 0 1 387.316 75.7671)\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"28.8755\" height=\"11.1196\" transform=\"matrix(0.862126 -0.506694 0 1 458.514 117.612)\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"28.8755\" transform=\"matrix(0.862126 0.506694 -0.862126 0.506694 386.205 76.4194)\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"11.1196\" transform=\"matrix(0.862126 0.506694 0 1 361.311 91.0503)\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"28.8755\" height=\"11.1196\" transform=\"matrix(0.862126 -0.506694 0 1 432.508 132.895)\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"28.8755\" transform=\"matrix(0.862126 0.506694 -0.862126 0.506694 360.201 91.7046)\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"11.1196\" transform=\"matrix(0.862126 0.506694 0 1 335.307 106.335)\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"28.8755\" height=\"11.1196\" transform=\"matrix(0.862126 -0.506694 0 1 406.506 148.18)\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M317.406 152.137L330.904 160.07L377.066 132.939V141.757L330.904 168.888L317.406 160.955V152.137Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"15.6044\" height=\"8.74496\" transform=\"matrix(-0.862126 -0.506694 0 1 330.869 160.09)\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M363.569 125.005L317.406 152.136L330.904 160.069L377.066 132.938L363.569 125.005Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M269.971 180.06L283.468 187.993L329.631 160.862V169.68L283.468 196.811L269.971 188.878V180.06Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"15.6044\" height=\"8.74496\" transform=\"matrix(-0.862126 -0.506694 0 1 283.434 188.014)\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M316.133 152.929L269.971 180.06L283.468 187.993L329.631 160.862L316.133 152.929Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M275.486 279.044C275.711 274.805 273.01 270.523 267.384 267.287C256.565 261.064 239.024 261.064 228.205 267.287C223.012 270.274 220.311 274.152 220.104 278.066V290.085C220.311 286.171 223.012 282.293 228.205 279.306C239.024 273.083 256.565 273.083 267.384 279.306C273.01 282.542 275.711 286.824 275.486 291.063V279.044Z\" fill=\"#D4D9DE\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M229.512 267.738C239.61 261.93 255.981 261.93 266.079 267.738V279.757C255.981 273.949 239.61 273.949 229.512 279.757V267.738Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M266.082 267.738C270.929 270.526 273.449 274.146 273.643 277.798V289.817C273.449 286.165 270.929 282.545 266.082 279.757V267.738Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M273.643 277.798C273.853 281.755 271.333 285.751 266.082 288.772V300.791C271.333 297.77 273.853 293.774 273.643 289.817V277.798Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M266.079 288.771C255.981 294.579 239.61 294.579 229.512 288.771V300.79C239.61 306.598 255.981 306.598 266.079 300.79V288.771Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M221.954 278.712C221.743 274.755 224.264 270.759 229.515 267.738V279.757C224.264 282.777 221.743 286.774 221.954 290.731V278.712Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M229.512 288.771C224.665 285.983 222.145 282.364 221.951 278.711V290.73C222.145 294.383 224.665 298.002 229.512 300.79V288.771Z\" fill=\"var(--c8y-brand-40)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M220.099 277.464C219.874 281.704 222.574 285.985 228.2 289.221C239.019 295.444 256.56 295.445 267.38 289.221C272.573 286.234 275.273 282.356 275.481 278.443V290.462C275.273 294.375 272.573 298.253 267.38 301.24C256.56 307.463 239.019 307.463 228.2 301.24C222.574 298.004 219.874 293.723 220.099 289.483V277.464Z\" fill=\"#D4D9DE\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M300.031 277.954L247.792 247.906L195.553 277.954V289.973L247.792 259.925L300.031 289.973V277.954Z\" fill=\"#D4D9DE\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M195.553 278.314L247.792 308.362L300.031 278.314V290.333L247.792 320.381L195.553 290.333V278.314Z\" fill=\"var(--c8y-palette-gray-10)\" fill-opacity=\"0.8\" stroke=\"#212121\" stroke-opacity=\"0.8\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M247.836 308.122L300.075 278.074V290.093L247.836 320.141V308.122Z\" fill=\"var(--c8y-palette-gray-10)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M300.031 277.953L247.792 247.906L195.553 277.953L247.792 308.001L300.031 277.953ZM267.381 266.685C256.562 260.462 239.021 260.462 228.202 266.685C217.383 272.908 217.383 282.998 228.202 289.221C239.021 295.444 256.562 295.444 267.381 289.221C278.201 282.998 278.201 272.908 267.381 266.685Z\" fill=\"#212121\" stroke=\"black\" stroke-opacity=\"0.8\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M229.511 267.737C239.609 261.929 255.98 261.929 266.078 267.737C276.176 273.546 276.176 282.962 266.078 288.771C255.98 294.579 239.609 294.579 229.511 288.771C219.413 282.962 219.413 273.546 229.511 267.737Z\" fill=\"var(--c8y-brand-60)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M254.234 281.447C251.072 283.265 245.949 283.265 242.789 281.447C239.628 279.629 239.627 276.682 242.789 274.864C245.949 273.046 251.073 273.046 254.234 274.864C257.395 276.682 257.394 279.629 254.234 281.447ZM257.667 270.067L255.084 271.378C254.141 271.074 253.149 270.842 252.13 270.682L251.978 268.713C251.977 268.174 251.22 267.738 250.283 267.738L246.74 267.738C245.803 267.738 245.045 268.174 245.045 268.713L244.892 270.682C243.874 270.842 242.881 271.074 241.939 271.378L239.355 270.068C238.69 269.685 237.622 269.685 236.957 270.068L234.45 271.51C233.786 271.892 233.785 272.507 234.45 272.889L236.729 274.375C236.2 274.917 235.797 275.488 235.519 276.073L232.096 276.162C231.158 276.162 230.401 276.597 230.401 277.137L230.401 279.174C230.401 279.713 231.159 280.149 232.096 280.149L235.518 280.237C235.796 280.823 236.2 281.393 236.728 281.936L234.451 283.422C233.786 283.804 233.785 284.418 234.45 284.801L236.957 286.243C237.622 286.625 238.69 286.625 239.355 286.243L241.938 284.933C242.881 285.236 243.874 285.469 244.893 285.629L245.045 287.597C245.045 288.136 245.803 288.572 246.74 288.572L250.282 288.572C251.22 288.572 251.977 288.137 251.977 287.597L252.131 285.628C253.149 285.469 254.142 285.237 255.084 284.933L257.667 286.243C258.332 286.626 259.401 286.625 260.065 286.243L262.572 284.801C263.237 284.419 263.237 283.804 262.572 283.422L260.294 281.936C260.823 281.393 261.226 280.823 261.504 280.237L264.927 280.149C265.864 280.149 266.622 279.713 266.622 279.174L266.622 277.136C266.622 276.597 265.864 276.162 264.927 276.161L261.504 276.074C261.227 275.488 260.823 274.917 260.294 274.375L262.572 272.889C263.236 272.506 263.237 271.892 262.572 271.509L260.065 270.067C259.4 269.685 258.332 269.685 257.667 270.067ZM244.969 276.118C246.925 274.993 250.097 274.992 252.054 276.118C254.01 277.243 254.01 279.068 252.054 280.193C250.097 281.318 246.925 281.318 244.969 280.193C243.013 279.068 243.013 277.243 244.969 276.118ZM246.462 276.976C245.331 277.628 245.33 278.683 246.462 279.334C247.594 279.985 249.429 279.985 250.561 279.334C251.692 278.683 251.692 277.628 250.561 276.977C249.429 276.326 247.594 276.326 246.462 276.976Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-opacity=\"0.8\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M271.79 266.809C271.985 263.135 269.645 259.424 264.769 256.62C255.393 251.226 240.19 251.226 230.814 256.62C226.125 259.316 223.781 262.851 223.781 266.385V278.404C223.781 274.87 226.125 271.335 230.814 268.639C240.19 263.245 255.393 263.245 264.769 268.639C269.645 271.443 271.985 275.154 271.79 278.828V266.809Z\" fill=\"#D4D9DE\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M269.944 265.693C270.124 269.085 267.964 272.51 263.463 275.099V287.118C267.964 284.529 270.124 281.104 269.944 277.712V265.693Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M263.461 275.1C254.805 280.078 240.772 280.078 232.117 275.1V287.119C240.772 292.097 254.805 292.097 263.461 287.119V275.1Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M225.631 266.085C225.631 262.822 227.795 259.56 232.122 257.071V257.071C240.778 252.092 254.81 252.092 263.466 257.071V257.071C267.62 259.46 269.781 262.563 269.947 265.693V277.712C269.781 274.582 267.62 271.479 263.466 269.09V269.09C254.81 264.111 240.778 264.111 232.122 269.09V269.09C227.795 271.579 225.631 274.841 225.631 278.104V266.085Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M232.122 275.1C227.795 272.61 225.631 269.348 225.631 266.085V278.104C225.631 281.367 227.795 284.629 232.122 287.119V275.1Z\" fill=\"var(--c8y-brand-40)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M300.031 266.383L247.792 236.335L195.553 266.383V278.402L247.792 248.354L300.031 278.402V266.383Z\" fill=\"#D4D9DE\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M223.781 266.382C223.781 269.917 226.125 273.451 230.814 276.148C240.19 281.541 255.393 281.541 264.769 276.148C269.27 273.559 271.61 270.198 271.79 266.806V278.825C271.61 282.217 269.27 285.578 264.769 288.167C255.393 293.56 240.19 293.56 230.814 288.167C226.125 285.47 223.781 281.936 223.781 278.401V266.382Z\" fill=\"#D4D9DE\" fill-opacity=\"0.6\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M195.553 266.382L247.792 296.43L300.031 266.382V278.401L247.792 308.449L195.553 278.401V266.382Z\" fill=\"#8B96A0\" fill-opacity=\"0.8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path opacity=\"0.6\" fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M247.428 296.431L299.667 266.383V278.402L247.428 308.45V296.431Z\" fill=\"#212121\" fill-opacity=\"0.8\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M300.031 266.385L247.792 236.337L195.553 266.385L247.792 296.432L300.031 266.385ZM264.769 256.619C255.393 251.226 240.191 251.226 230.814 256.619C221.438 262.013 221.438 270.757 230.814 276.15C240.191 281.544 255.393 281.544 264.769 276.15C274.146 270.757 274.146 262.013 264.769 256.619Z\" fill=\"#E3E5E8\" fill-opacity=\"0.8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M232.124 257.07C240.779 252.091 254.812 252.091 263.468 257.07V257.07C272.123 262.048 272.123 270.12 263.468 275.098V275.098C254.812 280.077 240.779 280.077 232.124 275.098V275.098C223.469 270.12 223.469 262.048 232.124 257.07V257.07Z\" fill=\"var(--c8y-brand-60)\"/>\n        <path d=\"M257.965 270.166C257.412 270.554 256.857 270.911 256.349 271.203C253.371 272.916 248.485 274.72 247.078 273.911L245.298 272.887C248.317 272.498 251.364 271.185 253.84 269.761C254.136 269.591 254.429 269.415 254.714 269.237C254.1 268.944 253.565 268.613 253.064 268.159C252.731 268.377 252.404 268.579 252.095 268.757C249.117 270.47 244.232 272.274 242.826 271.465L240.762 270.278C243.779 269.889 246.828 268.577 249.305 267.152C250.196 266.639 251.057 266.084 251.83 265.503C251.955 263.658 253.933 262.091 256.78 261.42L249.676 257.333C246.742 255.646 240.663 258.138 237.148 260.16C233.461 262.281 229.288 265.686 232.22 267.373L245.553 275.042C248.487 276.729 254.779 274.114 258.094 272.207C259.038 271.665 260.078 270.98 261.021 270.242C260.005 270.329 258.967 270.304 257.965 270.166ZM238.894 261.164C242.069 259.337 246.662 257.608 247.929 258.337C249.309 259.131 245.535 262.084 243.015 263.534C240.038 265.247 235.236 267.1 233.966 266.369C232.583 265.574 236.105 262.768 238.894 261.164ZM236.219 267.665C239.238 267.276 242.284 265.963 244.761 264.539C247.23 263.118 249.507 261.369 250.183 259.633L252.253 260.824C253.783 261.704 250.056 264.712 247.559 266.148C244.568 267.867 239.692 269.662 238.288 268.855L236.219 267.665Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path d=\"M255.916 263.434C258.083 262.188 261.601 262.187 263.77 263.434C265.939 264.682 265.937 266.706 263.77 267.952C261.603 269.199 258.084 269.2 255.916 267.952C253.747 266.705 253.749 264.681 255.916 263.434ZM258.56 263.764L257.692 264.657L259.061 266.916L260.167 265.806L261.361 267.675L260.755 263.875L259.441 265.19L258.56 263.764Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M268.102 254.586C268.267 251.477 266.286 248.337 262.161 245.964C254.227 241.401 241.363 241.401 233.429 245.964C229.621 248.155 227.641 250.998 227.488 253.868V265.887C227.641 263.017 229.621 260.174 233.429 257.983C241.363 253.42 254.227 253.42 262.161 257.983C266.286 260.356 268.267 263.496 268.102 266.605V254.586Z\" fill=\"#D4D9DE\" fill-opacity=\"0.8\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M266.187 254.002C266.187 256.721 264.384 259.439 260.777 261.514V273.533C264.384 271.458 266.187 268.74 266.187 266.021V254.002Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M260.778 261.514C253.565 265.662 241.871 265.662 234.658 261.514V273.533C241.871 277.681 253.565 277.681 260.778 273.533V261.514Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M229.25 254.002C229.25 251.283 231.053 248.564 234.66 246.49V246.49C241.872 242.341 253.566 242.341 260.779 246.49V246.49C264.385 248.564 266.189 251.283 266.189 254.002V266.021C266.189 263.302 264.385 260.583 260.779 258.509V258.509C253.566 254.36 241.872 254.36 234.66 258.509V258.509C231.053 260.583 229.25 263.302 229.25 266.021V254.002Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M234.66 261.514C231.053 259.439 229.25 256.721 229.25 254.002V266.021C229.25 268.74 231.053 271.458 234.66 273.533V261.514Z\" fill=\"var(--c8y-brand-40)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M300.031 254.229L247.792 224.181L195.553 254.229V266.248L247.792 236.2L300.031 266.248V254.229Z\" fill=\"#D4D9DE\" fill-opacity=\"0.8\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M195.553 254.229L247.792 284.276L300.031 254.229V266.247L247.792 296.295L195.553 266.247V254.229Z\" fill=\"#8B96A0\" fill-opacity=\"0.6\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path opacity=\"0.6\" fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M247.428 284.276L299.667 254.229V266.248L247.428 296.295V284.276Z\" fill=\"#212121\" fill-opacity=\"0.6\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M227.488 253.869C227.323 256.978 229.303 260.117 233.429 262.491C241.363 267.054 254.227 267.054 262.16 262.491C265.969 260.3 267.949 257.456 268.101 254.586V266.605C267.949 269.475 265.969 272.319 262.16 274.509C254.227 279.073 241.363 279.073 233.429 274.509C229.303 272.136 227.323 268.997 227.488 265.888V253.869Z\" fill=\"#D4D9DE\" fill-opacity=\"0.8\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M300.031 254.229L247.792 224.181L195.553 254.229L247.792 284.276L300.031 254.229ZM262.158 245.966C254.224 241.402 241.36 241.402 233.426 245.966C225.492 250.529 225.492 257.928 233.426 262.492C241.36 267.055 254.224 267.055 262.158 262.492C270.091 257.928 270.091 250.529 262.158 245.966Z\" fill=\"#E3E5E8\" fill-opacity=\"0.6\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M234.66 246.492C241.872 242.343 253.566 242.343 260.779 246.492V246.492C267.992 250.641 267.992 257.367 260.779 261.516V261.516C253.566 265.664 241.872 265.664 234.66 261.516V261.516C227.447 257.367 227.447 250.641 234.66 246.492V246.492Z\" fill=\"var(--c8y-brand-60)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M249.266 247.358L250.755 246.502L254.922 248.899L250.717 251.317L246.55 248.921L248.039 248.064L245.265 246.47L246.495 245.763L249.266 247.358ZM243.482 250.685L244.971 249.829L249.138 252.226L244.933 254.644L240.766 252.248L242.255 251.391L239.481 249.797L240.711 249.09L243.482 250.685ZM237.698 254.012L239.187 253.155L243.354 255.553L239.149 257.97L234.982 255.574L236.471 254.717L233.697 253.124L234.927 252.417L237.698 254.012Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M254.237 251.68L253.601 251.314L254.915 250.558L255.551 250.924L254.237 251.68ZM252.39 251.324L253.624 252.033L252.791 252.511L256.874 254.86L258.363 254.004L261.037 255.543L262.266 254.836L259.592 253.298L261.081 252.441L256.998 250.093L256.165 250.572L254.931 249.862L252.39 251.324ZM248.454 255.007L247.818 254.64L249.132 253.885L249.768 254.251L248.454 255.007ZM246.606 254.65L247.84 255.359L247.008 255.838L251.091 258.187L252.58 257.331L255.254 258.869L256.482 258.163L253.808 256.624L255.297 255.768L251.214 253.42L250.381 253.898L249.147 253.188L246.606 254.65ZM242.67 258.333L242.034 257.967L243.348 257.212L243.984 257.578L242.67 258.333ZM240.823 257.977L242.057 258.686L241.224 259.165L245.307 261.514L246.796 260.657L249.47 262.196L250.699 261.49L248.025 259.951L249.514 259.095L245.431 256.746L244.598 257.225L243.364 256.515L240.823 257.977Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M264.417 195.046C264.417 192.599 262.794 190.153 259.548 188.286C253.057 184.552 242.532 184.552 236.04 188.286C232.925 190.078 231.304 192.405 231.18 194.753V206.772C231.304 204.424 232.925 202.097 236.04 200.305C242.532 196.571 253.057 196.571 259.548 200.305C262.794 202.172 264.417 204.618 264.417 207.065V195.046Z\" fill=\"#D4D9DE\" fill-opacity=\"0.6\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M262.563 194.334C262.683 196.596 261.243 198.879 258.242 200.605V212.624C261.243 210.898 262.683 208.615 262.563 206.353V194.334Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M258.241 200.606C252.471 203.925 243.116 203.925 237.346 200.606V212.625C243.116 215.944 252.471 215.944 258.241 212.625V200.606Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M233.02 194.595C233.02 192.42 234.462 190.245 237.347 188.586V188.586C243.117 185.267 252.473 185.267 258.243 188.586V188.586C261.012 190.179 262.453 192.247 262.563 194.334V206.353C262.453 204.266 261.012 202.198 258.243 200.605V200.605C252.473 197.286 243.117 197.286 237.347 200.605V200.605C234.462 202.264 233.02 204.439 233.02 206.614V194.595Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M237.347 200.606C234.462 198.946 233.02 196.771 233.02 194.596V206.615C233.02 208.79 234.462 210.965 237.347 212.625V200.606Z\" fill=\"var(--c8y-brand-40)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M300.029 195.045L247.79 164.998L195.551 195.045V207.064L247.79 177.017L300.029 207.064V195.045Z\" fill=\"#D4D9DE\" fill-opacity=\"0.6\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M195.551 195.045L247.79 225.093L300.029 195.045V207.064L247.79 237.112L195.551 207.064V195.045Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path opacity=\"0.6\" fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M247.426 225.093L299.665 195.045V207.064L247.426 237.112V225.093Z\" fill=\"#212121\" fill-opacity=\"0.4\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M231.176 194.752C231.041 197.296 232.661 199.865 236.037 201.807C242.528 205.541 253.053 205.541 259.544 201.807C262.79 199.94 264.413 197.493 264.413 195.046V207.065C264.413 209.512 262.79 211.959 259.544 213.826C253.053 217.559 242.528 217.559 236.037 213.826C232.661 211.884 231.041 209.315 231.176 206.771V194.752Z\" fill=\"#D4D9DE\" fill-opacity=\"0.8\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M300.029 195.045L247.79 164.998L195.551 195.045L247.79 225.093L300.029 195.045ZM259.544 188.285C253.052 184.551 242.527 184.551 236.036 188.285C229.545 192.019 229.545 198.072 236.036 201.806C242.527 205.54 253.052 205.54 259.544 201.806C266.035 198.072 266.035 192.019 259.544 188.285Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M237.345 188.586C243.115 185.267 252.471 185.267 258.241 188.586V188.586C264.011 191.905 264.011 197.286 258.241 200.605V200.605C252.471 203.924 243.115 203.924 237.345 200.605V200.605C231.575 197.286 231.575 191.905 237.345 188.586V188.586Z\" fill=\"var(--c8y-brand-60)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M241.841 198.505C245.268 200.476 250.843 200.476 254.27 198.505C257.696 196.534 257.696 193.328 254.27 191.357C250.843 189.386 245.268 189.386 241.841 191.357C238.415 193.328 238.415 196.534 241.841 198.505ZM242.877 197.91C240.021 196.267 240.021 193.595 242.877 191.952C245.733 190.31 250.379 190.31 253.234 191.952C256.09 193.595 256.09 196.267 253.234 197.91C250.379 199.552 245.733 199.552 242.877 197.91Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M242.31 196.134L244.142 195.717C244.239 195.897 244.369 196.072 244.532 196.237L242.7 196.655C242.548 196.488 242.417 196.313 242.31 196.134ZM250.052 191.608C250.363 191.667 250.669 191.739 250.963 191.824L250.266 192.885C249.976 192.794 249.671 192.721 249.354 192.669L250.052 191.608ZM247.685 191.428C248.007 191.418 248.333 191.422 248.656 191.44L248.697 192.589C248.374 192.565 248.048 192.561 247.726 192.578L247.685 191.428ZM241.966 194.718L243.964 194.741C243.935 194.927 243.941 195.114 243.984 195.3L241.986 195.277C241.955 195.091 241.949 194.903 241.966 194.718ZM242.572 193.368L244.438 193.826C244.287 193.988 244.17 194.16 244.088 194.338L242.223 193.882C242.316 193.705 242.433 193.533 242.572 193.368ZM245.316 191.783C245.601 191.703 245.9 191.634 246.206 191.58L247.009 192.652C246.698 192.7 246.399 192.768 246.119 192.855L245.316 191.783ZM243.724 192.44C243.834 192.376 243.951 192.314 244.073 192.254L245.515 193.083C245.391 193.14 245.271 193.201 245.159 193.265C245.048 193.329 244.942 193.398 244.842 193.47L243.401 192.641C243.506 192.571 243.614 192.503 243.724 192.44Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M248.435 196.533C249.107 196.92 250.196 196.919 250.869 196.533C251.541 196.146 251.542 195.519 250.87 195.132C250.411 194.868 249.758 194.785 249.175 194.881L245.83 193.634L247.998 195.559C247.831 195.894 247.976 196.269 248.435 196.533Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M326.16 236.114L312.662 244.047L266.5 216.916V225.734L312.662 252.865L326.16 244.932V236.114Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"15.6044\" height=\"8.74496\" transform=\"matrix(0.862126 -0.506694 0 1 312.697 244.068)\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M279.998 208.982L326.16 236.113L312.662 244.046L266.5 216.915L279.998 208.982Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M373.598 264.037L360.1 271.97L313.938 244.839V253.657L360.1 280.788L373.598 272.855V264.037Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"15.6044\" height=\"8.74496\" transform=\"matrix(0.862126 -0.506694 0 1 360.135 271.991)\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M327.435 236.905L373.598 264.036L360.1 271.969L313.938 244.838L327.435 236.905Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"28.8755\" transform=\"matrix(0.862126 0.506694 -0.862126 0.506694 405.285 242.196)\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"11.1196\" transform=\"matrix(0.862126 0.506694 0 1 380.391 256.827)\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"28.8755\" height=\"11.1196\" transform=\"matrix(0.862126 -0.506694 0 1 451.588 298.672)\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"28.8755\" transform=\"matrix(0.862126 0.506694 -0.862126 0.506694 379.279 257.48)\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"11.1196\" transform=\"matrix(0.862126 0.506694 0 1 354.385 272.111)\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"28.8755\" height=\"11.1196\" transform=\"matrix(0.862126 -0.506694 0 1 425.582 313.956)\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"28.8755\" transform=\"matrix(0.862126 0.506694 -0.862126 0.506694 353.275 272.765)\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"11.1196\" transform=\"matrix(0.862126 0.506694 0 1 328.381 287.396)\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"28.8755\" height=\"11.1196\" transform=\"matrix(0.862126 -0.506694 0 1 399.58 329.24)\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M385.395 227.124L382.77 236.325L379.521 234.415L382.145 225.214L385.395 227.124Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M380.707 218.974L372.201 233.971L368.951 232.061L377.457 217.064L380.707 218.974Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M372.201 233.971L375.621 241.95L372.371 240.04L368.951 232.062L372.201 233.971Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M378.636 238.755L376.02 232.634L380.707 224.369L385.395 227.124L382.771 236.325L385.785 235.976L389.205 223.977L380.707 218.973L372.201 233.971L375.622 241.949L378.636 238.755Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M394.1 205.756L386.341 219.419L381.143 216.368L388.902 202.705L394.1 205.756Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M383.402 217.693L391.16 204.03L385.963 200.979L378.204 214.642L383.402 217.693Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path d=\"M391.159 204.03L394.1 205.756L386.341 219.419L383.401 217.693L391.159 204.03Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M380.443 225.67C379.746 225.309 379.312 224.473 379.312 223.262C379.312 220.934 380.92 218.102 382.903 216.938C383.855 216.379 384.721 216.306 385.363 216.638L379.378 213.125C378.735 212.792 377.87 212.865 376.917 213.424C374.934 214.588 373.326 217.42 373.326 219.749C373.326 220.959 373.761 221.796 374.457 222.156L380.443 225.67Z\" fill=\"url(#paint6_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path d=\"M382.903 225.37C380.919 226.535 379.312 225.591 379.312 223.262C379.312 220.934 380.919 218.102 382.903 216.938C384.886 215.773 386.494 216.717 386.494 219.046C386.494 221.374 384.886 224.206 382.903 225.37Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M402.358 255.791L423.906 217.844L411.935 210.816L390.387 248.763L402.358 255.791Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path d=\"M433.484 223.466L411.936 261.413L402.36 255.791L423.908 217.844L433.484 223.466Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M395.474 297.252L431.387 276.17V284.603L395.474 305.684V297.252Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M359.559 276.17L395.473 297.252V305.684L359.559 284.603V276.17Z\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path d=\"M395.474 255.088L359.56 276.17L395.474 297.252L431.387 276.17L395.474 255.088Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M379.775 270.895C379.668 273.331 381.206 275.796 384.385 277.664C390.499 281.258 400.365 281.285 406.421 277.726C409.328 276.017 410.829 273.793 410.928 271.544V276.455C410.829 278.703 409.328 280.928 406.421 282.636C400.365 286.195 390.499 286.168 384.385 282.575C381.206 280.706 379.668 278.241 379.775 275.805V270.895Z\" fill=\"url(#paint7_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M384.282 264.713C378.226 268.273 378.272 274.071 384.386 277.664C390.5 281.257 400.366 281.285 406.422 277.726C412.478 274.166 412.431 268.368 406.317 264.775C400.204 261.181 390.338 261.154 384.282 264.713Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M384.044 268.079C383.965 269.867 385.095 271.676 387.428 273.048C391.916 275.685 399.157 275.705 403.602 273.093C405.736 271.839 406.838 270.206 406.91 268.556V272.16C406.838 273.81 405.736 275.443 403.602 276.697C399.157 279.31 391.916 279.289 387.428 276.652C385.095 275.281 383.965 273.471 384.044 271.683V268.079Z\" fill=\"url(#paint8_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M387.35 263.542C382.905 266.154 382.939 270.41 387.426 273.047C391.914 275.685 399.155 275.705 403.601 273.093C408.046 270.48 408.011 266.224 403.524 263.587C399.036 260.949 391.795 260.929 387.35 263.542Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M410.646 250.543C412.367 251.433 413.441 253.501 413.441 256.494C413.441 262.25 409.467 269.249 404.565 272.127C402.211 273.508 400.072 273.689 398.483 272.867L380.73 262.445C382.318 263.267 384.458 263.086 386.811 261.705C391.713 258.827 395.688 251.828 395.688 246.072C395.688 243.079 394.613 241.012 392.892 240.121L410.646 250.543Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M398.484 272.867C396.763 271.976 395.688 269.909 395.688 266.916C395.688 261.16 399.663 254.161 404.565 251.283C406.918 249.901 409.058 249.721 410.646 250.543L392.893 240.121C391.304 239.299 389.165 239.48 386.811 240.861C381.909 243.739 377.935 250.738 377.935 256.494C377.935 259.487 379.009 261.554 380.73 262.445L398.484 272.867Z\" fill=\"url(#paint9_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M404.565 272.126C399.662 275.004 395.688 272.671 395.688 266.915C395.688 261.159 399.662 254.16 404.565 251.282C409.467 248.405 413.441 250.738 413.441 256.493C413.441 262.249 409.467 269.248 404.565 272.126ZM404.565 267.784C401.705 269.462 399.386 268.102 399.386 264.744C399.386 261.386 401.705 257.304 404.565 255.625C407.424 253.946 409.743 255.307 409.743 258.665C409.743 262.022 407.424 266.105 404.565 267.784Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M408.523 259.759C408.054 259.455 407.388 259.479 406.65 259.905C405.229 260.722 404.077 262.711 404.077 264.346C404.077 265.164 404.365 265.739 404.831 266.006L403.279 265.109C402.814 264.841 402.526 264.266 402.526 263.449C402.526 261.813 403.678 259.825 405.098 259.007C405.837 258.582 406.503 258.557 406.972 258.861L408.523 259.759Z\" fill=\"url(#paint10_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path d=\"M404.076 264.346C404.076 265.982 405.228 266.644 406.649 265.827C408.069 265.009 409.221 263.02 409.221 261.385C409.221 259.75 408.069 259.087 406.649 259.904C405.228 260.722 404.076 262.711 404.076 264.346Z\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M434.838 211.303C433.538 210.54 431.742 210.65 429.759 211.814C425.792 214.143 422.576 219.806 422.576 224.463C422.576 226.792 423.38 228.428 424.68 229.191L410.315 220.759C409.015 219.996 408.211 218.359 408.211 216.031C408.211 211.373 411.427 205.71 415.394 203.382C417.377 202.217 419.173 202.107 420.473 202.87L434.838 211.303Z\" fill=\"url(#paint11_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path d=\"M422.576 224.463C422.576 229.121 425.792 231.008 429.759 228.68C433.726 226.351 436.941 220.688 436.941 216.031C436.941 211.373 433.726 209.486 429.759 211.814C425.792 214.143 422.576 219.806 422.576 224.463Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M433.357 218.021C432.888 217.717 432.222 217.742 431.484 218.167C430.063 218.984 428.911 220.973 428.911 222.608C428.911 223.426 429.199 224.001 429.665 224.269L428.113 223.371C427.648 223.103 427.36 222.528 427.36 221.711C427.36 220.075 428.512 218.087 429.932 217.269C430.671 216.844 431.337 216.819 431.806 217.123L433.357 218.021Z\" fill=\"url(#paint12_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path d=\"M428.91 222.608C428.91 224.244 430.062 224.907 431.482 224.089C432.903 223.271 434.055 221.283 434.055 219.647C434.055 218.012 432.903 217.349 431.482 218.167C430.062 218.984 428.91 220.973 428.91 222.608Z\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path d=\"M406.015 199.573L427.264 212.047L421.877 221.533L400.628 209.06L406.015 199.573Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M405.115 192.329C403.815 191.566 402.02 191.676 400.036 192.841C396.069 195.169 392.854 200.833 392.854 205.49C392.854 207.818 393.658 209.455 394.957 210.218L380.592 201.785C379.292 201.022 378.488 199.386 378.488 197.057C378.488 192.4 381.704 186.737 385.671 184.408C387.654 183.244 389.45 183.134 390.75 183.897L405.115 192.329Z\" fill=\"url(#paint13_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path d=\"M392.853 205.49C392.853 210.147 396.069 212.035 400.036 209.706C404.003 207.377 407.219 201.714 407.219 197.057C407.219 192.4 404.003 190.512 400.036 192.841C396.069 195.169 392.853 200.832 392.853 205.49Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M403.326 199.209C402.857 198.905 402.191 198.93 401.452 199.355C400.032 200.173 398.88 202.162 398.88 203.797C398.88 204.615 399.168 205.189 399.634 205.457L398.082 204.559C397.617 204.292 397.329 203.717 397.329 202.899C397.329 201.264 398.48 199.275 399.901 198.458C400.64 198.032 401.306 198.008 401.775 198.312L403.326 199.209Z\" fill=\"url(#paint14_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path d=\"M398.879 203.797C398.879 205.432 400.031 206.095 401.451 205.277C402.872 204.46 404.023 202.471 404.023 200.836C404.023 199.2 402.872 198.537 401.451 199.355C400.031 200.173 398.879 202.161 398.879 203.797Z\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M501.8 203.577L475.767 244.131L470.766 241.191L496.799 200.638L501.8 203.577Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M475.767 244.13L449.394 259.63L444.393 256.691L470.766 241.191L475.767 244.13Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M449.394 259.631L429.901 300.81L424.9 297.871L444.392 256.691L449.394 259.631Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M429.901 300.81L422.808 269.125L417.807 266.186L424.9 297.871L429.901 300.81Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M422.807 269.125L414.263 310.134L409.262 307.195L417.806 266.186L422.807 269.125Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M414.265 310.134L405.966 300.075L400.965 297.135L409.264 307.195L414.265 310.134Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M405.965 300.075L400.017 316.259L395.016 313.32L400.964 297.135L405.965 300.075Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M400.017 316.259L398.265 316.154L393.264 313.215L395.016 313.32L400.017 316.259Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M398.265 316.154L405.82 295.598L400.818 292.659L393.264 313.215L398.265 316.154Z\" fill=\"url(#paint15_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M405.819 295.598L413.524 304.937L408.523 301.998L400.818 292.659L405.819 295.598Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M413.525 304.937L421.933 264.579L416.932 261.64L408.523 301.998L413.525 304.937Z\" fill=\"url(#paint16_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M421.933 264.579L423.87 263.49L418.869 260.55L416.932 261.639L421.933 264.579Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M430.895 294.862L448.411 257.857L443.41 254.918L427.625 288.045L430.895 294.862Z\" fill=\"url(#paint17_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M448.409 257.858L475.048 242.201L470.047 239.262L443.408 254.918L448.409 257.858Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M475.048 242.201L500.527 202.512L495.525 199.573L470.047 239.262L475.048 242.201Z\" fill=\"url(#paint18_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M501.799 203.577L475.766 244.13L449.392 259.63L429.9 300.81L422.807 269.125L414.263 310.134L405.964 300.074L400.016 316.259L398.264 316.154L405.818 295.598L413.523 304.937L421.932 264.579L423.869 263.489L430.893 294.862L448.409 257.857L475.047 242.201L500.526 202.512L501.799 203.577Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M421.576 269.496C421.091 269.245 420.788 268.662 420.788 267.818C420.788 266.195 421.908 264.221 423.289 263.409C423.952 263.019 424.554 262.968 425.002 263.2L420.001 260.261C419.553 260.029 418.951 260.08 418.288 260.47C416.907 261.281 415.787 263.255 415.787 264.879C415.787 265.723 416.09 266.306 416.575 266.557L421.576 269.496Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M425.788 264.878C425.788 266.502 424.669 268.476 423.288 269.287C421.907 270.099 420.787 269.441 420.787 267.818C420.787 266.194 421.907 264.22 423.288 263.409C424.669 262.597 425.788 263.255 425.788 264.878Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M433.491 296.035C433.491 297.658 432.372 299.632 430.991 300.443C429.61 301.255 428.49 300.597 428.49 298.974C428.49 297.351 429.61 295.377 430.991 294.565C432.372 293.753 433.491 294.411 433.491 296.035Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M404.25 300.653C403.765 300.401 403.462 299.818 403.462 298.974C403.462 297.351 404.582 295.377 405.963 294.565C406.625 294.176 407.228 294.125 407.676 294.357L402.675 291.417C402.227 291.185 401.624 291.236 400.961 291.626C399.58 292.438 398.461 294.412 398.461 296.035C398.461 296.879 398.764 297.462 399.248 297.713L404.25 300.653Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M408.462 296.035C408.462 297.658 407.342 299.632 405.961 300.443C404.58 301.255 403.461 300.597 403.461 298.974C403.461 297.351 404.58 295.377 405.961 294.565C407.342 293.753 408.462 294.411 408.462 296.035Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M416.165 306.028C416.165 307.652 415.046 309.625 413.665 310.437C412.284 311.249 411.164 310.591 411.164 308.967C411.164 307.344 412.284 305.37 413.665 304.559C415.046 303.747 416.165 304.405 416.165 306.028Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M446.982 261.854C446.497 261.603 446.194 261.02 446.194 260.176C446.194 258.553 447.314 256.579 448.695 255.767C449.358 255.377 449.961 255.326 450.408 255.558L445.407 252.619C444.959 252.387 444.357 252.438 443.694 252.828C442.313 253.639 441.193 255.613 441.193 257.237C441.193 258.081 441.496 258.664 441.981 258.915L446.982 261.854Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M451.196 257.236C451.196 258.86 450.077 260.833 448.696 261.645C447.315 262.457 446.195 261.799 446.195 260.176C446.195 258.552 447.315 256.578 448.696 255.767C450.077 254.955 451.196 255.613 451.196 257.236Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M472.392 245.982C471.907 245.731 471.605 245.148 471.605 244.304C471.605 242.68 472.724 240.706 474.105 239.895C474.768 239.505 475.371 239.454 475.818 239.686L470.817 236.747C470.37 236.515 469.767 236.566 469.104 236.956C467.723 237.767 466.604 239.741 466.604 241.364C466.604 242.209 466.906 242.792 467.391 243.043L472.392 245.982Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M476.605 241.364C476.605 242.987 475.485 244.961 474.104 245.773C472.723 246.585 471.604 245.927 471.604 244.303C471.604 242.68 472.723 240.706 474.104 239.895C475.485 239.083 476.605 239.741 476.605 241.364Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M498.38 207.183C497.896 206.932 497.593 206.349 497.593 205.505C497.593 203.882 498.712 201.908 500.093 201.096C500.756 200.706 501.359 200.655 501.806 200.887L496.805 197.948C496.358 197.716 495.755 197.767 495.092 198.157C493.711 198.968 492.592 200.942 492.592 202.566C492.592 203.41 492.895 203.993 493.379 204.244L498.38 207.183Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M502.593 202.565C502.593 204.189 501.473 206.163 500.092 206.974C498.711 207.786 497.592 207.128 497.592 205.505C497.592 203.881 498.711 201.907 500.092 201.096C501.473 200.284 502.593 200.942 502.593 202.565Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M419.252 18.0155C413.049 13.9115 404.244 14.2478 394.479 19.987C375.7 31.024 360.472 57.8684 360.472 79.9483C360.472 90.5466 363.979 98.1191 369.704 101.908L365.703 99.5565C359.978 95.7677 356.471 88.1952 356.471 77.5968C356.471 55.517 371.699 28.6726 390.478 17.6356C400.243 11.8964 409.048 11.5601 415.251 15.6641L419.252 18.0155Z\" fill=\"url(#paint19_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path opacity=\"0.4\" d=\"M394.478 99.9353C413.262 88.8954 428.486 62.054 428.486 39.9741C428.486 17.8943 413.257 8.95006 394.478 19.987C375.699 31.024 360.471 57.8684 360.471 79.9483C360.471 102.028 375.694 110.975 394.478 99.9353Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M428.486 39.9742C428.486 62.0541 413.262 88.8956 394.478 99.9355C375.694 110.975 360.471 102.028 360.471 79.9484C360.471 57.8686 375.699 31.0242 394.478 19.9872C413.257 8.95019 428.486 17.8944 428.486 39.9742ZM426.718 41.4439C426.718 62.2246 412.39 87.4876 394.711 97.878C377.032 108.268 362.704 99.8473 362.704 79.0666C362.704 58.2859 377.032 33.0229 394.711 22.6325C412.39 12.2422 426.718 20.6632 426.718 41.4439Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M418.028 20.7766C412.19 16.9136 403.903 17.23 394.71 22.633C377.031 33.0233 362.703 58.2864 362.703 79.067C362.703 89.0418 366.005 96.1688 371.393 99.7347L370.393 99.1469C365.004 95.581 361.703 88.4539 361.703 78.4792C361.703 57.6985 376.031 32.4354 393.71 22.0451C402.903 16.6421 411.19 16.3257 417.028 20.1888L418.028 20.7766Z\" fill=\"url(#paint20_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M418.028 20.7771C412.19 16.9141 403.903 17.2305 394.71 22.6334C377.031 33.0238 362.703 58.2869 362.703 79.0675C362.703 89.0423 366.005 96.1693 371.393 99.7352L370.393 99.1474C365.004 95.5815 361.703 88.4544 361.703 78.4797C361.703 57.699 376.031 32.4359 393.71 22.0456C402.903 16.6426 411.19 16.3262 417.028 20.1893L418.028 20.7771Z\" fill=\"url(#paint21_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M369.669 75.5532C370.221 75.2139 370.661 74.4197 370.651 73.7792C370.641 73.1388 370.185 72.8946 369.633 73.2339C369.081 73.5731 368.641 74.3673 368.651 75.0078C368.661 75.6483 369.117 75.8924 369.669 75.5532Z\" fill=\"#8B96A0\"/>\n        <path d=\"M371.83 64.3632C371.991 63.6508 371.694 63.1741 371.165 63.2986C370.637 63.4231 370.078 64.1016 369.917 64.814C369.756 65.5265 370.053 66.0031 370.582 65.8786C371.11 65.7541 371.669 65.0757 371.83 64.3632Z\" fill=\"#8B96A0\"/>\n        <path d=\"M375.244 54.4959C375.56 53.7743 375.45 53.1062 374.997 53.0036C374.545 52.9011 373.921 53.4029 373.604 54.1245C373.288 54.8462 373.398 55.5143 373.851 55.6169C374.304 55.7194 374.927 55.2176 375.244 54.4959Z\" fill=\"#8B96A0\"/>\n        <path d=\"M380.564 45.1337C381.005 44.4805 381.093 43.6918 380.76 43.3719C380.427 43.0521 379.8 43.3223 379.359 43.9755C378.918 44.6287 378.83 45.4175 379.163 45.7373C379.496 46.0572 380.123 45.7869 380.564 45.1337Z\" fill=\"#8B96A0\"/>\n        <path d=\"M387.256 37.1966C387.778 36.6751 388.056 35.8429 387.875 35.3378C387.695 34.8326 387.126 34.8458 386.604 35.3673C386.082 35.8888 385.804 36.721 385.985 37.2262C386.165 37.7313 386.734 37.7181 387.256 37.1966Z\" fill=\"#8B96A0\"/>\n        <path d=\"M394.677 31.4633C395.229 31.1241 395.669 30.3298 395.659 29.6894C395.649 29.0489 395.193 28.8047 394.641 29.144C394.088 29.4833 393.649 30.2775 393.659 30.918C393.669 31.5584 394.125 31.8026 394.677 31.4633Z\" fill=\"#8B96A0\"/>\n        <path d=\"M403.342 26.9755C403.503 26.2631 403.205 25.7865 402.677 25.9109C402.149 26.0354 401.59 26.7139 401.428 27.4263C401.267 28.1388 401.565 28.6154 402.093 28.4909C402.622 28.3664 403.181 27.688 403.342 26.9755Z\" fill=\"#8B96A0\"/>\n        <path d=\"M410.174 27.4618C410.49 26.7401 410.38 26.072 409.927 25.9695C409.474 25.8669 408.851 26.3687 408.534 27.0904C408.218 27.812 408.328 28.4801 408.781 28.5827C409.233 28.6852 409.857 28.1834 410.174 27.4618Z\" fill=\"#8B96A0\"/>\n        <path d=\"M415.492 31.1064C415.933 30.4532 416.02 29.6644 415.688 29.3446C415.355 29.0247 414.728 29.295 414.287 29.9482C413.846 30.6013 413.758 31.3901 414.091 31.71C414.424 32.0298 415.051 31.7596 415.492 31.1064Z\" fill=\"#8B96A0\"/>\n        <path d=\"M418.76 37.5516C419.282 37.0301 419.56 36.1979 419.379 35.6927C419.199 35.1876 418.63 35.2008 418.108 35.7223C417.585 36.2438 417.308 37.076 417.488 37.5812C417.669 38.0863 418.238 38.0731 418.76 37.5516Z\" fill=\"#8B96A0\"/>\n        <path d=\"M419.677 46.1591C420.229 45.8199 420.669 45.0256 420.659 44.3852C420.649 43.7447 420.193 43.5005 419.641 43.8398C419.088 44.1791 418.649 44.9733 418.659 45.6138C418.669 46.2542 419.125 46.4984 419.677 46.1591Z\" fill=\"#8B96A0\"/>\n        <path d=\"M411.66 62.8484L409.994 63.8384V69.5118L411.66 68.5218V62.8484Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path d=\"M406.126 71.8665C407.507 71.0184 408.606 69.0328 408.581 67.4317C408.556 65.8305 407.416 65.2201 406.035 66.0683C404.655 66.9164 403.555 68.902 403.581 70.5031C403.606 72.1043 404.745 72.7147 406.126 71.8665Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path d=\"M399.577 75.715C400.957 74.8965 402.077 72.9213 402.077 71.306C402.077 69.6908 400.957 69.0441 399.577 69.8625C398.196 70.681 397.076 72.6562 397.076 74.2714C397.076 75.8867 398.196 76.5334 399.577 75.715Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path d=\"M393.264 79.4244C394.645 78.606 395.765 76.6308 395.765 75.0155C395.765 73.4002 394.645 72.7535 393.264 73.572C391.884 74.3904 390.764 76.3656 390.764 77.9809C390.764 79.5962 391.884 80.2429 393.264 79.4244Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path d=\"M386.854 83.1925C388.234 82.374 389.355 80.3988 389.355 78.7836C389.355 77.1683 388.234 76.5216 386.854 77.3401C385.474 78.1585 384.354 80.1337 384.354 81.749C384.354 83.3642 385.474 84.0109 386.854 83.1925Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path d=\"M414.816 60.9935L413.15 61.9834V67.6568L414.816 66.6669V60.9935Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path d=\"M383.058 79.7049L381.393 80.6948V86.3682L383.058 85.3783V79.7049Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path d=\"M377.487 88.7511C378.867 87.9326 379.987 85.9574 379.987 84.3422C379.987 82.7269 378.867 82.0802 377.487 82.8987C376.107 83.7171 374.986 85.6923 374.986 87.3076C374.986 88.9228 376.107 89.5695 377.487 88.7511Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M407.446 35.7055L399.008 50.5826L398.008 49.9948L406.445 35.1177L407.446 35.7055Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M407.447 35.7065L399.01 50.5836L400.75 51.6061L409.187 36.7291L407.447 35.7065Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M399.452 53.1471C398.357 52.4228 396.803 52.482 395.08 53.4949C391.765 55.4429 389.079 60.1804 389.079 64.0763C389.079 65.9464 389.698 67.2827 390.708 67.9513L388.708 66.7756C387.697 66.1069 387.078 64.7707 387.078 62.9006C387.078 59.0047 389.765 54.2672 393.079 52.3192C394.803 51.3063 396.357 51.2471 397.451 51.9714L399.452 53.1471Z\" fill=\"url(#paint22_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M395.079 67.6034C398.394 65.6554 401.081 60.9179 401.081 57.022C401.081 53.126 398.394 51.5469 395.079 53.4948C391.765 55.4428 389.078 60.1803 389.078 64.0762C389.078 67.9722 391.765 69.5513 395.079 67.6034Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M406.527 116.983V133.443L398.525 128.74V112.28L406.527 116.983Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M417.529 101.111V126.976L409.527 122.273V96.4077L417.529 101.111Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M428.531 98.1716V120.51L420.529 115.807V93.4688L428.531 98.1716Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M439.535 74.0691V114.043L431.533 109.34V69.3662L439.535 74.0691Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M450.537 51.1428V107.577L442.535 102.874V46.4399L450.537 51.1428Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M414.529 112.28L406.527 116.983L398.525 112.28L406.527 107.577L414.529 112.28Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M436.533 94.6442L428.531 99.3471L420.529 94.6442L428.531 89.9414L436.533 94.6442Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M447.537 69.3664L439.535 74.0693L431.533 69.3664L439.535 64.6636L447.537 69.3664Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M425.531 96.4079L417.529 101.111L409.527 96.4079L417.529 91.7051L425.531 96.4079Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M458.539 46.4401L450.537 51.143L442.535 46.4401L450.537 41.7373L458.539 46.4401Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M406.527 116.983V133.443L414.529 128.74V112.28L406.527 116.983Z\" fill=\"#8B96A0\"/>\n        <path d=\"M417.53 101.11V126.976L425.532 122.273V96.4076L417.53 101.11Z\" fill=\"#8B96A0\"/>\n        <path d=\"M428.532 99.3469V120.51L436.534 115.807V94.6441L428.532 99.3469Z\" fill=\"#8B96A0\"/>\n        <path d=\"M439.535 74.0691V114.043L447.536 109.34V69.3663L439.535 74.0691Z\" fill=\"#8B96A0\"/>\n        <path d=\"M450.537 51.1428V107.577L458.539 102.874V46.4399L450.537 51.1428Z\" fill=\"#8B96A0\"/>\n        <path d=\"M406.527 116.983V133.443L414.529 128.74V112.28L406.527 116.983Z\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path d=\"M417.53 101.11V126.976L425.532 122.273V96.4076L417.53 101.11Z\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path d=\"M428.532 99.3469V120.51L436.534 115.807V94.6441L428.532 99.3469Z\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path d=\"M439.535 74.0691V114.043L447.536 109.34V69.3663L439.535 74.0691Z\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path d=\"M450.537 51.1428V107.577L458.539 102.874V46.4399L450.537 51.1428Z\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path d=\"M417.5 101.111V126.976L425.502 122.274V96.408L417.5 101.111Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path d=\"M439.443 74.0693V114.043L447.445 109.341V69.3665L439.443 74.0693Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M83.9683 346.379C83.8423 348.79 85.3436 351.225 88.4725 353.064C94.4897 356.6 104.255 356.599 110.274 353.061C113.164 351.363 114.667 349.158 114.783 346.932V348.779C114.667 351.004 113.164 353.209 110.274 354.907C104.255 358.445 94.4897 358.446 88.4725 354.91C85.3436 353.071 83.8423 350.636 83.9683 348.226V346.379Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M142.713 329.962C142.838 332.373 141.335 334.808 138.205 336.647C132.185 340.185 122.42 340.186 116.403 336.65C113.515 334.953 112.013 332.748 111.898 330.522V332.368C112.013 334.594 113.515 336.799 116.403 338.496C122.42 342.032 132.185 342.032 138.205 338.494C141.335 336.654 142.838 334.219 142.713 331.809V329.962Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M139.398 313.803C139.272 316.214 140.773 318.648 143.902 320.487C149.92 324.024 159.684 324.023 165.704 320.485C168.593 318.787 170.096 316.582 170.212 314.356V316.203C170.096 318.428 168.593 320.633 165.704 322.331C159.684 325.869 149.92 325.87 143.902 322.334C140.773 320.495 139.272 318.06 139.398 315.649V313.803Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M198.577 296.965C198.776 299.374 197.348 301.824 194.274 303.697C188.363 307.3 178.603 307.405 172.476 303.932C169.535 302.266 167.965 300.077 167.781 297.854V299.7C167.965 301.924 169.535 304.112 172.476 305.779C178.603 309.251 188.363 309.146 194.274 305.544C197.348 303.67 198.776 301.22 198.577 298.812V296.965Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M217.993 289.324L210.734 293.59V295.436L217.993 291.17V289.324Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M210.734 293.59L189.674 281.213V283.059L210.734 295.436V293.59Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M231.741 281.241L224.482 285.507V287.353L231.741 283.087V281.241Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M224.486 285.507L203.426 273.13V274.976L224.486 287.353V285.507Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M65.2246 354.56L86.2847 366.937V368.783L65.2246 356.406V354.56Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M86.2852 366.937L93.5439 362.671V364.517L86.2852 368.783V366.937Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M74.1381 370.472C74.2625 372.883 72.7595 375.317 69.6294 377.157C63.6099 380.695 53.8449 380.696 47.8277 377.159C44.9394 375.462 43.4414 373.259 43.3301 371.036V372.882C43.4414 375.105 44.9394 377.308 47.8277 379.006C53.8449 382.542 63.6099 382.541 69.6294 379.003C72.7595 377.164 74.2625 374.729 74.1381 372.318V370.472Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M165.71 320.489C171.729 316.951 171.731 311.212 165.714 307.676C159.697 304.139 149.932 304.14 143.912 307.678C137.893 311.216 137.891 316.955 143.908 320.492C149.925 324.028 159.69 324.027 165.71 320.489ZM193.886 290.89C200.014 294.363 200.189 300.098 194.278 303.701C188.366 307.304 178.607 307.409 172.48 303.936C166.352 300.463 166.177 294.727 172.088 291.125C177.999 287.522 187.759 287.417 193.886 290.89ZM189.677 281.213L196.935 276.947L217.996 289.325L210.737 293.591L189.677 281.213ZM138.214 323.838C144.231 327.375 144.229 333.114 138.21 336.652C132.19 340.189 122.425 340.191 116.408 336.654C110.391 333.118 110.393 327.378 116.412 323.841C122.432 320.303 132.197 320.302 138.214 323.838ZM110.281 353.068C116.301 349.53 116.303 343.791 110.285 340.255C104.268 336.718 94.5031 336.719 88.4836 340.257C82.4642 343.795 82.4623 349.534 88.4795 353.071C94.4966 356.607 104.262 356.606 110.281 353.068ZM203.43 273.134L210.689 268.867L231.749 281.245L224.49 285.511L203.43 273.134ZM72.4891 350.298L65.2303 354.564L86.2904 366.942L93.5492 362.676L72.4891 350.298ZM69.6362 364.35C75.6534 367.886 75.6515 373.625 69.6321 377.163C63.6126 380.701 53.8475 380.702 47.8304 377.166C41.8132 373.629 41.8298 367.899 47.8493 364.361C53.8687 360.823 63.619 360.813 69.6362 364.35Z\" fill=\"var(--c8y-brand-60)\"/>\n        <path d=\"M194.278 303.701L194.607 303.888L194.607 303.888L194.278 303.701ZM193.886 290.89L194.204 290.696L193.886 290.89ZM172.48 303.936L172.797 303.743L172.48 303.936ZM172.088 291.125L171.759 290.938L172.088 291.125ZM196.935 276.947L197.259 276.757C197.173 276.707 197.057 276.678 196.935 276.678C196.814 276.678 196.698 276.707 196.612 276.757L196.935 276.947ZM189.677 281.213L189.353 281.023C189.175 281.128 189.175 281.298 189.353 281.403L189.677 281.213ZM217.996 289.325L218.319 289.515C218.405 289.464 218.453 289.396 218.453 289.325C218.453 289.253 218.405 289.185 218.319 289.135L217.996 289.325ZM210.737 293.591L210.413 293.781C210.592 293.886 210.881 293.886 211.06 293.781L210.737 293.591ZM116.412 323.841L116.089 323.651L116.412 323.841ZM88.4836 340.257L88.1603 340.067L88.4836 340.257ZM210.689 268.867L211.012 268.677C210.926 268.627 210.81 268.599 210.689 268.599C210.568 268.599 210.451 268.627 210.366 268.677L210.689 268.867ZM203.43 273.134L203.107 272.944C202.928 273.048 202.928 273.219 203.107 273.324L203.43 273.134ZM231.749 281.245L232.072 281.435C232.251 281.33 232.251 281.16 232.072 281.055L231.749 281.245ZM224.49 285.511L224.167 285.701C224.253 285.752 224.369 285.78 224.49 285.78C224.611 285.78 224.728 285.752 224.813 285.701L224.49 285.511ZM65.2303 354.564L64.907 354.374C64.7284 354.479 64.7284 354.649 64.907 354.754L65.2303 354.564ZM72.4891 350.298L72.8124 350.108C72.7266 350.058 72.6103 350.029 72.4891 350.029C72.3678 350.029 72.2515 350.058 72.1658 350.108L72.4891 350.298ZM86.2904 366.942L85.9671 367.132C86.1457 367.237 86.4352 367.237 86.6137 367.132L86.2904 366.942ZM93.5492 362.676L93.8725 362.866C93.9583 362.815 94.0064 362.747 94.0064 362.676C94.0064 362.604 93.9583 362.536 93.8725 362.486L93.5492 362.676ZM69.6321 377.163L69.3088 376.973L69.3088 376.973L69.6321 377.163ZM47.8493 364.361L48.1726 364.551L47.8493 364.361ZM165.391 307.866C171.229 311.297 171.228 316.866 165.387 320.299L166.033 320.679C172.231 317.036 172.233 311.127 166.037 307.486L165.391 307.866ZM144.236 307.868C150.077 304.435 159.552 304.434 165.391 307.866L166.037 307.486C159.841 303.844 149.787 303.845 143.589 307.488L144.236 307.868ZM144.231 320.301C138.393 316.87 138.395 311.301 144.236 307.868L143.589 307.488C137.391 311.131 137.389 317.04 143.585 320.682L144.231 320.301ZM165.387 320.299C159.546 323.732 150.07 323.733 144.231 320.301L143.585 320.682C149.781 324.323 159.835 324.322 166.033 320.679L165.387 320.299ZM194.607 303.888C200.693 300.178 200.513 294.272 194.204 290.696L193.569 291.083C199.514 294.453 199.685 300.019 193.949 303.514L194.607 303.888ZM172.162 304.129C178.472 307.705 188.52 307.597 194.607 303.888L193.949 303.514C188.213 307.01 178.743 307.112 172.797 303.743L172.162 304.129ZM171.759 290.938C165.672 294.648 165.853 300.554 172.162 304.129L172.797 303.743C166.851 300.373 166.681 294.807 172.417 291.311L171.759 290.938ZM194.204 290.696C187.894 287.12 177.845 287.229 171.759 290.938L172.417 291.311C178.153 287.815 187.623 287.713 193.569 291.083L194.204 290.696ZM196.612 276.757L189.353 281.023L190 281.403L197.259 277.137L196.612 276.757ZM218.319 289.135L197.259 276.757L196.612 277.137L217.672 289.515L218.319 289.135ZM211.06 293.781L218.319 289.515L217.672 289.135L210.413 293.401L211.06 293.781ZM189.353 281.403L210.413 293.781L211.06 293.401L190 281.023L189.353 281.403ZM138.533 336.842C144.731 333.199 144.733 327.29 138.537 323.648L137.891 324.028C143.729 327.46 143.728 333.029 137.887 336.462L138.533 336.842ZM116.085 336.844C122.281 340.486 132.335 340.484 138.533 336.842L137.887 336.462C132.045 339.895 122.57 339.896 116.731 336.464L116.085 336.844ZM116.089 323.651C109.891 327.293 109.889 333.203 116.085 336.844L116.731 336.464C110.893 333.033 110.895 327.464 116.736 324.031L116.089 323.651ZM138.537 323.648C132.341 320.007 122.287 320.008 116.089 323.651L116.736 324.031C122.577 320.598 132.052 320.597 137.891 324.028L138.537 323.648ZM109.962 340.445C115.801 343.876 115.799 349.445 109.958 352.878L110.604 353.258C116.802 349.616 116.804 343.706 110.609 340.065L109.962 340.445ZM88.8069 340.447C94.648 337.014 104.124 337.013 109.962 340.445L110.609 340.065C104.413 336.423 94.3582 336.425 88.1603 340.067L88.8069 340.447ZM88.8028 352.881C82.9643 349.449 82.9659 343.88 88.8069 340.447L88.1603 340.067C81.9624 343.71 81.9603 349.619 88.1562 353.261L88.8028 352.881ZM109.958 352.878C104.117 356.311 94.6413 356.312 88.8028 352.881L88.1562 353.261C94.352 356.902 104.407 356.901 110.604 353.258L109.958 352.878ZM210.366 268.677L203.107 272.944L203.753 273.324L211.012 269.057L210.366 268.677ZM232.072 281.055L211.012 268.677L210.366 269.057L231.426 281.435L232.072 281.055ZM224.813 285.701L232.072 281.435L231.426 281.055L224.167 285.321L224.813 285.701ZM203.107 273.324L224.167 285.701L224.813 285.321L203.753 272.944L203.107 273.324ZM65.5536 354.754L72.8124 350.488L72.1658 350.108L64.907 354.374L65.5536 354.754ZM86.6137 366.752L65.5536 354.374L64.907 354.754L85.9671 367.132L86.6137 366.752ZM93.2259 362.486L85.9671 366.752L86.6137 367.132L93.8725 362.866L93.2259 362.486ZM72.1658 350.488L93.2259 362.866L93.8725 362.486L72.8124 350.108L72.1658 350.488ZM69.9554 377.353C76.1533 373.71 76.1554 367.801 69.9595 364.16L69.3129 364.54C75.1514 367.971 75.1498 373.54 69.3088 376.973L69.9554 377.353ZM47.5071 377.356C53.7029 380.997 63.7574 380.996 69.9554 377.353L69.3088 376.973C63.4677 380.406 53.9922 380.407 48.1537 376.975L47.5071 377.356ZM47.526 364.171C41.3286 367.813 41.3106 373.714 47.5071 377.356L48.1537 376.975C42.3157 373.544 42.331 367.984 48.1726 364.551L47.526 364.171ZM69.9595 364.16C63.7631 360.518 53.7233 360.528 47.526 364.171L48.1726 364.551C54.0142 361.117 63.475 361.109 69.3129 364.54L69.9595 364.16Z\" fill=\"#212121\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M300.031 135.273L247.792 105.225L195.553 135.273V147.291L247.792 117.244L300.031 147.291V135.273Z\" fill=\"#D4D9DE\" fill-opacity=\"0.4\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M195.553 135.466L247.792 165.514L300.031 135.466V147.485L247.792 177.533L195.553 147.485V135.466Z\" fill=\"var(--c8y-palette-gray-10)\" fill-opacity=\"0.8\" stroke=\"#212121\" stroke-opacity=\"0.8\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M247.26 165.274L299.499 135.227V147.246L247.26 177.293V165.274Z\" fill=\"var(--c8y-palette-gray-10)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M234.869 135.044C234.764 137.022 236.025 139.02 238.65 140.531C243.699 143.435 251.885 143.435 256.934 140.531C259.458 139.079 260.72 137.175 260.72 135.272V147.291C260.72 149.194 259.458 151.098 256.934 152.55C251.885 155.454 243.699 155.454 238.65 152.55C236.025 151.039 234.764 149.041 234.869 147.063V135.044Z\" fill=\"#D4D9DE\" fill-opacity=\"0.4\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M300.031 135.273L247.792 105.225L195.553 135.273L247.792 165.32L300.031 135.273Z\" fill=\"var(--c8y-palette-gray-10)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path id=\"c8y-mark\" d=\"M266.412 144.258C263.201 146.105 259.329 147.036 254.793 147.051C250.258 147.043 246.39 146.118 243.188 144.276C239.986 142.434 238.388 140.215 238.394 137.618C238.399 134.998 240.008 132.764 243.218 130.917C245.52 129.593 248.159 128.718 251.134 128.291C254.109 127.864 257.02 127.898 259.867 128.394L257.833 132.326C254.037 131.698 250.788 132.162 248.085 133.716C246.268 134.761 245.379 136.036 245.418 137.54C245.478 139.033 246.424 140.306 248.257 141.36C250.09 142.414 252.303 142.958 254.898 142.993C257.513 143.015 259.729 142.504 261.546 141.459C264.249 139.904 265.055 138.035 263.963 135.852L270.8 134.682C271.661 136.319 271.72 137.994 270.978 139.705C270.236 141.416 268.714 142.934 266.412 144.258ZM223.181 136.028C224.342 135.36 224.34 134.277 223.178 133.608C222.015 132.939 220.132 132.939 218.971 133.606C217.81 134.274 217.812 135.357 218.974 136.026C220.137 136.694 222.02 136.695 223.181 136.028ZM223.521 131.069L222.119 131.876L226.19 134.217L227.591 133.411L223.521 131.069ZM230.739 131.68C231.9 131.013 231.898 129.929 230.736 129.261C229.573 128.592 227.69 128.591 226.529 129.259C225.369 129.926 225.37 131.01 226.533 131.678C227.695 132.347 229.579 132.348 230.739 131.68ZM235.919 128.701C237.08 128.033 237.078 126.95 235.916 126.281C234.753 125.613 232.87 125.612 231.71 126.279C230.549 126.947 230.55 128.03 231.713 128.699C232.875 129.367 234.758 129.368 235.919 128.701ZM241.099 125.721C242.26 125.054 242.258 123.97 241.096 123.302C239.933 122.633 238.05 122.632 236.889 123.3C235.729 123.967 235.73 125.051 236.893 125.719C238.055 126.388 239.938 126.389 241.099 125.721ZM246.279 122.742C247.44 122.074 247.438 120.991 246.276 120.322C245.113 119.654 243.23 119.653 242.069 120.32C240.909 120.988 240.91 122.071 242.072 122.74C243.235 123.409 245.118 123.409 246.279 122.742ZM246.619 117.784L245.217 118.59L249.288 120.931L250.689 120.125L246.619 117.784ZM248.997 116.416L247.595 117.222L251.666 119.563L253.068 118.757L248.997 116.416Z\" fill=\"var(--c8y-brand-60)\"/>\n        <defs>\n        <filter id=\"filter0_f_641_19870\" x=\"17.4668\" y=\"135.085\" width=\"164.453\" height=\"101.354\" filterUnits=\"userSpaceOnUse\" color-interpolation-filters=\"sRGB\">\n        <feFlood flood-opacity=\"0\" result=\"BackgroundImageFix\"/>\n        <feBlend mode=\"normal\" in=\"SourceGraphic\" in2=\"BackgroundImageFix\" result=\"shape\"/>\n        <feGaussianBlur stdDeviation=\"3\" result=\"effect1_foregroundBlur_641_19870\"/>\n        </filter>\n        <filter id=\"filter1_f_641_19870\" x=\"332.77\" y=\"136.261\" width=\"164.453\" height=\"101.354\" filterUnits=\"userSpaceOnUse\" color-interpolation-filters=\"sRGB\">\n        <feFlood flood-opacity=\"0\" result=\"BackgroundImageFix\"/>\n        <feBlend mode=\"normal\" in=\"SourceGraphic\" in2=\"BackgroundImageFix\" result=\"shape\"/>\n        <feGaussianBlur stdDeviation=\"3\" result=\"effect1_foregroundBlur_641_19870\"/>\n        </filter>\n        <filter id=\"filter2_f_641_19870\" x=\"123.143\" y=\"199.75\" width=\"119.09\" height=\"74.9868\" filterUnits=\"userSpaceOnUse\" color-interpolation-filters=\"sRGB\">\n        <feFlood flood-opacity=\"0\" result=\"BackgroundImageFix\"/>\n        <feBlend mode=\"normal\" in=\"SourceGraphic\" in2=\"BackgroundImageFix\" result=\"shape\"/>\n        <feGaussianBlur stdDeviation=\"3\" result=\"effect1_foregroundBlur_641_19870\"/>\n        </filter>\n        <filter id=\"filter3_f_641_19870\" x=\"269.168\" y=\"200.133\" width=\"120.359\" height=\"75.7793\" filterUnits=\"userSpaceOnUse\" color-interpolation-filters=\"sRGB\">\n        <feFlood flood-opacity=\"0\" result=\"BackgroundImageFix\"/>\n        <feBlend mode=\"normal\" in=\"SourceGraphic\" in2=\"BackgroundImageFix\" result=\"shape\"/>\n        <feGaussianBlur stdDeviation=\"3\" result=\"effect1_foregroundBlur_641_19870\"/>\n        </filter>\n        <filter id=\"filter4_f_641_19870\" x=\"271.557\" y=\"289.989\" width=\"109.887\" height=\"69.3096\" filterUnits=\"userSpaceOnUse\" color-interpolation-filters=\"sRGB\">\n        <feFlood flood-opacity=\"0\" result=\"BackgroundImageFix\"/>\n        <feBlend mode=\"normal\" in=\"SourceGraphic\" in2=\"BackgroundImageFix\" result=\"shape\"/>\n        <feGaussianBlur stdDeviation=\"3\" result=\"effect1_foregroundBlur_641_19870\"/>\n        </filter>\n        <filter id=\"filter5_f_641_19870\" x=\"325.838\" y=\"317.321\" width=\"164.453\" height=\"101.354\" filterUnits=\"userSpaceOnUse\" color-interpolation-filters=\"sRGB\">\n        <feFlood flood-opacity=\"0\" result=\"BackgroundImageFix\"/>\n        <feBlend mode=\"normal\" in=\"SourceGraphic\" in2=\"BackgroundImageFix\" result=\"shape\"/>\n        <feGaussianBlur stdDeviation=\"3\" result=\"effect1_foregroundBlur_641_19870\"/>\n        </filter>\n        <filter id=\"filter6_f_641_19870\" x=\"43.0938\" y=\"345.167\" width=\"200.42\" height=\"124.792\" filterUnits=\"userSpaceOnUse\" color-interpolation-filters=\"sRGB\">\n        <feFlood flood-opacity=\"0\" result=\"BackgroundImageFix\"/>\n        <feBlend mode=\"normal\" in=\"SourceGraphic\" in2=\"BackgroundImageFix\" result=\"shape\"/>\n        <feGaussianBlur stdDeviation=\"3\" result=\"effect1_foregroundBlur_641_19870\"/>\n        </filter>\n        <filter id=\"filter7_f_641_19870\" x=\"194.176\" y=\"304.388\" width=\"116.479\" height=\"72.0947\" filterUnits=\"userSpaceOnUse\" color-interpolation-filters=\"sRGB\">\n        <feFlood flood-opacity=\"0\" result=\"BackgroundImageFix\"/>\n        <feBlend mode=\"normal\" in=\"SourceGraphic\" in2=\"BackgroundImageFix\" result=\"shape\"/>\n        <feGaussianBlur stdDeviation=\"3\" result=\"effect1_foregroundBlur_641_19870\"/>\n        </filter>\n        <linearGradient id=\"paint0_linear_641_19870\" x1=\"67.6453\" y1=\"74.6233\" x2=\"70.9751\" y2=\"78.8959\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"1\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint1_linear_641_19870\" x1=\"65.7555\" y1=\"72.9387\" x2=\"78.4635\" y2=\"82.716\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"1\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint2_linear_641_19870\" x1=\"107.491\" y1=\"56.3991\" x2=\"110.821\" y2=\"60.6718\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"1\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint3_linear_641_19870\" x1=\"105.601\" y1=\"54.7146\" x2=\"118.309\" y2=\"64.4919\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"1\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint4_linear_641_19870\" x1=\"98.7193\" y1=\"71.7487\" x2=\"96.6163\" y2=\"82.8728\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"var(--c8y-brand-60)\"/>\n        <stop offset=\"1\" stop-color=\"var(--c8y-brand-30)\"/>\n        </linearGradient>\n        <linearGradient id=\"paint5_linear_641_19870\" x1=\"99.4365\" y1=\"58.6103\" x2=\"86.7853\" y2=\"98.7343\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"var(--c8y-brand-60)\"/>\n        <stop offset=\"1\" stop-color=\"var(--c8y-brand-30)\"/>\n        </linearGradient>\n        <linearGradient id=\"paint6_linear_641_19870\" x1=\"380.058\" y1=\"215.743\" x2=\"376.493\" y2=\"222.746\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"0.597975\" stop-color=\"#8B96A0\"/>\n        <stop offset=\"0.985\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint7_linear_641_19870\" x1=\"410.322\" y1=\"278.681\" x2=\"380.111\" y2=\"278.681\" gradientUnits=\"userSpaceOnUse\">\n        <stop offset=\"0.015\" stop-color=\"#8B96A0\"/>\n        <stop offset=\"0.402025\" stop-color=\"#8B96A0\"/>\n        <stop offset=\"1\" stop-color=\"#D4D9DE\"/>\n        </linearGradient>\n        <linearGradient id=\"paint8_linear_641_19870\" x1=\"389.36\" y1=\"266.198\" x2=\"390.187\" y2=\"278.3\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"var(--c8y-brand-60)\"/>\n        <stop offset=\"1\" stop-color=\"var(--c8y-brand-30)\"/>\n        </linearGradient>\n        <linearGradient id=\"paint9_linear_641_19870\" x1=\"386.123\" y1=\"247.193\" x2=\"379.278\" y2=\"263.272\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"0.765\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint10_linear_641_19870\" x1=\"403.921\" y1=\"257.348\" x2=\"405.405\" y2=\"265.538\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"var(--c8y-brand-60)\"/>\n        <stop offset=\"1\" stop-color=\"var(--c8y-brand-30)\"/>\n        </linearGradient>\n        <linearGradient id=\"paint11_linear_641_19870\" x1=\"414.876\" y1=\"208.485\" x2=\"409.391\" y2=\"221.49\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"0.765\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint12_linear_641_19870\" x1=\"428.755\" y1=\"215.61\" x2=\"430.239\" y2=\"223.8\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"var(--c8y-brand-60)\"/>\n        <stop offset=\"1\" stop-color=\"var(--c8y-brand-30)\"/>\n        </linearGradient>\n        <linearGradient id=\"paint13_linear_641_19870\" x1=\"385.154\" y1=\"189.512\" x2=\"379.668\" y2=\"202.516\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"0.765\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint14_linear_641_19870\" x1=\"398.724\" y1=\"196.799\" x2=\"400.208\" y2=\"204.988\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"var(--c8y-brand-60)\"/>\n        <stop offset=\"1\" stop-color=\"var(--c8y-brand-30)\"/>\n        </linearGradient>\n        <linearGradient id=\"paint15_linear_641_19870\" x1=\"399.671\" y1=\"297.979\" x2=\"407.661\" y2=\"304.981\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"1\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint16_linear_641_19870\" x1=\"415.366\" y1=\"271.444\" x2=\"427.36\" y2=\"277.536\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"1\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint17_linear_641_19870\" x1=\"438.232\" y1=\"263.963\" x2=\"451.763\" y2=\"275.511\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"1\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint18_linear_641_19870\" x1=\"485.601\" y1=\"209.225\" x2=\"500.039\" y2=\"226.157\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"1\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint19_linear_641_19870\" x1=\"404.649\" y1=\"-2.93926\" x2=\"384.076\" y2=\"95.1763\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"var(--c8y-brand-60)\"/>\n        <stop offset=\"1\" stop-color=\"var(--c8y-brand-30)\"/>\n        </linearGradient>\n        <linearGradient id=\"paint20_linear_641_19870\" x1=\"361.626\" y1=\"99.9359\" x2=\"397.901\" y2=\"22.2408\" gradientUnits=\"userSpaceOnUse\">\n        <stop offset=\"0.015\" stop-color=\"#8B96A0\"/>\n        <stop offset=\"1\" stop-color=\"#D4D9DE\"/>\n        </linearGradient>\n        <linearGradient id=\"paint21_linear_641_19870\" x1=\"361.626\" y1=\"99.9364\" x2=\"397.901\" y2=\"22.2413\" gradientUnits=\"userSpaceOnUse\">\n        <stop offset=\"0.015\" stop-color=\"#8B96A0\"/>\n        <stop offset=\"1\" stop-color=\"#D4D9DE\"/>\n        </linearGradient>\n        <linearGradient id=\"paint22_linear_641_19870\" x1=\"393.393\" y1=\"55.2134\" x2=\"398.919\" y2=\"62.0251\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"1\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        </defs>\n      </svg>\n\n    </div>\n  </div>\n</div>\n", dependencies: [{ kind: "ngmodule", type: CoreModule }, { kind: "pipe", type: i2.C8yTranslatePipe, name: "translate" }, { kind: "directive", type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i2.ProductExperienceDirective, selector: "[c8yProductExperience]", inputs: ["actionName", "actionData", "inherit", "suppressDataOverriding"] }, { kind: "ngmodule", type: QuickLinkModule }, { kind: "component", type: i2.QuickLinkComponent, selector: "c8y-quick-link", inputs: ["icon", "label"] }, { kind: "ngmodule", type: RouterModule }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WelcomeToCockpitComponent, decorators: [{
            type: Component,
            args: [{ selector: 'c8y-welcome-to-cockpit', standalone: true, imports: [CoreModule, QuickLinkModule, RouterModule], template: "<div class=\"welcome-widget welcome-cockpit\" tabindex=\"0\">\n  <div class=\"d-flex fit-h\">\n    <div class=\"col-xs-12 col-md-6 a-s-stretch p-24\">\n      <h2 class=\"text-light\">{{ 'Welcome to Cockpit' | translate }}</h2>\n      <p class=\"text-16 text-light p-t-16 p-b-24\">{{ welcomeMessage | translate }}</p>\n      <div class=\"card-group interact-grid tight-grid\">\n        <div *ngFor=\"let link of quickLinks\" class=\"col-sm-4 col-xs-6\">\n          <button\n            type=\"button\"\n            title=\"{{ link.label }}\" \n            class=\"btn-clean card text-pre-normal\"\n            (click)=\"link.click ? link.click() : false\"\n            c8yProductExperience\n            [actionName]=\"'welcomeWidgetClicked'\"\n            [actionData]=\"{ link: link.label }\"\n          >\n            <c8y-quick-link [icon]=\"link.icon\" [label]=\"link.label\"></c8y-quick-link>\n          </button>\n        </div>\n      </div>\n    </div>\n    <div class=\"welcome-illustration a-s-stretch\">\n      <svg class=\"p-0\" viewBox=\"0 0 519 376\" fill=\"none\" xmlns=\"http://www.w3.org/2000/svg\">\n        <g opacity=\"0.05\" filter=\"url(#filter0_f_641_19870)\">\n        <path d=\"M102.632 141.085L175.921 184.041L150.295 199.06L77.006 156.105L102.632 141.085Z\" fill=\"#212121\"/>\n        <path d=\"M50.2364 171.795L123.526 214.75L96.756 230.439L23.4668 187.484L50.2364 171.795Z\" fill=\"#212121\"/>\n        <path d=\"M150.295 199.06L77.006 156.105L50.2364 171.795L123.526 214.75L150.295 199.06Z\" fill=\"#212121\"/>\n        </g>\n        <g opacity=\"0.05\" filter=\"url(#filter1_f_641_19870)\">\n        <path d=\"M417.934 142.261L491.223 185.216L465.598 200.236L392.309 157.28L417.934 142.261Z\" fill=\"#212121\"/>\n        <path d=\"M365.539 172.97L438.828 215.925L412.059 231.615L338.77 188.66L365.539 172.97Z\" fill=\"#212121\"/>\n        <path d=\"M465.598 200.236L392.309 157.28L365.539 172.97L438.828 215.925L465.598 200.236Z\" fill=\"#212121\"/>\n        </g>\n        <g opacity=\"0.05\">\n        <g filter=\"url(#filter2_f_641_19870)\">\n        <path d=\"M190.071 233.673L236.233 260.804L222.735 268.737L176.573 241.606L190.071 233.673Z\" fill=\"#212121\"/>\n        <path d=\"M190.071 233.673L142.64 205.75L129.143 213.683L176.573 241.606L190.071 233.673Z\" fill=\"#212121\"/>\n        </g>\n        </g>\n        <g opacity=\"0.05\" filter=\"url(#filter3_f_641_19870)\">\n        <path d=\"M322.599 234.056L275.169 261.98L288.667 269.913L336.097 241.989L322.599 234.056Z\" fill=\"#212121\"/>\n        <path d=\"M322.599 234.056L370.03 206.133L383.527 214.066L336.097 241.989L322.599 234.056Z\" fill=\"#212121\"/>\n        </g>\n        <g opacity=\"0.05\" filter=\"url(#filter4_f_641_19870)\">\n        <path d=\"M291.054 295.989L328.012 317.442L314.515 325.375L277.557 303.922L291.054 295.989Z\" fill=\"#212121\"/>\n        <path d=\"M375.443 345.366L328.012 317.442L314.515 325.375L361.945 353.298L375.443 345.366Z\" fill=\"#212121\"/>\n        </g>\n        <g opacity=\"0.05\" filter=\"url(#filter5_f_641_19870)\">\n        <path d=\"M411.003 323.321L484.292 366.276L458.666 381.295L385.377 338.34L411.003 323.321Z\" fill=\"#212121\"/>\n        <path d=\"M358.607 354.03L431.897 396.985L405.127 412.675L331.838 369.72L358.607 354.03Z\" fill=\"#212121\"/>\n        <path d=\"M458.666 381.295L385.377 338.34L358.607 354.03L431.897 396.985L458.666 381.295Z\" fill=\"#212121\"/>\n        </g>\n        <g opacity=\"0.05\" filter=\"url(#filter6_f_641_19870)\">\n        <path d=\"M148.483 412.836C148.616 410.421 147.115 407.98 143.98 406.137C137.963 402.601 128.198 402.602 122.178 406.14C118.408 408.356 116.998 411.435 117.95 414.296C117.788 413.81 117.694 413.317 117.669 412.823V414.669C117.784 416.894 119.285 419.099 122.173 420.797C128.19 424.333 137.955 424.332 143.975 420.794C147.105 418.955 148.608 416.52 148.483 414.109V412.836Z\" fill=\"#212121\"/>\n        <path d=\"M175.984 396.671V398.503C175.868 400.728 174.365 402.934 171.475 404.632C165.456 408.169 155.691 408.17 149.674 404.634C146.545 402.795 145.044 400.361 145.17 397.95V396.663C145.182 396.906 145.212 397.149 145.257 397.391C145.211 397.146 145.182 396.901 145.17 396.656V396.663C145.16 396.477 145.16 396.29 145.17 396.104V396.116C145.282 393.887 146.785 391.678 149.679 389.977C155.698 386.439 165.463 386.438 171.48 389.974C174.615 391.816 176.116 394.256 175.984 396.671Z\" fill=\"#212121\"/>\n        <path d=\"M204.347 379.268C204.163 377.044 202.594 374.856 199.652 373.189C193.525 369.716 183.765 369.821 177.854 373.424C174.78 375.297 173.352 377.747 173.551 380.156V382C173.735 384.223 175.304 386.411 178.246 388.078C184.373 391.551 194.133 391.446 200.044 387.843C203.118 385.97 204.546 383.52 204.347 381.111V380.151C204.352 380.094 204.355 380.037 204.358 379.98C204.366 379.827 204.367 379.673 204.362 379.519C204.359 379.434 204.354 379.35 204.347 379.265V379.268Z\" fill=\"#212121\"/>\n        <path d=\"M202.702 359.246L195.444 363.512L216.504 375.89L223.762 371.624L202.702 359.246Z\" fill=\"#212121\"/>\n        <path d=\"M120.554 429.278V431.079C120.438 433.304 118.935 435.51 116.045 437.208C110.026 440.745 100.261 440.747 94.2434 437.21C91.1145 435.371 89.6132 432.937 89.7392 430.526V429.24C89.7704 429.838 89.9019 430.435 90.1336 431.021C89.8973 430.422 89.7658 429.811 89.7392 429.199V429.24C89.7294 429.053 89.7294 428.867 89.7392 428.68V428.732C89.8368 426.491 91.3404 424.267 94.2499 422.557C100.269 419.019 110.034 419.018 116.052 422.554C119.197 424.403 120.698 426.854 120.554 429.278Z\" fill=\"#212121\"/>\n        <path d=\"M237.512 363.546V365.387L230.254 369.653V369.654L230.253 369.653L209.194 357.276V355.43L209.197 355.432L216.454 351.167L237.511 363.542L237.512 363.541V363.543L237.514 363.544L237.512 363.546Z\" fill=\"#212121\"/>\n        <path d=\"M70.9987 436.862L78.2554 432.597L99.3126 444.973L99.3145 444.971V444.974L99.3155 444.974L99.3145 444.975V446.818L92.0568 451.083V451.084L92.0561 451.084L70.9966 438.707L70.9966 436.863L70.9966 436.861L70.9987 436.862Z\" fill=\"#212121\"/>\n        <path d=\"M79.9086 452.78C79.7951 450.553 78.2935 448.347 75.4039 446.648C69.3867 443.112 59.6364 443.122 53.617 446.66C50.4854 448.5 48.9785 450.934 49.1006 453.344V455.183C49.2119 457.406 50.71 459.609 53.5982 461.306C59.6154 464.843 69.3804 464.842 75.3999 461.304C78.5301 459.464 80.033 457.029 79.9086 454.619V453.326C79.9095 453.308 79.9104 453.29 79.9111 453.272C79.918 453.105 79.9172 452.939 79.9086 452.772V452.78Z\" fill=\"#212121\"/>\n        <path d=\"M195.444 363.513L216.504 375.891V377.737L195.444 365.36V363.513Z\" fill=\"#212121\"/>\n        <path d=\"M223.763 371.624L216.504 375.89V377.737L223.763 373.471V371.624Z\" fill=\"#212121\"/>\n        </g>\n        <g opacity=\"0.05\" filter=\"url(#filter7_f_641_19870)\">\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M304.654 340.435L252.415 310.388L200.176 340.435L252.415 370.483L304.654 340.435Z\" fill=\"#212121\"/>\n        </g>\n        <rect width=\"82.5838\" height=\"28.8755\" transform=\"matrix(0.862126 0.506694 -0.862126 0.506694 96.9082 59.9609)\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"11.1196\" transform=\"matrix(0.862126 0.506694 0 1 72.0137 74.5918)\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"28.8755\" height=\"11.1196\" transform=\"matrix(0.862126 -0.506694 0 1 143.213 116.437)\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"28.8755\" transform=\"matrix(0.862126 0.506694 -0.862126 0.506694 70.9043 75.2446)\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"11.1196\" transform=\"matrix(0.862126 0.506694 0 1 46.0098 89.8755)\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"28.8755\" height=\"11.1196\" transform=\"matrix(0.862126 -0.506694 0 1 117.209 131.72)\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"28.8755\" transform=\"matrix(0.862126 0.506694 -0.862126 0.506694 44.8984 90.5293)\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"11.1196\" transform=\"matrix(0.862126 0.506694 0 1 20.0039 105.16)\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"28.8755\" height=\"11.1196\" transform=\"matrix(0.862126 -0.506694 0 1 91.2031 147.005)\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M147.397 94.0562L82.3828 132.267V134.618L147.397 96.4076V94.0562Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M82.382 132.267L41.373 108.165V110.516L82.382 134.618V132.267Z\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"75.4116\" height=\"47.5673\" transform=\"matrix(0.862126 -0.506694 0.862126 0.506694 41.373 108.165)\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"69.6107\" height=\"41.7664\" transform=\"matrix(0.862126 -0.506694 0.862126 0.506694 46.7637 107.871)\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M119.184 93.219C118.94 93.3624 118.933 93.5906 119.166 93.7275L119.36 93.8414C119.594 93.9791 119.982 93.9751 120.226 93.8317L121.157 93.2845C121.401 93.1411 121.408 92.9129 121.174 92.7751L120.98 92.6612C120.747 92.5244 120.359 92.5284 120.115 92.6718L119.184 93.219Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M119.167 94.5219L117.464 93.5207C117.231 93.3838 116.843 93.3878 116.599 93.5312L115.403 94.2341C115.159 94.3775 115.152 94.6058 115.385 94.7426L115.969 95.0861C116.202 95.223 116.505 95.2691 116.699 95.1547L116.749 95.1257C116.96 95.0017 117.103 95.1419 117.336 95.2788L117.608 95.4386C117.843 95.5772 118.227 95.5723 118.473 95.4281L119.148 95.0313C119.392 94.8879 119.402 94.6614 119.166 94.5228L119.167 94.5219Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M117.31 89.3159L118.155 90.1029C118.309 90.2423 118.264 90.4309 118.058 90.5523L115.289 92.1798C115.045 92.3232 115.036 92.5524 115.269 92.6892L115.591 92.8782C115.824 93.015 116.212 93.0093 116.456 92.8659L116.546 92.8131C116.791 92.6688 117.18 92.6648 117.414 92.8026L117.624 92.9262C117.857 93.063 118.245 93.059 118.489 92.9156L121.917 90.901C122.125 90.7787 122.167 90.5919 122.015 90.4516L119.595 88.1867C119.5 88.0958 119.335 88.0392 119.154 88.0293C118.968 88.0203 118.784 88.0598 118.649 88.1389L117.409 88.8674C117.201 88.9897 117.161 89.1773 117.312 89.3168L117.31 89.3159Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M117.163 85.7022L115.241 86.8318C115.028 86.9568 114.992 87.148 115.148 87.2892L116.264 88.2721C116.364 88.3595 116.526 88.4143 116.708 88.4224C116.888 88.4297 117.069 88.3902 117.201 88.3128L119.123 87.1832C119.337 87.0574 119.375 86.8671 119.218 86.7268L118.1 85.7429C118 85.6555 117.837 85.6007 117.659 85.5926C117.475 85.5845 117.295 85.6248 117.163 85.7022Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M126.741 93.6807C126.613 93.6762 126.485 93.7042 126.39 93.7597L126.254 93.8397C126.077 93.9435 126.079 94.1119 126.257 94.2161C126.434 94.3202 126.433 94.4886 126.258 94.5915L124.944 95.3639C124.768 95.4669 124.481 95.4666 124.305 95.3633L124.426 95.4348C124.305 95.3633 124.129 95.3393 123.966 95.3699C123.804 95.3997 123.684 95.4807 123.658 95.5811L123.085 97.7592C123.062 97.8438 123.111 97.9276 123.215 97.9885L125.484 99.3217C125.659 99.425 125.946 99.4262 126.122 99.3224L129.564 97.2998C129.676 97.2339 129.841 97.2058 129.995 97.2298L130.815 97.354C130.966 97.378 131.131 97.3517 131.243 97.2857L132.547 96.5195C132.631 96.4702 132.677 96.4042 132.681 96.3363L132.708 95.1624C132.712 95.091 132.661 95.0222 132.574 94.971L130.759 93.9044C130.681 93.8585 130.576 93.8302 130.469 93.8257L126.742 93.6798L126.741 93.6807Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M113.816 103.173L113.599 103.301C113.263 103.498 113.183 103.799 113.404 104.047L114.181 104.919C114.342 105.098 114.639 105.225 114.98 105.256C115.322 105.286 115.668 105.221 115.912 105.077L116.13 104.949C116.466 104.752 116.543 104.45 116.325 104.204L115.545 103.331C115.386 103.151 115.09 103.026 114.746 102.993C114.406 102.962 114.061 103.029 113.816 103.173Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M86.4069 106.588L82.4312 108.925C82.0974 109.121 81.6328 109.223 81.1589 109.199L79.3337 109.119C78.6978 109.092 78.1482 108.848 77.9237 108.496C77.7021 108.144 77.8464 107.751 78.2955 107.487L78.8807 107.143C79.213 106.947 79.3847 106.677 79.3508 106.4L78.7693 101.621C78.7309 101.303 78.4226 101.014 77.9512 100.855L70.2655 98.2681C69.626 98.0542 68.8239 98.1159 68.306 98.4203L53.3762 107.195C52.74 107.569 52.7418 108.173 53.3803 108.549L58.2868 111.432C58.9237 111.807 59.9539 111.809 60.5901 111.435L62.8519 110.105C63.4177 109.773 64.3098 109.732 64.96 110.011L69.9346 112.139C70.2694 112.281 70.682 112.346 71.0898 112.315L79.8979 111.691C80.4466 111.652 80.9898 111.778 81.3445 112.027L91.6581 119.229C91.9542 119.433 92.3804 119.556 92.8379 119.57C93.2908 119.581 93.7373 119.481 94.0592 119.292L95.6997 118.328C96.0829 118.103 96.2484 117.781 96.144 117.468L93.5498 109.667C93.4862 109.48 93.3297 109.308 93.0999 109.172L88.7072 106.591C88.0703 106.216 87.0401 106.214 86.4039 106.588L86.4069 106.588Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M84.9527 96.8779L86.8583 95.7579C86.978 95.6875 86.9792 95.5739 86.8575 95.5023L83.2986 93.4107C83.1784 93.34 82.9835 93.3416 82.8652 93.4111L80.9597 94.531C80.8399 94.6014 80.8403 94.7142 80.9605 94.7849L84.5194 96.8765C84.6411 96.948 84.833 96.9482 84.9527 96.8779Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M83.1499 97.9375L83.7876 97.5627C83.9073 97.4923 83.9085 97.3786 83.7868 97.3071L82.624 96.6237C82.5039 96.5531 82.3089 96.5546 82.1907 96.6241L81.553 96.9989C81.4317 97.0702 81.4321 97.183 81.5523 97.2536L82.715 97.937C82.8367 98.0085 83.0287 98.0087 83.1499 97.9375Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M105.885 76.3363L92.3633 84.2831C92.0655 84.4582 91.9703 84.719 92.1135 84.9509L93.6717 87.4573C93.8164 87.6901 93.7182 87.9509 93.4203 88.126L92.5821 88.6186C92.3111 88.7779 91.9169 88.84 91.5449 88.785L88.4453 88.3093C88.0732 88.2525 87.6775 88.3156 87.4066 88.4748L85.8708 89.3774C85.5819 89.5472 85.4807 89.7974 85.6074 90.0267L87.8646 94.0489C88.0425 94.3646 88.6069 94.5502 89.16 94.4706L90.548 94.2694C91.1056 94.1889 91.457 93.8658 91.351 93.5343L91.1087 92.7744C91.0497 92.5919 91.1331 92.4086 91.3156 92.2678C91.7369 92.2303 92.1766 92.341 92.4097 92.5677L93.0504 93.1871C93.3076 93.4368 93.2441 93.7602 92.8909 93.9678L87.5231 97.1226C87.3854 97.2035 87.2867 97.3039 87.2406 97.4158L86.0999 100.034C86.0076 100.252 86.1148 100.484 86.3867 100.644L88.254 101.742C88.6777 101.991 89.3645 101.991 89.7881 101.742L90.7506 101.177C91.1727 100.929 91.6222 100.79 91.9001 100.953C92.4003 101.247 92.9775 101.205 93.3982 100.975C93.7888 100.73 93.8748 100.4 93.358 100.096C93.0426 99.9108 93.3162 99.6687 93.7399 99.4198L94.4314 99.0133C94.855 98.7644 95.5418 98.7651 95.9655 99.0141L96.1683 99.1333C96.5919 99.3823 96.5932 99.7859 96.1695 100.035L91.5232 102.766C91.0996 103.015 91.1009 103.418 91.526 103.668L96.9733 106.87C97.3999 107.12 98.0882 107.122 98.5118 106.873L100.887 105.477C101.31 105.229 101.996 105.229 102.42 105.478L108.207 108.88C108.633 109.13 109.319 109.13 109.742 108.881L113.426 106.716C113.757 106.522 113.835 106.223 113.623 105.977L107.486 98.9179C107.339 98.7467 107.07 98.6257 106.755 98.5831L102.535 98.026C101.998 97.9567 101.636 97.6611 101.692 97.3403C101.733 97.217 101.835 97.1025 101.986 97.0136L103.908 95.884C104.196 95.7151 104.618 95.6556 105.008 95.7283L109.66 96.6093C110.018 96.6758 110.413 96.6295 110.697 96.4852C110.984 96.341 111.12 96.1164 111.058 95.8987L110.097 92.5168C110.039 92.3141 110.151 92.1071 110.397 91.9628L112.239 90.8798C112.5 90.7267 112.613 90.5065 112.53 90.294L111.562 87.7072C111.458 87.4312 111.31 86.9745 111.271 86.6916C111.227 86.3469 111.58 86.0582 111.807 86.1915C112.23 86.4405 112.917 86.4412 113.341 86.1923L113.369 86.1755C113.728 85.9644 113.789 85.6322 113.514 85.3807L111.721 83.7448C111.542 83.5798 111.498 83.378 111.606 83.193L113.287 80.3049C113.422 80.075 113.32 79.8193 113.027 79.6471L107.408 76.345C106.983 76.0951 106.296 76.0944 105.874 76.3425L105.885 76.3363Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M93.4406 100.953C93.4284 100.96 93.4133 100.966 93.4012 100.973C93.3875 100.981 93.3784 100.99 93.3663 100.997L93.4406 100.953Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M65.6489 82.1346C66.3191 82.5148 67.1222 82.4298 68.0612 81.878C69.0003 81.3261 69.8033 80.4671 70.4736 79.299C71.1438 78.1039 71.4806 76.9461 71.4806 75.8237C71.4806 74.7013 71.1471 73.9375 70.4736 73.5322L68.4731 72.3564C69.1466 72.7617 69.4802 73.5256 69.4802 74.648C69.4802 75.7704 69.1434 76.9282 68.4731 78.1233C67.8028 79.2913 66.9998 80.1503 66.0608 80.7023C65.1218 81.2541 64.3187 81.3391 63.6484 80.9589L65.6489 82.1346Z\" fill=\"url(#paint0_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M68.0679 66.7282C69.3834 65.956 70.6117 65.5282 71.7497 65.4467C72.8192 65.3844 73.7544 65.5811 74.5603 66.0339L72.5598 64.8582C71.7539 64.4053 70.8187 64.2087 69.7493 64.271C68.6095 64.3526 67.379 64.7817 66.0611 65.5562C64.7424 66.3322 63.5174 67.3465 62.3794 68.6027C61.217 69.9013 60.1776 71.3675 59.3292 72.8802C58.4808 74.3928 57.8105 75.975 57.3184 77.6266C56.8262 79.3053 56.5801 80.9595 56.5801 82.5076C56.5801 84.0558 56.8132 85.5598 57.2827 87.0216C57.7749 88.4431 58.4452 89.903 59.2936 91.4093C60.1646 92.8752 61.1814 94.4295 62.3438 96.0685C63.5872 97.8458 64.8274 99.6287 66.0644 101.414L68.0648 102.589C66.8279 100.804 65.5877 99.0215 64.3443 97.2442C63.1818 95.6052 62.165 94.0509 61.294 92.585C60.4456 91.0787 59.7754 89.6188 59.2832 88.1973C58.8137 86.7355 58.5805 85.2315 58.5805 83.6833C58.5805 82.1352 58.8266 80.4811 59.3188 78.8023C59.811 77.1507 60.4813 75.5685 61.3296 74.0559C62.178 72.5432 63.2174 71.077 64.3799 69.7784C65.5197 68.5202 66.7467 67.5047 68.0679 66.7282Z\" fill=\"url(#paint1_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M68.0631 81.8778C69.0021 81.3259 69.8051 80.4669 70.4754 79.2988C71.1457 78.1037 71.4825 76.946 71.4825 75.8235C71.4825 74.7011 71.1489 73.9373 70.4754 73.532C69.8019 73.1266 69.0021 73.1942 68.0631 73.7461C67.124 74.298 66.321 75.1686 65.6507 76.3676C64.9804 77.5665 64.6437 78.7205 64.6437 79.8429C64.6437 80.9653 64.9804 81.7272 65.6507 82.1344C66.321 82.5146 67.124 82.4297 68.0631 81.8778ZM68.0631 66.7329C69.381 65.9584 70.6114 65.5293 71.7512 65.4478C72.9137 65.3799 73.9175 65.6182 74.7691 66.1589C75.6401 66.661 76.3234 67.4476 76.8123 68.5226C77.3272 69.6095 77.583 70.9415 77.583 72.5168C77.583 74.092 77.3369 75.8545 76.8447 77.8777C76.3525 79.8777 75.6725 82.1312 74.8015 84.648C73.9531 87.1244 72.959 89.8567 71.8192 92.8527C70.5564 96.0952 69.3032 99.3436 68.0663 102.59C66.8294 100.805 65.5892 99.0223 64.3458 97.2451C63.1833 95.606 62.1666 94.0517 61.2955 92.5858C60.4472 91.0796 59.7769 89.6196 59.2847 88.1982C58.8152 86.7363 58.582 85.2323 58.582 83.6841C58.582 82.136 58.8281 80.4819 59.3203 78.8031C59.8125 77.1515 60.4828 75.5693 61.3311 74.0567C62.1795 72.544 63.2189 71.0778 64.3814 69.7792C65.5212 68.521 66.7484 67.5056 68.0695 66.7291L68.0631 66.7329Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M105.495 63.9105C106.165 64.2907 106.968 64.2057 107.907 63.6538C108.846 63.1019 109.649 62.2429 110.319 61.0749C110.99 59.8798 111.326 58.722 111.326 57.5996C111.326 56.4772 110.993 55.7133 110.319 55.308L108.319 54.1323C108.992 54.5376 109.326 55.3015 109.326 56.4239C109.326 57.5463 108.989 58.7041 108.319 59.8992C107.649 61.0672 106.846 61.9262 105.906 62.4781C104.967 63.03 104.164 63.115 103.494 62.7348L105.495 63.9105Z\" fill=\"url(#paint2_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M107.914 48.5041C109.229 47.7319 110.457 47.3041 111.595 47.2226C112.665 47.1602 113.6 47.3569 114.406 47.8098L112.406 46.6341C111.6 46.1812 110.664 45.9845 109.595 46.0469C108.455 46.1285 107.225 46.5575 105.907 47.3321C104.588 48.1081 103.363 49.1224 102.225 50.3785C101.063 51.6771 100.023 53.1434 99.1749 54.656C98.3265 56.1687 97.6562 57.7508 97.1641 59.4025C96.6719 61.0812 96.4258 62.7354 96.4258 64.2835C96.4258 65.8316 96.6589 67.3357 97.1284 68.7975C97.6206 70.2189 98.2909 71.6789 99.1393 73.1852C100.01 74.651 101.027 76.2054 102.19 77.8444C103.433 79.6217 104.673 81.4046 105.91 83.1895L107.91 84.3652C106.674 82.5803 105.433 80.7974 104.19 79.0201C103.028 77.3811 102.011 75.8267 101.14 74.3609C100.291 72.8546 99.6211 71.3946 99.1289 69.9732C98.6594 68.5114 98.4262 67.0074 98.4262 65.4592C98.4262 63.9111 98.6723 62.2569 99.1645 60.5782C99.6567 58.9266 100.327 57.3444 101.175 55.8318C102.024 54.3191 103.063 52.8529 104.226 51.5543C105.365 50.2961 106.592 49.2806 107.914 48.5041Z\" fill=\"url(#paint3_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M107.909 63.6536C108.848 63.1017 109.651 62.2427 110.321 61.0747C110.991 59.8796 111.328 58.7218 111.328 57.5994C111.328 56.477 110.995 55.7132 110.321 55.3078C109.648 54.9025 108.848 54.9701 107.909 55.5219C106.97 56.0738 106.167 56.9445 105.496 58.1434C104.826 59.3424 104.489 60.4963 104.489 61.6187C104.489 62.7412 104.826 63.5031 105.496 63.9103C106.167 64.2905 106.97 64.2055 107.909 63.6536ZM107.909 48.5088C109.227 47.7342 110.457 47.3052 111.597 47.2236C112.759 47.1558 113.763 47.3941 114.615 47.9347C115.486 48.4368 116.169 49.2235 116.658 50.2985C117.173 51.3854 117.429 52.7174 117.429 54.2927C117.429 55.8679 117.183 57.6304 116.69 59.6536C116.198 61.6536 115.518 63.9071 114.647 66.4239C113.799 68.9003 112.805 71.6326 111.665 74.6286C110.402 77.8711 109.149 81.1195 107.912 84.3661C106.675 82.5812 105.435 80.7982 104.191 79.0209C103.029 77.3819 102.012 75.8275 101.141 74.3617C100.293 72.8555 99.6226 71.3955 99.1304 69.974C98.6609 68.5122 98.4277 67.0082 98.4277 65.46C98.4277 63.9118 98.6738 62.2578 99.166 60.579C99.6582 58.9274 100.328 57.3452 101.177 55.8326C102.025 54.3199 103.065 52.8537 104.227 51.5551C105.367 50.2969 106.594 49.2815 107.915 48.505L107.909 48.5088Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M94.7094 83.3094C95.3797 83.6896 96.1827 83.6046 97.1218 83.0528C98.0608 82.5009 98.8638 81.6419 99.5341 80.4738C100.204 79.2787 100.541 78.1209 100.541 76.9985C100.541 75.8761 100.208 75.1123 99.5341 74.707L97.5337 73.5312C98.2072 73.9365 98.5407 74.7004 98.5407 75.8228C98.5407 76.9452 98.2039 78.103 97.5337 79.2981C96.8634 80.4661 96.0604 81.3251 95.1213 81.8771C94.1823 82.4289 93.3792 82.5139 92.709 82.1337L94.7094 83.3094Z\" fill=\"url(#paint4_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M97.1265 67.9035C98.442 67.1313 99.6703 66.7035 100.808 66.622C101.878 66.5597 102.813 66.7564 103.619 67.2092L101.618 66.0335C100.813 65.5806 99.8773 65.3839 98.8079 65.4463C97.6681 65.5279 96.4376 65.957 95.1197 66.7315C93.801 67.5075 92.576 68.5218 91.438 69.778C90.2756 71.0766 89.2362 72.5428 88.3878 74.0555C87.5394 75.5681 86.8691 77.1503 86.3769 78.8019C85.8848 80.4806 85.6387 82.1348 85.6387 83.6829C85.6387 85.2311 85.8718 86.7351 86.3413 88.1969C86.8335 89.6183 87.5038 91.0783 88.3522 92.5846C89.2232 94.0504 90.24 95.6048 91.4024 97.2438C92.6458 99.0211 93.886 100.804 95.123 102.589L97.1234 103.765C95.8865 101.98 94.6462 100.197 93.4029 98.4195C92.2404 96.7805 91.2236 95.2262 90.3526 93.7603C89.5042 92.254 88.834 90.7941 88.3418 89.3726C87.8723 87.9108 87.6391 86.4068 87.6391 84.8586C87.6391 83.3105 87.8852 81.6563 88.3774 79.9776C88.8696 78.326 89.5399 76.7438 90.3882 75.2312C91.2366 73.7185 92.276 72.2523 93.4385 70.9537C94.5783 69.6955 95.8053 68.68 97.1265 67.9035Z\" fill=\"url(#paint5_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M97.1217 83.0531C98.0607 82.5012 98.8637 81.6421 99.534 80.4741C100.204 79.279 100.541 78.1212 100.541 76.9988C100.541 75.8764 100.208 75.1126 99.534 74.7073C98.8605 74.3019 98.0607 74.3695 97.1217 74.9214C96.1826 75.4733 95.3796 76.3439 94.7093 77.5429C94.039 78.7418 93.7023 79.8957 93.7023 81.0182C93.7023 82.1406 94.039 82.9025 94.7093 83.3097C95.3796 83.6899 96.1826 83.6049 97.1217 83.0531ZM97.1217 67.9082C98.4396 67.1337 99.67 66.7046 100.81 66.623C101.972 66.5552 102.976 66.7935 103.828 67.3342C104.699 67.8363 105.382 68.6229 105.871 69.6979C106.386 70.7848 106.642 72.1168 106.642 73.6921C106.642 75.2673 106.395 77.0298 105.903 79.053C105.411 81.053 104.731 83.3065 103.86 85.8233C103.012 88.2997 102.018 91.032 100.878 94.028C99.615 97.2705 98.3618 100.519 97.1249 103.765C95.888 101.981 94.6478 100.198 93.4044 98.4204C92.2419 96.7813 91.2252 95.227 90.3541 93.7611C89.5057 92.2549 88.8355 90.7949 88.3433 89.3735C87.8738 87.9116 87.6406 86.4076 87.6406 84.8594C87.6406 83.3113 87.8867 81.6572 88.3789 79.9784C88.8711 78.3268 89.5414 76.7446 90.3897 75.232C91.2381 73.7193 92.2775 72.2531 93.44 70.9545C94.5798 69.6963 95.807 68.6809 97.1281 67.9044L97.1217 67.9082Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M183.029 150.581L169.532 158.514L123.369 131.383V140.201L169.532 167.332L183.029 159.399V150.581Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"15.6044\" height=\"8.74496\" transform=\"matrix(0.862126 -0.506694 0 1 169.566 158.535)\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M136.867 123.45L183.029 150.581L169.532 158.514L123.369 131.383L136.867 123.45Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M230.461 178.504L216.963 186.437L170.801 159.306V168.124L216.963 195.255L230.461 187.322V178.504Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"15.6044\" height=\"8.74496\" transform=\"matrix(0.862126 -0.506694 0 1 216.998 186.458)\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M184.297 151.373L230.459 178.504L216.961 186.437L170.799 159.306L184.297 151.373Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"28.8755\" transform=\"matrix(0.862126 0.506694 -0.862126 0.506694 412.211 61.1362)\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"11.1196\" transform=\"matrix(0.862126 0.506694 0 1 387.316 75.7671)\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"28.8755\" height=\"11.1196\" transform=\"matrix(0.862126 -0.506694 0 1 458.514 117.612)\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"28.8755\" transform=\"matrix(0.862126 0.506694 -0.862126 0.506694 386.205 76.4194)\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"11.1196\" transform=\"matrix(0.862126 0.506694 0 1 361.311 91.0503)\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"28.8755\" height=\"11.1196\" transform=\"matrix(0.862126 -0.506694 0 1 432.508 132.895)\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"28.8755\" transform=\"matrix(0.862126 0.506694 -0.862126 0.506694 360.201 91.7046)\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"11.1196\" transform=\"matrix(0.862126 0.506694 0 1 335.307 106.335)\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"28.8755\" height=\"11.1196\" transform=\"matrix(0.862126 -0.506694 0 1 406.506 148.18)\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M317.406 152.137L330.904 160.07L377.066 132.939V141.757L330.904 168.888L317.406 160.955V152.137Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"15.6044\" height=\"8.74496\" transform=\"matrix(-0.862126 -0.506694 0 1 330.869 160.09)\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M363.569 125.005L317.406 152.136L330.904 160.069L377.066 132.938L363.569 125.005Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M269.971 180.06L283.468 187.993L329.631 160.862V169.68L283.468 196.811L269.971 188.878V180.06Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"15.6044\" height=\"8.74496\" transform=\"matrix(-0.862126 -0.506694 0 1 283.434 188.014)\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M316.133 152.929L269.971 180.06L283.468 187.993L329.631 160.862L316.133 152.929Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M275.486 279.044C275.711 274.805 273.01 270.523 267.384 267.287C256.565 261.064 239.024 261.064 228.205 267.287C223.012 270.274 220.311 274.152 220.104 278.066V290.085C220.311 286.171 223.012 282.293 228.205 279.306C239.024 273.083 256.565 273.083 267.384 279.306C273.01 282.542 275.711 286.824 275.486 291.063V279.044Z\" fill=\"#D4D9DE\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M229.512 267.738C239.61 261.93 255.981 261.93 266.079 267.738V279.757C255.981 273.949 239.61 273.949 229.512 279.757V267.738Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M266.082 267.738C270.929 270.526 273.449 274.146 273.643 277.798V289.817C273.449 286.165 270.929 282.545 266.082 279.757V267.738Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M273.643 277.798C273.853 281.755 271.333 285.751 266.082 288.772V300.791C271.333 297.77 273.853 293.774 273.643 289.817V277.798Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M266.079 288.771C255.981 294.579 239.61 294.579 229.512 288.771V300.79C239.61 306.598 255.981 306.598 266.079 300.79V288.771Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M221.954 278.712C221.743 274.755 224.264 270.759 229.515 267.738V279.757C224.264 282.777 221.743 286.774 221.954 290.731V278.712Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M229.512 288.771C224.665 285.983 222.145 282.364 221.951 278.711V290.73C222.145 294.383 224.665 298.002 229.512 300.79V288.771Z\" fill=\"var(--c8y-brand-40)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M220.099 277.464C219.874 281.704 222.574 285.985 228.2 289.221C239.019 295.444 256.56 295.445 267.38 289.221C272.573 286.234 275.273 282.356 275.481 278.443V290.462C275.273 294.375 272.573 298.253 267.38 301.24C256.56 307.463 239.019 307.463 228.2 301.24C222.574 298.004 219.874 293.723 220.099 289.483V277.464Z\" fill=\"#D4D9DE\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M300.031 277.954L247.792 247.906L195.553 277.954V289.973L247.792 259.925L300.031 289.973V277.954Z\" fill=\"#D4D9DE\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M195.553 278.314L247.792 308.362L300.031 278.314V290.333L247.792 320.381L195.553 290.333V278.314Z\" fill=\"var(--c8y-palette-gray-10)\" fill-opacity=\"0.8\" stroke=\"#212121\" stroke-opacity=\"0.8\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M247.836 308.122L300.075 278.074V290.093L247.836 320.141V308.122Z\" fill=\"var(--c8y-palette-gray-10)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M300.031 277.953L247.792 247.906L195.553 277.953L247.792 308.001L300.031 277.953ZM267.381 266.685C256.562 260.462 239.021 260.462 228.202 266.685C217.383 272.908 217.383 282.998 228.202 289.221C239.021 295.444 256.562 295.444 267.381 289.221C278.201 282.998 278.201 272.908 267.381 266.685Z\" fill=\"#212121\" stroke=\"black\" stroke-opacity=\"0.8\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M229.511 267.737C239.609 261.929 255.98 261.929 266.078 267.737C276.176 273.546 276.176 282.962 266.078 288.771C255.98 294.579 239.609 294.579 229.511 288.771C219.413 282.962 219.413 273.546 229.511 267.737Z\" fill=\"var(--c8y-brand-60)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M254.234 281.447C251.072 283.265 245.949 283.265 242.789 281.447C239.628 279.629 239.627 276.682 242.789 274.864C245.949 273.046 251.073 273.046 254.234 274.864C257.395 276.682 257.394 279.629 254.234 281.447ZM257.667 270.067L255.084 271.378C254.141 271.074 253.149 270.842 252.13 270.682L251.978 268.713C251.977 268.174 251.22 267.738 250.283 267.738L246.74 267.738C245.803 267.738 245.045 268.174 245.045 268.713L244.892 270.682C243.874 270.842 242.881 271.074 241.939 271.378L239.355 270.068C238.69 269.685 237.622 269.685 236.957 270.068L234.45 271.51C233.786 271.892 233.785 272.507 234.45 272.889L236.729 274.375C236.2 274.917 235.797 275.488 235.519 276.073L232.096 276.162C231.158 276.162 230.401 276.597 230.401 277.137L230.401 279.174C230.401 279.713 231.159 280.149 232.096 280.149L235.518 280.237C235.796 280.823 236.2 281.393 236.728 281.936L234.451 283.422C233.786 283.804 233.785 284.418 234.45 284.801L236.957 286.243C237.622 286.625 238.69 286.625 239.355 286.243L241.938 284.933C242.881 285.236 243.874 285.469 244.893 285.629L245.045 287.597C245.045 288.136 245.803 288.572 246.74 288.572L250.282 288.572C251.22 288.572 251.977 288.137 251.977 287.597L252.131 285.628C253.149 285.469 254.142 285.237 255.084 284.933L257.667 286.243C258.332 286.626 259.401 286.625 260.065 286.243L262.572 284.801C263.237 284.419 263.237 283.804 262.572 283.422L260.294 281.936C260.823 281.393 261.226 280.823 261.504 280.237L264.927 280.149C265.864 280.149 266.622 279.713 266.622 279.174L266.622 277.136C266.622 276.597 265.864 276.162 264.927 276.161L261.504 276.074C261.227 275.488 260.823 274.917 260.294 274.375L262.572 272.889C263.236 272.506 263.237 271.892 262.572 271.509L260.065 270.067C259.4 269.685 258.332 269.685 257.667 270.067ZM244.969 276.118C246.925 274.993 250.097 274.992 252.054 276.118C254.01 277.243 254.01 279.068 252.054 280.193C250.097 281.318 246.925 281.318 244.969 280.193C243.013 279.068 243.013 277.243 244.969 276.118ZM246.462 276.976C245.331 277.628 245.33 278.683 246.462 279.334C247.594 279.985 249.429 279.985 250.561 279.334C251.692 278.683 251.692 277.628 250.561 276.977C249.429 276.326 247.594 276.326 246.462 276.976Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-opacity=\"0.8\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M271.79 266.809C271.985 263.135 269.645 259.424 264.769 256.62C255.393 251.226 240.19 251.226 230.814 256.62C226.125 259.316 223.781 262.851 223.781 266.385V278.404C223.781 274.87 226.125 271.335 230.814 268.639C240.19 263.245 255.393 263.245 264.769 268.639C269.645 271.443 271.985 275.154 271.79 278.828V266.809Z\" fill=\"#D4D9DE\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M269.944 265.693C270.124 269.085 267.964 272.51 263.463 275.099V287.118C267.964 284.529 270.124 281.104 269.944 277.712V265.693Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M263.461 275.1C254.805 280.078 240.772 280.078 232.117 275.1V287.119C240.772 292.097 254.805 292.097 263.461 287.119V275.1Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M225.631 266.085C225.631 262.822 227.795 259.56 232.122 257.071V257.071C240.778 252.092 254.81 252.092 263.466 257.071V257.071C267.62 259.46 269.781 262.563 269.947 265.693V277.712C269.781 274.582 267.62 271.479 263.466 269.09V269.09C254.81 264.111 240.778 264.111 232.122 269.09V269.09C227.795 271.579 225.631 274.841 225.631 278.104V266.085Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M232.122 275.1C227.795 272.61 225.631 269.348 225.631 266.085V278.104C225.631 281.367 227.795 284.629 232.122 287.119V275.1Z\" fill=\"var(--c8y-brand-40)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M300.031 266.383L247.792 236.335L195.553 266.383V278.402L247.792 248.354L300.031 278.402V266.383Z\" fill=\"#D4D9DE\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M223.781 266.382C223.781 269.917 226.125 273.451 230.814 276.148C240.19 281.541 255.393 281.541 264.769 276.148C269.27 273.559 271.61 270.198 271.79 266.806V278.825C271.61 282.217 269.27 285.578 264.769 288.167C255.393 293.56 240.19 293.56 230.814 288.167C226.125 285.47 223.781 281.936 223.781 278.401V266.382Z\" fill=\"#D4D9DE\" fill-opacity=\"0.6\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M195.553 266.382L247.792 296.43L300.031 266.382V278.401L247.792 308.449L195.553 278.401V266.382Z\" fill=\"#8B96A0\" fill-opacity=\"0.8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path opacity=\"0.6\" fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M247.428 296.431L299.667 266.383V278.402L247.428 308.45V296.431Z\" fill=\"#212121\" fill-opacity=\"0.8\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M300.031 266.385L247.792 236.337L195.553 266.385L247.792 296.432L300.031 266.385ZM264.769 256.619C255.393 251.226 240.191 251.226 230.814 256.619C221.438 262.013 221.438 270.757 230.814 276.15C240.191 281.544 255.393 281.544 264.769 276.15C274.146 270.757 274.146 262.013 264.769 256.619Z\" fill=\"#E3E5E8\" fill-opacity=\"0.8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M232.124 257.07C240.779 252.091 254.812 252.091 263.468 257.07V257.07C272.123 262.048 272.123 270.12 263.468 275.098V275.098C254.812 280.077 240.779 280.077 232.124 275.098V275.098C223.469 270.12 223.469 262.048 232.124 257.07V257.07Z\" fill=\"var(--c8y-brand-60)\"/>\n        <path d=\"M257.965 270.166C257.412 270.554 256.857 270.911 256.349 271.203C253.371 272.916 248.485 274.72 247.078 273.911L245.298 272.887C248.317 272.498 251.364 271.185 253.84 269.761C254.136 269.591 254.429 269.415 254.714 269.237C254.1 268.944 253.565 268.613 253.064 268.159C252.731 268.377 252.404 268.579 252.095 268.757C249.117 270.47 244.232 272.274 242.826 271.465L240.762 270.278C243.779 269.889 246.828 268.577 249.305 267.152C250.196 266.639 251.057 266.084 251.83 265.503C251.955 263.658 253.933 262.091 256.78 261.42L249.676 257.333C246.742 255.646 240.663 258.138 237.148 260.16C233.461 262.281 229.288 265.686 232.22 267.373L245.553 275.042C248.487 276.729 254.779 274.114 258.094 272.207C259.038 271.665 260.078 270.98 261.021 270.242C260.005 270.329 258.967 270.304 257.965 270.166ZM238.894 261.164C242.069 259.337 246.662 257.608 247.929 258.337C249.309 259.131 245.535 262.084 243.015 263.534C240.038 265.247 235.236 267.1 233.966 266.369C232.583 265.574 236.105 262.768 238.894 261.164ZM236.219 267.665C239.238 267.276 242.284 265.963 244.761 264.539C247.23 263.118 249.507 261.369 250.183 259.633L252.253 260.824C253.783 261.704 250.056 264.712 247.559 266.148C244.568 267.867 239.692 269.662 238.288 268.855L236.219 267.665Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path d=\"M255.916 263.434C258.083 262.188 261.601 262.187 263.77 263.434C265.939 264.682 265.937 266.706 263.77 267.952C261.603 269.199 258.084 269.2 255.916 267.952C253.747 266.705 253.749 264.681 255.916 263.434ZM258.56 263.764L257.692 264.657L259.061 266.916L260.167 265.806L261.361 267.675L260.755 263.875L259.441 265.19L258.56 263.764Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M268.102 254.586C268.267 251.477 266.286 248.337 262.161 245.964C254.227 241.401 241.363 241.401 233.429 245.964C229.621 248.155 227.641 250.998 227.488 253.868V265.887C227.641 263.017 229.621 260.174 233.429 257.983C241.363 253.42 254.227 253.42 262.161 257.983C266.286 260.356 268.267 263.496 268.102 266.605V254.586Z\" fill=\"#D4D9DE\" fill-opacity=\"0.8\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M266.187 254.002C266.187 256.721 264.384 259.439 260.777 261.514V273.533C264.384 271.458 266.187 268.74 266.187 266.021V254.002Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M260.778 261.514C253.565 265.662 241.871 265.662 234.658 261.514V273.533C241.871 277.681 253.565 277.681 260.778 273.533V261.514Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M229.25 254.002C229.25 251.283 231.053 248.564 234.66 246.49V246.49C241.872 242.341 253.566 242.341 260.779 246.49V246.49C264.385 248.564 266.189 251.283 266.189 254.002V266.021C266.189 263.302 264.385 260.583 260.779 258.509V258.509C253.566 254.36 241.872 254.36 234.66 258.509V258.509C231.053 260.583 229.25 263.302 229.25 266.021V254.002Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M234.66 261.514C231.053 259.439 229.25 256.721 229.25 254.002V266.021C229.25 268.74 231.053 271.458 234.66 273.533V261.514Z\" fill=\"var(--c8y-brand-40)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M300.031 254.229L247.792 224.181L195.553 254.229V266.248L247.792 236.2L300.031 266.248V254.229Z\" fill=\"#D4D9DE\" fill-opacity=\"0.8\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M195.553 254.229L247.792 284.276L300.031 254.229V266.247L247.792 296.295L195.553 266.247V254.229Z\" fill=\"#8B96A0\" fill-opacity=\"0.6\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path opacity=\"0.6\" fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M247.428 284.276L299.667 254.229V266.248L247.428 296.295V284.276Z\" fill=\"#212121\" fill-opacity=\"0.6\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M227.488 253.869C227.323 256.978 229.303 260.117 233.429 262.491C241.363 267.054 254.227 267.054 262.16 262.491C265.969 260.3 267.949 257.456 268.101 254.586V266.605C267.949 269.475 265.969 272.319 262.16 274.509C254.227 279.073 241.363 279.073 233.429 274.509C229.303 272.136 227.323 268.997 227.488 265.888V253.869Z\" fill=\"#D4D9DE\" fill-opacity=\"0.8\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M300.031 254.229L247.792 224.181L195.553 254.229L247.792 284.276L300.031 254.229ZM262.158 245.966C254.224 241.402 241.36 241.402 233.426 245.966C225.492 250.529 225.492 257.928 233.426 262.492C241.36 267.055 254.224 267.055 262.158 262.492C270.091 257.928 270.091 250.529 262.158 245.966Z\" fill=\"#E3E5E8\" fill-opacity=\"0.6\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M234.66 246.492C241.872 242.343 253.566 242.343 260.779 246.492V246.492C267.992 250.641 267.992 257.367 260.779 261.516V261.516C253.566 265.664 241.872 265.664 234.66 261.516V261.516C227.447 257.367 227.447 250.641 234.66 246.492V246.492Z\" fill=\"var(--c8y-brand-60)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M249.266 247.358L250.755 246.502L254.922 248.899L250.717 251.317L246.55 248.921L248.039 248.064L245.265 246.47L246.495 245.763L249.266 247.358ZM243.482 250.685L244.971 249.829L249.138 252.226L244.933 254.644L240.766 252.248L242.255 251.391L239.481 249.797L240.711 249.09L243.482 250.685ZM237.698 254.012L239.187 253.155L243.354 255.553L239.149 257.97L234.982 255.574L236.471 254.717L233.697 253.124L234.927 252.417L237.698 254.012Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M254.237 251.68L253.601 251.314L254.915 250.558L255.551 250.924L254.237 251.68ZM252.39 251.324L253.624 252.033L252.791 252.511L256.874 254.86L258.363 254.004L261.037 255.543L262.266 254.836L259.592 253.298L261.081 252.441L256.998 250.093L256.165 250.572L254.931 249.862L252.39 251.324ZM248.454 255.007L247.818 254.64L249.132 253.885L249.768 254.251L248.454 255.007ZM246.606 254.65L247.84 255.359L247.008 255.838L251.091 258.187L252.58 257.331L255.254 258.869L256.482 258.163L253.808 256.624L255.297 255.768L251.214 253.42L250.381 253.898L249.147 253.188L246.606 254.65ZM242.67 258.333L242.034 257.967L243.348 257.212L243.984 257.578L242.67 258.333ZM240.823 257.977L242.057 258.686L241.224 259.165L245.307 261.514L246.796 260.657L249.47 262.196L250.699 261.49L248.025 259.951L249.514 259.095L245.431 256.746L244.598 257.225L243.364 256.515L240.823 257.977Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M264.417 195.046C264.417 192.599 262.794 190.153 259.548 188.286C253.057 184.552 242.532 184.552 236.04 188.286C232.925 190.078 231.304 192.405 231.18 194.753V206.772C231.304 204.424 232.925 202.097 236.04 200.305C242.532 196.571 253.057 196.571 259.548 200.305C262.794 202.172 264.417 204.618 264.417 207.065V195.046Z\" fill=\"#D4D9DE\" fill-opacity=\"0.6\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M262.563 194.334C262.683 196.596 261.243 198.879 258.242 200.605V212.624C261.243 210.898 262.683 208.615 262.563 206.353V194.334Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M258.241 200.606C252.471 203.925 243.116 203.925 237.346 200.606V212.625C243.116 215.944 252.471 215.944 258.241 212.625V200.606Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M233.02 194.595C233.02 192.42 234.462 190.245 237.347 188.586V188.586C243.117 185.267 252.473 185.267 258.243 188.586V188.586C261.012 190.179 262.453 192.247 262.563 194.334V206.353C262.453 204.266 261.012 202.198 258.243 200.605V200.605C252.473 197.286 243.117 197.286 237.347 200.605V200.605C234.462 202.264 233.02 204.439 233.02 206.614V194.595Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M237.347 200.606C234.462 198.946 233.02 196.771 233.02 194.596V206.615C233.02 208.79 234.462 210.965 237.347 212.625V200.606Z\" fill=\"var(--c8y-brand-40)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M300.029 195.045L247.79 164.998L195.551 195.045V207.064L247.79 177.017L300.029 207.064V195.045Z\" fill=\"#D4D9DE\" fill-opacity=\"0.6\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M195.551 195.045L247.79 225.093L300.029 195.045V207.064L247.79 237.112L195.551 207.064V195.045Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path opacity=\"0.6\" fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M247.426 225.093L299.665 195.045V207.064L247.426 237.112V225.093Z\" fill=\"#212121\" fill-opacity=\"0.4\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M231.176 194.752C231.041 197.296 232.661 199.865 236.037 201.807C242.528 205.541 253.053 205.541 259.544 201.807C262.79 199.94 264.413 197.493 264.413 195.046V207.065C264.413 209.512 262.79 211.959 259.544 213.826C253.053 217.559 242.528 217.559 236.037 213.826C232.661 211.884 231.041 209.315 231.176 206.771V194.752Z\" fill=\"#D4D9DE\" fill-opacity=\"0.8\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M300.029 195.045L247.79 164.998L195.551 195.045L247.79 225.093L300.029 195.045ZM259.544 188.285C253.052 184.551 242.527 184.551 236.036 188.285C229.545 192.019 229.545 198.072 236.036 201.806C242.527 205.54 253.052 205.54 259.544 201.806C266.035 198.072 266.035 192.019 259.544 188.285Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M237.345 188.586C243.115 185.267 252.471 185.267 258.241 188.586V188.586C264.011 191.905 264.011 197.286 258.241 200.605V200.605C252.471 203.924 243.115 203.924 237.345 200.605V200.605C231.575 197.286 231.575 191.905 237.345 188.586V188.586Z\" fill=\"var(--c8y-brand-60)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M241.841 198.505C245.268 200.476 250.843 200.476 254.27 198.505C257.696 196.534 257.696 193.328 254.27 191.357C250.843 189.386 245.268 189.386 241.841 191.357C238.415 193.328 238.415 196.534 241.841 198.505ZM242.877 197.91C240.021 196.267 240.021 193.595 242.877 191.952C245.733 190.31 250.379 190.31 253.234 191.952C256.09 193.595 256.09 196.267 253.234 197.91C250.379 199.552 245.733 199.552 242.877 197.91Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M242.31 196.134L244.142 195.717C244.239 195.897 244.369 196.072 244.532 196.237L242.7 196.655C242.548 196.488 242.417 196.313 242.31 196.134ZM250.052 191.608C250.363 191.667 250.669 191.739 250.963 191.824L250.266 192.885C249.976 192.794 249.671 192.721 249.354 192.669L250.052 191.608ZM247.685 191.428C248.007 191.418 248.333 191.422 248.656 191.44L248.697 192.589C248.374 192.565 248.048 192.561 247.726 192.578L247.685 191.428ZM241.966 194.718L243.964 194.741C243.935 194.927 243.941 195.114 243.984 195.3L241.986 195.277C241.955 195.091 241.949 194.903 241.966 194.718ZM242.572 193.368L244.438 193.826C244.287 193.988 244.17 194.16 244.088 194.338L242.223 193.882C242.316 193.705 242.433 193.533 242.572 193.368ZM245.316 191.783C245.601 191.703 245.9 191.634 246.206 191.58L247.009 192.652C246.698 192.7 246.399 192.768 246.119 192.855L245.316 191.783ZM243.724 192.44C243.834 192.376 243.951 192.314 244.073 192.254L245.515 193.083C245.391 193.14 245.271 193.201 245.159 193.265C245.048 193.329 244.942 193.398 244.842 193.47L243.401 192.641C243.506 192.571 243.614 192.503 243.724 192.44Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M248.435 196.533C249.107 196.92 250.196 196.919 250.869 196.533C251.541 196.146 251.542 195.519 250.87 195.132C250.411 194.868 249.758 194.785 249.175 194.881L245.83 193.634L247.998 195.559C247.831 195.894 247.976 196.269 248.435 196.533Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M326.16 236.114L312.662 244.047L266.5 216.916V225.734L312.662 252.865L326.16 244.932V236.114Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"15.6044\" height=\"8.74496\" transform=\"matrix(0.862126 -0.506694 0 1 312.697 244.068)\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M279.998 208.982L326.16 236.113L312.662 244.046L266.5 216.915L279.998 208.982Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M373.598 264.037L360.1 271.97L313.938 244.839V253.657L360.1 280.788L373.598 272.855V264.037Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"15.6044\" height=\"8.74496\" transform=\"matrix(0.862126 -0.506694 0 1 360.135 271.991)\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M327.435 236.905L373.598 264.036L360.1 271.969L313.938 244.838L327.435 236.905Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"28.8755\" transform=\"matrix(0.862126 0.506694 -0.862126 0.506694 405.285 242.196)\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"11.1196\" transform=\"matrix(0.862126 0.506694 0 1 380.391 256.827)\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"28.8755\" height=\"11.1196\" transform=\"matrix(0.862126 -0.506694 0 1 451.588 298.672)\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"28.8755\" transform=\"matrix(0.862126 0.506694 -0.862126 0.506694 379.279 257.48)\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"11.1196\" transform=\"matrix(0.862126 0.506694 0 1 354.385 272.111)\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"28.8755\" height=\"11.1196\" transform=\"matrix(0.862126 -0.506694 0 1 425.582 313.956)\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"28.8755\" transform=\"matrix(0.862126 0.506694 -0.862126 0.506694 353.275 272.765)\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"82.5838\" height=\"11.1196\" transform=\"matrix(0.862126 0.506694 0 1 328.381 287.396)\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <rect width=\"28.8755\" height=\"11.1196\" transform=\"matrix(0.862126 -0.506694 0 1 399.58 329.24)\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M385.395 227.124L382.77 236.325L379.521 234.415L382.145 225.214L385.395 227.124Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M380.707 218.974L372.201 233.971L368.951 232.061L377.457 217.064L380.707 218.974Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M372.201 233.971L375.621 241.95L372.371 240.04L368.951 232.062L372.201 233.971Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M378.636 238.755L376.02 232.634L380.707 224.369L385.395 227.124L382.771 236.325L385.785 235.976L389.205 223.977L380.707 218.973L372.201 233.971L375.622 241.949L378.636 238.755Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M394.1 205.756L386.341 219.419L381.143 216.368L388.902 202.705L394.1 205.756Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M383.402 217.693L391.16 204.03L385.963 200.979L378.204 214.642L383.402 217.693Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path d=\"M391.159 204.03L394.1 205.756L386.341 219.419L383.401 217.693L391.159 204.03Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M380.443 225.67C379.746 225.309 379.312 224.473 379.312 223.262C379.312 220.934 380.92 218.102 382.903 216.938C383.855 216.379 384.721 216.306 385.363 216.638L379.378 213.125C378.735 212.792 377.87 212.865 376.917 213.424C374.934 214.588 373.326 217.42 373.326 219.749C373.326 220.959 373.761 221.796 374.457 222.156L380.443 225.67Z\" fill=\"url(#paint6_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path d=\"M382.903 225.37C380.919 226.535 379.312 225.591 379.312 223.262C379.312 220.934 380.919 218.102 382.903 216.938C384.886 215.773 386.494 216.717 386.494 219.046C386.494 221.374 384.886 224.206 382.903 225.37Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M402.358 255.791L423.906 217.844L411.935 210.816L390.387 248.763L402.358 255.791Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path d=\"M433.484 223.466L411.936 261.413L402.36 255.791L423.908 217.844L433.484 223.466Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M395.474 297.252L431.387 276.17V284.603L395.474 305.684V297.252Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M359.559 276.17L395.473 297.252V305.684L359.559 284.603V276.17Z\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path d=\"M395.474 255.088L359.56 276.17L395.474 297.252L431.387 276.17L395.474 255.088Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M379.775 270.895C379.668 273.331 381.206 275.796 384.385 277.664C390.499 281.258 400.365 281.285 406.421 277.726C409.328 276.017 410.829 273.793 410.928 271.544V276.455C410.829 278.703 409.328 280.928 406.421 282.636C400.365 286.195 390.499 286.168 384.385 282.575C381.206 280.706 379.668 278.241 379.775 275.805V270.895Z\" fill=\"url(#paint7_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M384.282 264.713C378.226 268.273 378.272 274.071 384.386 277.664C390.5 281.257 400.366 281.285 406.422 277.726C412.478 274.166 412.431 268.368 406.317 264.775C400.204 261.181 390.338 261.154 384.282 264.713Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M384.044 268.079C383.965 269.867 385.095 271.676 387.428 273.048C391.916 275.685 399.157 275.705 403.602 273.093C405.736 271.839 406.838 270.206 406.91 268.556V272.16C406.838 273.81 405.736 275.443 403.602 276.697C399.157 279.31 391.916 279.289 387.428 276.652C385.095 275.281 383.965 273.471 384.044 271.683V268.079Z\" fill=\"url(#paint8_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M387.35 263.542C382.905 266.154 382.939 270.41 387.426 273.047C391.914 275.685 399.155 275.705 403.601 273.093C408.046 270.48 408.011 266.224 403.524 263.587C399.036 260.949 391.795 260.929 387.35 263.542Z\" fill=\"var(--c8y-brand-60)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M410.646 250.543C412.367 251.433 413.441 253.501 413.441 256.494C413.441 262.25 409.467 269.249 404.565 272.127C402.211 273.508 400.072 273.689 398.483 272.867L380.73 262.445C382.318 263.267 384.458 263.086 386.811 261.705C391.713 258.827 395.688 251.828 395.688 246.072C395.688 243.079 394.613 241.012 392.892 240.121L410.646 250.543Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M398.484 272.867C396.763 271.976 395.688 269.909 395.688 266.916C395.688 261.16 399.663 254.161 404.565 251.283C406.918 249.901 409.058 249.721 410.646 250.543L392.893 240.121C391.304 239.299 389.165 239.48 386.811 240.861C381.909 243.739 377.935 250.738 377.935 256.494C377.935 259.487 379.009 261.554 380.73 262.445L398.484 272.867Z\" fill=\"url(#paint9_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M404.565 272.126C399.662 275.004 395.688 272.671 395.688 266.915C395.688 261.159 399.662 254.16 404.565 251.282C409.467 248.405 413.441 250.738 413.441 256.493C413.441 262.249 409.467 269.248 404.565 272.126ZM404.565 267.784C401.705 269.462 399.386 268.102 399.386 264.744C399.386 261.386 401.705 257.304 404.565 255.625C407.424 253.946 409.743 255.307 409.743 258.665C409.743 262.022 407.424 266.105 404.565 267.784Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M408.523 259.759C408.054 259.455 407.388 259.479 406.65 259.905C405.229 260.722 404.077 262.711 404.077 264.346C404.077 265.164 404.365 265.739 404.831 266.006L403.279 265.109C402.814 264.841 402.526 264.266 402.526 263.449C402.526 261.813 403.678 259.825 405.098 259.007C405.837 258.582 406.503 258.557 406.972 258.861L408.523 259.759Z\" fill=\"url(#paint10_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path d=\"M404.076 264.346C404.076 265.982 405.228 266.644 406.649 265.827C408.069 265.009 409.221 263.02 409.221 261.385C409.221 259.75 408.069 259.087 406.649 259.904C405.228 260.722 404.076 262.711 404.076 264.346Z\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M434.838 211.303C433.538 210.54 431.742 210.65 429.759 211.814C425.792 214.143 422.576 219.806 422.576 224.463C422.576 226.792 423.38 228.428 424.68 229.191L410.315 220.759C409.015 219.996 408.211 218.359 408.211 216.031C408.211 211.373 411.427 205.71 415.394 203.382C417.377 202.217 419.173 202.107 420.473 202.87L434.838 211.303Z\" fill=\"url(#paint11_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path d=\"M422.576 224.463C422.576 229.121 425.792 231.008 429.759 228.68C433.726 226.351 436.941 220.688 436.941 216.031C436.941 211.373 433.726 209.486 429.759 211.814C425.792 214.143 422.576 219.806 422.576 224.463Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M433.357 218.021C432.888 217.717 432.222 217.742 431.484 218.167C430.063 218.984 428.911 220.973 428.911 222.608C428.911 223.426 429.199 224.001 429.665 224.269L428.113 223.371C427.648 223.103 427.36 222.528 427.36 221.711C427.36 220.075 428.512 218.087 429.932 217.269C430.671 216.844 431.337 216.819 431.806 217.123L433.357 218.021Z\" fill=\"url(#paint12_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path d=\"M428.91 222.608C428.91 224.244 430.062 224.907 431.482 224.089C432.903 223.271 434.055 221.283 434.055 219.647C434.055 218.012 432.903 217.349 431.482 218.167C430.062 218.984 428.91 220.973 428.91 222.608Z\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path d=\"M406.015 199.573L427.264 212.047L421.877 221.533L400.628 209.06L406.015 199.573Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M405.115 192.329C403.815 191.566 402.02 191.676 400.036 192.841C396.069 195.169 392.854 200.833 392.854 205.49C392.854 207.818 393.658 209.455 394.957 210.218L380.592 201.785C379.292 201.022 378.488 199.386 378.488 197.057C378.488 192.4 381.704 186.737 385.671 184.408C387.654 183.244 389.45 183.134 390.75 183.897L405.115 192.329Z\" fill=\"url(#paint13_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path d=\"M392.853 205.49C392.853 210.147 396.069 212.035 400.036 209.706C404.003 207.377 407.219 201.714 407.219 197.057C407.219 192.4 404.003 190.512 400.036 192.841C396.069 195.169 392.853 200.832 392.853 205.49Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M403.326 199.209C402.857 198.905 402.191 198.93 401.452 199.355C400.032 200.173 398.88 202.162 398.88 203.797C398.88 204.615 399.168 205.189 399.634 205.457L398.082 204.559C397.617 204.292 397.329 203.717 397.329 202.899C397.329 201.264 398.48 199.275 399.901 198.458C400.64 198.032 401.306 198.008 401.775 198.312L403.326 199.209Z\" fill=\"url(#paint14_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path d=\"M398.879 203.797C398.879 205.432 400.031 206.095 401.451 205.277C402.872 204.46 404.023 202.471 404.023 200.836C404.023 199.2 402.872 198.537 401.451 199.355C400.031 200.173 398.879 202.161 398.879 203.797Z\" fill=\"var(--c8y-brand-40)\" stroke=\"#212121\" stroke-width=\"0.75\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M501.8 203.577L475.767 244.131L470.766 241.191L496.799 200.638L501.8 203.577Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M475.767 244.13L449.394 259.63L444.393 256.691L470.766 241.191L475.767 244.13Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M449.394 259.631L429.901 300.81L424.9 297.871L444.392 256.691L449.394 259.631Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M429.901 300.81L422.808 269.125L417.807 266.186L424.9 297.871L429.901 300.81Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M422.807 269.125L414.263 310.134L409.262 307.195L417.806 266.186L422.807 269.125Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M414.265 310.134L405.966 300.075L400.965 297.135L409.264 307.195L414.265 310.134Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M405.965 300.075L400.017 316.259L395.016 313.32L400.964 297.135L405.965 300.075Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M400.017 316.259L398.265 316.154L393.264 313.215L395.016 313.32L400.017 316.259Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M398.265 316.154L405.82 295.598L400.818 292.659L393.264 313.215L398.265 316.154Z\" fill=\"url(#paint15_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M405.819 295.598L413.524 304.937L408.523 301.998L400.818 292.659L405.819 295.598Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M413.525 304.937L421.933 264.579L416.932 261.64L408.523 301.998L413.525 304.937Z\" fill=\"url(#paint16_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M421.933 264.579L423.87 263.49L418.869 260.55L416.932 261.639L421.933 264.579Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M430.895 294.862L448.411 257.857L443.41 254.918L427.625 288.045L430.895 294.862Z\" fill=\"url(#paint17_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M448.409 257.858L475.048 242.201L470.047 239.262L443.408 254.918L448.409 257.858Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M475.048 242.201L500.527 202.512L495.525 199.573L470.047 239.262L475.048 242.201Z\" fill=\"url(#paint18_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M501.799 203.577L475.766 244.13L449.392 259.63L429.9 300.81L422.807 269.125L414.263 310.134L405.964 300.074L400.016 316.259L398.264 316.154L405.818 295.598L413.523 304.937L421.932 264.579L423.869 263.489L430.893 294.862L448.409 257.857L475.047 242.201L500.526 202.512L501.799 203.577Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M421.576 269.496C421.091 269.245 420.788 268.662 420.788 267.818C420.788 266.195 421.908 264.221 423.289 263.409C423.952 263.019 424.554 262.968 425.002 263.2L420.001 260.261C419.553 260.029 418.951 260.08 418.288 260.47C416.907 261.281 415.787 263.255 415.787 264.879C415.787 265.723 416.09 266.306 416.575 266.557L421.576 269.496Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M425.788 264.878C425.788 266.502 424.669 268.476 423.288 269.287C421.907 270.099 420.787 269.441 420.787 267.818C420.787 266.194 421.907 264.22 423.288 263.409C424.669 262.597 425.788 263.255 425.788 264.878Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M433.491 296.035C433.491 297.658 432.372 299.632 430.991 300.443C429.61 301.255 428.49 300.597 428.49 298.974C428.49 297.351 429.61 295.377 430.991 294.565C432.372 293.753 433.491 294.411 433.491 296.035Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M404.25 300.653C403.765 300.401 403.462 299.818 403.462 298.974C403.462 297.351 404.582 295.377 405.963 294.565C406.625 294.176 407.228 294.125 407.676 294.357L402.675 291.417C402.227 291.185 401.624 291.236 400.961 291.626C399.58 292.438 398.461 294.412 398.461 296.035C398.461 296.879 398.764 297.462 399.248 297.713L404.25 300.653Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M408.462 296.035C408.462 297.658 407.342 299.632 405.961 300.443C404.58 301.255 403.461 300.597 403.461 298.974C403.461 297.351 404.58 295.377 405.961 294.565C407.342 293.753 408.462 294.411 408.462 296.035Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M416.165 306.028C416.165 307.652 415.046 309.625 413.665 310.437C412.284 311.249 411.164 310.591 411.164 308.967C411.164 307.344 412.284 305.37 413.665 304.559C415.046 303.747 416.165 304.405 416.165 306.028Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M446.982 261.854C446.497 261.603 446.194 261.02 446.194 260.176C446.194 258.553 447.314 256.579 448.695 255.767C449.358 255.377 449.961 255.326 450.408 255.558L445.407 252.619C444.959 252.387 444.357 252.438 443.694 252.828C442.313 253.639 441.193 255.613 441.193 257.237C441.193 258.081 441.496 258.664 441.981 258.915L446.982 261.854Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M451.196 257.236C451.196 258.86 450.077 260.833 448.696 261.645C447.315 262.457 446.195 261.799 446.195 260.176C446.195 258.552 447.315 256.578 448.696 255.767C450.077 254.955 451.196 255.613 451.196 257.236Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M472.392 245.982C471.907 245.731 471.605 245.148 471.605 244.304C471.605 242.68 472.724 240.706 474.105 239.895C474.768 239.505 475.371 239.454 475.818 239.686L470.817 236.747C470.37 236.515 469.767 236.566 469.104 236.956C467.723 237.767 466.604 239.741 466.604 241.364C466.604 242.209 466.906 242.792 467.391 243.043L472.392 245.982Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M476.605 241.364C476.605 242.987 475.485 244.961 474.104 245.773C472.723 246.585 471.604 245.927 471.604 244.303C471.604 242.68 472.723 240.706 474.104 239.895C475.485 239.083 476.605 239.741 476.605 241.364Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M498.38 207.183C497.896 206.932 497.593 206.349 497.593 205.505C497.593 203.882 498.712 201.908 500.093 201.096C500.756 200.706 501.359 200.655 501.806 200.887L496.805 197.948C496.358 197.716 495.755 197.767 495.092 198.157C493.711 198.968 492.592 200.942 492.592 202.566C492.592 203.41 492.895 203.993 493.379 204.244L498.38 207.183Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M502.593 202.565C502.593 204.189 501.473 206.163 500.092 206.974C498.711 207.786 497.592 207.128 497.592 205.505C497.592 203.881 498.711 201.907 500.092 201.096C501.473 200.284 502.593 200.942 502.593 202.565Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M419.252 18.0155C413.049 13.9115 404.244 14.2478 394.479 19.987C375.7 31.024 360.472 57.8684 360.472 79.9483C360.472 90.5466 363.979 98.1191 369.704 101.908L365.703 99.5565C359.978 95.7677 356.471 88.1952 356.471 77.5968C356.471 55.517 371.699 28.6726 390.478 17.6356C400.243 11.8964 409.048 11.5601 415.251 15.6641L419.252 18.0155Z\" fill=\"url(#paint19_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path opacity=\"0.4\" d=\"M394.478 99.9353C413.262 88.8954 428.486 62.054 428.486 39.9741C428.486 17.8943 413.257 8.95006 394.478 19.987C375.699 31.024 360.471 57.8684 360.471 79.9483C360.471 102.028 375.694 110.975 394.478 99.9353Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M428.486 39.9742C428.486 62.0541 413.262 88.8956 394.478 99.9355C375.694 110.975 360.471 102.028 360.471 79.9484C360.471 57.8686 375.699 31.0242 394.478 19.9872C413.257 8.95019 428.486 17.8944 428.486 39.9742ZM426.718 41.4439C426.718 62.2246 412.39 87.4876 394.711 97.878C377.032 108.268 362.704 99.8473 362.704 79.0666C362.704 58.2859 377.032 33.0229 394.711 22.6325C412.39 12.2422 426.718 20.6632 426.718 41.4439Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M418.028 20.7766C412.19 16.9136 403.903 17.23 394.71 22.633C377.031 33.0233 362.703 58.2864 362.703 79.067C362.703 89.0418 366.005 96.1688 371.393 99.7347L370.393 99.1469C365.004 95.581 361.703 88.4539 361.703 78.4792C361.703 57.6985 376.031 32.4354 393.71 22.0451C402.903 16.6421 411.19 16.3257 417.028 20.1888L418.028 20.7766Z\" fill=\"url(#paint20_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M418.028 20.7771C412.19 16.9141 403.903 17.2305 394.71 22.6334C377.031 33.0238 362.703 58.2869 362.703 79.0675C362.703 89.0423 366.005 96.1693 371.393 99.7352L370.393 99.1474C365.004 95.5815 361.703 88.4544 361.703 78.4797C361.703 57.699 376.031 32.4359 393.71 22.0456C402.903 16.6426 411.19 16.3262 417.028 20.1893L418.028 20.7771Z\" fill=\"url(#paint21_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M369.669 75.5532C370.221 75.2139 370.661 74.4197 370.651 73.7792C370.641 73.1388 370.185 72.8946 369.633 73.2339C369.081 73.5731 368.641 74.3673 368.651 75.0078C368.661 75.6483 369.117 75.8924 369.669 75.5532Z\" fill=\"#8B96A0\"/>\n        <path d=\"M371.83 64.3632C371.991 63.6508 371.694 63.1741 371.165 63.2986C370.637 63.4231 370.078 64.1016 369.917 64.814C369.756 65.5265 370.053 66.0031 370.582 65.8786C371.11 65.7541 371.669 65.0757 371.83 64.3632Z\" fill=\"#8B96A0\"/>\n        <path d=\"M375.244 54.4959C375.56 53.7743 375.45 53.1062 374.997 53.0036C374.545 52.9011 373.921 53.4029 373.604 54.1245C373.288 54.8462 373.398 55.5143 373.851 55.6169C374.304 55.7194 374.927 55.2176 375.244 54.4959Z\" fill=\"#8B96A0\"/>\n        <path d=\"M380.564 45.1337C381.005 44.4805 381.093 43.6918 380.76 43.3719C380.427 43.0521 379.8 43.3223 379.359 43.9755C378.918 44.6287 378.83 45.4175 379.163 45.7373C379.496 46.0572 380.123 45.7869 380.564 45.1337Z\" fill=\"#8B96A0\"/>\n        <path d=\"M387.256 37.1966C387.778 36.6751 388.056 35.8429 387.875 35.3378C387.695 34.8326 387.126 34.8458 386.604 35.3673C386.082 35.8888 385.804 36.721 385.985 37.2262C386.165 37.7313 386.734 37.7181 387.256 37.1966Z\" fill=\"#8B96A0\"/>\n        <path d=\"M394.677 31.4633C395.229 31.1241 395.669 30.3298 395.659 29.6894C395.649 29.0489 395.193 28.8047 394.641 29.144C394.088 29.4833 393.649 30.2775 393.659 30.918C393.669 31.5584 394.125 31.8026 394.677 31.4633Z\" fill=\"#8B96A0\"/>\n        <path d=\"M403.342 26.9755C403.503 26.2631 403.205 25.7865 402.677 25.9109C402.149 26.0354 401.59 26.7139 401.428 27.4263C401.267 28.1388 401.565 28.6154 402.093 28.4909C402.622 28.3664 403.181 27.688 403.342 26.9755Z\" fill=\"#8B96A0\"/>\n        <path d=\"M410.174 27.4618C410.49 26.7401 410.38 26.072 409.927 25.9695C409.474 25.8669 408.851 26.3687 408.534 27.0904C408.218 27.812 408.328 28.4801 408.781 28.5827C409.233 28.6852 409.857 28.1834 410.174 27.4618Z\" fill=\"#8B96A0\"/>\n        <path d=\"M415.492 31.1064C415.933 30.4532 416.02 29.6644 415.688 29.3446C415.355 29.0247 414.728 29.295 414.287 29.9482C413.846 30.6013 413.758 31.3901 414.091 31.71C414.424 32.0298 415.051 31.7596 415.492 31.1064Z\" fill=\"#8B96A0\"/>\n        <path d=\"M418.76 37.5516C419.282 37.0301 419.56 36.1979 419.379 35.6927C419.199 35.1876 418.63 35.2008 418.108 35.7223C417.585 36.2438 417.308 37.076 417.488 37.5812C417.669 38.0863 418.238 38.0731 418.76 37.5516Z\" fill=\"#8B96A0\"/>\n        <path d=\"M419.677 46.1591C420.229 45.8199 420.669 45.0256 420.659 44.3852C420.649 43.7447 420.193 43.5005 419.641 43.8398C419.088 44.1791 418.649 44.9733 418.659 45.6138C418.669 46.2542 419.125 46.4984 419.677 46.1591Z\" fill=\"#8B96A0\"/>\n        <path d=\"M411.66 62.8484L409.994 63.8384V69.5118L411.66 68.5218V62.8484Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path d=\"M406.126 71.8665C407.507 71.0184 408.606 69.0328 408.581 67.4317C408.556 65.8305 407.416 65.2201 406.035 66.0683C404.655 66.9164 403.555 68.902 403.581 70.5031C403.606 72.1043 404.745 72.7147 406.126 71.8665Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path d=\"M399.577 75.715C400.957 74.8965 402.077 72.9213 402.077 71.306C402.077 69.6908 400.957 69.0441 399.577 69.8625C398.196 70.681 397.076 72.6562 397.076 74.2714C397.076 75.8867 398.196 76.5334 399.577 75.715Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path d=\"M393.264 79.4244C394.645 78.606 395.765 76.6308 395.765 75.0155C395.765 73.4002 394.645 72.7535 393.264 73.572C391.884 74.3904 390.764 76.3656 390.764 77.9809C390.764 79.5962 391.884 80.2429 393.264 79.4244Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path d=\"M386.854 83.1925C388.234 82.374 389.355 80.3988 389.355 78.7836C389.355 77.1683 388.234 76.5216 386.854 77.3401C385.474 78.1585 384.354 80.1337 384.354 81.749C384.354 83.3642 385.474 84.0109 386.854 83.1925Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path d=\"M414.816 60.9935L413.15 61.9834V67.6568L414.816 66.6669V60.9935Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path d=\"M383.058 79.7049L381.393 80.6948V86.3682L383.058 85.3783V79.7049Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path d=\"M377.487 88.7511C378.867 87.9326 379.987 85.9574 379.987 84.3422C379.987 82.7269 378.867 82.0802 377.487 82.8987C376.107 83.7171 374.986 85.6923 374.986 87.3076C374.986 88.9228 376.107 89.5695 377.487 88.7511Z\" fill=\"var(--c8y-brand-30)\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M407.446 35.7055L399.008 50.5826L398.008 49.9948L406.445 35.1177L407.446 35.7055Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M407.447 35.7065L399.01 50.5836L400.75 51.6061L409.187 36.7291L407.447 35.7065Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M399.452 53.1471C398.357 52.4228 396.803 52.482 395.08 53.4949C391.765 55.4429 389.079 60.1804 389.079 64.0763C389.079 65.9464 389.698 67.2827 390.708 67.9513L388.708 66.7756C387.697 66.1069 387.078 64.7707 387.078 62.9006C387.078 59.0047 389.765 54.2672 393.079 52.3192C394.803 51.3063 396.357 51.2471 397.451 51.9714L399.452 53.1471Z\" fill=\"url(#paint22_linear_641_19870)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M395.079 67.6034C398.394 65.6554 401.081 60.9179 401.081 57.022C401.081 53.126 398.394 51.5469 395.079 53.4948C391.765 55.4428 389.078 60.1803 389.078 64.0762C389.078 67.9722 391.765 69.5513 395.079 67.6034Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M406.527 116.983V133.443L398.525 128.74V112.28L406.527 116.983Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M417.529 101.111V126.976L409.527 122.273V96.4077L417.529 101.111Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M428.531 98.1716V120.51L420.529 115.807V93.4688L428.531 98.1716Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M439.535 74.0691V114.043L431.533 109.34V69.3662L439.535 74.0691Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M450.537 51.1428V107.577L442.535 102.874V46.4399L450.537 51.1428Z\" fill=\"#D4D9DE\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M414.529 112.28L406.527 116.983L398.525 112.28L406.527 107.577L414.529 112.28Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M436.533 94.6442L428.531 99.3471L420.529 94.6442L428.531 89.9414L436.533 94.6442Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M447.537 69.3664L439.535 74.0693L431.533 69.3664L439.535 64.6636L447.537 69.3664Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M425.531 96.4079L417.529 101.111L409.527 96.4079L417.529 91.7051L425.531 96.4079Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M458.539 46.4401L450.537 51.143L442.535 46.4401L450.537 41.7373L458.539 46.4401Z\" fill=\"#E3E5E8\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path d=\"M406.527 116.983V133.443L414.529 128.74V112.28L406.527 116.983Z\" fill=\"#8B96A0\"/>\n        <path d=\"M417.53 101.11V126.976L425.532 122.273V96.4076L417.53 101.11Z\" fill=\"#8B96A0\"/>\n        <path d=\"M428.532 99.3469V120.51L436.534 115.807V94.6441L428.532 99.3469Z\" fill=\"#8B96A0\"/>\n        <path d=\"M439.535 74.0691V114.043L447.536 109.34V69.3663L439.535 74.0691Z\" fill=\"#8B96A0\"/>\n        <path d=\"M450.537 51.1428V107.577L458.539 102.874V46.4399L450.537 51.1428Z\" fill=\"#8B96A0\"/>\n        <path d=\"M406.527 116.983V133.443L414.529 128.74V112.28L406.527 116.983Z\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path d=\"M417.53 101.11V126.976L425.532 122.273V96.4076L417.53 101.11Z\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path d=\"M428.532 99.3469V120.51L436.534 115.807V94.6441L428.532 99.3469Z\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path d=\"M439.535 74.0691V114.043L447.536 109.34V69.3663L439.535 74.0691Z\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path d=\"M450.537 51.1428V107.577L458.539 102.874V46.4399L450.537 51.1428Z\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path d=\"M417.5 101.111V126.976L425.502 122.274V96.408L417.5 101.111Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path d=\"M439.443 74.0693V114.043L447.445 109.341V69.3665L439.443 74.0693Z\" fill=\"#8B96A0\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-miterlimit=\"10\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M83.9683 346.379C83.8423 348.79 85.3436 351.225 88.4725 353.064C94.4897 356.6 104.255 356.599 110.274 353.061C113.164 351.363 114.667 349.158 114.783 346.932V348.779C114.667 351.004 113.164 353.209 110.274 354.907C104.255 358.445 94.4897 358.446 88.4725 354.91C85.3436 353.071 83.8423 350.636 83.9683 348.226V346.379Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M142.713 329.962C142.838 332.373 141.335 334.808 138.205 336.647C132.185 340.185 122.42 340.186 116.403 336.65C113.515 334.953 112.013 332.748 111.898 330.522V332.368C112.013 334.594 113.515 336.799 116.403 338.496C122.42 342.032 132.185 342.032 138.205 338.494C141.335 336.654 142.838 334.219 142.713 331.809V329.962Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M139.398 313.803C139.272 316.214 140.773 318.648 143.902 320.487C149.92 324.024 159.684 324.023 165.704 320.485C168.593 318.787 170.096 316.582 170.212 314.356V316.203C170.096 318.428 168.593 320.633 165.704 322.331C159.684 325.869 149.92 325.87 143.902 322.334C140.773 320.495 139.272 318.06 139.398 315.649V313.803Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M198.577 296.965C198.776 299.374 197.348 301.824 194.274 303.697C188.363 307.3 178.603 307.405 172.476 303.932C169.535 302.266 167.965 300.077 167.781 297.854V299.7C167.965 301.924 169.535 304.112 172.476 305.779C178.603 309.251 188.363 309.146 194.274 305.544C197.348 303.67 198.776 301.22 198.577 298.812V296.965Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M217.993 289.324L210.734 293.59V295.436L217.993 291.17V289.324Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M210.734 293.59L189.674 281.213V283.059L210.734 295.436V293.59Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M231.741 281.241L224.482 285.507V287.353L231.741 283.087V281.241Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M224.486 285.507L203.426 273.13V274.976L224.486 287.353V285.507Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M65.2246 354.56L86.2847 366.937V368.783L65.2246 356.406V354.56Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M86.2852 366.937L93.5439 362.671V364.517L86.2852 368.783V366.937Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M74.1381 370.472C74.2625 372.883 72.7595 375.317 69.6294 377.157C63.6099 380.695 53.8449 380.696 47.8277 377.159C44.9394 375.462 43.4414 373.259 43.3301 371.036V372.882C43.4414 375.105 44.9394 377.308 47.8277 379.006C53.8449 382.542 63.6099 382.541 69.6294 379.003C72.7595 377.164 74.2625 374.729 74.1381 372.318V370.472Z\" fill=\"var(--c8y-brand-30)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M165.71 320.489C171.729 316.951 171.731 311.212 165.714 307.676C159.697 304.139 149.932 304.14 143.912 307.678C137.893 311.216 137.891 316.955 143.908 320.492C149.925 324.028 159.69 324.027 165.71 320.489ZM193.886 290.89C200.014 294.363 200.189 300.098 194.278 303.701C188.366 307.304 178.607 307.409 172.48 303.936C166.352 300.463 166.177 294.727 172.088 291.125C177.999 287.522 187.759 287.417 193.886 290.89ZM189.677 281.213L196.935 276.947L217.996 289.325L210.737 293.591L189.677 281.213ZM138.214 323.838C144.231 327.375 144.229 333.114 138.21 336.652C132.19 340.189 122.425 340.191 116.408 336.654C110.391 333.118 110.393 327.378 116.412 323.841C122.432 320.303 132.197 320.302 138.214 323.838ZM110.281 353.068C116.301 349.53 116.303 343.791 110.285 340.255C104.268 336.718 94.5031 336.719 88.4836 340.257C82.4642 343.795 82.4623 349.534 88.4795 353.071C94.4966 356.607 104.262 356.606 110.281 353.068ZM203.43 273.134L210.689 268.867L231.749 281.245L224.49 285.511L203.43 273.134ZM72.4891 350.298L65.2303 354.564L86.2904 366.942L93.5492 362.676L72.4891 350.298ZM69.6362 364.35C75.6534 367.886 75.6515 373.625 69.6321 377.163C63.6126 380.701 53.8475 380.702 47.8304 377.166C41.8132 373.629 41.8298 367.899 47.8493 364.361C53.8687 360.823 63.619 360.813 69.6362 364.35Z\" fill=\"var(--c8y-brand-60)\"/>\n        <path d=\"M194.278 303.701L194.607 303.888L194.607 303.888L194.278 303.701ZM193.886 290.89L194.204 290.696L193.886 290.89ZM172.48 303.936L172.797 303.743L172.48 303.936ZM172.088 291.125L171.759 290.938L172.088 291.125ZM196.935 276.947L197.259 276.757C197.173 276.707 197.057 276.678 196.935 276.678C196.814 276.678 196.698 276.707 196.612 276.757L196.935 276.947ZM189.677 281.213L189.353 281.023C189.175 281.128 189.175 281.298 189.353 281.403L189.677 281.213ZM217.996 289.325L218.319 289.515C218.405 289.464 218.453 289.396 218.453 289.325C218.453 289.253 218.405 289.185 218.319 289.135L217.996 289.325ZM210.737 293.591L210.413 293.781C210.592 293.886 210.881 293.886 211.06 293.781L210.737 293.591ZM116.412 323.841L116.089 323.651L116.412 323.841ZM88.4836 340.257L88.1603 340.067L88.4836 340.257ZM210.689 268.867L211.012 268.677C210.926 268.627 210.81 268.599 210.689 268.599C210.568 268.599 210.451 268.627 210.366 268.677L210.689 268.867ZM203.43 273.134L203.107 272.944C202.928 273.048 202.928 273.219 203.107 273.324L203.43 273.134ZM231.749 281.245L232.072 281.435C232.251 281.33 232.251 281.16 232.072 281.055L231.749 281.245ZM224.49 285.511L224.167 285.701C224.253 285.752 224.369 285.78 224.49 285.78C224.611 285.78 224.728 285.752 224.813 285.701L224.49 285.511ZM65.2303 354.564L64.907 354.374C64.7284 354.479 64.7284 354.649 64.907 354.754L65.2303 354.564ZM72.4891 350.298L72.8124 350.108C72.7266 350.058 72.6103 350.029 72.4891 350.029C72.3678 350.029 72.2515 350.058 72.1658 350.108L72.4891 350.298ZM86.2904 366.942L85.9671 367.132C86.1457 367.237 86.4352 367.237 86.6137 367.132L86.2904 366.942ZM93.5492 362.676L93.8725 362.866C93.9583 362.815 94.0064 362.747 94.0064 362.676C94.0064 362.604 93.9583 362.536 93.8725 362.486L93.5492 362.676ZM69.6321 377.163L69.3088 376.973L69.3088 376.973L69.6321 377.163ZM47.8493 364.361L48.1726 364.551L47.8493 364.361ZM165.391 307.866C171.229 311.297 171.228 316.866 165.387 320.299L166.033 320.679C172.231 317.036 172.233 311.127 166.037 307.486L165.391 307.866ZM144.236 307.868C150.077 304.435 159.552 304.434 165.391 307.866L166.037 307.486C159.841 303.844 149.787 303.845 143.589 307.488L144.236 307.868ZM144.231 320.301C138.393 316.87 138.395 311.301 144.236 307.868L143.589 307.488C137.391 311.131 137.389 317.04 143.585 320.682L144.231 320.301ZM165.387 320.299C159.546 323.732 150.07 323.733 144.231 320.301L143.585 320.682C149.781 324.323 159.835 324.322 166.033 320.679L165.387 320.299ZM194.607 303.888C200.693 300.178 200.513 294.272 194.204 290.696L193.569 291.083C199.514 294.453 199.685 300.019 193.949 303.514L194.607 303.888ZM172.162 304.129C178.472 307.705 188.52 307.597 194.607 303.888L193.949 303.514C188.213 307.01 178.743 307.112 172.797 303.743L172.162 304.129ZM171.759 290.938C165.672 294.648 165.853 300.554 172.162 304.129L172.797 303.743C166.851 300.373 166.681 294.807 172.417 291.311L171.759 290.938ZM194.204 290.696C187.894 287.12 177.845 287.229 171.759 290.938L172.417 291.311C178.153 287.815 187.623 287.713 193.569 291.083L194.204 290.696ZM196.612 276.757L189.353 281.023L190 281.403L197.259 277.137L196.612 276.757ZM218.319 289.135L197.259 276.757L196.612 277.137L217.672 289.515L218.319 289.135ZM211.06 293.781L218.319 289.515L217.672 289.135L210.413 293.401L211.06 293.781ZM189.353 281.403L210.413 293.781L211.06 293.401L190 281.023L189.353 281.403ZM138.533 336.842C144.731 333.199 144.733 327.29 138.537 323.648L137.891 324.028C143.729 327.46 143.728 333.029 137.887 336.462L138.533 336.842ZM116.085 336.844C122.281 340.486 132.335 340.484 138.533 336.842L137.887 336.462C132.045 339.895 122.57 339.896 116.731 336.464L116.085 336.844ZM116.089 323.651C109.891 327.293 109.889 333.203 116.085 336.844L116.731 336.464C110.893 333.033 110.895 327.464 116.736 324.031L116.089 323.651ZM138.537 323.648C132.341 320.007 122.287 320.008 116.089 323.651L116.736 324.031C122.577 320.598 132.052 320.597 137.891 324.028L138.537 323.648ZM109.962 340.445C115.801 343.876 115.799 349.445 109.958 352.878L110.604 353.258C116.802 349.616 116.804 343.706 110.609 340.065L109.962 340.445ZM88.8069 340.447C94.648 337.014 104.124 337.013 109.962 340.445L110.609 340.065C104.413 336.423 94.3582 336.425 88.1603 340.067L88.8069 340.447ZM88.8028 352.881C82.9643 349.449 82.9659 343.88 88.8069 340.447L88.1603 340.067C81.9624 343.71 81.9603 349.619 88.1562 353.261L88.8028 352.881ZM109.958 352.878C104.117 356.311 94.6413 356.312 88.8028 352.881L88.1562 353.261C94.352 356.902 104.407 356.901 110.604 353.258L109.958 352.878ZM210.366 268.677L203.107 272.944L203.753 273.324L211.012 269.057L210.366 268.677ZM232.072 281.055L211.012 268.677L210.366 269.057L231.426 281.435L232.072 281.055ZM224.813 285.701L232.072 281.435L231.426 281.055L224.167 285.321L224.813 285.701ZM203.107 273.324L224.167 285.701L224.813 285.321L203.753 272.944L203.107 273.324ZM65.5536 354.754L72.8124 350.488L72.1658 350.108L64.907 354.374L65.5536 354.754ZM86.6137 366.752L65.5536 354.374L64.907 354.754L85.9671 367.132L86.6137 366.752ZM93.2259 362.486L85.9671 366.752L86.6137 367.132L93.8725 362.866L93.2259 362.486ZM72.1658 350.488L93.2259 362.866L93.8725 362.486L72.8124 350.108L72.1658 350.488ZM69.9554 377.353C76.1533 373.71 76.1554 367.801 69.9595 364.16L69.3129 364.54C75.1514 367.971 75.1498 373.54 69.3088 376.973L69.9554 377.353ZM47.5071 377.356C53.7029 380.997 63.7574 380.996 69.9554 377.353L69.3088 376.973C63.4677 380.406 53.9922 380.407 48.1537 376.975L47.5071 377.356ZM47.526 364.171C41.3286 367.813 41.3106 373.714 47.5071 377.356L48.1537 376.975C42.3157 373.544 42.331 367.984 48.1726 364.551L47.526 364.171ZM69.9595 364.16C63.7631 360.518 53.7233 360.528 47.526 364.171L48.1726 364.551C54.0142 361.117 63.475 361.109 69.3129 364.54L69.9595 364.16Z\" fill=\"#212121\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M300.031 135.273L247.792 105.225L195.553 135.273V147.291L247.792 117.244L300.031 147.291V135.273Z\" fill=\"#D4D9DE\" fill-opacity=\"0.4\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M195.553 135.466L247.792 165.514L300.031 135.466V147.485L247.792 177.533L195.553 147.485V135.466Z\" fill=\"var(--c8y-palette-gray-10)\" fill-opacity=\"0.8\" stroke=\"#212121\" stroke-opacity=\"0.8\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M247.26 165.274L299.499 135.227V147.246L247.26 177.293V165.274Z\" fill=\"var(--c8y-palette-gray-10)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M234.869 135.044C234.764 137.022 236.025 139.02 238.65 140.531C243.699 143.435 251.885 143.435 256.934 140.531C259.458 139.079 260.72 137.175 260.72 135.272V147.291C260.72 149.194 259.458 151.098 256.934 152.55C251.885 155.454 243.699 155.454 238.65 152.55C236.025 151.039 234.764 149.041 234.869 147.063V135.044Z\" fill=\"#D4D9DE\" fill-opacity=\"0.4\"/>\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M300.031 135.273L247.792 105.225L195.553 135.273L247.792 165.32L300.031 135.273Z\" fill=\"var(--c8y-palette-gray-10)\" stroke=\"#212121\" stroke-width=\"0.75\" stroke-linejoin=\"round\"/>\n        <path id=\"c8y-mark\" d=\"M266.412 144.258C263.201 146.105 259.329 147.036 254.793 147.051C250.258 147.043 246.39 146.118 243.188 144.276C239.986 142.434 238.388 140.215 238.394 137.618C238.399 134.998 240.008 132.764 243.218 130.917C245.52 129.593 248.159 128.718 251.134 128.291C254.109 127.864 257.02 127.898 259.867 128.394L257.833 132.326C254.037 131.698 250.788 132.162 248.085 133.716C246.268 134.761 245.379 136.036 245.418 137.54C245.478 139.033 246.424 140.306 248.257 141.36C250.09 142.414 252.303 142.958 254.898 142.993C257.513 143.015 259.729 142.504 261.546 141.459C264.249 139.904 265.055 138.035 263.963 135.852L270.8 134.682C271.661 136.319 271.72 137.994 270.978 139.705C270.236 141.416 268.714 142.934 266.412 144.258ZM223.181 136.028C224.342 135.36 224.34 134.277 223.178 133.608C222.015 132.939 220.132 132.939 218.971 133.606C217.81 134.274 217.812 135.357 218.974 136.026C220.137 136.694 222.02 136.695 223.181 136.028ZM223.521 131.069L222.119 131.876L226.19 134.217L227.591 133.411L223.521 131.069ZM230.739 131.68C231.9 131.013 231.898 129.929 230.736 129.261C229.573 128.592 227.69 128.591 226.529 129.259C225.369 129.926 225.37 131.01 226.533 131.678C227.695 132.347 229.579 132.348 230.739 131.68ZM235.919 128.701C237.08 128.033 237.078 126.95 235.916 126.281C234.753 125.613 232.87 125.612 231.71 126.279C230.549 126.947 230.55 128.03 231.713 128.699C232.875 129.367 234.758 129.368 235.919 128.701ZM241.099 125.721C242.26 125.054 242.258 123.97 241.096 123.302C239.933 122.633 238.05 122.632 236.889 123.3C235.729 123.967 235.73 125.051 236.893 125.719C238.055 126.388 239.938 126.389 241.099 125.721ZM246.279 122.742C247.44 122.074 247.438 120.991 246.276 120.322C245.113 119.654 243.23 119.653 242.069 120.32C240.909 120.988 240.91 122.071 242.072 122.74C243.235 123.409 245.118 123.409 246.279 122.742ZM246.619 117.784L245.217 118.59L249.288 120.931L250.689 120.125L246.619 117.784ZM248.997 116.416L247.595 117.222L251.666 119.563L253.068 118.757L248.997 116.416Z\" fill=\"var(--c8y-brand-60)\"/>\n        <defs>\n        <filter id=\"filter0_f_641_19870\" x=\"17.4668\" y=\"135.085\" width=\"164.453\" height=\"101.354\" filterUnits=\"userSpaceOnUse\" color-interpolation-filters=\"sRGB\">\n        <feFlood flood-opacity=\"0\" result=\"BackgroundImageFix\"/>\n        <feBlend mode=\"normal\" in=\"SourceGraphic\" in2=\"BackgroundImageFix\" result=\"shape\"/>\n        <feGaussianBlur stdDeviation=\"3\" result=\"effect1_foregroundBlur_641_19870\"/>\n        </filter>\n        <filter id=\"filter1_f_641_19870\" x=\"332.77\" y=\"136.261\" width=\"164.453\" height=\"101.354\" filterUnits=\"userSpaceOnUse\" color-interpolation-filters=\"sRGB\">\n        <feFlood flood-opacity=\"0\" result=\"BackgroundImageFix\"/>\n        <feBlend mode=\"normal\" in=\"SourceGraphic\" in2=\"BackgroundImageFix\" result=\"shape\"/>\n        <feGaussianBlur stdDeviation=\"3\" result=\"effect1_foregroundBlur_641_19870\"/>\n        </filter>\n        <filter id=\"filter2_f_641_19870\" x=\"123.143\" y=\"199.75\" width=\"119.09\" height=\"74.9868\" filterUnits=\"userSpaceOnUse\" color-interpolation-filters=\"sRGB\">\n        <feFlood flood-opacity=\"0\" result=\"BackgroundImageFix\"/>\n        <feBlend mode=\"normal\" in=\"SourceGraphic\" in2=\"BackgroundImageFix\" result=\"shape\"/>\n        <feGaussianBlur stdDeviation=\"3\" result=\"effect1_foregroundBlur_641_19870\"/>\n        </filter>\n        <filter id=\"filter3_f_641_19870\" x=\"269.168\" y=\"200.133\" width=\"120.359\" height=\"75.7793\" filterUnits=\"userSpaceOnUse\" color-interpolation-filters=\"sRGB\">\n        <feFlood flood-opacity=\"0\" result=\"BackgroundImageFix\"/>\n        <feBlend mode=\"normal\" in=\"SourceGraphic\" in2=\"BackgroundImageFix\" result=\"shape\"/>\n        <feGaussianBlur stdDeviation=\"3\" result=\"effect1_foregroundBlur_641_19870\"/>\n        </filter>\n        <filter id=\"filter4_f_641_19870\" x=\"271.557\" y=\"289.989\" width=\"109.887\" height=\"69.3096\" filterUnits=\"userSpaceOnUse\" color-interpolation-filters=\"sRGB\">\n        <feFlood flood-opacity=\"0\" result=\"BackgroundImageFix\"/>\n        <feBlend mode=\"normal\" in=\"SourceGraphic\" in2=\"BackgroundImageFix\" result=\"shape\"/>\n        <feGaussianBlur stdDeviation=\"3\" result=\"effect1_foregroundBlur_641_19870\"/>\n        </filter>\n        <filter id=\"filter5_f_641_19870\" x=\"325.838\" y=\"317.321\" width=\"164.453\" height=\"101.354\" filterUnits=\"userSpaceOnUse\" color-interpolation-filters=\"sRGB\">\n        <feFlood flood-opacity=\"0\" result=\"BackgroundImageFix\"/>\n        <feBlend mode=\"normal\" in=\"SourceGraphic\" in2=\"BackgroundImageFix\" result=\"shape\"/>\n        <feGaussianBlur stdDeviation=\"3\" result=\"effect1_foregroundBlur_641_19870\"/>\n        </filter>\n        <filter id=\"filter6_f_641_19870\" x=\"43.0938\" y=\"345.167\" width=\"200.42\" height=\"124.792\" filterUnits=\"userSpaceOnUse\" color-interpolation-filters=\"sRGB\">\n        <feFlood flood-opacity=\"0\" result=\"BackgroundImageFix\"/>\n        <feBlend mode=\"normal\" in=\"SourceGraphic\" in2=\"BackgroundImageFix\" result=\"shape\"/>\n        <feGaussianBlur stdDeviation=\"3\" result=\"effect1_foregroundBlur_641_19870\"/>\n        </filter>\n        <filter id=\"filter7_f_641_19870\" x=\"194.176\" y=\"304.388\" width=\"116.479\" height=\"72.0947\" filterUnits=\"userSpaceOnUse\" color-interpolation-filters=\"sRGB\">\n        <feFlood flood-opacity=\"0\" result=\"BackgroundImageFix\"/>\n        <feBlend mode=\"normal\" in=\"SourceGraphic\" in2=\"BackgroundImageFix\" result=\"shape\"/>\n        <feGaussianBlur stdDeviation=\"3\" result=\"effect1_foregroundBlur_641_19870\"/>\n        </filter>\n        <linearGradient id=\"paint0_linear_641_19870\" x1=\"67.6453\" y1=\"74.6233\" x2=\"70.9751\" y2=\"78.8959\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"1\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint1_linear_641_19870\" x1=\"65.7555\" y1=\"72.9387\" x2=\"78.4635\" y2=\"82.716\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"1\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint2_linear_641_19870\" x1=\"107.491\" y1=\"56.3991\" x2=\"110.821\" y2=\"60.6718\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"1\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint3_linear_641_19870\" x1=\"105.601\" y1=\"54.7146\" x2=\"118.309\" y2=\"64.4919\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"1\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint4_linear_641_19870\" x1=\"98.7193\" y1=\"71.7487\" x2=\"96.6163\" y2=\"82.8728\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"var(--c8y-brand-60)\"/>\n        <stop offset=\"1\" stop-color=\"var(--c8y-brand-30)\"/>\n        </linearGradient>\n        <linearGradient id=\"paint5_linear_641_19870\" x1=\"99.4365\" y1=\"58.6103\" x2=\"86.7853\" y2=\"98.7343\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"var(--c8y-brand-60)\"/>\n        <stop offset=\"1\" stop-color=\"var(--c8y-brand-30)\"/>\n        </linearGradient>\n        <linearGradient id=\"paint6_linear_641_19870\" x1=\"380.058\" y1=\"215.743\" x2=\"376.493\" y2=\"222.746\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"0.597975\" stop-color=\"#8B96A0\"/>\n        <stop offset=\"0.985\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint7_linear_641_19870\" x1=\"410.322\" y1=\"278.681\" x2=\"380.111\" y2=\"278.681\" gradientUnits=\"userSpaceOnUse\">\n        <stop offset=\"0.015\" stop-color=\"#8B96A0\"/>\n        <stop offset=\"0.402025\" stop-color=\"#8B96A0\"/>\n        <stop offset=\"1\" stop-color=\"#D4D9DE\"/>\n        </linearGradient>\n        <linearGradient id=\"paint8_linear_641_19870\" x1=\"389.36\" y1=\"266.198\" x2=\"390.187\" y2=\"278.3\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"var(--c8y-brand-60)\"/>\n        <stop offset=\"1\" stop-color=\"var(--c8y-brand-30)\"/>\n        </linearGradient>\n        <linearGradient id=\"paint9_linear_641_19870\" x1=\"386.123\" y1=\"247.193\" x2=\"379.278\" y2=\"263.272\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"0.765\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint10_linear_641_19870\" x1=\"403.921\" y1=\"257.348\" x2=\"405.405\" y2=\"265.538\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"var(--c8y-brand-60)\"/>\n        <stop offset=\"1\" stop-color=\"var(--c8y-brand-30)\"/>\n        </linearGradient>\n        <linearGradient id=\"paint11_linear_641_19870\" x1=\"414.876\" y1=\"208.485\" x2=\"409.391\" y2=\"221.49\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"0.765\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint12_linear_641_19870\" x1=\"428.755\" y1=\"215.61\" x2=\"430.239\" y2=\"223.8\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"var(--c8y-brand-60)\"/>\n        <stop offset=\"1\" stop-color=\"var(--c8y-brand-30)\"/>\n        </linearGradient>\n        <linearGradient id=\"paint13_linear_641_19870\" x1=\"385.154\" y1=\"189.512\" x2=\"379.668\" y2=\"202.516\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"0.765\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint14_linear_641_19870\" x1=\"398.724\" y1=\"196.799\" x2=\"400.208\" y2=\"204.988\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"var(--c8y-brand-60)\"/>\n        <stop offset=\"1\" stop-color=\"var(--c8y-brand-30)\"/>\n        </linearGradient>\n        <linearGradient id=\"paint15_linear_641_19870\" x1=\"399.671\" y1=\"297.979\" x2=\"407.661\" y2=\"304.981\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"1\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint16_linear_641_19870\" x1=\"415.366\" y1=\"271.444\" x2=\"427.36\" y2=\"277.536\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"1\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint17_linear_641_19870\" x1=\"438.232\" y1=\"263.963\" x2=\"451.763\" y2=\"275.511\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"1\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint18_linear_641_19870\" x1=\"485.601\" y1=\"209.225\" x2=\"500.039\" y2=\"226.157\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"1\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        <linearGradient id=\"paint19_linear_641_19870\" x1=\"404.649\" y1=\"-2.93926\" x2=\"384.076\" y2=\"95.1763\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"var(--c8y-brand-60)\"/>\n        <stop offset=\"1\" stop-color=\"var(--c8y-brand-30)\"/>\n        </linearGradient>\n        <linearGradient id=\"paint20_linear_641_19870\" x1=\"361.626\" y1=\"99.9359\" x2=\"397.901\" y2=\"22.2408\" gradientUnits=\"userSpaceOnUse\">\n        <stop offset=\"0.015\" stop-color=\"#8B96A0\"/>\n        <stop offset=\"1\" stop-color=\"#D4D9DE\"/>\n        </linearGradient>\n        <linearGradient id=\"paint21_linear_641_19870\" x1=\"361.626\" y1=\"99.9364\" x2=\"397.901\" y2=\"22.2413\" gradientUnits=\"userSpaceOnUse\">\n        <stop offset=\"0.015\" stop-color=\"#8B96A0\"/>\n        <stop offset=\"1\" stop-color=\"#D4D9DE\"/>\n        </linearGradient>\n        <linearGradient id=\"paint22_linear_641_19870\" x1=\"393.393\" y1=\"55.2134\" x2=\"398.919\" y2=\"62.0251\" gradientUnits=\"userSpaceOnUse\">\n        <stop stop-color=\"#E3E5E8\"/>\n        <stop offset=\"1\" stop-color=\"#8B96A0\"/>\n        </linearGradient>\n        </defs>\n      </svg>\n\n    </div>\n  </div>\n</div>\n" }]
        }], ctorParameters: () => [{ type: i1.TenantService }, { type: i2.DocsService }, { type: i3.Router }, { type: i2.NavigatorService }, { type: i1.ApplicationService }], propDecorators: { config: [{
                type: Input
            }] } });

/**
 * @deprecated
 */
class CockpitWelcomeWidgetModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CockpitWelcomeWidgetModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: CockpitWelcomeWidgetModule, imports: [WelcomeToCockpitComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CockpitWelcomeWidgetModule, imports: [WelcomeToCockpitComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CockpitWelcomeWidgetModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [WelcomeToCockpitComponent]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { CockpitWelcomeWidgetModule, WelcomeToCockpitComponent };
//# sourceMappingURL=c8y-ngx-components-widgets-implementations-cockpit-welcome.mjs.map
